/* Automatically @generated by tree-sitter v0.25.6 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 2920
#define LARGE_STATE_COUNT 630
#define SYMBOL_COUNT 478
#define ALIAS_COUNT 0
#define TOKEN_COUNT 276
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 22
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 1
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  sym_comment = 1,
  sym_semi_colon = 2,
  sym_keyword_info = 3,
  sym_keyword_show = 4,
  sym_keyword_changes = 5,
  sym_keyword_since = 6,
  sym_keyword_if = 7,
  sym_keyword_throw = 8,
  sym_keyword_exists = 9,
  sym_keyword_tokenizers = 10,
  sym_keyword_overwrite = 11,
  sym_keyword_on = 12,
  sym_keyword_let = 13,
  sym_keyword_return = 14,
  sym_keyword_else = 15,
  sym_keyword_select = 16,
  sym_keyword_from = 17,
  sym_keyword_only = 18,
  sym_keyword_value = 19,
  sym_keyword_as = 20,
  sym_keyword_omit = 21,
  sym_keyword_explain = 22,
  sym_keyword_full = 23,
  sym_keyword_parallel = 24,
  sym_keyword_timeout = 25,
  sym_keyword_fetch = 26,
  sym_keyword_limit = 27,
  sym_keyword_by = 28,
  sym_keyword_rand = 29,
  sym_keyword_collate = 30,
  sym_keyword_numeric = 31,
  sym_keyword_asc = 32,
  sym_keyword_desc = 33,
  sym_keyword_order = 34,
  sym_keyword_with = 35,
  sym_keyword_index = 36,
  sym_keyword_no_index = 37,
  sym_keyword_where = 38,
  sym_keyword_split = 39,
  sym_keyword_at = 40,
  sym_keyword_group = 41,
  sym_keyword_true = 42,
  sym_keyword_false = 43,
  sym_keyword_begin = 44,
  sym_keyword_cancel = 45,
  sym_keyword_commit = 46,
  sym_keyword_transaction = 47,
  sym_keyword_none = 48,
  sym_keyword_null = 49,
  sym_keyword_and = 50,
  sym_keyword_or = 51,
  sym_keyword_is = 52,
  sym_keyword_not = 53,
  sym_keyword_contains = 54,
  sym_keyword_contains_not = 55,
  sym_keyword_contains_all = 56,
  sym_keyword_contains_any = 57,
  sym_keyword_contains_none = 58,
  sym_keyword_inside = 59,
  sym_keyword_in = 60,
  sym_keyword_not_inside = 61,
  sym_keyword_all_inside = 62,
  sym_keyword_any_inside = 63,
  sym_keyword_none_inside = 64,
  sym_keyword_outside = 65,
  sym_keyword_intersects = 66,
  sym_keyword_chebyshev = 67,
  sym_keyword_cosine = 68,
  sym_keyword_euclidean = 69,
  sym_keyword_hamming = 70,
  sym_keyword_jaccard = 71,
  sym_keyword_manhattan = 72,
  sym_keyword_minkowski = 73,
  sym_keyword_pearson = 74,
  sym_keyword_define = 75,
  sym_keyword_analyzer = 76,
  sym_keyword_event = 77,
  sym_keyword_field = 78,
  sym_keyword_function = 79,
  sym_keyword_namespace = 80,
  sym_keyword_param = 81,
  sym_keyword_scope = 82,
  sym_keyword_drop = 83,
  sym_keyword_schemafull = 84,
  sym_keyword_schemaless = 85,
  sym_keyword_live = 86,
  sym_keyword_diff = 87,
  sym_keyword_flexible = 88,
  sym_keyword_readonly = 89,
  sym_keyword_jwks = 90,
  sym_keyword_eddsa = 91,
  sym_keyword_es256 = 92,
  sym_keyword_es384 = 93,
  sym_keyword_es512 = 94,
  sym_keyword_ps256 = 95,
  sym_keyword_ps384 = 96,
  sym_keyword_ps512 = 97,
  sym_keyword_rs256 = 98,
  sym_keyword_rs384 = 99,
  sym_keyword_rs512 = 100,
  sym_keyword_hs256 = 101,
  sym_keyword_hs384 = 102,
  sym_keyword_hs512 = 103,
  sym_keyword_bm25 = 104,
  sym_keyword_doc_ids_cache = 105,
  sym_keyword_doc_ids_order = 106,
  sym_keyword_doc_lengths_cache = 107,
  sym_keyword_doc_lengths_order = 108,
  sym_keyword_postings_cache = 109,
  sym_keyword_postings_order = 110,
  sym_keyword_terms_cache = 111,
  sym_keyword_terms_order = 112,
  sym_keyword_highlights = 113,
  sym_keyword_any = 114,
  sym_keyword_normal = 115,
  sym_keyword_relation = 116,
  sym_keyword_out = 117,
  sym_keyword_to = 118,
  sym_keyword_changefeed = 119,
  sym_keyword_content = 120,
  sym_keyword_merge = 121,
  sym_keyword_patch = 122,
  sym_keyword_replace = 123,
  sym_keyword_before = 124,
  sym_keyword_after = 125,
  sym_keyword_table = 126,
  sym_keyword_root = 127,
  sym_keyword_token = 128,
  sym_keyword_use = 129,
  sym_keyword_ns = 130,
  sym_keyword_db = 131,
  sym_keyword_user = 132,
  sym_keyword_roles = 133,
  sym_keyword_remove = 134,
  sym_keyword_create = 135,
  sym_keyword_delete = 136,
  sym_keyword_update = 137,
  sym_keyword_upsert = 138,
  sym_keyword_insert = 139,
  sym_keyword_into = 140,
  sym_keyword_filters = 141,
  sym_keyword_when = 142,
  sym_keyword_then = 143,
  sym_keyword_type = 144,
  sym_keyword_default = 145,
  sym_keyword_assert = 146,
  sym_keyword_permissions = 147,
  sym_keyword_relate = 148,
  sym_keyword_ignore = 149,
  sym_keyword_values = 150,
  sym_keyword_for = 151,
  sym_keyword_comment = 152,
  sym_keyword_fields = 153,
  sym_keyword_columns = 154,
  sym_keyword_unique = 155,
  sym_keyword_search = 156,
  sym_keyword_session = 157,
  sym_keyword_signin = 158,
  sym_keyword_signup = 159,
  sym_keyword_database = 160,
  sym_keyword_password = 161,
  sym_keyword_password_hash = 162,
  sym_keyword_on_duplicate_key_update = 163,
  sym_keyword_count = 164,
  sym_keyword_unset = 165,
  sym_keyword_set = 166,
  sym_keyword_always = 167,
  sym_keyword_alter = 168,
  sym_keyword_break = 169,
  sym_keyword_continue = 170,
  sym_keyword_sleep = 171,
  sym_keyword_kill = 172,
  sym_keyword_rebuild = 173,
  sym_keyword_mtree = 174,
  sym_keyword_dimension = 175,
  sym_keyword_dist = 176,
  sym_keyword_efc = 177,
  sym_keyword_m = 178,
  sym_keyword_capacity = 179,
  sym_keyword_hnsw = 180,
  sym_keyword_owner = 181,
  sym_keyword_editor = 182,
  sym_keyword_viewer = 183,
  sym_keyword_duration = 184,
  sym_keyword_enforced = 185,
  sym_keyword_algorithm = 186,
  sym_keyword_key = 187,
  sym_keyword_url = 188,
  sym_keyword_jwt = 189,
  sym_keyword_issuer = 190,
  sym_keyword_refresh = 191,
  sym_keyword_record = 192,
  sym_keyword_bearer = 193,
  sym_keyword_authenticate = 194,
  sym_keyword_grant = 195,
  sym_keyword_access = 196,
  anon_sym_EQ = 197,
  anon_sym_COMMA = 198,
  anon_sym_LPAREN = 199,
  anon_sym_RPAREN = 200,
  anon_sym_DASH_GT = 201,
  anon_sym_LBRACK = 202,
  anon_sym_RBRACK = 203,
  anon_sym_QMARK = 204,
  anon_sym_COLON = 205,
  anon_sym_LBRACE = 206,
  anon_sym_RBRACE = 207,
  anon_sym_PIPE = 208,
  anon_sym_COLON_COLON = 209,
  anon_sym_LT = 210,
  anon_sym_GT = 211,
  anon_sym_BANG = 212,
  anon_sym_LT_DASH = 213,
  anon_sym_LT_DASH_GT = 214,
  anon_sym_STAR = 215,
  anon_sym_DOT = 216,
  aux_sym_type_name_token1 = 217,
  anon_sym_blank = 218,
  anon_sym_camel = 219,
  anon_sym_class = 220,
  anon_sym_punct = 221,
  anon_sym_ascii = 222,
  anon_sym_lowercase = 223,
  anon_sym_uppercase = 224,
  anon_sym_edgengram = 225,
  anon_sym_ngram = 226,
  anon_sym_snowball = 227,
  sym_string = 228,
  sym_prefixed_string = 229,
  sym_int = 230,
  sym_float = 231,
  sym_decimal = 232,
  sym_variable_name = 233,
  sym_custom_function_name = 234,
  sym_function_name = 235,
  sym_version_number = 236,
  sym_record_id_ident = 237,
  anon_sym_DOT_DOT = 238,
  sym_duration_part = 239,
  anon_sym_DASH = 240,
  anon_sym_PERCENT = 241,
  anon_sym_AT = 242,
  anon_sym_LT_PIPE = 243,
  anon_sym_PIPE_GT = 244,
  anon_sym_AMP_AMP = 245,
  anon_sym_PIPE_PIPE = 246,
  anon_sym_QMARK_QMARK = 247,
  anon_sym_QMARK_COLON = 248,
  anon_sym_BANG_EQ = 249,
  anon_sym_EQ_EQ = 250,
  anon_sym_QMARK_EQ = 251,
  anon_sym_STAR_EQ = 252,
  anon_sym_TILDE = 253,
  anon_sym_BANG_TILDE = 254,
  anon_sym_STAR_TILDE = 255,
  anon_sym_LT_EQ = 256,
  anon_sym_GT_EQ = 257,
  anon_sym_PLUS = 258,
  anon_sym_PLUS_EQ = 259,
  anon_sym_DASH_EQ = 260,
  anon_sym_u00d7 = 261,
  anon_sym_SLASH = 262,
  anon_sym_u00f7 = 263,
  anon_sym_STAR_STAR = 264,
  anon_sym_u220b = 265,
  anon_sym_u220c = 266,
  anon_sym_u2287 = 267,
  anon_sym_u2283 = 268,
  anon_sym_u2285 = 269,
  anon_sym_u2208 = 270,
  anon_sym_u2209 = 271,
  anon_sym_u2286 = 272,
  anon_sym_u2282 = 273,
  anon_sym_u2284 = 274,
  anon_sym_AT_AT = 275,
  sym_source_file = 276,
  sym_expressions = 277,
  sym_expression = 278,
  sym_primary_statement = 279,
  sym_subquery_statement = 280,
  sym_kill_statement = 281,
  sym_sleep_statement = 282,
  sym_break_statement = 283,
  sym_continue_statement = 284,
  sym_for_statement = 285,
  sym_return_statement = 286,
  sym_throw_statement = 287,
  sym_if_statement = 288,
  sym_else_if_clause = 289,
  sym_else_clause = 290,
  sym_let_statement = 291,
  sym_info_statement = 292,
  sym_info_target = 293,
  sym_use_statement = 294,
  sym_begin_statement = 295,
  sym_cancel_statement = 296,
  sym_commit_statement = 297,
  sym_alter_statement = 298,
  sym_define_analyzer_statement = 299,
  sym_define_database_statement = 300,
  sym_define_event_statement = 301,
  sym_define_field_statement = 302,
  sym_define_function_statement = 303,
  sym_define_index_statement = 304,
  sym_define_namespace_statement = 305,
  sym_define_param_statement = 306,
  sym_define_scope_statement = 307,
  sym_define_access_statement = 308,
  sym_access_record_jwt_clause = 309,
  sym_define_table_statement = 310,
  sym_define_token_statement = 311,
  sym_define_user_statement = 312,
  sym_rebuild_index_statement = 313,
  sym_remove_statement = 314,
  sym_create_statement = 315,
  sym_update_statement = 316,
  sym_upsert_statement = 317,
  sym_relate_statement = 318,
  sym_delete_statement = 319,
  sym_show_statement = 320,
  sym_insert_statement = 321,
  sym_select_statement = 322,
  sym_live_select_diff_statement = 323,
  sym_live_select_statement = 324,
  sym_root_info = 325,
  sym_namespace_info = 326,
  sym_database_info = 327,
  sym_table_info = 328,
  sym_user_info = 329,
  sym_on_level_clause = 330,
  sym_level_clause = 331,
  sym_ns_clause = 332,
  sym_db_clause = 333,
  sym_duration_clause = 334,
  sym_select_clause = 335,
  sym_from_clause = 336,
  sym_omit_clause = 337,
  sym_with_clause = 338,
  sym_where_clause = 339,
  sym_split_clause = 340,
  sym_group_clause = 341,
  sym_order_clause = 342,
  sym_order_criteria = 343,
  sym_limit_clause = 344,
  sym_fetch_clause = 345,
  sym_timeout_clause = 346,
  sym_parallel_clause = 347,
  sym_explain_clause = 348,
  sym_filter = 349,
  sym_tokenizers_clause = 350,
  sym_filters_clause = 351,
  sym_function_clause = 352,
  sym_on_table_clause = 353,
  sym_when_then_clause = 354,
  sym_type_object_property = 355,
  sym_type_object = 356,
  sym_type_clause = 357,
  sym_default_clause = 358,
  sym_readonly_clause = 359,
  sym_value_clause = 360,
  sym_assert_clause = 361,
  sym_permissions_for_clause = 362,
  sym_permissions_basic_clause = 363,
  sym_comment_clause = 364,
  sym_param_list = 365,
  sym_block = 366,
  sym_fields_columns_clause = 367,
  sym_unique_clause = 368,
  sym_mtree_dimension_clause = 369,
  sym_hnsw_dimension_clause = 370,
  sym_search_analyzer_clause = 371,
  sym_bm25_clause = 372,
  sym_doc_ids_cache_clause = 373,
  sym_doc_ids_order_clause = 374,
  sym_doc_lengths_cache_clause = 375,
  sym_doc_lengths_order_clause = 376,
  sym_postings_cache_clause = 377,
  sym_postings_order_clause = 378,
  sym_terms_cache_clause = 379,
  sym_terms_order_clause = 380,
  sym_session_clause = 381,
  sym_signin_clause = 382,
  sym_signup_clause = 383,
  sym_table_type_clause = 384,
  sym_table_view_clause = 385,
  sym_changefeed_clause = 386,
  sym_token_type_clause = 387,
  sym_if_not_exists_clause = 388,
  sym_if_exists_clause = 389,
  sym_create_target = 390,
  sym_content_clause = 391,
  sym_set_clause = 392,
  sym_unset_clause = 393,
  sym_return_clause = 394,
  sym_relate_subject = 395,
  sym_merge_clause = 396,
  sym_patch_clause = 397,
  sym_replace_clause = 398,
  sym_field_assignment = 399,
  sym_value = 400,
  sym_multi_record = 401,
  sym_function_call = 402,
  sym_base_value = 403,
  sym_cast_expression = 404,
  sym_binary_expression = 405,
  sym_negated_expression = 406,
  sym_path = 407,
  sym_path_element = 408,
  sym_graph_path = 409,
  sym_predicate = 410,
  sym_inclusive_predicate = 411,
  sym_graph_predicate = 412,
  sym_subscript = 413,
  sym_version = 414,
  sym_argument_list = 415,
  sym_argument_list_count = 416,
  sym_type_name = 417,
  sym_literal_value = 418,
  sym_record_or_separated = 419,
  sym_type = 420,
  sym_union_type = 421,
  sym_composite_type = 422,
  sym_parameterized_type = 423,
  sym_analyzer_tokenizers = 424,
  sym_distance_values = 425,
  sym_analyzer_filters = 426,
  sym_number = 427,
  sym_identifier = 428,
  sym_array = 429,
  sym_object = 430,
  sym_object_content = 431,
  sym_object_property = 432,
  sym_object_key = 433,
  sym_record_id = 434,
  sym_record_id_value = 435,
  sym_record_id_range = 436,
  sym_sub_query = 437,
  sym_duration = 438,
  sym_point = 439,
  sym_range = 440,
  sym_operator = 441,
  sym_binary_operator = 442,
  sym_assignment_operator = 443,
  aux_sym_expressions_repeat1 = 444,
  aux_sym_if_statement_repeat1 = 445,
  aux_sym_alter_statement_repeat1 = 446,
  aux_sym_define_analyzer_statement_repeat1 = 447,
  aux_sym_define_field_statement_repeat1 = 448,
  aux_sym_define_field_statement_repeat2 = 449,
  aux_sym_define_function_statement_repeat1 = 450,
  aux_sym_define_index_statement_repeat1 = 451,
  aux_sym_define_scope_statement_repeat1 = 452,
  aux_sym_update_statement_repeat1 = 453,
  aux_sym_upsert_statement_repeat1 = 454,
  aux_sym_upsert_statement_repeat2 = 455,
  aux_sym_insert_statement_repeat1 = 456,
  aux_sym_insert_statement_repeat2 = 457,
  aux_sym_duration_clause_repeat1 = 458,
  aux_sym_order_clause_repeat1 = 459,
  aux_sym_tokenizers_clause_repeat1 = 460,
  aux_sym_filters_clause_repeat1 = 461,
  aux_sym_when_then_clause_repeat1 = 462,
  aux_sym_type_object_repeat1 = 463,
  aux_sym_permissions_for_clause_repeat1 = 464,
  aux_sym_permissions_for_clause_repeat2 = 465,
  aux_sym_param_list_repeat1 = 466,
  aux_sym_search_analyzer_clause_repeat1 = 467,
  aux_sym_table_type_clause_repeat1 = 468,
  aux_sym_function_call_repeat1 = 469,
  aux_sym_path_repeat1 = 470,
  aux_sym_graph_path_repeat1 = 471,
  aux_sym_record_or_separated_repeat1 = 472,
  aux_sym_union_type_repeat1 = 473,
  aux_sym_composite_type_repeat1 = 474,
  aux_sym_parameterized_type_repeat1 = 475,
  aux_sym_object_content_repeat1 = 476,
  aux_sym_duration_repeat1 = 477,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_comment] = "comment",
  [sym_semi_colon] = "semi_colon",
  [sym_keyword_info] = "keyword_info",
  [sym_keyword_show] = "keyword_show",
  [sym_keyword_changes] = "keyword_changes",
  [sym_keyword_since] = "keyword_since",
  [sym_keyword_if] = "keyword_if",
  [sym_keyword_throw] = "keyword_throw",
  [sym_keyword_exists] = "keyword_exists",
  [sym_keyword_tokenizers] = "keyword_tokenizers",
  [sym_keyword_overwrite] = "keyword_overwrite",
  [sym_keyword_on] = "keyword_on",
  [sym_keyword_let] = "keyword_let",
  [sym_keyword_return] = "keyword_return",
  [sym_keyword_else] = "keyword_else",
  [sym_keyword_select] = "keyword_select",
  [sym_keyword_from] = "keyword_from",
  [sym_keyword_only] = "keyword_only",
  [sym_keyword_value] = "keyword_value",
  [sym_keyword_as] = "keyword_as",
  [sym_keyword_omit] = "keyword_omit",
  [sym_keyword_explain] = "keyword_explain",
  [sym_keyword_full] = "keyword_full",
  [sym_keyword_parallel] = "keyword_parallel",
  [sym_keyword_timeout] = "keyword_timeout",
  [sym_keyword_fetch] = "keyword_fetch",
  [sym_keyword_limit] = "keyword_limit",
  [sym_keyword_by] = "keyword_by",
  [sym_keyword_rand] = "keyword_rand",
  [sym_keyword_collate] = "keyword_collate",
  [sym_keyword_numeric] = "keyword_numeric",
  [sym_keyword_asc] = "keyword_asc",
  [sym_keyword_desc] = "keyword_desc",
  [sym_keyword_order] = "keyword_order",
  [sym_keyword_with] = "keyword_with",
  [sym_keyword_index] = "keyword_index",
  [sym_keyword_no_index] = "keyword_no_index",
  [sym_keyword_where] = "keyword_where",
  [sym_keyword_split] = "keyword_split",
  [sym_keyword_at] = "keyword_at",
  [sym_keyword_group] = "keyword_group",
  [sym_keyword_true] = "keyword_true",
  [sym_keyword_false] = "keyword_false",
  [sym_keyword_begin] = "keyword_begin",
  [sym_keyword_cancel] = "keyword_cancel",
  [sym_keyword_commit] = "keyword_commit",
  [sym_keyword_transaction] = "keyword_transaction",
  [sym_keyword_none] = "keyword_none",
  [sym_keyword_null] = "keyword_null",
  [sym_keyword_and] = "keyword_and",
  [sym_keyword_or] = "keyword_or",
  [sym_keyword_is] = "keyword_is",
  [sym_keyword_not] = "keyword_not",
  [sym_keyword_contains] = "keyword_contains",
  [sym_keyword_contains_not] = "keyword_contains_not",
  [sym_keyword_contains_all] = "keyword_contains_all",
  [sym_keyword_contains_any] = "keyword_contains_any",
  [sym_keyword_contains_none] = "keyword_contains_none",
  [sym_keyword_inside] = "keyword_inside",
  [sym_keyword_in] = "keyword_in",
  [sym_keyword_not_inside] = "keyword_not_inside",
  [sym_keyword_all_inside] = "keyword_all_inside",
  [sym_keyword_any_inside] = "keyword_any_inside",
  [sym_keyword_none_inside] = "keyword_none_inside",
  [sym_keyword_outside] = "keyword_outside",
  [sym_keyword_intersects] = "keyword_intersects",
  [sym_keyword_chebyshev] = "keyword_chebyshev",
  [sym_keyword_cosine] = "keyword_cosine",
  [sym_keyword_euclidean] = "keyword_euclidean",
  [sym_keyword_hamming] = "keyword_hamming",
  [sym_keyword_jaccard] = "keyword_jaccard",
  [sym_keyword_manhattan] = "keyword_manhattan",
  [sym_keyword_minkowski] = "keyword_minkowski",
  [sym_keyword_pearson] = "keyword_pearson",
  [sym_keyword_define] = "keyword_define",
  [sym_keyword_analyzer] = "keyword_analyzer",
  [sym_keyword_event] = "keyword_event",
  [sym_keyword_field] = "keyword_field",
  [sym_keyword_function] = "keyword_function",
  [sym_keyword_namespace] = "keyword_namespace",
  [sym_keyword_param] = "keyword_param",
  [sym_keyword_scope] = "keyword_scope",
  [sym_keyword_drop] = "keyword_drop",
  [sym_keyword_schemafull] = "keyword_schemafull",
  [sym_keyword_schemaless] = "keyword_schemaless",
  [sym_keyword_live] = "keyword_live",
  [sym_keyword_diff] = "keyword_diff",
  [sym_keyword_flexible] = "keyword_flexible",
  [sym_keyword_readonly] = "keyword_readonly",
  [sym_keyword_jwks] = "keyword_jwks",
  [sym_keyword_eddsa] = "keyword_eddsa",
  [sym_keyword_es256] = "keyword_es256",
  [sym_keyword_es384] = "keyword_es384",
  [sym_keyword_es512] = "keyword_es512",
  [sym_keyword_ps256] = "keyword_ps256",
  [sym_keyword_ps384] = "keyword_ps384",
  [sym_keyword_ps512] = "keyword_ps512",
  [sym_keyword_rs256] = "keyword_rs256",
  [sym_keyword_rs384] = "keyword_rs384",
  [sym_keyword_rs512] = "keyword_rs512",
  [sym_keyword_hs256] = "keyword_hs256",
  [sym_keyword_hs384] = "keyword_hs384",
  [sym_keyword_hs512] = "keyword_hs512",
  [sym_keyword_bm25] = "keyword_bm25",
  [sym_keyword_doc_ids_cache] = "keyword_doc_ids_cache",
  [sym_keyword_doc_ids_order] = "keyword_doc_ids_order",
  [sym_keyword_doc_lengths_cache] = "keyword_doc_lengths_cache",
  [sym_keyword_doc_lengths_order] = "keyword_doc_lengths_order",
  [sym_keyword_postings_cache] = "keyword_postings_cache",
  [sym_keyword_postings_order] = "keyword_postings_order",
  [sym_keyword_terms_cache] = "keyword_terms_cache",
  [sym_keyword_terms_order] = "keyword_terms_order",
  [sym_keyword_highlights] = "keyword_highlights",
  [sym_keyword_any] = "keyword_any",
  [sym_keyword_normal] = "keyword_normal",
  [sym_keyword_relation] = "keyword_relation",
  [sym_keyword_out] = "keyword_out",
  [sym_keyword_to] = "keyword_to",
  [sym_keyword_changefeed] = "keyword_changefeed",
  [sym_keyword_content] = "keyword_content",
  [sym_keyword_merge] = "keyword_merge",
  [sym_keyword_patch] = "keyword_patch",
  [sym_keyword_replace] = "keyword_replace",
  [sym_keyword_before] = "keyword_before",
  [sym_keyword_after] = "keyword_after",
  [sym_keyword_table] = "keyword_table",
  [sym_keyword_root] = "keyword_root",
  [sym_keyword_token] = "keyword_token",
  [sym_keyword_use] = "keyword_use",
  [sym_keyword_ns] = "keyword_ns",
  [sym_keyword_db] = "keyword_db",
  [sym_keyword_user] = "keyword_user",
  [sym_keyword_roles] = "keyword_roles",
  [sym_keyword_remove] = "keyword_remove",
  [sym_keyword_create] = "keyword_create",
  [sym_keyword_delete] = "keyword_delete",
  [sym_keyword_update] = "keyword_update",
  [sym_keyword_upsert] = "keyword_upsert",
  [sym_keyword_insert] = "keyword_insert",
  [sym_keyword_into] = "keyword_into",
  [sym_keyword_filters] = "keyword_filters",
  [sym_keyword_when] = "keyword_when",
  [sym_keyword_then] = "keyword_then",
  [sym_keyword_type] = "keyword_type",
  [sym_keyword_default] = "keyword_default",
  [sym_keyword_assert] = "keyword_assert",
  [sym_keyword_permissions] = "keyword_permissions",
  [sym_keyword_relate] = "keyword_relate",
  [sym_keyword_ignore] = "keyword_ignore",
  [sym_keyword_values] = "keyword_values",
  [sym_keyword_for] = "keyword_for",
  [sym_keyword_comment] = "keyword_comment",
  [sym_keyword_fields] = "keyword_fields",
  [sym_keyword_columns] = "keyword_columns",
  [sym_keyword_unique] = "keyword_unique",
  [sym_keyword_search] = "keyword_search",
  [sym_keyword_session] = "keyword_session",
  [sym_keyword_signin] = "keyword_signin",
  [sym_keyword_signup] = "keyword_signup",
  [sym_keyword_database] = "keyword_database",
  [sym_keyword_password] = "keyword_password",
  [sym_keyword_password_hash] = "keyword_password_hash",
  [sym_keyword_on_duplicate_key_update] = "keyword_on_duplicate_key_update",
  [sym_keyword_count] = "keyword_count",
  [sym_keyword_unset] = "keyword_unset",
  [sym_keyword_set] = "keyword_set",
  [sym_keyword_always] = "keyword_always",
  [sym_keyword_alter] = "keyword_alter",
  [sym_keyword_break] = "keyword_break",
  [sym_keyword_continue] = "keyword_continue",
  [sym_keyword_sleep] = "keyword_sleep",
  [sym_keyword_kill] = "keyword_kill",
  [sym_keyword_rebuild] = "keyword_rebuild",
  [sym_keyword_mtree] = "keyword_mtree",
  [sym_keyword_dimension] = "keyword_dimension",
  [sym_keyword_dist] = "keyword_dist",
  [sym_keyword_efc] = "keyword_efc",
  [sym_keyword_m] = "keyword_m",
  [sym_keyword_capacity] = "keyword_capacity",
  [sym_keyword_hnsw] = "keyword_hnsw",
  [sym_keyword_owner] = "keyword_owner",
  [sym_keyword_editor] = "keyword_editor",
  [sym_keyword_viewer] = "keyword_viewer",
  [sym_keyword_duration] = "keyword_duration",
  [sym_keyword_enforced] = "keyword_enforced",
  [sym_keyword_algorithm] = "keyword_algorithm",
  [sym_keyword_key] = "keyword_key",
  [sym_keyword_url] = "keyword_url",
  [sym_keyword_jwt] = "keyword_jwt",
  [sym_keyword_issuer] = "keyword_issuer",
  [sym_keyword_refresh] = "keyword_refresh",
  [sym_keyword_record] = "keyword_record",
  [sym_keyword_bearer] = "keyword_bearer",
  [sym_keyword_authenticate] = "keyword_authenticate",
  [sym_keyword_grant] = "keyword_grant",
  [sym_keyword_access] = "keyword_access",
  [anon_sym_EQ] = "=",
  [anon_sym_COMMA] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_DASH_GT] = "->",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_QMARK] = "\?",
  [anon_sym_COLON] = ":",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_PIPE] = "|",
  [anon_sym_COLON_COLON] = "::",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_BANG] = "!",
  [anon_sym_LT_DASH] = "<-",
  [anon_sym_LT_DASH_GT] = "<->",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT] = ".",
  [aux_sym_type_name_token1] = "type_name_token1",
  [anon_sym_blank] = "blank",
  [anon_sym_camel] = "camel",
  [anon_sym_class] = "class",
  [anon_sym_punct] = "punct",
  [anon_sym_ascii] = "ascii",
  [anon_sym_lowercase] = "lowercase",
  [anon_sym_uppercase] = "uppercase",
  [anon_sym_edgengram] = "edgengram",
  [anon_sym_ngram] = "ngram",
  [anon_sym_snowball] = "snowball",
  [sym_string] = "string",
  [sym_prefixed_string] = "prefixed_string",
  [sym_int] = "int",
  [sym_float] = "float",
  [sym_decimal] = "decimal",
  [sym_variable_name] = "variable_name",
  [sym_custom_function_name] = "custom_function_name",
  [sym_function_name] = "function_name",
  [sym_version_number] = "version_number",
  [sym_record_id_ident] = "record_id_ident",
  [anon_sym_DOT_DOT] = "..",
  [sym_duration_part] = "duration_part",
  [anon_sym_DASH] = "-",
  [anon_sym_PERCENT] = "%",
  [anon_sym_AT] = "@",
  [anon_sym_LT_PIPE] = "<|",
  [anon_sym_PIPE_GT] = "|>",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_QMARK_QMARK] = "\?\?",
  [anon_sym_QMARK_COLON] = "\?:",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_QMARK_EQ] = "\?=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_TILDE] = "~",
  [anon_sym_BANG_TILDE] = "!~",
  [anon_sym_STAR_TILDE] = "*~",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_PLUS] = "+",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_u00d7] = "\u00d7",
  [anon_sym_SLASH] = "/",
  [anon_sym_u00f7] = "\u00f7",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_u220b] = "\u220b",
  [anon_sym_u220c] = "\u220c",
  [anon_sym_u2287] = "\u2287",
  [anon_sym_u2283] = "\u2283",
  [anon_sym_u2285] = "\u2285",
  [anon_sym_u2208] = "\u2208",
  [anon_sym_u2209] = "\u2209",
  [anon_sym_u2286] = "\u2286",
  [anon_sym_u2282] = "\u2282",
  [anon_sym_u2284] = "\u2284",
  [anon_sym_AT_AT] = "@@",
  [sym_source_file] = "source_file",
  [sym_expressions] = "expressions",
  [sym_expression] = "expression",
  [sym_primary_statement] = "primary_statement",
  [sym_subquery_statement] = "subquery_statement",
  [sym_kill_statement] = "kill_statement",
  [sym_sleep_statement] = "sleep_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_for_statement] = "for_statement",
  [sym_return_statement] = "return_statement",
  [sym_throw_statement] = "throw_statement",
  [sym_if_statement] = "if_statement",
  [sym_else_if_clause] = "else_if_clause",
  [sym_else_clause] = "else_clause",
  [sym_let_statement] = "let_statement",
  [sym_info_statement] = "info_statement",
  [sym_info_target] = "info_target",
  [sym_use_statement] = "use_statement",
  [sym_begin_statement] = "begin_statement",
  [sym_cancel_statement] = "cancel_statement",
  [sym_commit_statement] = "commit_statement",
  [sym_alter_statement] = "alter_statement",
  [sym_define_analyzer_statement] = "define_analyzer_statement",
  [sym_define_database_statement] = "define_database_statement",
  [sym_define_event_statement] = "define_event_statement",
  [sym_define_field_statement] = "define_field_statement",
  [sym_define_function_statement] = "define_function_statement",
  [sym_define_index_statement] = "define_index_statement",
  [sym_define_namespace_statement] = "define_namespace_statement",
  [sym_define_param_statement] = "define_param_statement",
  [sym_define_scope_statement] = "define_scope_statement",
  [sym_define_access_statement] = "define_access_statement",
  [sym_access_record_jwt_clause] = "access_record_jwt_clause",
  [sym_define_table_statement] = "define_table_statement",
  [sym_define_token_statement] = "define_token_statement",
  [sym_define_user_statement] = "define_user_statement",
  [sym_rebuild_index_statement] = "rebuild_index_statement",
  [sym_remove_statement] = "remove_statement",
  [sym_create_statement] = "create_statement",
  [sym_update_statement] = "update_statement",
  [sym_upsert_statement] = "upsert_statement",
  [sym_relate_statement] = "relate_statement",
  [sym_delete_statement] = "delete_statement",
  [sym_show_statement] = "show_statement",
  [sym_insert_statement] = "insert_statement",
  [sym_select_statement] = "select_statement",
  [sym_live_select_diff_statement] = "live_select_diff_statement",
  [sym_live_select_statement] = "live_select_statement",
  [sym_root_info] = "root_info",
  [sym_namespace_info] = "namespace_info",
  [sym_database_info] = "database_info",
  [sym_table_info] = "table_info",
  [sym_user_info] = "user_info",
  [sym_on_level_clause] = "on_level_clause",
  [sym_level_clause] = "level_clause",
  [sym_ns_clause] = "ns_clause",
  [sym_db_clause] = "db_clause",
  [sym_duration_clause] = "duration_clause",
  [sym_select_clause] = "select_clause",
  [sym_from_clause] = "from_clause",
  [sym_omit_clause] = "omit_clause",
  [sym_with_clause] = "with_clause",
  [sym_where_clause] = "where_clause",
  [sym_split_clause] = "split_clause",
  [sym_group_clause] = "group_clause",
  [sym_order_clause] = "order_clause",
  [sym_order_criteria] = "order_criteria",
  [sym_limit_clause] = "limit_clause",
  [sym_fetch_clause] = "fetch_clause",
  [sym_timeout_clause] = "timeout_clause",
  [sym_parallel_clause] = "parallel_clause",
  [sym_explain_clause] = "explain_clause",
  [sym_filter] = "filter",
  [sym_tokenizers_clause] = "tokenizers_clause",
  [sym_filters_clause] = "filters_clause",
  [sym_function_clause] = "function_clause",
  [sym_on_table_clause] = "on_table_clause",
  [sym_when_then_clause] = "when_then_clause",
  [sym_type_object_property] = "type_object_property",
  [sym_type_object] = "type_object",
  [sym_type_clause] = "type_clause",
  [sym_default_clause] = "default_clause",
  [sym_readonly_clause] = "readonly_clause",
  [sym_value_clause] = "value_clause",
  [sym_assert_clause] = "assert_clause",
  [sym_permissions_for_clause] = "permissions_for_clause",
  [sym_permissions_basic_clause] = "permissions_basic_clause",
  [sym_comment_clause] = "comment_clause",
  [sym_param_list] = "param_list",
  [sym_block] = "block",
  [sym_fields_columns_clause] = "fields_columns_clause",
  [sym_unique_clause] = "unique_clause",
  [sym_mtree_dimension_clause] = "mtree_dimension_clause",
  [sym_hnsw_dimension_clause] = "hnsw_dimension_clause",
  [sym_search_analyzer_clause] = "search_analyzer_clause",
  [sym_bm25_clause] = "bm25_clause",
  [sym_doc_ids_cache_clause] = "doc_ids_cache_clause",
  [sym_doc_ids_order_clause] = "doc_ids_order_clause",
  [sym_doc_lengths_cache_clause] = "doc_lengths_cache_clause",
  [sym_doc_lengths_order_clause] = "doc_lengths_order_clause",
  [sym_postings_cache_clause] = "postings_cache_clause",
  [sym_postings_order_clause] = "postings_order_clause",
  [sym_terms_cache_clause] = "terms_cache_clause",
  [sym_terms_order_clause] = "terms_order_clause",
  [sym_session_clause] = "session_clause",
  [sym_signin_clause] = "signin_clause",
  [sym_signup_clause] = "signup_clause",
  [sym_table_type_clause] = "table_type_clause",
  [sym_table_view_clause] = "table_view_clause",
  [sym_changefeed_clause] = "changefeed_clause",
  [sym_token_type_clause] = "token_type_clause",
  [sym_if_not_exists_clause] = "if_not_exists_clause",
  [sym_if_exists_clause] = "if_exists_clause",
  [sym_create_target] = "create_target",
  [sym_content_clause] = "content_clause",
  [sym_set_clause] = "set_clause",
  [sym_unset_clause] = "unset_clause",
  [sym_return_clause] = "return_clause",
  [sym_relate_subject] = "relate_subject",
  [sym_merge_clause] = "merge_clause",
  [sym_patch_clause] = "patch_clause",
  [sym_replace_clause] = "replace_clause",
  [sym_field_assignment] = "field_assignment",
  [sym_value] = "value",
  [sym_multi_record] = "multi_record",
  [sym_function_call] = "function_call",
  [sym_base_value] = "base_value",
  [sym_cast_expression] = "cast_expression",
  [sym_binary_expression] = "binary_expression",
  [sym_negated_expression] = "negated_expression",
  [sym_path] = "path",
  [sym_path_element] = "path_element",
  [sym_graph_path] = "graph_path",
  [sym_predicate] = "predicate",
  [sym_inclusive_predicate] = "inclusive_predicate",
  [sym_graph_predicate] = "graph_predicate",
  [sym_subscript] = "subscript",
  [sym_version] = "version",
  [sym_argument_list] = "argument_list",
  [sym_argument_list_count] = "argument_list_count",
  [sym_type_name] = "type_name",
  [sym_literal_value] = "literal_value",
  [sym_record_or_separated] = "record_or_separated",
  [sym_type] = "type",
  [sym_union_type] = "union_type",
  [sym_composite_type] = "composite_type",
  [sym_parameterized_type] = "parameterized_type",
  [sym_analyzer_tokenizers] = "analyzer_tokenizers",
  [sym_distance_values] = "distance_values",
  [sym_analyzer_filters] = "analyzer_filters",
  [sym_number] = "number",
  [sym_identifier] = "identifier",
  [sym_array] = "array",
  [sym_object] = "object",
  [sym_object_content] = "object_content",
  [sym_object_property] = "object_property",
  [sym_object_key] = "object_key",
  [sym_record_id] = "record_id",
  [sym_record_id_value] = "record_id_value",
  [sym_record_id_range] = "record_id_range",
  [sym_sub_query] = "sub_query",
  [sym_duration] = "duration",
  [sym_point] = "point",
  [sym_range] = "range",
  [sym_operator] = "operator",
  [sym_binary_operator] = "binary_operator",
  [sym_assignment_operator] = "assignment_operator",
  [aux_sym_expressions_repeat1] = "expressions_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_alter_statement_repeat1] = "alter_statement_repeat1",
  [aux_sym_define_analyzer_statement_repeat1] = "define_analyzer_statement_repeat1",
  [aux_sym_define_field_statement_repeat1] = "define_field_statement_repeat1",
  [aux_sym_define_field_statement_repeat2] = "define_field_statement_repeat2",
  [aux_sym_define_function_statement_repeat1] = "define_function_statement_repeat1",
  [aux_sym_define_index_statement_repeat1] = "define_index_statement_repeat1",
  [aux_sym_define_scope_statement_repeat1] = "define_scope_statement_repeat1",
  [aux_sym_update_statement_repeat1] = "update_statement_repeat1",
  [aux_sym_upsert_statement_repeat1] = "upsert_statement_repeat1",
  [aux_sym_upsert_statement_repeat2] = "upsert_statement_repeat2",
  [aux_sym_insert_statement_repeat1] = "insert_statement_repeat1",
  [aux_sym_insert_statement_repeat2] = "insert_statement_repeat2",
  [aux_sym_duration_clause_repeat1] = "duration_clause_repeat1",
  [aux_sym_order_clause_repeat1] = "order_clause_repeat1",
  [aux_sym_tokenizers_clause_repeat1] = "tokenizers_clause_repeat1",
  [aux_sym_filters_clause_repeat1] = "filters_clause_repeat1",
  [aux_sym_when_then_clause_repeat1] = "when_then_clause_repeat1",
  [aux_sym_type_object_repeat1] = "type_object_repeat1",
  [aux_sym_permissions_for_clause_repeat1] = "permissions_for_clause_repeat1",
  [aux_sym_permissions_for_clause_repeat2] = "permissions_for_clause_repeat2",
  [aux_sym_param_list_repeat1] = "param_list_repeat1",
  [aux_sym_search_analyzer_clause_repeat1] = "search_analyzer_clause_repeat1",
  [aux_sym_table_type_clause_repeat1] = "table_type_clause_repeat1",
  [aux_sym_function_call_repeat1] = "function_call_repeat1",
  [aux_sym_path_repeat1] = "path_repeat1",
  [aux_sym_graph_path_repeat1] = "graph_path_repeat1",
  [aux_sym_record_or_separated_repeat1] = "record_or_separated_repeat1",
  [aux_sym_union_type_repeat1] = "union_type_repeat1",
  [aux_sym_composite_type_repeat1] = "composite_type_repeat1",
  [aux_sym_parameterized_type_repeat1] = "parameterized_type_repeat1",
  [aux_sym_object_content_repeat1] = "object_content_repeat1",
  [aux_sym_duration_repeat1] = "duration_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_comment] = sym_comment,
  [sym_semi_colon] = sym_semi_colon,
  [sym_keyword_info] = sym_keyword_info,
  [sym_keyword_show] = sym_keyword_show,
  [sym_keyword_changes] = sym_keyword_changes,
  [sym_keyword_since] = sym_keyword_since,
  [sym_keyword_if] = sym_keyword_if,
  [sym_keyword_throw] = sym_keyword_throw,
  [sym_keyword_exists] = sym_keyword_exists,
  [sym_keyword_tokenizers] = sym_keyword_tokenizers,
  [sym_keyword_overwrite] = sym_keyword_overwrite,
  [sym_keyword_on] = sym_keyword_on,
  [sym_keyword_let] = sym_keyword_let,
  [sym_keyword_return] = sym_keyword_return,
  [sym_keyword_else] = sym_keyword_else,
  [sym_keyword_select] = sym_keyword_select,
  [sym_keyword_from] = sym_keyword_from,
  [sym_keyword_only] = sym_keyword_only,
  [sym_keyword_value] = sym_keyword_value,
  [sym_keyword_as] = sym_keyword_as,
  [sym_keyword_omit] = sym_keyword_omit,
  [sym_keyword_explain] = sym_keyword_explain,
  [sym_keyword_full] = sym_keyword_full,
  [sym_keyword_parallel] = sym_keyword_parallel,
  [sym_keyword_timeout] = sym_keyword_timeout,
  [sym_keyword_fetch] = sym_keyword_fetch,
  [sym_keyword_limit] = sym_keyword_limit,
  [sym_keyword_by] = sym_keyword_by,
  [sym_keyword_rand] = sym_keyword_rand,
  [sym_keyword_collate] = sym_keyword_collate,
  [sym_keyword_numeric] = sym_keyword_numeric,
  [sym_keyword_asc] = sym_keyword_asc,
  [sym_keyword_desc] = sym_keyword_desc,
  [sym_keyword_order] = sym_keyword_order,
  [sym_keyword_with] = sym_keyword_with,
  [sym_keyword_index] = sym_keyword_index,
  [sym_keyword_no_index] = sym_keyword_no_index,
  [sym_keyword_where] = sym_keyword_where,
  [sym_keyword_split] = sym_keyword_split,
  [sym_keyword_at] = sym_keyword_at,
  [sym_keyword_group] = sym_keyword_group,
  [sym_keyword_true] = sym_keyword_true,
  [sym_keyword_false] = sym_keyword_false,
  [sym_keyword_begin] = sym_keyword_begin,
  [sym_keyword_cancel] = sym_keyword_cancel,
  [sym_keyword_commit] = sym_keyword_commit,
  [sym_keyword_transaction] = sym_keyword_transaction,
  [sym_keyword_none] = sym_keyword_none,
  [sym_keyword_null] = sym_keyword_null,
  [sym_keyword_and] = sym_keyword_and,
  [sym_keyword_or] = sym_keyword_or,
  [sym_keyword_is] = sym_keyword_is,
  [sym_keyword_not] = sym_keyword_not,
  [sym_keyword_contains] = sym_keyword_contains,
  [sym_keyword_contains_not] = sym_keyword_contains_not,
  [sym_keyword_contains_all] = sym_keyword_contains_all,
  [sym_keyword_contains_any] = sym_keyword_contains_any,
  [sym_keyword_contains_none] = sym_keyword_contains_none,
  [sym_keyword_inside] = sym_keyword_inside,
  [sym_keyword_in] = sym_keyword_in,
  [sym_keyword_not_inside] = sym_keyword_not_inside,
  [sym_keyword_all_inside] = sym_keyword_all_inside,
  [sym_keyword_any_inside] = sym_keyword_any_inside,
  [sym_keyword_none_inside] = sym_keyword_none_inside,
  [sym_keyword_outside] = sym_keyword_outside,
  [sym_keyword_intersects] = sym_keyword_intersects,
  [sym_keyword_chebyshev] = sym_keyword_chebyshev,
  [sym_keyword_cosine] = sym_keyword_cosine,
  [sym_keyword_euclidean] = sym_keyword_euclidean,
  [sym_keyword_hamming] = sym_keyword_hamming,
  [sym_keyword_jaccard] = sym_keyword_jaccard,
  [sym_keyword_manhattan] = sym_keyword_manhattan,
  [sym_keyword_minkowski] = sym_keyword_minkowski,
  [sym_keyword_pearson] = sym_keyword_pearson,
  [sym_keyword_define] = sym_keyword_define,
  [sym_keyword_analyzer] = sym_keyword_analyzer,
  [sym_keyword_event] = sym_keyword_event,
  [sym_keyword_field] = sym_keyword_field,
  [sym_keyword_function] = sym_keyword_function,
  [sym_keyword_namespace] = sym_keyword_namespace,
  [sym_keyword_param] = sym_keyword_param,
  [sym_keyword_scope] = sym_keyword_scope,
  [sym_keyword_drop] = sym_keyword_drop,
  [sym_keyword_schemafull] = sym_keyword_schemafull,
  [sym_keyword_schemaless] = sym_keyword_schemaless,
  [sym_keyword_live] = sym_keyword_live,
  [sym_keyword_diff] = sym_keyword_diff,
  [sym_keyword_flexible] = sym_keyword_flexible,
  [sym_keyword_readonly] = sym_keyword_readonly,
  [sym_keyword_jwks] = sym_keyword_jwks,
  [sym_keyword_eddsa] = sym_keyword_eddsa,
  [sym_keyword_es256] = sym_keyword_es256,
  [sym_keyword_es384] = sym_keyword_es384,
  [sym_keyword_es512] = sym_keyword_es512,
  [sym_keyword_ps256] = sym_keyword_ps256,
  [sym_keyword_ps384] = sym_keyword_ps384,
  [sym_keyword_ps512] = sym_keyword_ps512,
  [sym_keyword_rs256] = sym_keyword_rs256,
  [sym_keyword_rs384] = sym_keyword_rs384,
  [sym_keyword_rs512] = sym_keyword_rs512,
  [sym_keyword_hs256] = sym_keyword_hs256,
  [sym_keyword_hs384] = sym_keyword_hs384,
  [sym_keyword_hs512] = sym_keyword_hs512,
  [sym_keyword_bm25] = sym_keyword_bm25,
  [sym_keyword_doc_ids_cache] = sym_keyword_doc_ids_cache,
  [sym_keyword_doc_ids_order] = sym_keyword_doc_ids_order,
  [sym_keyword_doc_lengths_cache] = sym_keyword_doc_lengths_cache,
  [sym_keyword_doc_lengths_order] = sym_keyword_doc_lengths_order,
  [sym_keyword_postings_cache] = sym_keyword_postings_cache,
  [sym_keyword_postings_order] = sym_keyword_postings_order,
  [sym_keyword_terms_cache] = sym_keyword_terms_cache,
  [sym_keyword_terms_order] = sym_keyword_terms_order,
  [sym_keyword_highlights] = sym_keyword_highlights,
  [sym_keyword_any] = sym_keyword_any,
  [sym_keyword_normal] = sym_keyword_normal,
  [sym_keyword_relation] = sym_keyword_relation,
  [sym_keyword_out] = sym_keyword_out,
  [sym_keyword_to] = sym_keyword_to,
  [sym_keyword_changefeed] = sym_keyword_changefeed,
  [sym_keyword_content] = sym_keyword_content,
  [sym_keyword_merge] = sym_keyword_merge,
  [sym_keyword_patch] = sym_keyword_patch,
  [sym_keyword_replace] = sym_keyword_replace,
  [sym_keyword_before] = sym_keyword_before,
  [sym_keyword_after] = sym_keyword_after,
  [sym_keyword_table] = sym_keyword_table,
  [sym_keyword_root] = sym_keyword_root,
  [sym_keyword_token] = sym_keyword_token,
  [sym_keyword_use] = sym_keyword_use,
  [sym_keyword_ns] = sym_keyword_ns,
  [sym_keyword_db] = sym_keyword_db,
  [sym_keyword_user] = sym_keyword_user,
  [sym_keyword_roles] = sym_keyword_roles,
  [sym_keyword_remove] = sym_keyword_remove,
  [sym_keyword_create] = sym_keyword_create,
  [sym_keyword_delete] = sym_keyword_delete,
  [sym_keyword_update] = sym_keyword_update,
  [sym_keyword_upsert] = sym_keyword_upsert,
  [sym_keyword_insert] = sym_keyword_insert,
  [sym_keyword_into] = sym_keyword_into,
  [sym_keyword_filters] = sym_keyword_filters,
  [sym_keyword_when] = sym_keyword_when,
  [sym_keyword_then] = sym_keyword_then,
  [sym_keyword_type] = sym_keyword_type,
  [sym_keyword_default] = sym_keyword_default,
  [sym_keyword_assert] = sym_keyword_assert,
  [sym_keyword_permissions] = sym_keyword_permissions,
  [sym_keyword_relate] = sym_keyword_relate,
  [sym_keyword_ignore] = sym_keyword_ignore,
  [sym_keyword_values] = sym_keyword_values,
  [sym_keyword_for] = sym_keyword_for,
  [sym_keyword_comment] = sym_keyword_comment,
  [sym_keyword_fields] = sym_keyword_fields,
  [sym_keyword_columns] = sym_keyword_columns,
  [sym_keyword_unique] = sym_keyword_unique,
  [sym_keyword_search] = sym_keyword_search,
  [sym_keyword_session] = sym_keyword_session,
  [sym_keyword_signin] = sym_keyword_signin,
  [sym_keyword_signup] = sym_keyword_signup,
  [sym_keyword_database] = sym_keyword_database,
  [sym_keyword_password] = sym_keyword_password,
  [sym_keyword_password_hash] = sym_keyword_password_hash,
  [sym_keyword_on_duplicate_key_update] = sym_keyword_on_duplicate_key_update,
  [sym_keyword_count] = sym_keyword_count,
  [sym_keyword_unset] = sym_keyword_unset,
  [sym_keyword_set] = sym_keyword_set,
  [sym_keyword_always] = sym_keyword_always,
  [sym_keyword_alter] = sym_keyword_alter,
  [sym_keyword_break] = sym_keyword_break,
  [sym_keyword_continue] = sym_keyword_continue,
  [sym_keyword_sleep] = sym_keyword_sleep,
  [sym_keyword_kill] = sym_keyword_kill,
  [sym_keyword_rebuild] = sym_keyword_rebuild,
  [sym_keyword_mtree] = sym_keyword_mtree,
  [sym_keyword_dimension] = sym_keyword_dimension,
  [sym_keyword_dist] = sym_keyword_dist,
  [sym_keyword_efc] = sym_keyword_efc,
  [sym_keyword_m] = sym_keyword_m,
  [sym_keyword_capacity] = sym_keyword_capacity,
  [sym_keyword_hnsw] = sym_keyword_hnsw,
  [sym_keyword_owner] = sym_keyword_owner,
  [sym_keyword_editor] = sym_keyword_editor,
  [sym_keyword_viewer] = sym_keyword_viewer,
  [sym_keyword_duration] = sym_keyword_duration,
  [sym_keyword_enforced] = sym_keyword_enforced,
  [sym_keyword_algorithm] = sym_keyword_algorithm,
  [sym_keyword_key] = sym_keyword_key,
  [sym_keyword_url] = sym_keyword_url,
  [sym_keyword_jwt] = sym_keyword_jwt,
  [sym_keyword_issuer] = sym_keyword_issuer,
  [sym_keyword_refresh] = sym_keyword_refresh,
  [sym_keyword_record] = sym_keyword_record,
  [sym_keyword_bearer] = sym_keyword_bearer,
  [sym_keyword_authenticate] = sym_keyword_authenticate,
  [sym_keyword_grant] = sym_keyword_grant,
  [sym_keyword_access] = sym_keyword_access,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_DASH_GT] = anon_sym_DASH_GT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_COLON_COLON] = anon_sym_COLON_COLON,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_LT_DASH] = anon_sym_LT_DASH,
  [anon_sym_LT_DASH_GT] = anon_sym_LT_DASH_GT,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT] = anon_sym_DOT,
  [aux_sym_type_name_token1] = aux_sym_type_name_token1,
  [anon_sym_blank] = anon_sym_blank,
  [anon_sym_camel] = anon_sym_camel,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_punct] = anon_sym_punct,
  [anon_sym_ascii] = anon_sym_ascii,
  [anon_sym_lowercase] = anon_sym_lowercase,
  [anon_sym_uppercase] = anon_sym_uppercase,
  [anon_sym_edgengram] = anon_sym_edgengram,
  [anon_sym_ngram] = anon_sym_ngram,
  [anon_sym_snowball] = anon_sym_snowball,
  [sym_string] = sym_string,
  [sym_prefixed_string] = sym_prefixed_string,
  [sym_int] = sym_int,
  [sym_float] = sym_float,
  [sym_decimal] = sym_decimal,
  [sym_variable_name] = sym_variable_name,
  [sym_custom_function_name] = sym_custom_function_name,
  [sym_function_name] = sym_function_name,
  [sym_version_number] = sym_version_number,
  [sym_record_id_ident] = sym_record_id_ident,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [sym_duration_part] = sym_duration_part,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT_PIPE] = anon_sym_LT_PIPE,
  [anon_sym_PIPE_GT] = anon_sym_PIPE_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_QMARK_QMARK] = anon_sym_QMARK_QMARK,
  [anon_sym_QMARK_COLON] = anon_sym_QMARK_COLON,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_QMARK_EQ] = anon_sym_QMARK_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_BANG_TILDE] = anon_sym_BANG_TILDE,
  [anon_sym_STAR_TILDE] = anon_sym_STAR_TILDE,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_u00d7] = anon_sym_u00d7,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_u00f7] = anon_sym_u00f7,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_u220b] = anon_sym_u220b,
  [anon_sym_u220c] = anon_sym_u220c,
  [anon_sym_u2287] = anon_sym_u2287,
  [anon_sym_u2283] = anon_sym_u2283,
  [anon_sym_u2285] = anon_sym_u2285,
  [anon_sym_u2208] = anon_sym_u2208,
  [anon_sym_u2209] = anon_sym_u2209,
  [anon_sym_u2286] = anon_sym_u2286,
  [anon_sym_u2282] = anon_sym_u2282,
  [anon_sym_u2284] = anon_sym_u2284,
  [anon_sym_AT_AT] = anon_sym_AT_AT,
  [sym_source_file] = sym_source_file,
  [sym_expressions] = sym_expressions,
  [sym_expression] = sym_expression,
  [sym_primary_statement] = sym_primary_statement,
  [sym_subquery_statement] = sym_subquery_statement,
  [sym_kill_statement] = sym_kill_statement,
  [sym_sleep_statement] = sym_sleep_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_return_statement] = sym_return_statement,
  [sym_throw_statement] = sym_throw_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_else_if_clause] = sym_else_if_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_let_statement] = sym_let_statement,
  [sym_info_statement] = sym_info_statement,
  [sym_info_target] = sym_info_target,
  [sym_use_statement] = sym_use_statement,
  [sym_begin_statement] = sym_begin_statement,
  [sym_cancel_statement] = sym_cancel_statement,
  [sym_commit_statement] = sym_commit_statement,
  [sym_alter_statement] = sym_alter_statement,
  [sym_define_analyzer_statement] = sym_define_analyzer_statement,
  [sym_define_database_statement] = sym_define_database_statement,
  [sym_define_event_statement] = sym_define_event_statement,
  [sym_define_field_statement] = sym_define_field_statement,
  [sym_define_function_statement] = sym_define_function_statement,
  [sym_define_index_statement] = sym_define_index_statement,
  [sym_define_namespace_statement] = sym_define_namespace_statement,
  [sym_define_param_statement] = sym_define_param_statement,
  [sym_define_scope_statement] = sym_define_scope_statement,
  [sym_define_access_statement] = sym_define_access_statement,
  [sym_access_record_jwt_clause] = sym_access_record_jwt_clause,
  [sym_define_table_statement] = sym_define_table_statement,
  [sym_define_token_statement] = sym_define_token_statement,
  [sym_define_user_statement] = sym_define_user_statement,
  [sym_rebuild_index_statement] = sym_rebuild_index_statement,
  [sym_remove_statement] = sym_remove_statement,
  [sym_create_statement] = sym_create_statement,
  [sym_update_statement] = sym_update_statement,
  [sym_upsert_statement] = sym_upsert_statement,
  [sym_relate_statement] = sym_relate_statement,
  [sym_delete_statement] = sym_delete_statement,
  [sym_show_statement] = sym_show_statement,
  [sym_insert_statement] = sym_insert_statement,
  [sym_select_statement] = sym_select_statement,
  [sym_live_select_diff_statement] = sym_live_select_diff_statement,
  [sym_live_select_statement] = sym_live_select_statement,
  [sym_root_info] = sym_root_info,
  [sym_namespace_info] = sym_namespace_info,
  [sym_database_info] = sym_database_info,
  [sym_table_info] = sym_table_info,
  [sym_user_info] = sym_user_info,
  [sym_on_level_clause] = sym_on_level_clause,
  [sym_level_clause] = sym_level_clause,
  [sym_ns_clause] = sym_ns_clause,
  [sym_db_clause] = sym_db_clause,
  [sym_duration_clause] = sym_duration_clause,
  [sym_select_clause] = sym_select_clause,
  [sym_from_clause] = sym_from_clause,
  [sym_omit_clause] = sym_omit_clause,
  [sym_with_clause] = sym_with_clause,
  [sym_where_clause] = sym_where_clause,
  [sym_split_clause] = sym_split_clause,
  [sym_group_clause] = sym_group_clause,
  [sym_order_clause] = sym_order_clause,
  [sym_order_criteria] = sym_order_criteria,
  [sym_limit_clause] = sym_limit_clause,
  [sym_fetch_clause] = sym_fetch_clause,
  [sym_timeout_clause] = sym_timeout_clause,
  [sym_parallel_clause] = sym_parallel_clause,
  [sym_explain_clause] = sym_explain_clause,
  [sym_filter] = sym_filter,
  [sym_tokenizers_clause] = sym_tokenizers_clause,
  [sym_filters_clause] = sym_filters_clause,
  [sym_function_clause] = sym_function_clause,
  [sym_on_table_clause] = sym_on_table_clause,
  [sym_when_then_clause] = sym_when_then_clause,
  [sym_type_object_property] = sym_type_object_property,
  [sym_type_object] = sym_type_object,
  [sym_type_clause] = sym_type_clause,
  [sym_default_clause] = sym_default_clause,
  [sym_readonly_clause] = sym_readonly_clause,
  [sym_value_clause] = sym_value_clause,
  [sym_assert_clause] = sym_assert_clause,
  [sym_permissions_for_clause] = sym_permissions_for_clause,
  [sym_permissions_basic_clause] = sym_permissions_basic_clause,
  [sym_comment_clause] = sym_comment_clause,
  [sym_param_list] = sym_param_list,
  [sym_block] = sym_block,
  [sym_fields_columns_clause] = sym_fields_columns_clause,
  [sym_unique_clause] = sym_unique_clause,
  [sym_mtree_dimension_clause] = sym_mtree_dimension_clause,
  [sym_hnsw_dimension_clause] = sym_hnsw_dimension_clause,
  [sym_search_analyzer_clause] = sym_search_analyzer_clause,
  [sym_bm25_clause] = sym_bm25_clause,
  [sym_doc_ids_cache_clause] = sym_doc_ids_cache_clause,
  [sym_doc_ids_order_clause] = sym_doc_ids_order_clause,
  [sym_doc_lengths_cache_clause] = sym_doc_lengths_cache_clause,
  [sym_doc_lengths_order_clause] = sym_doc_lengths_order_clause,
  [sym_postings_cache_clause] = sym_postings_cache_clause,
  [sym_postings_order_clause] = sym_postings_order_clause,
  [sym_terms_cache_clause] = sym_terms_cache_clause,
  [sym_terms_order_clause] = sym_terms_order_clause,
  [sym_session_clause] = sym_session_clause,
  [sym_signin_clause] = sym_signin_clause,
  [sym_signup_clause] = sym_signup_clause,
  [sym_table_type_clause] = sym_table_type_clause,
  [sym_table_view_clause] = sym_table_view_clause,
  [sym_changefeed_clause] = sym_changefeed_clause,
  [sym_token_type_clause] = sym_token_type_clause,
  [sym_if_not_exists_clause] = sym_if_not_exists_clause,
  [sym_if_exists_clause] = sym_if_exists_clause,
  [sym_create_target] = sym_create_target,
  [sym_content_clause] = sym_content_clause,
  [sym_set_clause] = sym_set_clause,
  [sym_unset_clause] = sym_unset_clause,
  [sym_return_clause] = sym_return_clause,
  [sym_relate_subject] = sym_relate_subject,
  [sym_merge_clause] = sym_merge_clause,
  [sym_patch_clause] = sym_patch_clause,
  [sym_replace_clause] = sym_replace_clause,
  [sym_field_assignment] = sym_field_assignment,
  [sym_value] = sym_value,
  [sym_multi_record] = sym_multi_record,
  [sym_function_call] = sym_function_call,
  [sym_base_value] = sym_base_value,
  [sym_cast_expression] = sym_cast_expression,
  [sym_binary_expression] = sym_binary_expression,
  [sym_negated_expression] = sym_negated_expression,
  [sym_path] = sym_path,
  [sym_path_element] = sym_path_element,
  [sym_graph_path] = sym_graph_path,
  [sym_predicate] = sym_predicate,
  [sym_inclusive_predicate] = sym_inclusive_predicate,
  [sym_graph_predicate] = sym_graph_predicate,
  [sym_subscript] = sym_subscript,
  [sym_version] = sym_version,
  [sym_argument_list] = sym_argument_list,
  [sym_argument_list_count] = sym_argument_list_count,
  [sym_type_name] = sym_type_name,
  [sym_literal_value] = sym_literal_value,
  [sym_record_or_separated] = sym_record_or_separated,
  [sym_type] = sym_type,
  [sym_union_type] = sym_union_type,
  [sym_composite_type] = sym_composite_type,
  [sym_parameterized_type] = sym_parameterized_type,
  [sym_analyzer_tokenizers] = sym_analyzer_tokenizers,
  [sym_distance_values] = sym_distance_values,
  [sym_analyzer_filters] = sym_analyzer_filters,
  [sym_number] = sym_number,
  [sym_identifier] = sym_identifier,
  [sym_array] = sym_array,
  [sym_object] = sym_object,
  [sym_object_content] = sym_object_content,
  [sym_object_property] = sym_object_property,
  [sym_object_key] = sym_object_key,
  [sym_record_id] = sym_record_id,
  [sym_record_id_value] = sym_record_id_value,
  [sym_record_id_range] = sym_record_id_range,
  [sym_sub_query] = sym_sub_query,
  [sym_duration] = sym_duration,
  [sym_point] = sym_point,
  [sym_range] = sym_range,
  [sym_operator] = sym_operator,
  [sym_binary_operator] = sym_binary_operator,
  [sym_assignment_operator] = sym_assignment_operator,
  [aux_sym_expressions_repeat1] = aux_sym_expressions_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_alter_statement_repeat1] = aux_sym_alter_statement_repeat1,
  [aux_sym_define_analyzer_statement_repeat1] = aux_sym_define_analyzer_statement_repeat1,
  [aux_sym_define_field_statement_repeat1] = aux_sym_define_field_statement_repeat1,
  [aux_sym_define_field_statement_repeat2] = aux_sym_define_field_statement_repeat2,
  [aux_sym_define_function_statement_repeat1] = aux_sym_define_function_statement_repeat1,
  [aux_sym_define_index_statement_repeat1] = aux_sym_define_index_statement_repeat1,
  [aux_sym_define_scope_statement_repeat1] = aux_sym_define_scope_statement_repeat1,
  [aux_sym_update_statement_repeat1] = aux_sym_update_statement_repeat1,
  [aux_sym_upsert_statement_repeat1] = aux_sym_upsert_statement_repeat1,
  [aux_sym_upsert_statement_repeat2] = aux_sym_upsert_statement_repeat2,
  [aux_sym_insert_statement_repeat1] = aux_sym_insert_statement_repeat1,
  [aux_sym_insert_statement_repeat2] = aux_sym_insert_statement_repeat2,
  [aux_sym_duration_clause_repeat1] = aux_sym_duration_clause_repeat1,
  [aux_sym_order_clause_repeat1] = aux_sym_order_clause_repeat1,
  [aux_sym_tokenizers_clause_repeat1] = aux_sym_tokenizers_clause_repeat1,
  [aux_sym_filters_clause_repeat1] = aux_sym_filters_clause_repeat1,
  [aux_sym_when_then_clause_repeat1] = aux_sym_when_then_clause_repeat1,
  [aux_sym_type_object_repeat1] = aux_sym_type_object_repeat1,
  [aux_sym_permissions_for_clause_repeat1] = aux_sym_permissions_for_clause_repeat1,
  [aux_sym_permissions_for_clause_repeat2] = aux_sym_permissions_for_clause_repeat2,
  [aux_sym_param_list_repeat1] = aux_sym_param_list_repeat1,
  [aux_sym_search_analyzer_clause_repeat1] = aux_sym_search_analyzer_clause_repeat1,
  [aux_sym_table_type_clause_repeat1] = aux_sym_table_type_clause_repeat1,
  [aux_sym_function_call_repeat1] = aux_sym_function_call_repeat1,
  [aux_sym_path_repeat1] = aux_sym_path_repeat1,
  [aux_sym_graph_path_repeat1] = aux_sym_graph_path_repeat1,
  [aux_sym_record_or_separated_repeat1] = aux_sym_record_or_separated_repeat1,
  [aux_sym_union_type_repeat1] = aux_sym_union_type_repeat1,
  [aux_sym_composite_type_repeat1] = aux_sym_composite_type_repeat1,
  [aux_sym_parameterized_type_repeat1] = aux_sym_parameterized_type_repeat1,
  [aux_sym_object_content_repeat1] = aux_sym_object_content_repeat1,
  [aux_sym_duration_repeat1] = aux_sym_duration_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_semi_colon] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_info] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_show] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_changes] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_since] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_if] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_throw] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_exists] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_tokenizers] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_overwrite] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_on] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_let] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_return] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_else] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_select] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_from] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_only] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_value] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_as] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_omit] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_explain] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_full] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_parallel] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_timeout] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_fetch] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_limit] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_by] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rand] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_collate] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_numeric] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_asc] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_desc] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_with] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_index] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_no_index] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_where] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_split] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_at] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_group] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_true] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_false] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_begin] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_cancel] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_commit] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_transaction] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_none] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_null] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_and] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_or] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_is] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_not] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_not] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_all] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_any] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_contains_none] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_in] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_not_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_all_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_any_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_none_inside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_outside] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_intersects] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_chebyshev] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_cosine] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_euclidean] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_hamming] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_jaccard] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_manhattan] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_minkowski] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_pearson] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_define] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_analyzer] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_event] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_field] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_function] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_namespace] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_param] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_drop] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_schemafull] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_schemaless] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_live] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_diff] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_flexible] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_readonly] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_jwks] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_eddsa] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_es256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_es384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_es512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ps256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ps384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ps512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rs256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rs384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rs512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_hs256] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_hs384] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_hs512] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_bm25] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_ids_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_ids_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_lengths_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_doc_lengths_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_postings_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_postings_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_terms_cache] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_terms_order] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_highlights] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_any] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_normal] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_out] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_to] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_changefeed] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_content] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_merge] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_patch] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_replace] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_before] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_after] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_table] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_root] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_token] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_use] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ns] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_db] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_user] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_roles] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_remove] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_create] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_delete] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_update] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_upsert] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_insert] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_into] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_filters] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_when] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_then] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_type] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_default] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_assert] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_permissions] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_relate] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_ignore] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_values] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_for] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_fields] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_columns] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_unique] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_search] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_session] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_signin] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_signup] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_database] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_password] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_password_hash] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_on_duplicate_key_update] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_count] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_unset] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_set] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_always] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_alter] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_break] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_continue] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_sleep] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_kill] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_rebuild] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_mtree] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_dimension] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_dist] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_efc] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_m] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_capacity] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_hnsw] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_owner] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_editor] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_viewer] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_duration] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_enforced] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_algorithm] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_key] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_url] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_jwt] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_issuer] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_refresh] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_record] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_bearer] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_authenticate] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_grant] = {
    .visible = true,
    .named = true,
  },
  [sym_keyword_access] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_DASH_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_type_name_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_blank] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_camel] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_punct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ascii] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lowercase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_uppercase] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_edgengram] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ngram] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_snowball] = {
    .visible = true,
    .named = false,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_prefixed_string] = {
    .visible = true,
    .named = true,
  },
  [sym_int] = {
    .visible = true,
    .named = true,
  },
  [sym_float] = {
    .visible = true,
    .named = true,
  },
  [sym_decimal] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_name] = {
    .visible = true,
    .named = true,
  },
  [sym_custom_function_name] = {
    .visible = true,
    .named = true,
  },
  [sym_function_name] = {
    .visible = true,
    .named = true,
  },
  [sym_version_number] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id_ident] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [sym_duration_part] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u00d7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u00f7] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u220b] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u220c] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2287] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2283] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2285] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2208] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2209] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2286] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2282] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_u2284] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT_AT] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_expressions] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_primary_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_subquery_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_kill_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_sleep_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_else_if_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_let_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_info_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_info_target] = {
    .visible = true,
    .named = true,
  },
  [sym_use_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_begin_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_cancel_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_commit_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_alter_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_analyzer_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_database_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_event_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_field_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_function_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_index_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_namespace_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_param_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_scope_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_access_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_access_record_jwt_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_define_table_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_token_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_define_user_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_rebuild_index_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_remove_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_create_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_update_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_upsert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_relate_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_delete_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_show_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_insert_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_select_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_live_select_diff_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_live_select_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_root_info] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_info] = {
    .visible = true,
    .named = true,
  },
  [sym_database_info] = {
    .visible = true,
    .named = true,
  },
  [sym_table_info] = {
    .visible = true,
    .named = true,
  },
  [sym_user_info] = {
    .visible = true,
    .named = true,
  },
  [sym_on_level_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_level_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_ns_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_db_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_duration_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_select_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_from_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_omit_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_with_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_where_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_split_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_group_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_order_criteria] = {
    .visible = true,
    .named = true,
  },
  [sym_limit_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_fetch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_timeout_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_parallel_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_explain_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_filter] = {
    .visible = true,
    .named = true,
  },
  [sym_tokenizers_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_filters_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_function_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_on_table_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_when_then_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_type_object_property] = {
    .visible = true,
    .named = true,
  },
  [sym_type_object] = {
    .visible = true,
    .named = true,
  },
  [sym_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_default_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_readonly_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_value_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_permissions_for_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_permissions_basic_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_comment_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_param_list] = {
    .visible = true,
    .named = true,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym_fields_columns_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_unique_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_mtree_dimension_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_hnsw_dimension_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_search_analyzer_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_bm25_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_ids_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_ids_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_lengths_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_lengths_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_postings_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_postings_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_terms_cache_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_terms_order_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_session_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_signin_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_signup_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_table_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_table_view_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_changefeed_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_token_type_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_not_exists_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_exists_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_create_target] = {
    .visible = true,
    .named = true,
  },
  [sym_content_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_set_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_unset_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_return_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_relate_subject] = {
    .visible = true,
    .named = true,
  },
  [sym_merge_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_patch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_replace_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_field_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_value] = {
    .visible = true,
    .named = true,
  },
  [sym_multi_record] = {
    .visible = true,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_base_value] = {
    .visible = true,
    .named = true,
  },
  [sym_cast_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_negated_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_path] = {
    .visible = true,
    .named = true,
  },
  [sym_path_element] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_path] = {
    .visible = true,
    .named = true,
  },
  [sym_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_inclusive_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_graph_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript] = {
    .visible = true,
    .named = true,
  },
  [sym_version] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list_count] = {
    .visible = true,
    .named = true,
  },
  [sym_type_name] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_value] = {
    .visible = true,
    .named = true,
  },
  [sym_record_or_separated] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type] = {
    .visible = true,
    .named = true,
  },
  [sym_composite_type] = {
    .visible = true,
    .named = true,
  },
  [sym_parameterized_type] = {
    .visible = true,
    .named = true,
  },
  [sym_analyzer_tokenizers] = {
    .visible = true,
    .named = true,
  },
  [sym_distance_values] = {
    .visible = true,
    .named = true,
  },
  [sym_analyzer_filters] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [sym_array] = {
    .visible = true,
    .named = true,
  },
  [sym_object] = {
    .visible = true,
    .named = true,
  },
  [sym_object_content] = {
    .visible = true,
    .named = true,
  },
  [sym_object_property] = {
    .visible = true,
    .named = true,
  },
  [sym_object_key] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id_value] = {
    .visible = true,
    .named = true,
  },
  [sym_record_id_range] = {
    .visible = true,
    .named = true,
  },
  [sym_sub_query] = {
    .visible = true,
    .named = true,
  },
  [sym_duration] = {
    .visible = true,
    .named = true,
  },
  [sym_point] = {
    .visible = true,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_operator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_expressions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_alter_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_analyzer_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_field_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_field_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_function_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_index_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_define_scope_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_update_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_upsert_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_upsert_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_insert_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_insert_statement_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_duration_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_order_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_tokenizers_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_filters_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_when_then_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_object_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_permissions_for_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_permissions_for_clause_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_param_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_search_analyzer_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_table_type_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_call_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_graph_path_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_record_or_separated_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_union_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_composite_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameterized_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_content_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_duration_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 5,
  [7] = 4,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 10,
  [12] = 8,
  [13] = 8,
  [14] = 8,
  [15] = 8,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 20,
  [51] = 44,
  [52] = 16,
  [53] = 17,
  [54] = 54,
  [55] = 31,
  [56] = 56,
  [57] = 57,
  [58] = 54,
  [59] = 59,
  [60] = 60,
  [61] = 29,
  [62] = 23,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 26,
  [68] = 68,
  [69] = 38,
  [70] = 28,
  [71] = 30,
  [72] = 32,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 66,
  [77] = 57,
  [78] = 49,
  [79] = 39,
  [80] = 41,
  [81] = 19,
  [82] = 45,
  [83] = 73,
  [84] = 60,
  [85] = 2,
  [86] = 40,
  [87] = 33,
  [88] = 42,
  [89] = 59,
  [90] = 68,
  [91] = 64,
  [92] = 65,
  [93] = 43,
  [94] = 46,
  [95] = 47,
  [96] = 48,
  [97] = 74,
  [98] = 75,
  [99] = 18,
  [100] = 34,
  [101] = 35,
  [102] = 56,
  [103] = 36,
  [104] = 37,
  [105] = 63,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 110,
  [112] = 108,
  [113] = 24,
  [114] = 27,
  [115] = 109,
  [116] = 21,
  [117] = 106,
  [118] = 22,
  [119] = 107,
  [120] = 25,
  [121] = 27,
  [122] = 24,
  [123] = 25,
  [124] = 22,
  [125] = 21,
  [126] = 21,
  [127] = 25,
  [128] = 27,
  [129] = 22,
  [130] = 24,
  [131] = 38,
  [132] = 17,
  [133] = 20,
  [134] = 16,
  [135] = 44,
  [136] = 31,
  [137] = 26,
  [138] = 28,
  [139] = 30,
  [140] = 32,
  [141] = 2,
  [142] = 2,
  [143] = 29,
  [144] = 23,
  [145] = 54,
  [146] = 49,
  [147] = 2,
  [148] = 66,
  [149] = 18,
  [150] = 45,
  [151] = 60,
  [152] = 57,
  [153] = 68,
  [154] = 39,
  [155] = 41,
  [156] = 19,
  [157] = 73,
  [158] = 40,
  [159] = 33,
  [160] = 42,
  [161] = 59,
  [162] = 63,
  [163] = 64,
  [164] = 65,
  [165] = 43,
  [166] = 46,
  [167] = 47,
  [168] = 48,
  [169] = 74,
  [170] = 75,
  [171] = 34,
  [172] = 35,
  [173] = 56,
  [174] = 36,
  [175] = 37,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 178,
  [181] = 176,
  [182] = 179,
  [183] = 183,
  [184] = 184,
  [185] = 177,
  [186] = 186,
  [187] = 183,
  [188] = 184,
  [189] = 183,
  [190] = 184,
  [191] = 183,
  [192] = 184,
  [193] = 193,
  [194] = 25,
  [195] = 27,
  [196] = 21,
  [197] = 22,
  [198] = 186,
  [199] = 193,
  [200] = 24,
  [201] = 183,
  [202] = 183,
  [203] = 183,
  [204] = 184,
  [205] = 184,
  [206] = 184,
  [207] = 183,
  [208] = 184,
  [209] = 22,
  [210] = 25,
  [211] = 27,
  [212] = 106,
  [213] = 21,
  [214] = 183,
  [215] = 184,
  [216] = 107,
  [217] = 108,
  [218] = 183,
  [219] = 184,
  [220] = 24,
  [221] = 109,
  [222] = 183,
  [223] = 184,
  [224] = 183,
  [225] = 184,
  [226] = 184,
  [227] = 183,
  [228] = 184,
  [229] = 183,
  [230] = 38,
  [231] = 44,
  [232] = 183,
  [233] = 184,
  [234] = 183,
  [235] = 184,
  [236] = 17,
  [237] = 20,
  [238] = 16,
  [239] = 239,
  [240] = 31,
  [241] = 54,
  [242] = 20,
  [243] = 28,
  [244] = 2,
  [245] = 239,
  [246] = 16,
  [247] = 183,
  [248] = 184,
  [249] = 32,
  [250] = 239,
  [251] = 17,
  [252] = 29,
  [253] = 26,
  [254] = 183,
  [255] = 184,
  [256] = 183,
  [257] = 184,
  [258] = 23,
  [259] = 44,
  [260] = 38,
  [261] = 239,
  [262] = 30,
  [263] = 183,
  [264] = 66,
  [265] = 29,
  [266] = 23,
  [267] = 18,
  [268] = 54,
  [269] = 45,
  [270] = 60,
  [271] = 57,
  [272] = 68,
  [273] = 49,
  [274] = 39,
  [275] = 41,
  [276] = 19,
  [277] = 31,
  [278] = 26,
  [279] = 73,
  [280] = 183,
  [281] = 184,
  [282] = 183,
  [283] = 184,
  [284] = 28,
  [285] = 40,
  [286] = 33,
  [287] = 239,
  [288] = 59,
  [289] = 239,
  [290] = 63,
  [291] = 64,
  [292] = 65,
  [293] = 43,
  [294] = 46,
  [295] = 47,
  [296] = 48,
  [297] = 183,
  [298] = 184,
  [299] = 74,
  [300] = 75,
  [301] = 34,
  [302] = 35,
  [303] = 56,
  [304] = 36,
  [305] = 37,
  [306] = 30,
  [307] = 184,
  [308] = 183,
  [309] = 184,
  [310] = 239,
  [311] = 239,
  [312] = 32,
  [313] = 42,
  [314] = 183,
  [315] = 36,
  [316] = 37,
  [317] = 183,
  [318] = 184,
  [319] = 183,
  [320] = 184,
  [321] = 34,
  [322] = 184,
  [323] = 66,
  [324] = 184,
  [325] = 73,
  [326] = 184,
  [327] = 45,
  [328] = 60,
  [329] = 183,
  [330] = 49,
  [331] = 183,
  [332] = 39,
  [333] = 40,
  [334] = 57,
  [335] = 41,
  [336] = 19,
  [337] = 56,
  [338] = 33,
  [339] = 42,
  [340] = 59,
  [341] = 68,
  [342] = 18,
  [343] = 63,
  [344] = 64,
  [345] = 65,
  [346] = 43,
  [347] = 46,
  [348] = 47,
  [349] = 48,
  [350] = 183,
  [351] = 184,
  [352] = 74,
  [353] = 239,
  [354] = 239,
  [355] = 239,
  [356] = 75,
  [357] = 35,
  [358] = 183,
  [359] = 183,
  [360] = 183,
  [361] = 184,
  [362] = 184,
  [363] = 363,
  [364] = 183,
  [365] = 183,
  [366] = 184,
  [367] = 239,
  [368] = 239,
  [369] = 183,
  [370] = 183,
  [371] = 184,
  [372] = 184,
  [373] = 184,
  [374] = 184,
  [375] = 183,
  [376] = 184,
  [377] = 239,
  [378] = 378,
  [379] = 379,
  [380] = 184,
  [381] = 379,
  [382] = 183,
  [383] = 184,
  [384] = 378,
  [385] = 363,
  [386] = 183,
  [387] = 184,
  [388] = 183,
  [389] = 184,
  [390] = 379,
  [391] = 379,
  [392] = 183,
  [393] = 184,
  [394] = 183,
  [395] = 395,
  [396] = 183,
  [397] = 397,
  [398] = 239,
  [399] = 184,
  [400] = 239,
  [401] = 378,
  [402] = 378,
  [403] = 363,
  [404] = 183,
  [405] = 183,
  [406] = 184,
  [407] = 183,
  [408] = 184,
  [409] = 183,
  [410] = 184,
  [411] = 183,
  [412] = 184,
  [413] = 183,
  [414] = 184,
  [415] = 363,
  [416] = 397,
  [417] = 378,
  [418] = 379,
  [419] = 395,
  [420] = 378,
  [421] = 379,
  [422] = 184,
  [423] = 239,
  [424] = 239,
  [425] = 239,
  [426] = 426,
  [427] = 363,
  [428] = 378,
  [429] = 379,
  [430] = 183,
  [431] = 184,
  [432] = 363,
  [433] = 433,
  [434] = 378,
  [435] = 379,
  [436] = 433,
  [437] = 239,
  [438] = 438,
  [439] = 426,
  [440] = 183,
  [441] = 183,
  [442] = 239,
  [443] = 184,
  [444] = 239,
  [445] = 239,
  [446] = 184,
  [447] = 108,
  [448] = 448,
  [449] = 184,
  [450] = 363,
  [451] = 183,
  [452] = 239,
  [453] = 379,
  [454] = 184,
  [455] = 106,
  [456] = 378,
  [457] = 379,
  [458] = 183,
  [459] = 378,
  [460] = 363,
  [461] = 379,
  [462] = 184,
  [463] = 183,
  [464] = 464,
  [465] = 109,
  [466] = 184,
  [467] = 183,
  [468] = 107,
  [469] = 378,
  [470] = 378,
  [471] = 239,
  [472] = 239,
  [473] = 183,
  [474] = 474,
  [475] = 239,
  [476] = 239,
  [477] = 448,
  [478] = 184,
  [479] = 479,
  [480] = 480,
  [481] = 464,
  [482] = 378,
  [483] = 109,
  [484] = 379,
  [485] = 448,
  [486] = 379,
  [487] = 438,
  [488] = 107,
  [489] = 108,
  [490] = 106,
  [491] = 379,
  [492] = 239,
  [493] = 239,
  [494] = 239,
  [495] = 495,
  [496] = 378,
  [497] = 448,
  [498] = 378,
  [499] = 495,
  [500] = 239,
  [501] = 239,
  [502] = 379,
  [503] = 239,
  [504] = 239,
  [505] = 239,
  [506] = 378,
  [507] = 479,
  [508] = 379,
  [509] = 183,
  [510] = 480,
  [511] = 184,
  [512] = 239,
  [513] = 474,
  [514] = 239,
  [515] = 515,
  [516] = 448,
  [517] = 517,
  [518] = 515,
  [519] = 519,
  [520] = 363,
  [521] = 519,
  [522] = 519,
  [523] = 519,
  [524] = 519,
  [525] = 239,
  [526] = 239,
  [527] = 239,
  [528] = 239,
  [529] = 239,
  [530] = 239,
  [531] = 531,
  [532] = 517,
  [533] = 378,
  [534] = 379,
  [535] = 378,
  [536] = 379,
  [537] = 378,
  [538] = 379,
  [539] = 539,
  [540] = 540,
  [541] = 541,
  [542] = 239,
  [543] = 239,
  [544] = 239,
  [545] = 239,
  [546] = 546,
  [547] = 546,
  [548] = 239,
  [549] = 363,
  [550] = 531,
  [551] = 378,
  [552] = 379,
  [553] = 378,
  [554] = 379,
  [555] = 378,
  [556] = 379,
  [557] = 378,
  [558] = 379,
  [559] = 378,
  [560] = 379,
  [561] = 239,
  [562] = 540,
  [563] = 239,
  [564] = 539,
  [565] = 363,
  [566] = 539,
  [567] = 567,
  [568] = 363,
  [569] = 569,
  [570] = 448,
  [571] = 541,
  [572] = 363,
  [573] = 448,
  [574] = 378,
  [575] = 379,
  [576] = 378,
  [577] = 378,
  [578] = 378,
  [579] = 379,
  [580] = 378,
  [581] = 379,
  [582] = 363,
  [583] = 379,
  [584] = 378,
  [585] = 239,
  [586] = 363,
  [587] = 379,
  [588] = 239,
  [589] = 239,
  [590] = 239,
  [591] = 378,
  [592] = 539,
  [593] = 567,
  [594] = 379,
  [595] = 569,
  [596] = 448,
  [597] = 239,
  [598] = 567,
  [599] = 569,
  [600] = 539,
  [601] = 239,
  [602] = 239,
  [603] = 379,
  [604] = 378,
  [605] = 567,
  [606] = 567,
  [607] = 569,
  [608] = 448,
  [609] = 378,
  [610] = 379,
  [611] = 378,
  [612] = 379,
  [613] = 539,
  [614] = 378,
  [615] = 379,
  [616] = 378,
  [617] = 363,
  [618] = 379,
  [619] = 539,
  [620] = 378,
  [621] = 379,
  [622] = 379,
  [623] = 379,
  [624] = 363,
  [625] = 448,
  [626] = 378,
  [627] = 569,
  [628] = 363,
  [629] = 448,
  [630] = 630,
  [631] = 569,
  [632] = 448,
  [633] = 633,
  [634] = 633,
  [635] = 633,
  [636] = 633,
  [637] = 378,
  [638] = 363,
  [639] = 379,
  [640] = 569,
  [641] = 378,
  [642] = 379,
  [643] = 378,
  [644] = 567,
  [645] = 378,
  [646] = 379,
  [647] = 647,
  [648] = 378,
  [649] = 379,
  [650] = 239,
  [651] = 378,
  [652] = 379,
  [653] = 633,
  [654] = 654,
  [655] = 363,
  [656] = 363,
  [657] = 567,
  [658] = 539,
  [659] = 363,
  [660] = 448,
  [661] = 448,
  [662] = 379,
  [663] = 663,
  [664] = 378,
  [665] = 379,
  [666] = 378,
  [667] = 379,
  [668] = 379,
  [669] = 378,
  [670] = 379,
  [671] = 539,
  [672] = 378,
  [673] = 363,
  [674] = 379,
  [675] = 567,
  [676] = 378,
  [677] = 569,
  [678] = 378,
  [679] = 448,
  [680] = 448,
  [681] = 448,
  [682] = 379,
  [683] = 378,
  [684] = 379,
  [685] = 630,
  [686] = 686,
  [687] = 378,
  [688] = 379,
  [689] = 378,
  [690] = 379,
  [691] = 363,
  [692] = 539,
  [693] = 378,
  [694] = 379,
  [695] = 378,
  [696] = 379,
  [697] = 686,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 704,
  [705] = 705,
  [706] = 703,
  [707] = 707,
  [708] = 700,
  [709] = 686,
  [710] = 703,
  [711] = 698,
  [712] = 663,
  [713] = 378,
  [714] = 714,
  [715] = 379,
  [716] = 686,
  [717] = 686,
  [718] = 703,
  [719] = 704,
  [720] = 663,
  [721] = 721,
  [722] = 448,
  [723] = 723,
  [724] = 448,
  [725] = 705,
  [726] = 698,
  [727] = 703,
  [728] = 698,
  [729] = 378,
  [730] = 379,
  [731] = 379,
  [732] = 378,
  [733] = 698,
  [734] = 734,
  [735] = 448,
  [736] = 736,
  [737] = 701,
  [738] = 714,
  [739] = 702,
  [740] = 740,
  [741] = 723,
  [742] = 742,
  [743] = 721,
  [744] = 699,
  [745] = 745,
  [746] = 379,
  [747] = 747,
  [748] = 448,
  [749] = 747,
  [750] = 745,
  [751] = 745,
  [752] = 747,
  [753] = 745,
  [754] = 745,
  [755] = 747,
  [756] = 378,
  [757] = 747,
  [758] = 758,
  [759] = 759,
  [760] = 759,
  [761] = 759,
  [762] = 759,
  [763] = 759,
  [764] = 764,
  [765] = 759,
  [766] = 759,
  [767] = 764,
  [768] = 759,
  [769] = 769,
  [770] = 769,
  [771] = 771,
  [772] = 772,
  [773] = 771,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 776,
  [778] = 778,
  [779] = 778,
  [780] = 775,
  [781] = 774,
  [782] = 776,
  [783] = 783,
  [784] = 783,
  [785] = 783,
  [786] = 783,
  [787] = 787,
  [788] = 788,
  [789] = 787,
  [790] = 787,
  [791] = 791,
  [792] = 787,
  [793] = 787,
  [794] = 791,
  [795] = 783,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 799,
  [801] = 801,
  [802] = 801,
  [803] = 797,
  [804] = 804,
  [805] = 805,
  [806] = 804,
  [807] = 799,
  [808] = 799,
  [809] = 797,
  [810] = 804,
  [811] = 811,
  [812] = 798,
  [813] = 805,
  [814] = 798,
  [815] = 804,
  [816] = 804,
  [817] = 796,
  [818] = 798,
  [819] = 797,
  [820] = 820,
  [821] = 811,
  [822] = 797,
  [823] = 820,
  [824] = 824,
  [825] = 799,
  [826] = 798,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 827,
  [837] = 837,
  [838] = 838,
  [839] = 827,
  [840] = 840,
  [841] = 841,
  [842] = 841,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 835,
  [853] = 853,
  [854] = 828,
  [855] = 827,
  [856] = 841,
  [857] = 843,
  [858] = 858,
  [859] = 859,
  [860] = 843,
  [861] = 827,
  [862] = 841,
  [863] = 843,
  [864] = 844,
  [865] = 827,
  [866] = 845,
  [867] = 843,
  [868] = 868,
  [869] = 833,
  [870] = 870,
  [871] = 837,
  [872] = 872,
  [873] = 846,
  [874] = 847,
  [875] = 840,
  [876] = 848,
  [877] = 877,
  [878] = 827,
  [879] = 843,
  [880] = 880,
  [881] = 877,
  [882] = 838,
  [883] = 877,
  [884] = 849,
  [885] = 877,
  [886] = 877,
  [887] = 877,
  [888] = 835,
  [889] = 880,
  [890] = 827,
  [891] = 841,
  [892] = 843,
  [893] = 868,
  [894] = 849,
  [895] = 868,
  [896] = 850,
  [897] = 868,
  [898] = 868,
  [899] = 877,
  [900] = 849,
  [901] = 835,
  [902] = 827,
  [903] = 841,
  [904] = 843,
  [905] = 849,
  [906] = 827,
  [907] = 841,
  [908] = 843,
  [909] = 827,
  [910] = 841,
  [911] = 843,
  [912] = 827,
  [913] = 843,
  [914] = 877,
  [915] = 827,
  [916] = 843,
  [917] = 835,
  [918] = 827,
  [919] = 841,
  [920] = 843,
  [921] = 877,
  [922] = 851,
  [923] = 849,
  [924] = 835,
  [925] = 827,
  [926] = 841,
  [927] = 843,
  [928] = 849,
  [929] = 827,
  [930] = 843,
  [931] = 827,
  [932] = 843,
  [933] = 827,
  [934] = 843,
  [935] = 877,
  [936] = 827,
  [937] = 843,
  [938] = 835,
  [939] = 827,
  [940] = 841,
  [941] = 843,
  [942] = 877,
  [943] = 849,
  [944] = 835,
  [945] = 827,
  [946] = 841,
  [947] = 843,
  [948] = 849,
  [949] = 877,
  [950] = 827,
  [951] = 853,
  [952] = 843,
  [953] = 877,
  [954] = 827,
  [955] = 841,
  [956] = 843,
  [957] = 849,
  [958] = 877,
  [959] = 827,
  [960] = 841,
  [961] = 843,
  [962] = 877,
  [963] = 827,
  [964] = 841,
  [965] = 843,
  [966] = 877,
  [967] = 827,
  [968] = 841,
  [969] = 843,
  [970] = 877,
  [971] = 827,
  [972] = 841,
  [973] = 843,
  [974] = 877,
  [975] = 827,
  [976] = 841,
  [977] = 843,
  [978] = 978,
  [979] = 877,
  [980] = 827,
  [981] = 841,
  [982] = 843,
  [983] = 877,
  [984] = 827,
  [985] = 841,
  [986] = 843,
  [987] = 827,
  [988] = 841,
  [989] = 843,
  [990] = 877,
  [991] = 827,
  [992] = 841,
  [993] = 843,
  [994] = 827,
  [995] = 841,
  [996] = 843,
  [997] = 827,
  [998] = 843,
  [999] = 827,
  [1000] = 843,
  [1001] = 827,
  [1002] = 843,
  [1003] = 827,
  [1004] = 843,
  [1005] = 827,
  [1006] = 843,
  [1007] = 827,
  [1008] = 843,
  [1009] = 827,
  [1010] = 843,
  [1011] = 827,
  [1012] = 843,
  [1013] = 827,
  [1014] = 843,
  [1015] = 827,
  [1016] = 843,
  [1017] = 827,
  [1018] = 843,
  [1019] = 827,
  [1020] = 843,
  [1021] = 827,
  [1022] = 843,
  [1023] = 827,
  [1024] = 843,
  [1025] = 827,
  [1026] = 843,
  [1027] = 827,
  [1028] = 843,
  [1029] = 827,
  [1030] = 843,
  [1031] = 827,
  [1032] = 843,
  [1033] = 827,
  [1034] = 843,
  [1035] = 827,
  [1036] = 843,
  [1037] = 827,
  [1038] = 843,
  [1039] = 827,
  [1040] = 843,
  [1041] = 827,
  [1042] = 843,
  [1043] = 843,
  [1044] = 827,
  [1045] = 843,
  [1046] = 827,
  [1047] = 843,
  [1048] = 827,
  [1049] = 843,
  [1050] = 829,
  [1051] = 830,
  [1052] = 831,
  [1053] = 841,
  [1054] = 1054,
  [1055] = 1054,
  [1056] = 1054,
  [1057] = 1054,
  [1058] = 1054,
  [1059] = 1054,
  [1060] = 1054,
  [1061] = 1054,
  [1062] = 1054,
  [1063] = 1054,
  [1064] = 1054,
  [1065] = 1054,
  [1066] = 1054,
  [1067] = 1054,
  [1068] = 1054,
  [1069] = 1054,
  [1070] = 1054,
  [1071] = 1054,
  [1072] = 1054,
  [1073] = 1054,
  [1074] = 1054,
  [1075] = 1054,
  [1076] = 1054,
  [1077] = 1054,
  [1078] = 1054,
  [1079] = 1054,
  [1080] = 1054,
  [1081] = 1054,
  [1082] = 1054,
  [1083] = 1054,
  [1084] = 1054,
  [1085] = 1054,
  [1086] = 1054,
  [1087] = 1054,
  [1088] = 1054,
  [1089] = 1054,
  [1090] = 1054,
  [1091] = 1054,
  [1092] = 1054,
  [1093] = 1054,
  [1094] = 1054,
  [1095] = 1054,
  [1096] = 1054,
  [1097] = 1054,
  [1098] = 1054,
  [1099] = 1054,
  [1100] = 1054,
  [1101] = 1054,
  [1102] = 1054,
  [1103] = 1054,
  [1104] = 1054,
  [1105] = 1054,
  [1106] = 1054,
  [1107] = 1054,
  [1108] = 1054,
  [1109] = 1054,
  [1110] = 1054,
  [1111] = 1054,
  [1112] = 1054,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1119,
  [1120] = 1120,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1124,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1124,
  [1128] = 1128,
  [1129] = 1129,
  [1130] = 1120,
  [1131] = 1119,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 1118,
  [1137] = 1137,
  [1138] = 1138,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1141,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1144,
  [1145] = 1145,
  [1146] = 1146,
  [1147] = 1146,
  [1148] = 1138,
  [1149] = 1149,
  [1150] = 1150,
  [1151] = 1151,
  [1152] = 1152,
  [1153] = 1153,
  [1154] = 1152,
  [1155] = 1153,
  [1156] = 1150,
  [1157] = 1157,
  [1158] = 1158,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1162,
  [1163] = 1163,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1166,
  [1167] = 1167,
  [1168] = 1168,
  [1169] = 1169,
  [1170] = 1159,
  [1171] = 1171,
  [1172] = 1162,
  [1173] = 1157,
  [1174] = 1164,
  [1175] = 1175,
  [1176] = 1176,
  [1177] = 1166,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1180,
  [1181] = 1158,
  [1182] = 1182,
  [1183] = 1167,
  [1184] = 1161,
  [1185] = 1185,
  [1186] = 1165,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1160,
  [1191] = 1163,
  [1192] = 184,
  [1193] = 183,
  [1194] = 1194,
  [1195] = 1195,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1198,
  [1200] = 1197,
  [1201] = 1194,
  [1202] = 1195,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1205,
  [1206] = 1206,
  [1207] = 1207,
  [1208] = 1196,
  [1209] = 1209,
  [1210] = 1210,
  [1211] = 1211,
  [1212] = 1206,
  [1213] = 1213,
  [1214] = 1214,
  [1215] = 1215,
  [1216] = 1216,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1204,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1204,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1207,
  [1232] = 1232,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1236,
  [1237] = 1237,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1240,
  [1241] = 1241,
  [1242] = 1242,
  [1243] = 1243,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1246,
  [1247] = 1213,
  [1248] = 1232,
  [1249] = 1249,
  [1250] = 1209,
  [1251] = 1240,
  [1252] = 1242,
  [1253] = 1253,
  [1254] = 1204,
  [1255] = 1227,
  [1256] = 1256,
  [1257] = 1204,
  [1258] = 1204,
  [1259] = 1259,
  [1260] = 1215,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 1241,
  [1264] = 1264,
  [1265] = 1223,
  [1266] = 1266,
  [1267] = 1214,
  [1268] = 1268,
  [1269] = 1234,
  [1270] = 1238,
  [1271] = 1225,
  [1272] = 1272,
  [1273] = 1219,
  [1274] = 1226,
  [1275] = 1239,
  [1276] = 1210,
  [1277] = 1235,
  [1278] = 1278,
  [1279] = 1279,
  [1280] = 1211,
  [1281] = 1281,
  [1282] = 1259,
  [1283] = 1230,
  [1284] = 1284,
  [1285] = 1285,
  [1286] = 1286,
  [1287] = 1287,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1290,
  [1291] = 1291,
  [1292] = 1292,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 1295,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1204,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 1305,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 2,
  [1309] = 1309,
  [1310] = 1310,
  [1311] = 1311,
  [1312] = 1312,
  [1313] = 1312,
  [1314] = 1314,
  [1315] = 1315,
  [1316] = 1316,
  [1317] = 1261,
  [1318] = 1318,
  [1319] = 1319,
  [1320] = 1319,
  [1321] = 1306,
  [1322] = 1322,
  [1323] = 1323,
  [1324] = 1324,
  [1325] = 1204,
  [1326] = 1298,
  [1327] = 1296,
  [1328] = 1324,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1332,
  [1333] = 1333,
  [1334] = 1334,
  [1335] = 1188,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 1339,
  [1340] = 1340,
  [1341] = 1272,
  [1342] = 1304,
  [1343] = 1343,
  [1344] = 1344,
  [1345] = 1345,
  [1346] = 1264,
  [1347] = 1347,
  [1348] = 1293,
  [1349] = 1338,
  [1350] = 1350,
  [1351] = 1288,
  [1352] = 1352,
  [1353] = 1287,
  [1354] = 1354,
  [1355] = 1281,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1311,
  [1359] = 1300,
  [1360] = 1360,
  [1361] = 1337,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1316,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 1295,
  [1373] = 1305,
  [1374] = 1374,
  [1375] = 1333,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1382,
  [1383] = 1383,
  [1384] = 1384,
  [1385] = 1385,
  [1386] = 1386,
  [1387] = 1387,
  [1388] = 1388,
  [1389] = 1389,
  [1390] = 1390,
  [1391] = 1391,
  [1392] = 1347,
  [1393] = 1393,
  [1394] = 1394,
  [1395] = 1395,
  [1396] = 1396,
  [1397] = 1397,
  [1398] = 1398,
  [1399] = 1399,
  [1400] = 1400,
  [1401] = 1401,
  [1402] = 1329,
  [1403] = 1403,
  [1404] = 1345,
  [1405] = 1405,
  [1406] = 1406,
  [1407] = 1407,
  [1408] = 1408,
  [1409] = 239,
  [1410] = 1410,
  [1411] = 1411,
  [1412] = 1412,
  [1413] = 1413,
  [1414] = 1413,
  [1415] = 1415,
  [1416] = 1416,
  [1417] = 1398,
  [1418] = 1413,
  [1419] = 1419,
  [1420] = 1420,
  [1421] = 1407,
  [1422] = 1413,
  [1423] = 1423,
  [1424] = 1424,
  [1425] = 1394,
  [1426] = 1399,
  [1427] = 1400,
  [1428] = 1428,
  [1429] = 1385,
  [1430] = 1380,
  [1431] = 1431,
  [1432] = 1401,
  [1433] = 1382,
  [1434] = 1204,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1386,
  [1439] = 1439,
  [1440] = 1383,
  [1441] = 1441,
  [1442] = 1388,
  [1443] = 1443,
  [1444] = 1444,
  [1445] = 1445,
  [1446] = 1446,
  [1447] = 1447,
  [1448] = 1448,
  [1449] = 1395,
  [1450] = 1396,
  [1451] = 1451,
  [1452] = 1452,
  [1453] = 1453,
  [1454] = 1454,
  [1455] = 1455,
  [1456] = 1456,
  [1457] = 1457,
  [1458] = 1458,
  [1459] = 1387,
  [1460] = 1397,
  [1461] = 1413,
  [1462] = 1462,
  [1463] = 1463,
  [1464] = 1464,
  [1465] = 1411,
  [1466] = 1405,
  [1467] = 1467,
  [1468] = 1468,
  [1469] = 1469,
  [1470] = 1470,
  [1471] = 1390,
  [1472] = 1472,
  [1473] = 1473,
  [1474] = 1474,
  [1475] = 1475,
  [1476] = 1476,
  [1477] = 1477,
  [1478] = 1478,
  [1479] = 1479,
  [1480] = 1295,
  [1481] = 1305,
  [1482] = 1482,
  [1483] = 1483,
  [1484] = 1484,
  [1485] = 1403,
  [1486] = 1486,
  [1487] = 1413,
  [1488] = 1488,
  [1489] = 1489,
  [1490] = 1490,
  [1491] = 1490,
  [1492] = 1490,
  [1493] = 1490,
  [1494] = 1490,
  [1495] = 1490,
  [1496] = 1490,
  [1497] = 1490,
  [1498] = 1490,
  [1499] = 1490,
  [1500] = 1490,
  [1501] = 1501,
  [1502] = 1490,
  [1503] = 1490,
  [1504] = 1490,
  [1505] = 1490,
  [1506] = 1490,
  [1507] = 1490,
  [1508] = 1490,
  [1509] = 1490,
  [1510] = 1490,
  [1511] = 1490,
  [1512] = 1490,
  [1513] = 1513,
  [1514] = 1514,
  [1515] = 1490,
  [1516] = 1490,
  [1517] = 1490,
  [1518] = 1490,
  [1519] = 1490,
  [1520] = 1520,
  [1521] = 1490,
  [1522] = 1522,
  [1523] = 1523,
  [1524] = 1490,
  [1525] = 1525,
  [1526] = 183,
  [1527] = 1527,
  [1528] = 184,
  [1529] = 1490,
  [1530] = 1530,
  [1531] = 1464,
  [1532] = 1490,
  [1533] = 1533,
  [1534] = 1490,
  [1535] = 1484,
  [1536] = 1536,
  [1537] = 1490,
  [1538] = 1538,
  [1539] = 1539,
  [1540] = 1490,
  [1541] = 1541,
  [1542] = 1490,
  [1543] = 1543,
  [1544] = 1490,
  [1545] = 1437,
  [1546] = 1546,
  [1547] = 1365,
  [1548] = 1490,
  [1549] = 1549,
  [1550] = 1550,
  [1551] = 1490,
  [1552] = 1490,
  [1553] = 1490,
  [1554] = 1204,
  [1555] = 1357,
  [1556] = 1204,
  [1557] = 1557,
  [1558] = 1490,
  [1559] = 1559,
  [1560] = 1560,
  [1561] = 1490,
  [1562] = 1490,
  [1563] = 1490,
  [1564] = 1456,
  [1565] = 1565,
  [1566] = 1566,
  [1567] = 1567,
  [1568] = 1568,
  [1569] = 1490,
  [1570] = 1490,
  [1571] = 1571,
  [1572] = 1572,
  [1573] = 1573,
  [1574] = 1574,
  [1575] = 1490,
  [1576] = 1576,
  [1577] = 1490,
  [1578] = 1578,
  [1579] = 1490,
  [1580] = 1445,
  [1581] = 1204,
  [1582] = 1582,
  [1583] = 1583,
  [1584] = 1584,
  [1585] = 1585,
  [1586] = 1428,
  [1587] = 1587,
  [1588] = 1490,
  [1589] = 1589,
  [1590] = 1490,
  [1591] = 1591,
  [1592] = 1490,
  [1593] = 1490,
  [1594] = 1490,
  [1595] = 1490,
  [1596] = 1437,
  [1597] = 1597,
  [1598] = 1490,
  [1599] = 1490,
  [1600] = 1370,
  [1601] = 1371,
  [1602] = 1602,
  [1603] = 1490,
  [1604] = 1490,
  [1605] = 1295,
  [1606] = 1305,
  [1607] = 1490,
  [1608] = 1490,
  [1609] = 1609,
  [1610] = 1566,
  [1611] = 1489,
  [1612] = 1612,
  [1613] = 1613,
  [1614] = 1559,
  [1615] = 1615,
  [1616] = 1616,
  [1617] = 1617,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1624,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1629,
  [1630] = 1560,
  [1631] = 1631,
  [1632] = 1632,
  [1633] = 1633,
  [1634] = 1634,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1639,
  [1640] = 1640,
  [1641] = 1641,
  [1642] = 1642,
  [1643] = 1520,
  [1644] = 1644,
  [1645] = 1538,
  [1646] = 1646,
  [1647] = 1647,
  [1648] = 1648,
  [1649] = 1649,
  [1650] = 1650,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 1654,
  [1655] = 1655,
  [1656] = 1656,
  [1657] = 1204,
  [1658] = 1567,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1583,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1204,
  [1666] = 1541,
  [1667] = 1568,
  [1668] = 1567,
  [1669] = 1669,
  [1670] = 1437,
  [1671] = 1671,
  [1672] = 1578,
  [1673] = 1585,
  [1674] = 1543,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1204,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1536,
  [1682] = 1549,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1689,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1541,
  [1693] = 1437,
  [1694] = 1572,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1697,
  [1698] = 1698,
  [1699] = 1571,
  [1700] = 1609,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1703,
  [1704] = 1703,
  [1705] = 1705,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 1708,
  [1709] = 1709,
  [1710] = 1710,
  [1711] = 1711,
  [1712] = 1712,
  [1713] = 1702,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1716,
  [1717] = 1717,
  [1718] = 44,
  [1719] = 1719,
  [1720] = 1567,
  [1721] = 1701,
  [1722] = 1722,
  [1723] = 44,
  [1724] = 44,
  [1725] = 44,
  [1726] = 1726,
  [1727] = 1727,
  [1728] = 1728,
  [1729] = 1729,
  [1730] = 1730,
  [1731] = 1731,
  [1732] = 1732,
  [1733] = 1733,
  [1734] = 1734,
  [1735] = 1735,
  [1736] = 1736,
  [1737] = 1659,
  [1738] = 1636,
  [1739] = 1703,
  [1740] = 1740,
  [1741] = 1741,
  [1742] = 1567,
  [1743] = 1702,
  [1744] = 1744,
  [1745] = 1745,
  [1746] = 1746,
  [1747] = 1726,
  [1748] = 1748,
  [1749] = 1204,
  [1750] = 1204,
  [1751] = 1541,
  [1752] = 1752,
  [1753] = 1753,
  [1754] = 1204,
  [1755] = 1755,
  [1756] = 1437,
  [1757] = 1757,
  [1758] = 1703,
  [1759] = 1702,
  [1760] = 1726,
  [1761] = 1761,
  [1762] = 1762,
  [1763] = 1726,
  [1764] = 1764,
  [1765] = 1703,
  [1766] = 1766,
  [1767] = 1702,
  [1768] = 1726,
  [1769] = 1769,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1772,
  [1773] = 1697,
  [1774] = 1698,
  [1775] = 1541,
  [1776] = 1697,
  [1777] = 1698,
  [1778] = 1638,
  [1779] = 1639,
  [1780] = 1437,
  [1781] = 1781,
  [1782] = 1782,
  [1783] = 1783,
  [1784] = 1784,
  [1785] = 1785,
  [1786] = 1786,
  [1787] = 1787,
  [1788] = 1788,
  [1789] = 1789,
  [1790] = 1790,
  [1791] = 1791,
  [1792] = 1792,
  [1793] = 1793,
  [1794] = 1697,
  [1795] = 1795,
  [1796] = 1698,
  [1797] = 1797,
  [1798] = 1798,
  [1799] = 1786,
  [1800] = 1800,
  [1801] = 1204,
  [1802] = 1786,
  [1803] = 1803,
  [1804] = 1804,
  [1805] = 1805,
  [1806] = 1806,
  [1807] = 1807,
  [1808] = 1808,
  [1809] = 1809,
  [1810] = 1567,
  [1811] = 1729,
  [1812] = 1812,
  [1813] = 1813,
  [1814] = 1814,
  [1815] = 1815,
  [1816] = 1816,
  [1817] = 1817,
  [1818] = 1732,
  [1819] = 1819,
  [1820] = 1748,
  [1821] = 1814,
  [1822] = 1822,
  [1823] = 1823,
  [1824] = 1740,
  [1825] = 1825,
  [1826] = 1204,
  [1827] = 1827,
  [1828] = 1828,
  [1829] = 1728,
  [1830] = 1830,
  [1831] = 1204,
  [1832] = 1832,
  [1833] = 1833,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1836,
  [1837] = 1437,
  [1838] = 1838,
  [1839] = 1839,
  [1840] = 1840,
  [1841] = 1841,
  [1842] = 1842,
  [1843] = 1843,
  [1844] = 1844,
  [1845] = 1204,
  [1846] = 1846,
  [1847] = 1795,
  [1848] = 1848,
  [1849] = 1541,
  [1850] = 1850,
  [1851] = 1851,
  [1852] = 1852,
  [1853] = 1853,
  [1854] = 1814,
  [1855] = 1855,
  [1856] = 1856,
  [1857] = 1786,
  [1858] = 1858,
  [1859] = 1859,
  [1860] = 1860,
  [1861] = 1861,
  [1862] = 1862,
  [1863] = 1863,
  [1864] = 1864,
  [1865] = 1865,
  [1866] = 1866,
  [1867] = 1867,
  [1868] = 1868,
  [1869] = 1869,
  [1870] = 1870,
  [1871] = 1871,
  [1872] = 1872,
  [1873] = 1873,
  [1874] = 1874,
  [1875] = 1814,
  [1876] = 1838,
  [1877] = 1295,
  [1878] = 1838,
  [1879] = 1731,
  [1880] = 1880,
  [1881] = 1814,
  [1882] = 1838,
  [1883] = 1795,
  [1884] = 1697,
  [1885] = 1698,
  [1886] = 1886,
  [1887] = 1814,
  [1888] = 1888,
  [1889] = 1305,
  [1890] = 1838,
  [1891] = 1891,
  [1892] = 1892,
  [1893] = 1795,
  [1894] = 1795,
  [1895] = 1895,
  [1896] = 1896,
  [1897] = 1786,
  [1898] = 1898,
  [1899] = 1899,
  [1900] = 1730,
  [1901] = 1901,
  [1902] = 1838,
  [1903] = 1727,
  [1904] = 1904,
  [1905] = 1905,
  [1906] = 1906,
  [1907] = 1907,
  [1908] = 1908,
  [1909] = 1909,
  [1910] = 1910,
  [1911] = 1295,
  [1912] = 1912,
  [1913] = 1913,
  [1914] = 1914,
  [1915] = 1305,
  [1916] = 1437,
  [1917] = 1917,
  [1918] = 1918,
  [1919] = 1204,
  [1920] = 1920,
  [1921] = 1921,
  [1922] = 1922,
  [1923] = 1923,
  [1924] = 1698,
  [1925] = 1697,
  [1926] = 1926,
  [1927] = 1927,
  [1928] = 1928,
  [1929] = 1929,
  [1930] = 1930,
  [1931] = 2,
  [1932] = 1932,
  [1933] = 1933,
  [1934] = 1934,
  [1935] = 1935,
  [1936] = 1936,
  [1937] = 1937,
  [1938] = 1938,
  [1939] = 1939,
  [1940] = 1940,
  [1941] = 1698,
  [1942] = 1942,
  [1943] = 1943,
  [1944] = 1927,
  [1945] = 1945,
  [1946] = 1697,
  [1947] = 1947,
  [1948] = 1948,
  [1949] = 1949,
  [1950] = 1950,
  [1951] = 1951,
  [1952] = 1952,
  [1953] = 1953,
  [1954] = 1954,
  [1955] = 1955,
  [1956] = 1956,
  [1957] = 1957,
  [1958] = 1958,
  [1959] = 1959,
  [1960] = 1960,
  [1961] = 1961,
  [1962] = 1952,
  [1963] = 1954,
  [1964] = 1964,
  [1965] = 1965,
  [1966] = 1966,
  [1967] = 1967,
  [1968] = 1968,
  [1969] = 1969,
  [1970] = 1970,
  [1971] = 1954,
  [1972] = 1934,
  [1973] = 1973,
  [1974] = 1935,
  [1975] = 1975,
  [1976] = 1976,
  [1977] = 1977,
  [1978] = 1978,
  [1979] = 1979,
  [1980] = 1980,
  [1981] = 1981,
  [1982] = 1939,
  [1983] = 1942,
  [1984] = 1984,
  [1985] = 1985,
  [1986] = 1986,
  [1987] = 1987,
  [1988] = 1988,
  [1989] = 1989,
  [1990] = 1990,
  [1991] = 1945,
  [1992] = 1917,
  [1993] = 1993,
  [1994] = 1994,
  [1995] = 1995,
  [1996] = 1996,
  [1997] = 1997,
  [1998] = 1998,
  [1999] = 1920,
  [2000] = 1909,
  [2001] = 2001,
  [2002] = 2002,
  [2003] = 1907,
  [2004] = 2004,
  [2005] = 2005,
  [2006] = 2006,
  [2007] = 2007,
  [2008] = 2008,
  [2009] = 2009,
  [2010] = 1952,
  [2011] = 2011,
  [2012] = 2012,
  [2013] = 2013,
  [2014] = 2014,
  [2015] = 2015,
  [2016] = 2016,
  [2017] = 2017,
  [2018] = 2018,
  [2019] = 2019,
  [2020] = 2020,
  [2021] = 2021,
  [2022] = 2022,
  [2023] = 2023,
  [2024] = 2024,
  [2025] = 2025,
  [2026] = 2026,
  [2027] = 2027,
  [2028] = 1952,
  [2029] = 2029,
  [2030] = 1954,
  [2031] = 2031,
  [2032] = 2025,
  [2033] = 2033,
  [2034] = 2034,
  [2035] = 2035,
  [2036] = 2036,
  [2037] = 2018,
  [2038] = 2038,
  [2039] = 1964,
  [2040] = 2009,
  [2041] = 2041,
  [2042] = 2042,
  [2043] = 2043,
  [2044] = 2044,
  [2045] = 2045,
  [2046] = 2002,
  [2047] = 2047,
  [2048] = 2048,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 2025,
  [2052] = 2052,
  [2053] = 2053,
  [2054] = 2054,
  [2055] = 1964,
  [2056] = 1437,
  [2057] = 2057,
  [2058] = 2058,
  [2059] = 1697,
  [2060] = 2060,
  [2061] = 2061,
  [2062] = 2062,
  [2063] = 2063,
  [2064] = 2064,
  [2065] = 2065,
  [2066] = 2017,
  [2067] = 2002,
  [2068] = 2068,
  [2069] = 1950,
  [2070] = 2070,
  [2071] = 2071,
  [2072] = 2072,
  [2073] = 2043,
  [2074] = 2074,
  [2075] = 2075,
  [2076] = 2076,
  [2077] = 2077,
  [2078] = 2078,
  [2079] = 2079,
  [2080] = 2080,
  [2081] = 2081,
  [2082] = 2002,
  [2083] = 2083,
  [2084] = 2084,
  [2085] = 2085,
  [2086] = 2086,
  [2087] = 2002,
  [2088] = 2088,
  [2089] = 2089,
  [2090] = 2090,
  [2091] = 2002,
  [2092] = 2002,
  [2093] = 2093,
  [2094] = 2094,
  [2095] = 2095,
  [2096] = 2096,
  [2097] = 2097,
  [2098] = 1954,
  [2099] = 2099,
  [2100] = 2100,
  [2101] = 2101,
  [2102] = 1949,
  [2103] = 2103,
  [2104] = 2104,
  [2105] = 2105,
  [2106] = 2106,
  [2107] = 2107,
  [2108] = 2108,
  [2109] = 2109,
  [2110] = 2110,
  [2111] = 2111,
  [2112] = 2077,
  [2113] = 2113,
  [2114] = 2114,
  [2115] = 2115,
  [2116] = 1964,
  [2117] = 2117,
  [2118] = 2118,
  [2119] = 2119,
  [2120] = 2120,
  [2121] = 2121,
  [2122] = 2122,
  [2123] = 2123,
  [2124] = 2124,
  [2125] = 2125,
  [2126] = 2126,
  [2127] = 2127,
  [2128] = 2128,
  [2129] = 2129,
  [2130] = 2130,
  [2131] = 2131,
  [2132] = 2132,
  [2133] = 2133,
  [2134] = 2134,
  [2135] = 2135,
  [2136] = 2136,
  [2137] = 1929,
  [2138] = 2138,
  [2139] = 2139,
  [2140] = 2140,
  [2141] = 2141,
  [2142] = 2142,
  [2143] = 2013,
  [2144] = 2144,
  [2145] = 2145,
  [2146] = 1964,
  [2147] = 2147,
  [2148] = 2148,
  [2149] = 1698,
  [2150] = 2150,
  [2151] = 1204,
  [2152] = 2152,
  [2153] = 2153,
  [2154] = 2154,
  [2155] = 2155,
  [2156] = 2156,
  [2157] = 2157,
  [2158] = 1964,
  [2159] = 2020,
  [2160] = 2025,
  [2161] = 2021,
  [2162] = 2162,
  [2163] = 1952,
  [2164] = 2043,
  [2165] = 2002,
  [2166] = 1954,
  [2167] = 2167,
  [2168] = 2168,
  [2169] = 2169,
  [2170] = 2170,
  [2171] = 2025,
  [2172] = 2172,
  [2173] = 2043,
  [2174] = 2174,
  [2175] = 2175,
  [2176] = 2002,
  [2177] = 2177,
  [2178] = 2178,
  [2179] = 2179,
  [2180] = 2002,
  [2181] = 2181,
  [2182] = 2043,
  [2183] = 2183,
  [2184] = 2184,
  [2185] = 2140,
  [2186] = 2036,
  [2187] = 2187,
  [2188] = 2025,
  [2189] = 2189,
  [2190] = 2043,
  [2191] = 2121,
  [2192] = 2192,
  [2193] = 2193,
  [2194] = 2194,
  [2195] = 2195,
  [2196] = 2196,
  [2197] = 2197,
  [2198] = 2198,
  [2199] = 2199,
  [2200] = 2200,
  [2201] = 2201,
  [2202] = 2201,
  [2203] = 2203,
  [2204] = 2193,
  [2205] = 2205,
  [2206] = 2206,
  [2207] = 2207,
  [2208] = 2208,
  [2209] = 2209,
  [2210] = 2210,
  [2211] = 2211,
  [2212] = 2201,
  [2213] = 2213,
  [2214] = 2209,
  [2215] = 2203,
  [2216] = 2216,
  [2217] = 2217,
  [2218] = 2218,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2206,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 2226,
  [2227] = 2227,
  [2228] = 2228,
  [2229] = 239,
  [2230] = 2230,
  [2231] = 2231,
  [2232] = 2232,
  [2233] = 2208,
  [2234] = 2234,
  [2235] = 2201,
  [2236] = 2236,
  [2237] = 2237,
  [2238] = 2238,
  [2239] = 2239,
  [2240] = 2240,
  [2241] = 2241,
  [2242] = 2242,
  [2243] = 2193,
  [2244] = 2231,
  [2245] = 2238,
  [2246] = 2246,
  [2247] = 2247,
  [2248] = 2248,
  [2249] = 2249,
  [2250] = 2250,
  [2251] = 2251,
  [2252] = 2228,
  [2253] = 2253,
  [2254] = 2154,
  [2255] = 2255,
  [2256] = 2256,
  [2257] = 2257,
  [2258] = 2258,
  [2259] = 2259,
  [2260] = 2260,
  [2261] = 2261,
  [2262] = 2231,
  [2263] = 2263,
  [2264] = 2200,
  [2265] = 2265,
  [2266] = 2266,
  [2267] = 2238,
  [2268] = 2260,
  [2269] = 2269,
  [2270] = 2261,
  [2271] = 2271,
  [2272] = 2266,
  [2273] = 2273,
  [2274] = 2274,
  [2275] = 2257,
  [2276] = 2201,
  [2277] = 2277,
  [2278] = 2199,
  [2279] = 2279,
  [2280] = 2280,
  [2281] = 2281,
  [2282] = 2282,
  [2283] = 2283,
  [2284] = 2284,
  [2285] = 2203,
  [2286] = 2286,
  [2287] = 2287,
  [2288] = 2196,
  [2289] = 2273,
  [2290] = 2241,
  [2291] = 2291,
  [2292] = 2292,
  [2293] = 2251,
  [2294] = 2294,
  [2295] = 2269,
  [2296] = 2216,
  [2297] = 2218,
  [2298] = 2298,
  [2299] = 2299,
  [2300] = 2300,
  [2301] = 2301,
  [2302] = 2302,
  [2303] = 2196,
  [2304] = 2197,
  [2305] = 2201,
  [2306] = 2306,
  [2307] = 2258,
  [2308] = 2201,
  [2309] = 2197,
  [2310] = 2310,
  [2311] = 2259,
  [2312] = 2312,
  [2313] = 2196,
  [2314] = 2203,
  [2315] = 2315,
  [2316] = 2316,
  [2317] = 2317,
  [2318] = 2193,
  [2319] = 2222,
  [2320] = 2320,
  [2321] = 2154,
  [2322] = 2201,
  [2323] = 2323,
  [2324] = 2324,
  [2325] = 2231,
  [2326] = 2201,
  [2327] = 2327,
  [2328] = 2328,
  [2329] = 2231,
  [2330] = 2330,
  [2331] = 2331,
  [2332] = 2238,
  [2333] = 2333,
  [2334] = 2238,
  [2335] = 2335,
  [2336] = 2201,
  [2337] = 2196,
  [2338] = 2338,
  [2339] = 2339,
  [2340] = 2197,
  [2341] = 2263,
  [2342] = 2246,
  [2343] = 2343,
  [2344] = 2205,
  [2345] = 2203,
  [2346] = 2207,
  [2347] = 2347,
  [2348] = 2348,
  [2349] = 2253,
  [2350] = 2193,
  [2351] = 2351,
  [2352] = 2256,
  [2353] = 2193,
  [2354] = 2220,
  [2355] = 2355,
  [2356] = 2271,
  [2357] = 2234,
  [2358] = 2239,
  [2359] = 2301,
  [2360] = 2360,
  [2361] = 2197,
  [2362] = 2236,
  [2363] = 2363,
  [2364] = 2364,
  [2365] = 2365,
  [2366] = 2366,
  [2367] = 2367,
  [2368] = 2368,
  [2369] = 2369,
  [2370] = 2370,
  [2371] = 2371,
  [2372] = 2372,
  [2373] = 2373,
  [2374] = 2370,
  [2375] = 2370,
  [2376] = 2370,
  [2377] = 2377,
  [2378] = 2370,
  [2379] = 2379,
  [2380] = 2380,
  [2381] = 2381,
  [2382] = 2382,
  [2383] = 2383,
  [2384] = 2384,
  [2385] = 2370,
  [2386] = 2386,
  [2387] = 2387,
  [2388] = 2388,
  [2389] = 2389,
  [2390] = 1121,
  [2391] = 2391,
  [2392] = 2392,
  [2393] = 2393,
  [2394] = 2394,
  [2395] = 2395,
  [2396] = 2396,
  [2397] = 2397,
  [2398] = 2393,
  [2399] = 2370,
  [2400] = 2400,
  [2401] = 2401,
  [2402] = 2389,
  [2403] = 2403,
  [2404] = 2404,
  [2405] = 2405,
  [2406] = 2370,
  [2407] = 2370,
  [2408] = 2370,
  [2409] = 2370,
  [2410] = 2410,
  [2411] = 2395,
  [2412] = 2412,
  [2413] = 2413,
  [2414] = 2414,
  [2415] = 2415,
  [2416] = 2416,
  [2417] = 2394,
  [2418] = 2418,
  [2419] = 2419,
  [2420] = 2420,
  [2421] = 2370,
  [2422] = 2422,
  [2423] = 2423,
  [2424] = 2424,
  [2425] = 2425,
  [2426] = 2426,
  [2427] = 2427,
  [2428] = 2428,
  [2429] = 2429,
  [2430] = 2430,
  [2431] = 2370,
  [2432] = 2404,
  [2433] = 2433,
  [2434] = 2413,
  [2435] = 2435,
  [2436] = 2416,
  [2437] = 2413,
  [2438] = 2370,
  [2439] = 2420,
  [2440] = 2370,
  [2441] = 2441,
  [2442] = 2442,
  [2443] = 2443,
  [2444] = 2416,
  [2445] = 2420,
  [2446] = 2446,
  [2447] = 2370,
  [2448] = 2448,
  [2449] = 2419,
  [2450] = 2370,
  [2451] = 2451,
  [2452] = 2452,
  [2453] = 2453,
  [2454] = 2454,
  [2455] = 2455,
  [2456] = 2456,
  [2457] = 2370,
  [2458] = 2458,
  [2459] = 2370,
  [2460] = 2460,
  [2461] = 2461,
  [2462] = 2462,
  [2463] = 2453,
  [2464] = 2464,
  [2465] = 2465,
  [2466] = 2370,
  [2467] = 2467,
  [2468] = 2468,
  [2469] = 2469,
  [2470] = 2470,
  [2471] = 2471,
  [2472] = 2401,
  [2473] = 2370,
  [2474] = 2474,
  [2475] = 2370,
  [2476] = 2476,
  [2477] = 2477,
  [2478] = 2478,
  [2479] = 2479,
  [2480] = 2370,
  [2481] = 2481,
  [2482] = 2482,
  [2483] = 2483,
  [2484] = 2484,
  [2485] = 2370,
  [2486] = 2370,
  [2487] = 2479,
  [2488] = 2371,
  [2489] = 2370,
  [2490] = 2404,
  [2491] = 2491,
  [2492] = 2370,
  [2493] = 2493,
  [2494] = 2494,
  [2495] = 2413,
  [2496] = 2370,
  [2497] = 2416,
  [2498] = 2420,
  [2499] = 2370,
  [2500] = 2423,
  [2501] = 2405,
  [2502] = 2370,
  [2503] = 2370,
  [2504] = 2371,
  [2505] = 2370,
  [2506] = 2506,
  [2507] = 2370,
  [2508] = 2508,
  [2509] = 2370,
  [2510] = 2510,
  [2511] = 2511,
  [2512] = 2370,
  [2513] = 2513,
  [2514] = 2514,
  [2515] = 2370,
  [2516] = 2370,
  [2517] = 2517,
  [2518] = 2518,
  [2519] = 2396,
  [2520] = 2395,
  [2521] = 2370,
  [2522] = 2522,
  [2523] = 2523,
  [2524] = 2524,
  [2525] = 2370,
  [2526] = 2370,
  [2527] = 2508,
  [2528] = 2364,
  [2529] = 2482,
  [2530] = 2523,
  [2531] = 2531,
  [2532] = 2532,
  [2533] = 2404,
  [2534] = 2534,
  [2535] = 2535,
  [2536] = 2433,
  [2537] = 2537,
  [2538] = 2371,
  [2539] = 2539,
  [2540] = 2430,
  [2541] = 2371,
  [2542] = 2542,
  [2543] = 2395,
  [2544] = 2404,
  [2545] = 2395,
  [2546] = 2546,
  [2547] = 2370,
  [2548] = 2548,
  [2549] = 2549,
  [2550] = 2550,
  [2551] = 2551,
  [2552] = 2552,
  [2553] = 2553,
  [2554] = 2554,
  [2555] = 2555,
  [2556] = 2413,
  [2557] = 2416,
  [2558] = 2420,
  [2559] = 2370,
  [2560] = 2370,
  [2561] = 2370,
  [2562] = 2370,
  [2563] = 2563,
  [2564] = 2370,
  [2565] = 2370,
  [2566] = 2370,
  [2567] = 2370,
  [2568] = 2370,
  [2569] = 2370,
  [2570] = 2370,
  [2571] = 2370,
  [2572] = 2370,
  [2573] = 2370,
  [2574] = 2370,
  [2575] = 2370,
  [2576] = 2370,
  [2577] = 2377,
  [2578] = 2578,
  [2579] = 2579,
  [2580] = 2580,
  [2581] = 2581,
  [2582] = 2582,
  [2583] = 2370,
  [2584] = 2553,
  [2585] = 2382,
  [2586] = 2586,
  [2587] = 2587,
  [2588] = 2414,
  [2589] = 2477,
  [2590] = 2590,
  [2591] = 2591,
  [2592] = 2592,
  [2593] = 2593,
  [2594] = 2594,
  [2595] = 2592,
  [2596] = 2596,
  [2597] = 2597,
  [2598] = 2552,
  [2599] = 2599,
  [2600] = 2592,
  [2601] = 2593,
  [2602] = 2602,
  [2603] = 2603,
  [2604] = 2592,
  [2605] = 2592,
  [2606] = 2592,
  [2607] = 2592,
  [2608] = 2593,
  [2609] = 2592,
  [2610] = 2610,
  [2611] = 2592,
  [2612] = 2592,
  [2613] = 2592,
  [2614] = 2593,
  [2615] = 2615,
  [2616] = 2616,
  [2617] = 2592,
  [2618] = 2592,
  [2619] = 2593,
  [2620] = 2620,
  [2621] = 2593,
  [2622] = 2592,
  [2623] = 2623,
  [2624] = 2624,
  [2625] = 2625,
  [2626] = 2626,
  [2627] = 2593,
  [2628] = 2628,
  [2629] = 2602,
  [2630] = 2592,
  [2631] = 2592,
  [2632] = 2632,
  [2633] = 2633,
  [2634] = 2593,
  [2635] = 2592,
  [2636] = 2636,
  [2637] = 2592,
  [2638] = 2592,
  [2639] = 2639,
  [2640] = 2593,
  [2641] = 2641,
  [2642] = 2642,
  [2643] = 2592,
  [2644] = 2592,
  [2645] = 2592,
  [2646] = 2592,
  [2647] = 2593,
  [2648] = 2592,
  [2649] = 2592,
  [2650] = 2592,
  [2651] = 2651,
  [2652] = 2652,
  [2653] = 2593,
  [2654] = 2593,
  [2655] = 2592,
  [2656] = 2592,
  [2657] = 2657,
  [2658] = 2658,
  [2659] = 2659,
  [2660] = 2593,
  [2661] = 2592,
  [2662] = 2592,
  [2663] = 2592,
  [2664] = 2664,
  [2665] = 1121,
  [2666] = 2593,
  [2667] = 2667,
  [2668] = 2668,
  [2669] = 2592,
  [2670] = 2670,
  [2671] = 2592,
  [2672] = 2592,
  [2673] = 2593,
  [2674] = 2592,
  [2675] = 2675,
  [2676] = 2592,
  [2677] = 2592,
  [2678] = 2678,
  [2679] = 2593,
  [2680] = 2593,
  [2681] = 2592,
  [2682] = 2592,
  [2683] = 2683,
  [2684] = 2592,
  [2685] = 2685,
  [2686] = 2593,
  [2687] = 2687,
  [2688] = 2664,
  [2689] = 2592,
  [2690] = 2593,
  [2691] = 2592,
  [2692] = 2593,
  [2693] = 2593,
  [2694] = 2592,
  [2695] = 2695,
  [2696] = 2592,
  [2697] = 2592,
  [2698] = 2592,
  [2699] = 2593,
  [2700] = 2592,
  [2701] = 2701,
  [2702] = 2592,
  [2703] = 2592,
  [2704] = 2592,
  [2705] = 2593,
  [2706] = 2706,
  [2707] = 2592,
  [2708] = 2592,
  [2709] = 2592,
  [2710] = 2710,
  [2711] = 2592,
  [2712] = 2593,
  [2713] = 2713,
  [2714] = 2714,
  [2715] = 2639,
  [2716] = 2716,
  [2717] = 2593,
  [2718] = 2593,
  [2719] = 2719,
  [2720] = 2720,
  [2721] = 2721,
  [2722] = 2722,
  [2723] = 2723,
  [2724] = 2724,
  [2725] = 2593,
  [2726] = 2726,
  [2727] = 2727,
  [2728] = 2728,
  [2729] = 2729,
  [2730] = 2593,
  [2731] = 2593,
  [2732] = 2732,
  [2733] = 2733,
  [2734] = 2734,
  [2735] = 2735,
  [2736] = 2593,
  [2737] = 2737,
  [2738] = 2593,
  [2739] = 2593,
  [2740] = 2740,
  [2741] = 2741,
  [2742] = 2742,
  [2743] = 2743,
  [2744] = 2744,
  [2745] = 2593,
  [2746] = 2746,
  [2747] = 2667,
  [2748] = 2748,
  [2749] = 2749,
  [2750] = 2750,
  [2751] = 2751,
  [2752] = 2593,
  [2753] = 2602,
  [2754] = 2754,
  [2755] = 2755,
  [2756] = 2593,
  [2757] = 2751,
  [2758] = 2758,
  [2759] = 2593,
  [2760] = 2760,
  [2761] = 2761,
  [2762] = 2762,
  [2763] = 2628,
  [2764] = 2764,
  [2765] = 2765,
  [2766] = 2593,
  [2767] = 2593,
  [2768] = 2657,
  [2769] = 2769,
  [2770] = 2593,
  [2771] = 2771,
  [2772] = 2664,
  [2773] = 2593,
  [2774] = 2774,
  [2775] = 2775,
  [2776] = 2593,
  [2777] = 2777,
  [2778] = 2778,
  [2779] = 2779,
  [2780] = 2593,
  [2781] = 2593,
  [2782] = 2593,
  [2783] = 2783,
  [2784] = 2592,
  [2785] = 2751,
  [2786] = 2786,
  [2787] = 2787,
  [2788] = 2788,
  [2789] = 2639,
  [2790] = 2636,
  [2791] = 2695,
  [2792] = 2762,
  [2793] = 2593,
  [2794] = 2774,
  [2795] = 2733,
  [2796] = 2642,
  [2797] = 2632,
  [2798] = 2798,
  [2799] = 2593,
  [2800] = 2800,
  [2801] = 2801,
  [2802] = 2593,
  [2803] = 2657,
  [2804] = 2762,
  [2805] = 2593,
  [2806] = 2806,
  [2807] = 2807,
  [2808] = 2639,
  [2809] = 2592,
  [2810] = 2657,
  [2811] = 2593,
  [2812] = 2732,
  [2813] = 2813,
  [2814] = 2657,
  [2815] = 2593,
  [2816] = 2593,
  [2817] = 2817,
  [2818] = 2818,
  [2819] = 2593,
  [2820] = 2820,
  [2821] = 2741,
  [2822] = 2822,
  [2823] = 2593,
  [2824] = 2824,
  [2825] = 2591,
  [2826] = 2642,
  [2827] = 2602,
  [2828] = 2664,
  [2829] = 2829,
  [2830] = 2830,
  [2831] = 2831,
  [2832] = 2602,
  [2833] = 2833,
  [2834] = 2592,
  [2835] = 2835,
  [2836] = 2664,
  [2837] = 2837,
  [2838] = 2593,
  [2839] = 2839,
  [2840] = 2840,
  [2841] = 2841,
  [2842] = 2842,
  [2843] = 2751,
  [2844] = 2844,
  [2845] = 2845,
  [2846] = 2641,
  [2847] = 2847,
  [2848] = 2848,
  [2849] = 2667,
  [2850] = 2623,
  [2851] = 2851,
  [2852] = 2852,
  [2853] = 2853,
  [2854] = 2751,
  [2855] = 2783,
  [2856] = 2856,
  [2857] = 2857,
  [2858] = 2740,
  [2859] = 2658,
  [2860] = 2860,
  [2861] = 2861,
  [2862] = 2862,
  [2863] = 2642,
  [2864] = 2864,
  [2865] = 2865,
  [2866] = 2866,
  [2867] = 2867,
  [2868] = 2593,
  [2869] = 2869,
  [2870] = 2762,
  [2871] = 2871,
  [2872] = 2872,
  [2873] = 2873,
  [2874] = 2874,
  [2875] = 2875,
  [2876] = 2876,
  [2877] = 2877,
  [2878] = 2878,
  [2879] = 2593,
  [2880] = 2880,
  [2881] = 2881,
  [2882] = 2594,
  [2883] = 2883,
  [2884] = 2762,
  [2885] = 2716,
  [2886] = 2886,
  [2887] = 2880,
  [2888] = 2592,
  [2889] = 2889,
  [2890] = 2620,
  [2891] = 2891,
  [2892] = 2774,
  [2893] = 2893,
  [2894] = 2894,
  [2895] = 2844,
  [2896] = 2746,
  [2897] = 2624,
  [2898] = 2898,
  [2899] = 2899,
  [2900] = 2592,
  [2901] = 2670,
  [2902] = 2593,
  [2903] = 2903,
  [2904] = 2625,
  [2905] = 2881,
  [2906] = 2806,
  [2907] = 2642,
  [2908] = 2639,
  [2909] = 2909,
  [2910] = 2593,
  [2911] = 2911,
  [2912] = 2912,
  [2913] = 2913,
  [2914] = 2593,
  [2915] = 2915,
  [2916] = 2592,
  [2917] = 2592,
  [2918] = 2719,
  [2919] = 2919,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 1352,
        '"', 30,
        '#', 1022,
        '$', 958,
        '%', 1836,
        '&', 47,
        '\'', 48,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1358,
        '/', 1857,
        ':', 1338,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        'B', 330,
        'C', 169,
        'D', 170,
        'E', 300,
        'F', 173,
        'L', 397,
        'N', 174,
        'P', 177,
        'R', 178,
        'S', 258,
        'U', 649,
        '[', 1333,
        ']', 1334,
        'b', 133,
        'c', 96,
        'd', 35,
        'e', 97,
        'f', 142,
        'l', 147,
        'n', 125,
        'p', 163,
        'r', 36,
        's', 34,
        'u', 33,
        '{', 1339,
        '|', 1342,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 264,
        'a', 264,
        'G', 758,
        'g', 758,
        'H', 188,
        'h', 188,
        'I', 463,
        'i', 463,
        'J', 198,
        'j', 198,
        'K', 333,
        'k', 333,
        'M', 1307,
        'm', 1307,
        'O', 623,
        'o', 623,
        'T', 180,
        't', 180,
        'V', 200,
        'v', 200,
        'W', 494,
        'w', 494,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(965);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1568);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(2);
      if (lookahead == '*') ADVANCE(1);
      if (lookahead == '/') ADVANCE(1004);
      if (lookahead != 0) ADVANCE(2);
      END_STATE();
    case 2:
      if (lookahead == '\n') ADVANCE(2);
      if (lookahead == '*') ADVANCE(1);
      if (lookahead != 0) ADVANCE(2);
      END_STATE();
    case 3:
      if (lookahead == ' ') ADVANCE(573);
      END_STATE();
    case 4:
      if (lookahead == ' ') ADVANCE(321);
      END_STATE();
    case 5:
      if (lookahead == ' ') ADVANCE(921);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        ')', 1331,
        '*', 1355,
        '-', 53,
        '/', 50,
        '<', 1346,
        '?', 1335,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        ']', 1334,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        '|', 1341,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        ')', 1331,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        'S', 1457,
        'U', 1502,
        '[', 1333,
        'd', 1369,
        'f', 1372,
        'r', 1360,
        's', 1365,
        'u', 1368,
        '{', 1339,
        'B', 1393,
        'b', 1393,
        'C', 1380,
        'c', 1380,
        'I', 1470,
        'i', 1470,
        'K', 1442,
        'k', 1442,
        'L', 1441,
        'l', 1441,
        'N', 1481,
        'n', 1481,
        'T', 1439,
        't', 1439,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '*', 1355,
        '-', 53,
        '/', 50,
        '<', 1346,
        'D', 1443,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'd', 1364,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'V', 1382,
        'v', 1382,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '*', 1355,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'C', 1483,
        'c', 1483,
        'I', 1430,
        'i', 1430,
        'N', 1481,
        'n', 1481,
        'O', 1527,
        'o', 1527,
        'T', 1489,
        't', 1489,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '*', 1355,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'V', 1382,
        'v', 1382,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        ',', 1329,
        '-', 53,
        '/', 50,
        '<', 1346,
        '>', 1349,
        '?', 1335,
        'D', 1392,
        'F', 1377,
        'R', 1374,
        'S', 1415,
        'U', 1486,
        '[', 1333,
        ']', 1334,
        'd', 1361,
        'f', 1371,
        'r', 1359,
        's', 1362,
        'u', 1366,
        '{', 1339,
        '|', 1341,
        'A', 1451,
        'a', 1451,
        'B', 1393,
        'b', 1393,
        'C', 1379,
        'c', 1379,
        'I', 1428,
        'i', 1428,
        'K', 1442,
        'k', 1442,
        'L', 1411,
        'l', 1411,
        'N', 1481,
        'n', 1481,
        'T', 1439,
        't', 1439,
        'W', 1440,
        'w', 1440,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('E' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('e' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'D', 1392,
        'F', 1377,
        'R', 1374,
        'S', 1416,
        'U', 1487,
        '[', 1333,
        'd', 1361,
        'f', 1371,
        'r', 1359,
        's', 1363,
        'u', 1367,
        '{', 1339,
        'A', 1451,
        'a', 1451,
        'C', 1482,
        'c', 1482,
        'I', 1429,
        'i', 1429,
        'L', 1412,
        'l', 1412,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'D', 1443,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'd', 1364,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'A', 1437,
        'a', 1437,
        'B', 1425,
        'b', 1425,
        'C', 1483,
        'c', 1483,
        'I', 1430,
        'i', 1430,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'V', 1382,
        'v', 1382,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('E' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('e' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        'S', 1457,
        'U', 1502,
        '[', 1333,
        'd', 1369,
        'f', 1372,
        'r', 1360,
        's', 1365,
        'u', 1368,
        '{', 1339,
        'B', 1393,
        'b', 1393,
        'C', 1380,
        'c', 1380,
        'I', 1470,
        'i', 1470,
        'K', 1442,
        'k', 1442,
        'L', 1441,
        'l', 1441,
        'N', 1481,
        'n', 1481,
        'O', 1472,
        'o', 1472,
        'T', 1439,
        't', 1439,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        '|', 1341,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'O', 1472,
        'o', 1472,
        'T', 1489,
        't', 1489,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'A', 1459,
        'a', 1459,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'B', 1533,
        'b', 1533,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'C', 1483,
        'c', 1483,
        'N', 1481,
        'n', 1481,
        'T', 1489,
        't', 1489,
        'W', 1440,
        'w', 1440,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 53,
        '/', 50,
        '<', 1346,
        'F', 1378,
        'R', 1375,
        '[', 1333,
        'f', 1372,
        'r', 1360,
        '{', 1339,
        'C', 1483,
        'c', 1483,
        'N', 1479,
        'n', 1479,
        'T', 1489,
        't', 1489,
        'd', 1369,
        's', 1369,
        'u', 1369,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1834,
        '.', 1358,
        '/', 1857,
        ':', 1338,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        '[', 1333,
        ']', 1334,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 602,
        'a', 602,
        'C', 501,
        'c', 501,
        'D', 757,
        'd', 757,
        'E', 941,
        'e', 941,
        'F', 391,
        'f', 391,
        'G', 785,
        'g', 785,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'M', 402,
        'm', 402,
        'N', 717,
        'n', 717,
        'O', 624,
        'o', 624,
        'P', 185,
        'p', 185,
        'R', 383,
        'r', 383,
        'S', 292,
        's', 292,
        'T', 509,
        't', 509,
        'U', 704,
        'u', 704,
        'W', 514,
        'w', 514,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1833,
        '/', 1857,
        ';', 1023,
        '<', 1348,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        ']', 1334,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 602,
        'a', 602,
        'C', 501,
        'c', 501,
        'D', 757,
        'd', 757,
        'E', 941,
        'e', 941,
        'F', 391,
        'f', 391,
        'G', 785,
        'g', 785,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'M', 402,
        'm', 402,
        'N', 717,
        'n', 717,
        'O', 624,
        'o', 624,
        'P', 185,
        'p', 185,
        'R', 383,
        'r', 383,
        'S', 292,
        's', 292,
        'T', 509,
        't', 509,
        'U', 704,
        'u', 704,
        'W', 514,
        'w', 514,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'T', 1669,
        't', 1669,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1692,
        'a', 1692,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1692,
        'a', 1692,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1692,
        'a', 1692,
        'C', 1758,
        'c', 1758,
        'F', 1779,
        'f', 1779,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1692,
        'a', 1692,
        'C', 1758,
        'c', 1758,
        'F', 1779,
        'f', 1779,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1722,
        'o', 1722,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1692,
        'a', 1692,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1728,
        'o', 1728,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'F', 1779,
        'f', 1779,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 29:
      ADVANCE_MAP(
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        '-', 54,
        '/', 50,
        '?', 1335,
        '[', 1333,
        '{', 1339,
        '}', 1340,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1568);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 30:
      if (lookahead == '"') ADVANCE(1563);
      if (lookahead == '\\') ADVANCE(961);
      if (lookahead != 0) ADVANCE(30);
      END_STATE();
    case 31:
      if (lookahead == '"') ADVANCE(1564);
      if (lookahead == '\\') ADVANCE(963);
      if (lookahead != 0) ADVANCE(31);
      END_STATE();
    case 32:
      if (lookahead == '"') ADVANCE(1565);
      if (lookahead == '\\') ADVANCE(963);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(32);
      END_STATE();
    case 33:
      ADVANCE_MAP(
        '"', 31,
        '\'', 49,
        'P', 327,
        'p', 152,
        'N', 521,
        'n', 521,
        'R', 578,
        'r', 578,
        'S', 336,
        's', 336,
      );
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '"', 31,
        '\'', 49,
        'n', 149,
        'C', 498,
        'c', 498,
        'E', 207,
        'e', 207,
        'H', 712,
        'h', 712,
        'I', 479,
        'i', 479,
        'L', 424,
        'l', 424,
        'P', 616,
        'p', 616,
      );
      END_STATE();
    case 35:
      ADVANCE_MAP(
        '"', 31,
        '\'', 49,
        'A', 887,
        'a', 887,
        'B', 1236,
        'b', 1236,
        'E', 465,
        'e', 465,
        'I', 468,
        'i', 468,
        'O', 259,
        'o', 259,
        'R', 716,
        'r', 716,
        'U', 800,
        'u', 800,
      );
      END_STATE();
    case 36:
      ADVANCE_MAP(
        '"', 31,
        '\'', 49,
        'A', 652,
        'a', 652,
        'E', 191,
        'e', 191,
        'O', 598,
        'o', 598,
        'S', 70,
        's', 70,
      );
      END_STATE();
    case 37:
      ADVANCE_MAP(
        '#', 1022,
        '$', 958,
        '-', 54,
        '/', 50,
        '=', 1327,
        '[', 1333,
        'f', 1373,
        'C', 1483,
        'c', 1483,
        'O', 1472,
        'o', 1472,
        'R', 1375,
        'r', 1375,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(37);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1569);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 38:
      ADVANCE_MAP(
        '#', 1022,
        '$', 958,
        '-', 56,
        '/', 50,
        '[', 1333,
        'f', 1373,
        'C', 1483,
        'c', 1483,
        'R', 1375,
        'r', 1375,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(38);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(58);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 39:
      ADVANCE_MAP(
        '#', 1022,
        '(', 1330,
        '-', 51,
        '/', 50,
        ':', 89,
        '<', 1345,
        'O', 1544,
        'o', 1544,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(39);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 40:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '*') ADVANCE(1355);
      if (lookahead == '-') ADVANCE(51);
      if (lookahead == '/') ADVANCE(50);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(40);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 41:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '-') ADVANCE(51);
      if (lookahead == '/') ADVANCE(50);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1547);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(41);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 42:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '-') ADVANCE(51);
      if (lookahead == '/') ADVANCE(50);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1551);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(42);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 43:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '-') ADVANCE(51);
      if (lookahead == '/') ADVANCE(50);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1541);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1549);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(43);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 44:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '-') ADVANCE(51);
      if (lookahead == '/') ADVANCE(50);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1541);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(44);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 45:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '-') ADVANCE(51);
      if (lookahead == '/') ADVANCE(50);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1536);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 46:
      if (lookahead == '#') ADVANCE(1022);
      if (lookahead == '-') ADVANCE(52);
      if (lookahead == '.') ADVANCE(57);
      if (lookahead == '/') ADVANCE(50);
      if (lookahead == '=') ADVANCE(1327);
      if (lookahead == '[') ADVANCE(1333);
      if (lookahead == '{') ADVANCE(1339);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(46);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 47:
      if (lookahead == '&') ADVANCE(1840);
      END_STATE();
    case 48:
      if (lookahead == '\'') ADVANCE(1563);
      if (lookahead == '\\') ADVANCE(962);
      if (lookahead != 0) ADVANCE(48);
      END_STATE();
    case 49:
      if (lookahead == '\'') ADVANCE(1564);
      if (lookahead == '\\') ADVANCE(964);
      if (lookahead != 0) ADVANCE(49);
      END_STATE();
    case 50:
      if (lookahead == '*') ADVANCE(2);
      if (lookahead == '/') ADVANCE(1022);
      END_STATE();
    case 51:
      if (lookahead == '-') ADVANCE(1011);
      END_STATE();
    case 52:
      if (lookahead == '-') ADVANCE(1011);
      if (lookahead == '>') ADVANCE(1332);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1569);
      END_STATE();
    case 53:
      if (lookahead == '-') ADVANCE(1011);
      if (lookahead == '>') ADVANCE(1332);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1567);
      END_STATE();
    case 54:
      if (lookahead == '-') ADVANCE(1011);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1569);
      END_STATE();
    case 55:
      if (lookahead == '-') ADVANCE(1011);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1567);
      END_STATE();
    case 56:
      if (lookahead == '-') ADVANCE(1011);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(58);
      END_STATE();
    case 57:
      if (lookahead == '.') ADVANCE(1830);
      END_STATE();
    case 58:
      if (lookahead == '.') ADVANCE(955);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(58);
      END_STATE();
    case 59:
      if (lookahead == '1') ADVANCE(64);
      END_STATE();
    case 60:
      if (lookahead == '1') ADVANCE(65);
      END_STATE();
    case 61:
      if (lookahead == '1') ADVANCE(66);
      END_STATE();
    case 62:
      if (lookahead == '1') ADVANCE(67);
      END_STATE();
    case 63:
      if (lookahead == '2') ADVANCE(76);
      END_STATE();
    case 64:
      if (lookahead == '2') ADVANCE(1189);
      END_STATE();
    case 65:
      if (lookahead == '2') ADVANCE(1192);
      END_STATE();
    case 66:
      if (lookahead == '2') ADVANCE(1195);
      END_STATE();
    case 67:
      if (lookahead == '2') ADVANCE(1198);
      END_STATE();
    case 68:
      if (lookahead == '2') ADVANCE(77);
      if (lookahead == '3') ADVANCE(85);
      if (lookahead == '5') ADVANCE(59);
      END_STATE();
    case 69:
      if (lookahead == '2') ADVANCE(78);
      if (lookahead == '3') ADVANCE(86);
      if (lookahead == '5') ADVANCE(60);
      END_STATE();
    case 70:
      if (lookahead == '2') ADVANCE(79);
      if (lookahead == '3') ADVANCE(87);
      if (lookahead == '5') ADVANCE(61);
      END_STATE();
    case 71:
      if (lookahead == '2') ADVANCE(80);
      if (lookahead == '3') ADVANCE(88);
      if (lookahead == '5') ADVANCE(62);
      END_STATE();
    case 72:
      if (lookahead == '4') ADVANCE(1188);
      END_STATE();
    case 73:
      if (lookahead == '4') ADVANCE(1191);
      END_STATE();
    case 74:
      if (lookahead == '4') ADVANCE(1194);
      END_STATE();
    case 75:
      if (lookahead == '4') ADVANCE(1197);
      END_STATE();
    case 76:
      if (lookahead == '5') ADVANCE(1199);
      END_STATE();
    case 77:
      if (lookahead == '5') ADVANCE(81);
      END_STATE();
    case 78:
      if (lookahead == '5') ADVANCE(82);
      END_STATE();
    case 79:
      if (lookahead == '5') ADVANCE(83);
      END_STATE();
    case 80:
      if (lookahead == '5') ADVANCE(84);
      END_STATE();
    case 81:
      if (lookahead == '6') ADVANCE(1187);
      END_STATE();
    case 82:
      if (lookahead == '6') ADVANCE(1190);
      END_STATE();
    case 83:
      if (lookahead == '6') ADVANCE(1193);
      END_STATE();
    case 84:
      if (lookahead == '6') ADVANCE(1196);
      END_STATE();
    case 85:
      if (lookahead == '8') ADVANCE(72);
      END_STATE();
    case 86:
      if (lookahead == '8') ADVANCE(73);
      END_STATE();
    case 87:
      if (lookahead == '8') ADVANCE(74);
      END_STATE();
    case 88:
      if (lookahead == '8') ADVANCE(75);
      END_STATE();
    case 89:
      if (lookahead == ':') ADVANCE(1344);
      END_STATE();
    case 90:
      if (lookahead == ':') ADVANCE(1843);
      if (lookahead == '=') ADVANCE(1846);
      if (lookahead == '?') ADVANCE(1842);
      END_STATE();
    case 91:
      if (lookahead == ':') ADVANCE(959);
      END_STATE();
    case 92:
      if (lookahead == ':') ADVANCE(960);
      END_STATE();
    case 93:
      if (lookahead == '=') ADVANCE(1844);
      if (lookahead == '~') ADVANCE(1849);
      END_STATE();
    case 94:
      if (lookahead == '>') ADVANCE(1839);
      END_STATE();
    case 95:
      if (lookahead == '>') ADVANCE(1839);
      if (lookahead == '|') ADVANCE(1841);
      END_STATE();
    case 96:
      ADVANCE_MAP(
        'A', 700,
        'a', 139,
        'l', 106,
        'H', 203,
        'h', 203,
        'O', 576,
        'o', 576,
        'R', 400,
        'r', 400,
      );
      END_STATE();
    case 97:
      ADVANCE_MAP(
        'D', 310,
        'd', 128,
        'F', 260,
        'f', 260,
        'L', 838,
        'l', 838,
        'N', 472,
        'n', 472,
        'S', 68,
        's', 68,
        'U', 267,
        'u', 267,
        'V', 450,
        'v', 450,
        'X', 546,
        'x', 546,
      );
      END_STATE();
    case 98:
      if (lookahead == 'S') ADVANCE(849);
      if (lookahead == 's') ADVANCE(114);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(617);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(301);
      END_STATE();
    case 99:
      if (lookahead == '_') ADVANCE(523);
      END_STATE();
    case 100:
      if (lookahead == '_') ADVANCE(285);
      END_STATE();
    case 101:
      if (lookahead == '_') ADVANCE(293);
      END_STATE();
    case 102:
      if (lookahead == '_') ADVANCE(294);
      END_STATE();
    case 103:
      if (lookahead == '_') ADVANCE(296);
      END_STATE();
    case 104:
      if (lookahead == 'a') ADVANCE(140);
      END_STATE();
    case 105:
      if (lookahead == 'a') ADVANCE(145);
      END_STATE();
    case 106:
      if (lookahead == 'a') ADVANCE(159);
      END_STATE();
    case 107:
      if (lookahead == 'a') ADVANCE(136);
      END_STATE();
    case 108:
      if (lookahead == 'a') ADVANCE(141);
      END_STATE();
    case 109:
      if (lookahead == 'a') ADVANCE(160);
      END_STATE();
    case 110:
      if (lookahead == 'a') ADVANCE(161);
      END_STATE();
    case 111:
      if (lookahead == 'b') ADVANCE(107);
      END_STATE();
    case 112:
      if (lookahead == 'c') ADVANCE(162);
      END_STATE();
    case 113:
      if (lookahead == 'c') ADVANCE(1576);
      END_STATE();
    case 114:
      if (lookahead == 'c') ADVANCE(131);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(454);
      END_STATE();
    case 115:
      if (lookahead == 'c') ADVANCE(109);
      END_STATE();
    case 116:
      if (lookahead == 'c') ADVANCE(110);
      END_STATE();
    case 117:
      if (lookahead == 'd') ADVANCE(127);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(260);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(749);
      END_STATE();
    case 118:
      if (lookahead == 'e') ADVANCE(134);
      END_STATE();
    case 119:
      if (lookahead == 'e') ADVANCE(1558);
      END_STATE();
    case 120:
      if (lookahead == 'e') ADVANCE(1559);
      END_STATE();
    case 121:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 122:
      if (lookahead == 'e') ADVANCE(146);
      END_STATE();
    case 123:
      if (lookahead == 'e') ADVANCE(113);
      END_STATE();
    case 124:
      if (lookahead == 'e') ADVANCE(156);
      END_STATE();
    case 125:
      ADVANCE_MAP(
        'g', 154,
        'A', 632,
        'a', 632,
        'O', 543,
        'o', 543,
        'S', 1235,
        's', 1235,
        'U', 596,
        'u', 596,
      );
      END_STATE();
    case 126:
      if (lookahead == 'g') ADVANCE(154);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(698);
      END_STATE();
    case 127:
      if (lookahead == 'g') ADVANCE(122);
      END_STATE();
    case 128:
      if (lookahead == 'g') ADVANCE(122);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(834);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(908);
      END_STATE();
    case 129:
      if (lookahead == 'g') ADVANCE(155);
      END_STATE();
    case 130:
      if (lookahead == 'i') ADVANCE(1557);
      END_STATE();
    case 131:
      if (lookahead == 'i') ADVANCE(130);
      END_STATE();
    case 132:
      if (lookahead == 'k') ADVANCE(1553);
      END_STATE();
    case 133:
      ADVANCE_MAP(
        'l', 105,
        'E', 204,
        'e', 204,
        'M', 63,
        'm', 63,
        'R', 334,
        'r', 334,
        'Y', 1071,
        'y', 1071,
      );
      END_STATE();
    case 134:
      if (lookahead == 'l') ADVANCE(1554);
      END_STATE();
    case 135:
      if (lookahead == 'l') ADVANCE(1562);
      END_STATE();
    case 136:
      if (lookahead == 'l') ADVANCE(135);
      END_STATE();
    case 137:
      ADVANCE_MAP(
        'm', 1832,
        'n', 157,
        'u', 157,
        0xb5, 157,
        'd', 1831,
        'h', 1831,
        's', 1831,
        'w', 1831,
        'y', 1831,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(137);
      END_STATE();
    case 138:
      ADVANCE_MAP(
        'm', 1832,
        'n', 157,
        'u', 157,
        0xb5, 157,
        'd', 1831,
        'h', 1831,
        's', 1831,
        'w', 1831,
        'y', 1831,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 139:
      if (lookahead == 'm') ADVANCE(118);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(273);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(210);
      END_STATE();
    case 140:
      if (lookahead == 'm') ADVANCE(1561);
      END_STATE();
    case 141:
      if (lookahead == 'm') ADVANCE(1560);
      END_STATE();
    case 142:
      ADVANCE_MAP(
        'n', 1578,
        'A', 610,
        'a', 610,
        'E', 889,
        'e', 889,
        'I', 409,
        'i', 409,
        'L', 335,
        'l', 335,
        'O', 760,
        'o', 760,
        'R', 720,
        'r', 720,
        'U', 594,
        'u', 594,
      );
      END_STATE();
    case 143:
      if (lookahead == 'n') ADVANCE(149);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(206);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(616);
      END_STATE();
    case 144:
      if (lookahead == 'n') ADVANCE(112);
      END_STATE();
    case 145:
      if (lookahead == 'n') ADVANCE(132);
      END_STATE();
    case 146:
      if (lookahead == 'n') ADVANCE(129);
      END_STATE();
    case 147:
      if (lookahead == 'o') ADVANCE(165);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(862);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(637);
      END_STATE();
    case 148:
      if (lookahead == 'o') ADVANCE(165);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(636);
      END_STATE();
    case 149:
      if (lookahead == 'o') ADVANCE(164);
      END_STATE();
    case 150:
      if (lookahead == 'p') ADVANCE(151);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(520);
      END_STATE();
    case 151:
      if (lookahead == 'p') ADVANCE(124);
      END_STATE();
    case 152:
      if (lookahead == 'p') ADVANCE(124);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(236);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(421);
      END_STATE();
    case 153:
      if (lookahead == 'r') ADVANCE(115);
      END_STATE();
    case 154:
      if (lookahead == 'r') ADVANCE(104);
      END_STATE();
    case 155:
      if (lookahead == 'r') ADVANCE(108);
      END_STATE();
    case 156:
      if (lookahead == 'r') ADVANCE(116);
      END_STATE();
    case 157:
      if (lookahead == 's') ADVANCE(1831);
      END_STATE();
    case 158:
      if (lookahead == 's') ADVANCE(1555);
      END_STATE();
    case 159:
      if (lookahead == 's') ADVANCE(158);
      END_STATE();
    case 160:
      if (lookahead == 's') ADVANCE(119);
      END_STATE();
    case 161:
      if (lookahead == 's') ADVANCE(120);
      END_STATE();
    case 162:
      if (lookahead == 't') ADVANCE(1556);
      END_STATE();
    case 163:
      ADVANCE_MAP(
        'u', 144,
        'A', 778,
        'a', 778,
        'E', 205,
        'e', 205,
        'O', 839,
        'o', 839,
        'S', 69,
        's', 69,
      );
      END_STATE();
    case 164:
      if (lookahead == 'w') ADVANCE(111);
      END_STATE();
    case 165:
      if (lookahead == 'w') ADVANCE(121);
      END_STATE();
    case 166:
      if (lookahead == '|') ADVANCE(1841);
      END_STATE();
    case 167:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(953);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1573);
      END_STATE();
    case 168:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(956);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1575);
      END_STATE();
    case 169:
      ADVANCE_MAP(
        'A', 700,
        'a', 700,
        'H', 203,
        'h', 203,
        'O', 576,
        'o', 576,
        'R', 400,
        'r', 400,
      );
      END_STATE();
    case 170:
      ADVANCE_MAP(
        'A', 887,
        'a', 887,
        'B', 1236,
        'b', 1236,
        'E', 465,
        'e', 465,
        'I', 468,
        'i', 468,
        'O', 259,
        'o', 259,
        'R', 716,
        'r', 716,
        'U', 800,
        'u', 800,
      );
      END_STATE();
    case 171:
      ADVANCE_MAP(
        'A', 887,
        'a', 887,
        'B', 1236,
        'b', 1236,
        'O', 259,
        'o', 259,
        'R', 716,
        'r', 716,
      );
      END_STATE();
    case 172:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(887);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(470);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(836);
      END_STATE();
    case 173:
      ADVANCE_MAP(
        'A', 610,
        'a', 610,
        'E', 889,
        'e', 889,
        'I', 409,
        'i', 409,
        'L', 335,
        'l', 335,
        'O', 760,
        'o', 760,
        'R', 720,
        'r', 720,
        'U', 594,
        'u', 594,
      );
      END_STATE();
    case 174:
      ADVANCE_MAP(
        'A', 632,
        'a', 632,
        'O', 543,
        'o', 543,
        'S', 1235,
        's', 1235,
        'U', 596,
        'u', 596,
      );
      END_STATE();
    case 175:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(632);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(544);
      END_STATE();
    case 176:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(632);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(698);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1235);
      END_STATE();
    case 177:
      ADVANCE_MAP(
        'A', 778,
        'a', 778,
        'E', 205,
        'e', 205,
        'O', 839,
        'o', 839,
        'S', 69,
        's', 69,
      );
      END_STATE();
    case 178:
      ADVANCE_MAP(
        'A', 652,
        'a', 652,
        'E', 191,
        'e', 191,
        'O', 598,
        'o', 598,
        'S', 70,
        's', 70,
      );
      END_STATE();
    case 179:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(652);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(193);
      END_STATE();
    case 180:
      ADVANCE_MAP(
        'A', 256,
        'a', 256,
        'E', 781,
        'e', 781,
        'H', 412,
        'h', 412,
        'I', 635,
        'i', 635,
        'O', 1214,
        'o', 1214,
        'R', 209,
        'r', 209,
        'Y', 752,
        'y', 752,
      );
      END_STATE();
    case 181:
      ADVANCE_MAP(
        'A', 256,
        'a', 256,
        'E', 781,
        'e', 781,
        'H', 411,
        'h', 411,
        'I', 635,
        'i', 635,
        'O', 574,
        'o', 574,
        'Y', 752,
        'y', 752,
      );
      END_STATE();
    case 182:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(256);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(575);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(752);
      END_STATE();
    case 183:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1186);
      END_STATE();
    case 184:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(469);
      END_STATE();
    case 185:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(790);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(779);
      END_STATE();
    case 186:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(790);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(779);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(839);
      END_STATE();
    case 187:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(630);
      END_STATE();
    case 188:
      ADVANCE_MAP(
        'A', 630,
        'a', 630,
        'I', 477,
        'i', 477,
        'N', 829,
        'n', 829,
        'S', 71,
        's', 71,
      );
      END_STATE();
    case 189:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(615);
      END_STATE();
    case 190:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(311);
      END_STATE();
    case 191:
      ADVANCE_MAP(
        'A', 311,
        'a', 311,
        'B', 918,
        'b', 918,
        'C', 726,
        'c', 726,
        'F', 793,
        'f', 793,
        'L', 217,
        'l', 217,
        'M', 713,
        'm', 713,
        'P', 611,
        'p', 611,
        'T', 922,
        't', 922,
      );
      END_STATE();
    case 192:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(311);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(252);
      END_STATE();
    case 193:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(311);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(611);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(922);
      END_STATE();
    case 194:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(569);
      END_STATE();
    case 195:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(675);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(653);
      END_STATE();
    case 196:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(255);
      END_STATE();
    case 197:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(270);
      END_STATE();
    case 198:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(270);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(570);
      END_STATE();
    case 199:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(589);
      END_STATE();
    case 200:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(589);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(401);
      END_STATE();
    case 201:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(923);
      END_STATE();
    case 202:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(923);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(696);
      END_STATE();
    case 203:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(699);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(254);
      END_STATE();
    case 204:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(807);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(740);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(525);
      END_STATE();
    case 205:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(783);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(629);
      END_STATE();
    case 206:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(787);
      END_STATE();
    case 207:
      ADVANCE_MAP(
        'A', 787,
        'a', 787,
        'L', 452,
        'l', 452,
        'S', 833,
        's', 833,
        'T', 1287,
        't', 1287,
      );
      END_STATE();
    case 208:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(787);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(833);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1287);
      END_STATE();
    case 209:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(681);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(341);
      END_STATE();
    case 210:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(283);
      END_STATE();
    case 211:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(587);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1115);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1210);
      END_STATE();
    case 212:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(587);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1209);
      END_STATE();
    case 213:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(626);
      END_STATE();
    case 214:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(910);
      END_STATE();
    case 215:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(281);
      END_STATE();
    case 216:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(583);
      END_STATE();
    case 217:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(885);
      END_STATE();
    case 218:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(837);
      END_STATE();
    case 219:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(784);
      END_STATE();
    case 220:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(903);
      END_STATE();
    case 221:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(667);
      END_STATE();
    case 222:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(668);
      END_STATE();
    case 223:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(789);
      END_STATE();
    case 224:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(789);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(779);
      END_STATE();
    case 225:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(949);
      END_STATE();
    case 226:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(895);
      END_STATE();
    case 227:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(618);
      END_STATE();
    case 228:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(748);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(247);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(577);
      END_STATE();
    case 229:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(748);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(247);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(605);
      END_STATE();
    case 230:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(748);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(641);
      END_STATE();
    case 231:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(748);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(639);
      END_STATE();
    case 232:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(792);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(779);
      END_STATE();
    case 233:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(614);
      END_STATE();
    case 234:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(689);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(916);
      END_STATE();
    case 235:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(845);
      END_STATE();
    case 236:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(897);
      END_STATE();
    case 237:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(898);
      END_STATE();
    case 238:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(278);
      END_STATE();
    case 239:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(553);
      END_STATE();
    case 240:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(553);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(692);
      END_STATE();
    case 241:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(553);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(692);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(703);
      END_STATE();
    case 242:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(279);
      END_STATE();
    case 243:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(537);
      END_STATE();
    case 244:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(900);
      END_STATE();
    case 245:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(901);
      END_STATE();
    case 246:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(902);
      END_STATE();
    case 247:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(702);
      END_STATE();
    case 248:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(702);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(254);
      END_STATE();
    case 249:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(284);
      END_STATE();
    case 250:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(286);
      END_STATE();
    case 251:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(287);
      END_STATE();
    case 252:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(914);
      END_STATE();
    case 253:
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(299);
      END_STATE();
    case 254:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(948);
      END_STATE();
    case 255:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(235);
      END_STATE();
    case 256:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(606);
      END_STATE();
    case 257:
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(609);
      END_STATE();
    case 258:
      ADVANCE_MAP(
        'C', 498,
        'c', 498,
        'E', 207,
        'e', 207,
        'H', 712,
        'h', 712,
        'I', 479,
        'i', 479,
        'L', 424,
        'l', 424,
        'P', 616,
        'p', 616,
      );
      END_STATE();
    case 259:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(99);
      END_STATE();
    case 260:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1306);
      END_STATE();
    case 261:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1083);
      END_STATE();
    case 262:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1079);
      END_STATE();
    case 263:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1081);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(454);
      END_STATE();
    case 264:
      ADVANCE_MAP(
        'C', 272,
        'c', 272,
        'F', 907,
        'f', 907,
        'L', 485,
        'l', 485,
        'N', 211,
        'n', 211,
        'S', 1056,
        's', 1056,
        'T', 1096,
        't', 1096,
        'U', 864,
        'u', 864,
      );
      END_STATE();
    case 265:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(272);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(212);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(849);
      END_STATE();
    case 266:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(488);
      END_STATE();
    case 267:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(612);
      END_STATE();
    case 268:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(489);
      END_STATE();
    case 269:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(490);
      END_STATE();
    case 270:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(271);
      END_STATE();
    case 271:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(219);
      END_STATE();
    case 272:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(416);
      END_STATE();
    case 273:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(422);
      END_STATE();
    case 274:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(877);
      END_STATE();
    case 275:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(345);
      END_STATE();
    case 276:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(894);
      END_STATE();
    case 277:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(414);
      END_STATE();
    case 278:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(364);
      END_STATE();
    case 279:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(368);
      END_STATE();
    case 280:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(739);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(206);
      END_STATE();
    case 281:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(505);
      END_STATE();
    case 282:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(726);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(611);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(922);
      END_STATE();
    case 283:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(538);
      END_STATE();
    case 284:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(506);
      END_STATE();
    case 285:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(215);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(806);
      END_STATE();
    case 286:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(507);
      END_STATE();
    case 287:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(508);
      END_STATE();
    case 288:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(497);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(208);
      END_STATE();
    case 289:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(497);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(208);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(479);
      END_STATE();
    case 290:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(497);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(208);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(478);
      END_STATE();
    case 291:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(497);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(832);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(478);
      END_STATE();
    case 292:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(497);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(863);
      END_STATE();
    case 293:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(249);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(808);
      END_STATE();
    case 294:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(250);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(809);
      END_STATE();
    case 295:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(244);
      END_STATE();
    case 296:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(251);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(810);
      END_STATE();
    case 297:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(245);
      END_STATE();
    case 298:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(912);
      END_STATE();
    case 299:
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(913);
      END_STATE();
    case 300:
      ADVANCE_MAP(
        'D', 310,
        'd', 310,
        'F', 260,
        'f', 260,
        'L', 838,
        'l', 838,
        'N', 472,
        'n', 472,
        'S', 68,
        's', 68,
        'U', 267,
        'u', 267,
        'V', 450,
        'v', 450,
        'X', 546,
        'x', 546,
      );
      END_STATE();
    case 301:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1115);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(567);
      END_STATE();
    case 302:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1074);
      END_STATE();
    case 303:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1166);
      END_STATE();
    case 304:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1322);
      END_STATE();
    case 305:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1301);
      END_STATE();
    case 306:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1158);
      END_STATE();
    case 307:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1316);
      END_STATE();
    case 308:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1280);
      END_STATE();
    case 309:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1215);
      END_STATE();
    case 310:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(834);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(908);
      END_STATE();
    case 311:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(727);
      END_STATE();
    case 312:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(825);
      END_STATE();
    case 313:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(392);
      END_STATE();
    case 314:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(362);
      END_STATE();
    case 315:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(369);
      END_STATE();
    case 316:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(370);
      END_STATE();
    case 317:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(371);
      END_STATE();
    case 318:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(380);
      END_STATE();
    case 319:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(381);
      END_STATE();
    case 320:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(405);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(715);
      END_STATE();
    case 321:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(919);
      END_STATE();
    case 322:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(420);
      END_STATE();
    case 323:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(440);
      END_STATE();
    case 324:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(441);
      END_STATE();
    case 325:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(444);
      END_STATE();
    case 326:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(445);
      END_STATE();
    case 327:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(236);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(421);
      END_STATE();
    case 328:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(246);
      END_STATE();
    case 329:
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(858);
      END_STATE();
    case 330:
      ADVANCE_MAP(
        'E', 204,
        'e', 204,
        'M', 63,
        'm', 63,
        'R', 334,
        'r', 334,
        'Y', 1071,
        'y', 1071,
      );
      END_STATE();
    case 331:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(205);
      END_STATE();
    case 332:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(942);
      END_STATE();
    case 333:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(942);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(597);
      END_STATE();
    case 334:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(194);
      END_STATE();
    case 335:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(940);
      END_STATE();
    case 336:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1234);
      END_STATE();
    case 337:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(656);
      END_STATE();
    case 338:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1047);
      END_STATE();
    case 339:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1177);
      END_STATE();
    case 340:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1111);
      END_STATE();
    case 341:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1100);
      END_STATE();
    case 342:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1255);
      END_STATE();
    case 343:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1102);
      END_STATE();
    case 344:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1170);
      END_STATE();
    case 345:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1028);
      END_STATE();
    case 346:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1219);
      END_STATE();
    case 347:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1303);
      END_STATE();
    case 348:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1229);
      END_STATE();
    case 349:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1053);
      END_STATE();
    case 350:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1091);
      END_STATE();
    case 351:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1225);
      END_STATE();
    case 352:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(474);
      END_STATE();
    case 353:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1155);
      END_STATE();
    case 354:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1241);
      END_STATE();
    case 355:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1162);
      END_STATE();
    case 356:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1243);
      END_STATE();
    case 357:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1263);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(734);
      END_STATE();
    case 358:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1239);
      END_STATE();
    case 359:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1274);
      END_STATE();
    case 360:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1245);
      END_STATE();
    case 361:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1265);
      END_STATE();
    case 362:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1137);
      END_STATE();
    case 363:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1077);
      END_STATE();
    case 364:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1223);
      END_STATE();
    case 365:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1295);
      END_STATE();
    case 366:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1279);
      END_STATE();
    case 367:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1181);
      END_STATE();
    case 368:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1168);
      END_STATE();
    case 369:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1142);
      END_STATE();
    case 370:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1144);
      END_STATE();
    case 371:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1146);
      END_STATE();
    case 372:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1036);
      END_STATE();
    case 373:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1206);
      END_STATE();
    case 374:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1135);
      END_STATE();
    case 375:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1324);
      END_STATE();
    case 376:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1200);
      END_STATE();
    case 377:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1204);
      END_STATE();
    case 378:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1202);
      END_STATE();
    case 379:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(282);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(725);
      END_STATE();
    case 380:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1150);
      END_STATE();
    case 381:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1148);
      END_STATE();
    case 382:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1282);
      END_STATE();
    case 383:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(750);
      END_STATE();
    case 384:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(192);
      END_STATE();
    case 385:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(889);
      END_STATE();
    case 386:
      ADVANCE_MAP(
        'E', 889,
        'e', 889,
        'I', 436,
        'i', 436,
        'L', 335,
        'l', 335,
        'O', 760,
        'o', 760,
        'U', 679,
        'u', 679,
      );
      END_STATE();
    case 387:
      ADVANCE_MAP(
        'E', 889,
        'e', 889,
        'I', 436,
        'i', 436,
        'O', 760,
        'o', 760,
        'R', 720,
        'r', 720,
        'U', 679,
        'u', 679,
      );
      END_STATE();
    case 388:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(889);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(335);
      END_STATE();
    case 389:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(889);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(335);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(760);
      END_STATE();
    case 390:
      ADVANCE_MAP(
        'E', 889,
        'e', 889,
        'L', 335,
        'l', 335,
        'O', 760,
        'o', 760,
        'R', 720,
        'r', 720,
      );
      END_STATE();
    case 391:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(889);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(760);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(720);
      END_STATE();
    case 392:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(938);
      END_STATE();
    case 393:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(930);
      END_STATE();
    case 394:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(471);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(836);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(716);
      END_STATE();
    case 395:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(471);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(716);
      END_STATE();
    case 396:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(3);
      END_STATE();
    case 397:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(862);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(637);
      END_STATE();
    case 398:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(473);
      END_STATE();
    case 399:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(744);
      END_STATE();
    case 400:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(226);
      END_STATE();
    case 401:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(936);
      END_STATE();
    case 402:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(776);
      END_STATE();
    case 403:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(776);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(801);
      END_STATE();
    case 404:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(470);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(836);
      END_STATE();
    case 405:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(939);
      END_STATE();
    case 406:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(947);
      END_STATE();
    case 407:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(831);
      END_STATE();
    case 408:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(588);
      END_STATE();
    case 409:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(588);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(909);
      END_STATE();
    case 410:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(722);
      END_STATE();
    case 411:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(655);
      END_STATE();
    case 412:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(655);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(721);
      END_STATE();
    case 413:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(814);
      END_STATE();
    case 414:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(307);
      END_STATE();
    case 415:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(777);
      END_STATE();
    case 416:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(842);
      END_STATE();
    case 417:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(707);
      END_STATE();
    case 418:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(309);
      END_STATE();
    case 419:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(782);
      END_STATE();
    case 420:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(221);
      END_STATE();
    case 421:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(794);
      END_STATE();
    case 422:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(582);
      END_STATE();
    case 423:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(762);
      END_STATE();
    case 424:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(399);
      END_STATE();
    case 425:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(835);
      END_STATE();
    case 426:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(763);
      END_STATE();
    case 427:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(678);
      END_STATE();
    case 428:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(206);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(616);
      END_STATE();
    case 429:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(802);
      END_STATE();
    case 430:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(190);
      END_STATE();
    case 431:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(764);
      END_STATE();
    case 432:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(874);
      END_STATE();
    case 433:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(584);
      END_STATE();
    case 434:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(765);
      END_STATE();
    case 435:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(766);
      END_STATE();
    case 436:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(613);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(909);
      END_STATE();
    case 437:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(768);
      END_STATE();
    case 438:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(769);
      END_STATE();
    case 439:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(347);
      END_STATE();
    case 440:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(770);
      END_STATE();
    case 441:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(771);
      END_STATE();
    case 442:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(826);
      END_STATE();
    case 443:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(680);
      END_STATE();
    case 444:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(772);
      END_STATE();
    case 445:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(773);
      END_STATE();
    case 446:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(671);
      END_STATE();
    case 447:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(761);
      END_STATE();
    case 448:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(418);
      END_STATE();
    case 449:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(634);
      END_STATE();
    case 450:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(685);
      END_STATE();
    case 451:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(791);
      END_STATE();
    case 452:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(274);
      END_STATE();
    case 453:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(844);
      END_STATE();
    case 454:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(798);
      END_STATE();
    case 455:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(896);
      END_STATE();
    case 456:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(796);
      END_STATE();
    case 457:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 458:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(691);
      END_STATE();
    case 459:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(691);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(876);
      END_STATE();
    case 460:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(795);
      END_STATE();
    case 461:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(694);
      END_STATE();
    case 462:
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(568);
      END_STATE();
    case 463:
      ADVANCE_MAP(
        'F', 1029,
        'f', 1029,
        'G', 706,
        'g', 706,
        'N', 1140,
        'n', 1140,
        'S', 1121,
        's', 1121,
      );
      END_STATE();
    case 464:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1179);
      END_STATE();
    case 465:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(202);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(455);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(261);
      END_STATE();
    case 466:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(260);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(450);
      END_STATE();
    case 467:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(260);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(749);
      END_STATE();
    case 468:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(464);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(417);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(867);
      END_STATE();
    case 469:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(929);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(453);
      END_STATE();
    case 470:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(201);
      END_STATE();
    case 471:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(201);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(261);
      END_STATE();
    case 472:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(724);
      END_STATE();
    case 473:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(448);
      END_STATE();
    case 474:
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(448);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1027);
      END_STATE();
    case 475:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1157);
      END_STATE();
    case 476:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(706);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(320);
      END_STATE();
    case 477:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(499);
      END_STATE();
    case 478:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(654);
      END_STATE();
    case 479:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(654);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(275);
      END_STATE();
    case 480:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(503);
      END_STATE();
    case 481:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(346);
      END_STATE();
    case 482:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(352);
      END_STATE();
    case 483:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(891);
      END_STATE();
    case 484:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(398);
      END_STATE();
    case 485:
      ADVANCE_MAP(
        'G', 728,
        'g', 728,
        'L', 566,
        'l', 566,
        'T', 426,
        't', 426,
        'W', 225,
        'w', 225,
      );
      END_STATE();
    case 486:
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(859);
      END_STATE();
    case 487:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1087);
      END_STATE();
    case 488:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1067);
      END_STATE();
    case 489:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1221);
      END_STATE();
    case 490:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1275);
      END_STATE();
    case 491:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1321);
      END_STATE();
    case 492:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1281);
      END_STATE();
    case 493:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(337);
      END_STATE();
    case 494:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(337);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(888);
      END_STATE();
    case 495:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(627);
      END_STATE();
    case 496:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(218);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(736);
      END_STATE();
    case 497:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(449);
      END_STATE();
    case 498:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(449);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(753);
      END_STATE();
    case 499:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(595);
      END_STATE();
    case 500:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(247);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(593);
      END_STATE();
    case 501:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(247);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(640);
      END_STATE();
    case 502:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(247);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(605);
      END_STATE();
    case 503:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(893);
      END_STATE();
    case 504:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(393);
      END_STATE();
    case 505:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(373);
      END_STATE();
    case 506:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(376);
      END_STATE();
    case 507:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(377);
      END_STATE();
    case 508:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(378);
      END_STATE();
    case 509:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(411);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(635);
      END_STATE();
    case 510:
      ADVANCE_MAP(
        'H', 411,
        'h', 411,
        'I', 635,
        'i', 635,
        'O', 574,
        'o', 574,
        'Y', 752,
        'y', 752,
      );
      END_STATE();
    case 511:
      ADVANCE_MAP(
        'H', 411,
        'h', 411,
        'I', 635,
        'i', 635,
        'O', 575,
        'o', 575,
        'Y', 752,
        'y', 752,
      );
      END_STATE();
    case 512:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(411);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(635);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(752);
      END_STATE();
    case 513:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(220);
      END_STATE();
    case 514:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(460);
      END_STATE();
    case 515:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(460);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(888);
      END_STATE();
    case 516:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(461);
      END_STATE();
    case 517:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(248);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(642);
      END_STATE();
    case 518:
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(861);
      END_STATE();
    case 519:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(477);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(829);
      END_STATE();
    case 520:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(756);
      END_STATE();
    case 521:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(756);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(432);
      END_STATE();
    case 522:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1160);
      END_STATE();
    case 523:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(329);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(427);
      END_STATE();
    case 524:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(322);
      END_STATE();
    case 525:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(657);
      END_STATE();
    case 526:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(636);
      END_STATE();
    case 527:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(869);
      END_STATE();
    case 528:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(262);
      END_STATE();
    case 529:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(295);
      END_STATE();
    case 530:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(674);
      END_STATE();
    case 531:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(860);
      END_STATE();
    case 532:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(659);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(746);
      END_STATE();
    case 533:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(872);
      END_STATE();
    case 534:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(676);
      END_STATE();
    case 535:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(592);
      END_STATE();
    case 536:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(873);
      END_STATE();
    case 537:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(660);
      END_STATE();
    case 538:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(886);
      END_STATE();
    case 539:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(890);
      END_STATE();
    case 540:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(408);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(335);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(679);
      END_STATE();
    case 541:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(635);
      END_STATE();
    case 542:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(635);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(752);
      END_STATE();
    case 543:
      ADVANCE_MAP(
        'I', 677,
        'i', 677,
        'N', 340,
        'n', 340,
        'R', 631,
        'r', 631,
        'T', 1125,
        't', 1125,
      );
      END_STATE();
    case 544:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(677);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(631);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1123);
      END_STATE();
    case 545:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(480);
      END_STATE();
    case 546:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(840);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(591);
      END_STATE();
    case 547:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(314);
      END_STATE();
    case 548:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(695);
      END_STATE();
    case 549:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(315);
      END_STATE();
    case 550:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(730);
      END_STATE();
    case 551:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(316);
      END_STATE();
    case 552:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(731);
      END_STATE();
    case 553:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(690);
      END_STATE();
    case 554:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(317);
      END_STATE();
    case 555:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(733);
      END_STATE();
    case 556:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(899);
      END_STATE();
    case 557:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(734);
      END_STATE();
    case 558:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(318);
      END_STATE();
    case 559:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(735);
      END_STATE();
    case 560:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(319);
      END_STATE();
    case 561:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(742);
      END_STATE();
    case 562:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(737);
      END_STATE();
    case 563:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(257);
      END_STATE();
    case 564:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(951);
      END_STATE();
    case 565:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(297);
      END_STATE();
    case 566:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(708);
      END_STATE();
    case 567:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(709);
      END_STATE();
    case 568:
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(710);
      END_STATE();
    case 569:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1293);
      END_STATE();
    case 570:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(813);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1320);
      END_STATE();
    case 571:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(723);
      END_STATE();
    case 572:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(522);
      END_STATE();
    case 573:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(406);
      END_STATE();
    case 574:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(443);
      END_STATE();
    case 575:
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(446);
      END_STATE();
    case 576:
      ADVANCE_MAP(
        'L', 620,
        'l', 620,
        'M', 628,
        'm', 628,
        'N', 866,
        'n', 866,
        'S', 548,
        's', 548,
        'U', 684,
        'u', 684,
      );
      END_STATE();
    case 577:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(620);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(884);
      END_STATE();
    case 578:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1319);
      END_STATE();
    case 579:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1062);
      END_STATE();
    case 580:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1113);
      END_STATE();
    case 581:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1299);
      END_STATE();
    case 582:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1106);
      END_STATE();
    case 583:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1211);
      END_STATE();
    case 584:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1063);
      END_STATE();
    case 585:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1173);
      END_STATE();
    case 586:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1131);
      END_STATE();
    case 587:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(943);
      END_STATE();
    case 588:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(303);
      END_STATE();
    case 589:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(924);
      END_STATE();
    case 590:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(945);
      END_STATE();
    case 591:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(243);
      END_STATE();
    case 592:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(305);
      END_STATE();
    case 593:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(920);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(884);
      END_STATE();
    case 594:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(579);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(298);
      END_STATE();
    case 595:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(545);
      END_STATE();
    case 596:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(580);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(419);
      END_STATE();
    case 597:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(581);
      END_STATE();
    case 598:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(413);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(868);
      END_STATE();
    case 599:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(585);
      END_STATE();
    case 600:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(586);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(946);
      END_STATE();
    case 601:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(617);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(301);
      END_STATE();
    case 602:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(617);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(301);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1056);
      END_STATE();
    case 603:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(617);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(301);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(263);
      END_STATE();
    case 604:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(617);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(301);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(849);
      END_STATE();
    case 605:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(619);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(884);
      END_STATE();
    case 606:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(348);
      END_STATE();
    case 607:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(881);
      END_STATE();
    case 608:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(433);
      END_STATE();
    case 609:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(367);
      END_STATE();
    case 610:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(843);
      END_STATE();
    case 611:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(238);
      END_STATE();
    case 612:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(524);
      END_STATE();
    case 613:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(312);
      END_STATE();
    case 614:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(608);
      END_STATE();
    case 615:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(608);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1169);
      END_STATE();
    case 616:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(536);
      END_STATE();
    case 617:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(566);
      END_STATE();
    case 618:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(928);
      END_STATE();
    case 619:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(237);
      END_STATE();
    case 620:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(237);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(643);
      END_STATE();
    case 621:
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(565);
      END_STATE();
    case 622:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(63);
      END_STATE();
    case 623:
      ADVANCE_MAP(
        'M', 527,
        'm', 527,
        'N', 1039,
        'n', 1039,
        'R', 1119,
        'r', 1119,
        'U', 865,
        'u', 865,
        'V', 415,
        'v', 415,
        'W', 705,
        'w', 705,
      );
      END_STATE();
    case 624:
      ADVANCE_MAP(
        'M', 527,
        'm', 527,
        'N', 1039,
        'n', 1039,
        'R', 1117,
        'r', 1117,
        'U', 915,
        'u', 915,
      );
      END_STATE();
    case 625:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1050);
      END_STATE();
    case 626:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1169);
      END_STATE();
    case 627:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1317);
      END_STATE();
    case 628:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(459);
      END_STATE();
    case 629:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(531);
      END_STATE();
    case 630:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(644);
      END_STATE();
    case 631:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(216);
      END_STATE();
    case 632:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(407);
      END_STATE();
    case 633:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(828);
      END_STATE();
    case 634:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(184);
      END_STATE();
    case 635:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(410);
      END_STATE();
    case 636:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(533);
      END_STATE();
    case 637:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(533);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(339);
      END_STATE();
    case 638:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(419);
      END_STATE();
    case 639:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      END_STATE();
    case 640:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(884);
      END_STATE();
    case 641:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(911);
      END_STATE();
    case 642:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(645);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(548);
      END_STATE();
    case 643:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(688);
      END_STATE();
    case 644:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(534);
      END_STATE();
    case 645:
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(458);
      END_STATE();
    case 646:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(472);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(267);
      END_STATE();
    case 647:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(472);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(749);
      END_STATE();
    case 648:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(521);
      END_STATE();
    case 649:
      ADVANCE_MAP(
        'N', 521,
        'n', 521,
        'P', 327,
        'p', 327,
        'R', 578,
        'r', 578,
        'S', 336,
        's', 336,
      );
      END_STATE();
    case 650:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(521);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(447);
      END_STATE();
    case 651:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1140);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1121);
      END_STATE();
    case 652:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(302);
      END_STATE();
    case 653:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(571);
      END_STATE();
    case 654:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(532);
      END_STATE();
    case 655:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1253);
      END_STATE();
    case 656:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1252);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(350);
      END_STATE();
    case 657:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1104);
      END_STATE();
    case 658:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1044);
      END_STATE();
    case 659:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1277);
      END_STATE();
    case 660:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1060);
      END_STATE();
    case 661:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1161);
      END_STATE();
    case 662:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1276);
      END_STATE();
    case 663:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1315);
      END_STATE();
    case 664:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1167);
      END_STATE();
    case 665:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1212);
      END_STATE();
    case 666:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1304);
      END_STATE();
    case 667:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1156);
      END_STATE();
    case 668:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1159);
      END_STATE();
    case 669:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1110);
      END_STATE();
    case 670:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(4);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1117);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(915);
      END_STATE();
    case 671:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1232);
      END_STATE();
    case 672:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1139);
      END_STATE();
    case 673:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(829);
      END_STATE();
    case 674:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(486);
      END_STATE();
    case 675:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(513);
      END_STATE();
    case 676:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(475);
      END_STATE();
    case 677:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(313);
      END_STATE();
    case 678:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(483);
      END_STATE();
    case 679:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(298);
      END_STATE();
    case 680:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(564);
      END_STATE();
    case 681:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(848);
      END_STATE();
    case 682:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(520);
      END_STATE();
    case 683:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(520);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(447);
      END_STATE();
    case 684:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(870);
      END_STATE();
    case 685:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(871);
      END_STATE();
    case 686:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(850);
      END_STATE();
    case 687:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(590);
      END_STATE();
    case 688:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(818);
      END_STATE();
    case 689:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(875);
      END_STATE();
    case 690:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(820);
      END_STATE();
    case 691:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(879);
      END_STATE();
    case 692:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(880);
      END_STATE();
    case 693:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(824);
      END_STATE();
    case 694:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(904);
      END_STATE();
    case 695:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(353);
      END_STATE();
    case 696:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(355);
      END_STATE();
    case 697:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(374);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1129);
      END_STATE();
    case 698:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(462);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1125);
      END_STATE();
    case 699:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(482);
      END_STATE();
    case 700:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(273);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(210);
      END_STATE();
    case 701:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(911);
      END_STATE();
    case 702:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(484);
      END_STATE();
    case 703:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(927);
      END_STATE();
    case 704:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(841);
      END_STATE();
    case 705:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(434);
      END_STATE();
    case 706:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(741);
      END_STATE();
    case 707:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(854);
      END_STATE();
    case 708:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(852);
      END_STATE();
    case 709:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(853);
      END_STATE();
    case 710:
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(857);
      END_STATE();
    case 711:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1214);
      END_STATE();
    case 712:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(932);
      END_STATE();
    case 713:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(931);
      END_STATE();
    case 714:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(697);
      END_STATE();
    case 715:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1250);
      END_STATE();
    case 716:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(743);
      END_STATE();
    case 717:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(698);
      END_STATE();
    case 718:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(698);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(638);
      END_STATE();
    case 719:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(916);
      END_STATE();
    case 720:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(625);
      END_STATE();
    case 721:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(934);
      END_STATE();
    case 722:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(925);
      END_STATE();
    case 723:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(935);
      END_STATE();
    case 724:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(803);
      END_STATE();
    case 725:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(868);
      END_STATE();
    case 726:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(780);
      END_STATE();
    case 727:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(687);
      END_STATE();
    case 728:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(804);
      END_STATE();
    case 729:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(661);
      END_STATE();
    case 730:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(662);
      END_STATE();
    case 731:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(663);
      END_STATE();
    case 732:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(767);
      END_STATE();
    case 733:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(664);
      END_STATE();
    case 734:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(665);
      END_STATE();
    case 735:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(666);
      END_STATE();
    case 736:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(786);
      END_STATE();
    case 737:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(669);
      END_STATE();
    case 738:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(701);
      END_STATE();
    case 739:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(753);
      END_STATE();
    case 740:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(797);
      END_STATE();
    case 741:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(799);
      END_STATE();
    case 742:
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(693);
      END_STATE();
    case 743:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1171);
      END_STATE();
    case 744:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1297);
      END_STATE();
    case 745:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1098);
      END_STATE();
    case 746:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1278);
      END_STATE();
    case 747:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(616);
      END_STATE();
    case 748:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(210);
      END_STATE();
    case 749:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(591);
      END_STATE();
    case 750:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(611);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(922);
      END_STATE();
    case 751:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(328);
      END_STATE();
    case 752:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(342);
      END_STATE();
    case 753:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(344);
      END_STATE();
    case 754:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(621);
      END_STATE();
    case 755:
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(242);
      END_STATE();
    case 756:
      if (lookahead == 'Q' ||
          lookahead == 'q') ADVANCE(926);
      END_STATE();
    case 757:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(716);
      END_STATE();
    case 758:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(234);
      END_STATE();
    case 759:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1119);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(915);
      END_STATE();
    case 760:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1267);
      END_STATE();
    case 761:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1237);
      END_STATE();
    case 762:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1227);
      END_STATE();
    case 763:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1291);
      END_STATE();
    case 764:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1085);
      END_STATE();
    case 765:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1312);
      END_STATE();
    case 766:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1323);
      END_STATE();
    case 767:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1313);
      END_STATE();
    case 768:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1314);
      END_STATE();
    case 769:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1164);
      END_STATE();
    case 770:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1207);
      END_STATE();
    case 771:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1201);
      END_STATE();
    case 772:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1205);
      END_STATE();
    case 773:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1203);
      END_STATE();
    case 774:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1117);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(915);
      END_STATE();
    case 775:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(720);
      END_STATE();
    case 776:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(481);
      END_STATE();
    case 777:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(937);
      END_STATE();
    case 778:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(189);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(812);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(268);
      END_STATE();
    case 779:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(629);
      END_STATE();
    case 780:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(304);
      END_STATE();
    case 781:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(633);
      END_STATE();
    case 782:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(528);
      END_STATE();
    case 783:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(847);
      END_STATE();
    case 784:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(306);
      END_STATE();
    case 785:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(719);
      END_STATE();
    case 786:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(308);
      END_STATE();
    case 787:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(269);
      END_STATE();
    case 788:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(658);
      END_STATE();
    case 789:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(233);
      END_STATE();
    case 790:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(233);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(268);
      END_STATE();
    case 791:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(819);
      END_STATE();
    case 792:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(213);
      END_STATE();
    case 793:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(425);
      END_STATE();
    case 794:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(878);
      END_STATE();
    case 795:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(350);
      END_STATE();
    case 796:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(827);
      END_STATE();
    case 797:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(351);
      END_STATE();
    case 798:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(883);
      END_STATE();
    case 799:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(361);
      END_STATE();
    case 800:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(214);
      END_STATE();
    case 801:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(439);
      END_STATE();
    case 802:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(851);
      END_STATE();
    case 803:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(277);
      END_STATE();
    case 804:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(539);
      END_STATE();
    case 805:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(556);
      END_STATE();
    case 806:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(323);
      END_STATE();
    case 807:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(435);
      END_STATE();
    case 808:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(324);
      END_STATE();
    case 809:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(325);
      END_STATE();
    case 810:
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(326);
      END_STATE();
    case 811:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1056);
      END_STATE();
    case 812:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(496);
      END_STATE();
    case 813:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1185);
      END_STATE();
    case 814:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1238);
      END_STATE();
    case 815:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1034);
      END_STATE();
    case 816:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1326);
      END_STATE();
    case 817:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1289);
      END_STATE();
    case 818:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1273);
      END_STATE();
    case 819:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1251);
      END_STATE();
    case 820:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1127);
      END_STATE();
    case 821:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1175);
      END_STATE();
    case 822:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1208);
      END_STATE();
    case 823:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1152);
      END_STATE();
    case 824:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1261);
      END_STATE();
    case 825:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1272);
      END_STATE();
    case 826:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1266);
      END_STATE();
    case 827:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1035);
      END_STATE();
    case 828:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(100);
      END_STATE();
    case 829:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(933);
      END_STATE();
    case 830:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(572);
      END_STATE();
    case 831:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(755);
      END_STATE();
    case 832:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(833);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1287);
      END_STATE();
    case 833:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(550);
      END_STATE();
    case 834:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(183);
      END_STATE();
    case 835:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(491);
      END_STATE();
    case 836:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(867);
      END_STATE();
    case 837:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(492);
      END_STATE();
    case 838:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(338);
      END_STATE();
    case 839:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(906);
      END_STATE();
    case 840:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(892);
      END_STATE();
    case 841:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(432);
      END_STATE();
    case 842:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(816);
      END_STATE();
    case 843:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(343);
      END_STATE();
    case 844:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(821);
      END_STATE();
    case 845:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(366);
      END_STATE();
    case 846:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(504);
      END_STATE();
    case 847:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(729);
      END_STATE();
    case 848:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(253);
      END_STATE();
    case 849:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(454);
      END_STATE();
    case 850:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(549);
      END_STATE();
    case 851:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(457);
      END_STATE();
    case 852:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(551);
      END_STATE();
    case 853:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(554);
      END_STATE();
    case 854:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(559);
      END_STATE();
    case 855:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(558);
      END_STATE();
    case 856:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(561);
      END_STATE();
    case 857:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(560);
      END_STATE();
    case 858:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(101);
      END_STATE();
    case 859:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(102);
      END_STATE();
    case 860:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(856);
      END_STATE();
    case 861:
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(103);
      END_STATE();
    case 862:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1042);
      END_STATE();
    case 863:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1287);
      END_STATE();
    case 864:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(516);
      END_STATE();
    case 865:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1213);
      END_STATE();
    case 866:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(241);
      END_STATE();
    case 867:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1305);
      END_STATE();
    case 868:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1231);
      END_STATE();
    case 869:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1058);
      END_STATE();
    case 870:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1283);
      END_STATE();
    case 871:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1165);
      END_STATE();
    case 872:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1069);
      END_STATE();
    case 873:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1094);
      END_STATE();
    case 874:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1285);
      END_STATE();
    case 875:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1325);
      END_STATE();
    case 876:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1108);
      END_STATE();
    case 877:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1048);
      END_STATE();
    case 878:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1247);
      END_STATE();
    case 879:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1270);
      END_STATE();
    case 880:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1217);
      END_STATE();
    case 881:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1257);
      END_STATE();
    case 882:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1065);
      END_STATE();
    case 883:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1259);
      END_STATE();
    case 884:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(240);
      END_STATE();
    case 885:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(357);
      END_STATE();
    case 886:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(944);
      END_STATE();
    case 887:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(196);
      END_STATE();
    case 888:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(487);
      END_STATE();
    case 889:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(266);
      END_STATE();
    case 890:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(495);
      END_STATE();
    case 891:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(518);
      END_STATE();
    case 892:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(815);
      END_STATE();
    case 893:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(822);
      END_STATE();
    case 894:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(823);
      END_STATE();
    case 895:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(354);
      END_STATE();
    case 896:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(356);
      END_STATE();
    case 897:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(360);
      END_STATE();
    case 898:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(363);
      END_STATE();
    case 899:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(372);
      END_STATE();
    case 900:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(375);
      END_STATE();
    case 901:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(396);
      END_STATE();
    case 902:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(382);
      END_STATE();
    case 903:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(905);
      END_STATE();
    case 904:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(529);
      END_STATE();
    case 905:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(222);
      END_STATE();
    case 906:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(530);
      END_STATE();
    case 907:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(423);
      END_STATE();
    case 908:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(732);
      END_STATE();
    case 909:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(451);
      END_STATE();
    case 910:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(552);
      END_STATE();
    case 911:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(239);
      END_STATE();
    case 912:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(555);
      END_STATE();
    case 913:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(562);
      END_STATE();
    case 914:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(557);
      END_STATE();
    case 915:
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(855);
      END_STATE();
    case 916:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(745);
      END_STATE();
    case 917:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(865);
      END_STATE();
    case 918:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(535);
      END_STATE();
    case 919:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(754);
      END_STATE();
    case 920:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(643);
      END_STATE();
    case 921:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(751);
      END_STATE();
    case 922:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(788);
      END_STATE();
    case 923:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(607);
      END_STATE();
    case 924:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(349);
      END_STATE();
    case 925:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(882);
      END_STATE();
    case 926:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(359);
      END_STATE();
    case 927:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(365);
      END_STATE();
    case 928:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(442);
      END_STATE();
    case 929:
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(599);
      END_STATE();
    case 930:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1154);
      END_STATE();
    case 931:
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(358);
      END_STATE();
    case 932:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1025);
      END_STATE();
    case 933:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1311);
      END_STATE();
    case 934:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1032);
      END_STATE();
    case 935:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(830);
      END_STATE();
    case 936:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(437);
      END_STATE();
    case 937:
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(805);
      END_STATE();
    case 938:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1090);
      END_STATE();
    case 939:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1089);
      END_STATE();
    case 940:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(563);
      END_STATE();
    case 941:
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(749);
      END_STATE();
    case 942:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1318);
      END_STATE();
    case 943:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(950);
      END_STATE();
    case 944:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1310);
      END_STATE();
    case 945:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1183);
      END_STATE();
    case 946:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1133);
      END_STATE();
    case 947:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(5);
      END_STATE();
    case 948:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(846);
      END_STATE();
    case 949:
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(817);
      END_STATE();
    case 950:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(438);
      END_STATE();
    case 951:
      if (lookahead == 'Z' ||
          lookahead == 'z') ADVANCE(456);
      END_STATE();
    case 952:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1572);
      END_STATE();
    case 953:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1573);
      END_STATE();
    case 954:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1583);
      END_STATE();
    case 955:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1574);
      END_STATE();
    case 956:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1575);
      END_STATE();
    case 957:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1582);
      END_STATE();
    case 958:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1577);
      END_STATE();
    case 959:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1579);
      END_STATE();
    case 960:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1580);
      END_STATE();
    case 961:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(30);
      END_STATE();
    case 962:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(48);
      END_STATE();
    case 963:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(32);
      END_STATE();
    case 964:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(49);
      END_STATE();
    case 965:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 1352,
        '"', 30,
        '#', 1022,
        '$', 958,
        '%', 1836,
        '&', 47,
        '\'', 48,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1358,
        '/', 1857,
        ':', 1338,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        'B', 330,
        'C', 169,
        'D', 170,
        'E', 300,
        'F', 173,
        'L', 397,
        'N', 174,
        'P', 177,
        'R', 178,
        'S', 258,
        'U', 649,
        '[', 1333,
        ']', 1334,
        'b', 133,
        'c', 96,
        'd', 35,
        'e', 97,
        'f', 142,
        'l', 147,
        'n', 125,
        'p', 163,
        'r', 36,
        's', 34,
        'u', 33,
        '{', 1339,
        '|', 1342,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 264,
        'a', 264,
        'G', 758,
        'g', 758,
        'H', 188,
        'h', 188,
        'I', 463,
        'i', 463,
        'J', 198,
        'j', 198,
        'K', 333,
        'k', 333,
        'M', 1307,
        'm', 1307,
        'O', 623,
        'o', 623,
        'T', 180,
        't', 180,
        'V', 200,
        'v', 200,
        'W', 494,
        'w', 494,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(965);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1568);
      END_STATE();
    case 966:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 1351,
        '"', 30,
        '#', 1022,
        '$', 958,
        '\'', 48,
        '(', 1330,
        ',', 1329,
        '-', 53,
        '/', 50,
        '<', 1346,
        'D', 1392,
        'F', 1377,
        'R', 1374,
        'S', 1415,
        'U', 1486,
        '[', 1333,
        'd', 1361,
        'f', 1371,
        'r', 1359,
        's', 1362,
        'u', 1366,
        '{', 1339,
        '|', 94,
        '}', 1340,
        'A', 1451,
        'a', 1451,
        'B', 1393,
        'b', 1393,
        'C', 1379,
        'c', 1379,
        'I', 1428,
        'i', 1428,
        'K', 1442,
        'k', 1442,
        'L', 1411,
        'l', 1411,
        'N', 1481,
        'n', 1481,
        'T', 1439,
        't', 1439,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(966);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      if (('E' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('e' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 967:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1834,
        '.', 1358,
        '/', 1857,
        ':', 1338,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        '[', 1333,
        ']', 1334,
        '{', 1339,
        '|', 95,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 603,
        'a', 603,
        'C', 229,
        'c', 229,
        'D', 394,
        'd', 394,
        'E', 467,
        'e', 467,
        'F', 390,
        'f', 390,
        'G', 758,
        'g', 758,
        'H', 673,
        'h', 673,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'M', 1308,
        'm', 1308,
        'N', 718,
        'n', 718,
        'O', 774,
        'o', 774,
        'P', 185,
        'p', 185,
        'R', 179,
        'r', 179,
        'S', 288,
        's', 288,
        'T', 511,
        't', 511,
        'U', 648,
        'u', 648,
        'V', 199,
        'v', 199,
        'W', 514,
        'w', 514,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(967);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 968:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1834,
        '.', 1358,
        '/', 1857,
        ':', 1338,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        'A', 604,
        'E', 467,
        'L', 526,
        'N', 717,
        'S', 428,
        'U', 682,
        '[', 1333,
        ']', 1334,
        'a', 98,
        'e', 117,
        'l', 148,
        'n', 126,
        's', 143,
        'u', 150,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'C', 230,
        'c', 230,
        'D', 404,
        'd', 404,
        'F', 388,
        'f', 388,
        'G', 785,
        'g', 785,
        'H', 673,
        'h', 673,
        'I', 651,
        'i', 651,
        'M', 1309,
        'm', 1309,
        'O', 759,
        'o', 759,
        'P', 224,
        'p', 224,
        'R', 430,
        'r', 430,
        'T', 542,
        't', 542,
        'V', 199,
        'v', 199,
        'W', 515,
        'w', 515,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(968);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 969:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1834,
        '.', 1358,
        '/', 1857,
        ':', 1338,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        ']', 1334,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 603,
        'a', 603,
        'C', 502,
        'c', 502,
        'D', 395,
        'd', 395,
        'E', 941,
        'e', 941,
        'F', 389,
        'f', 389,
        'G', 785,
        'g', 785,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'M', 402,
        'm', 402,
        'N', 718,
        'n', 718,
        'O', 774,
        'o', 774,
        'P', 185,
        'p', 185,
        'R', 179,
        'r', 179,
        'S', 291,
        's', 291,
        'T', 542,
        't', 542,
        'U', 704,
        'u', 704,
        'V', 199,
        'v', 199,
        'W', 514,
        'w', 514,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(969);
      END_STATE();
    case 970:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1834,
        '.', 1357,
        '/', 1857,
        ':', 1337,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 1343,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 602,
        'a', 602,
        'B', 622,
        'b', 622,
        'C', 500,
        'c', 500,
        'D', 171,
        'd', 171,
        'E', 647,
        'e', 647,
        'F', 387,
        'f', 387,
        'G', 785,
        'g', 785,
        'H', 519,
        'h', 519,
        'I', 651,
        'i', 651,
        'K', 332,
        'k', 332,
        'L', 526,
        'l', 526,
        'M', 403,
        'm', 403,
        'N', 176,
        'n', 176,
        'O', 624,
        'o', 624,
        'P', 186,
        'p', 186,
        'R', 379,
        'r', 379,
        'S', 289,
        's', 289,
        'T', 181,
        't', 181,
        'U', 650,
        'u', 650,
        'V', 227,
        'v', 227,
        'W', 493,
        'w', 493,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(970);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1581);
      END_STATE();
    case 971:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1834,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        ']', 1334,
        '{', 1339,
        '|', 1343,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 603,
        'a', 603,
        'C', 228,
        'c', 228,
        'D', 394,
        'd', 394,
        'E', 467,
        'e', 467,
        'F', 386,
        'f', 386,
        'G', 785,
        'g', 785,
        'H', 673,
        'h', 673,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'M', 1308,
        'm', 1308,
        'N', 718,
        'n', 718,
        'O', 670,
        'o', 670,
        'P', 185,
        'p', 185,
        'R', 179,
        'r', 179,
        'S', 290,
        's', 290,
        'T', 510,
        't', 510,
        'U', 648,
        'u', 648,
        'V', 199,
        'v', 199,
        'W', 493,
        'w', 493,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(971);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(138);
      END_STATE();
    case 972:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        '(', 1330,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1833,
        '/', 1857,
        ':', 89,
        ';', 1023,
        '<', 1348,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        ']', 1334,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 603,
        'a', 603,
        'C', 502,
        'c', 502,
        'D', 395,
        'd', 395,
        'E', 941,
        'e', 941,
        'F', 390,
        'f', 390,
        'G', 785,
        'g', 785,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'M', 402,
        'm', 402,
        'N', 718,
        'n', 718,
        'O', 774,
        'o', 774,
        'P', 185,
        'p', 185,
        'R', 179,
        'r', 179,
        'S', 292,
        's', 292,
        'T', 512,
        't', 512,
        'U', 704,
        'u', 704,
        'V', 199,
        'v', 199,
        'W', 514,
        'w', 514,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(972);
      END_STATE();
    case 973:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 1336,
        '@', 1837,
        '[', 1333,
        ']', 1334,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(973);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 974:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1749,
        'c', 1749,
        'E', 1824,
        'e', 1824,
        'I', 1724,
        'i', 1724,
        'M', 1617,
        'm', 1617,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1584,
        'p', 1584,
        'R', 1618,
        'r', 1618,
        'S', 1636,
        's', 1636,
        'T', 1672,
        't', 1672,
        'U', 1725,
        'u', 1725,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(974);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 975:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1749,
        'c', 1749,
        'I', 1724,
        'i', 1724,
        'M', 1617,
        'm', 1617,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1584,
        'p', 1584,
        'R', 1654,
        'r', 1654,
        'S', 1636,
        's', 1636,
        'T', 1672,
        't', 1672,
        'U', 1725,
        'u', 1725,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(975);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 976:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1749,
        'c', 1749,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'R', 1654,
        'r', 1654,
        'S', 1636,
        's', 1636,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(976);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 977:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1667,
        'c', 1667,
        'G', 1775,
        'g', 1775,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1652,
        'p', 1652,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(977);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 978:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'E', 1824,
        'e', 1824,
        'F', 1647,
        'f', 1647,
        'G', 1775,
        'g', 1775,
        'I', 1724,
        'i', 1724,
        'L', 1675,
        'l', 1675,
        'N', 1747,
        'n', 1747,
        'O', 1769,
        'o', 1769,
        'P', 1591,
        'p', 1591,
        'S', 1765,
        's', 1765,
        'T', 1672,
        't', 1672,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(978);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 979:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'E', 1824,
        'e', 1824,
        'F', 1647,
        'f', 1647,
        'G', 1775,
        'g', 1775,
        'I', 1724,
        'i', 1724,
        'L', 1675,
        'l', 1675,
        'N', 1747,
        'n', 1747,
        'O', 1769,
        'o', 1769,
        'P', 1591,
        'p', 1591,
        'S', 1765,
        's', 1765,
        'T', 1672,
        't', 1672,
        'W', 1670,
        'w', 1670,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(979);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 980:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'E', 1824,
        'e', 1824,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'R', 1654,
        'r', 1654,
        'T', 1672,
        't', 1672,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(980);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 981:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'E', 1824,
        'e', 1824,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(981);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 982:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'F', 1647,
        'f', 1647,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(982);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 983:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'R', 1654,
        'r', 1654,
        'T', 1672,
        't', 1672,
        'W', 1671,
        'w', 1671,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(983);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 984:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'R', 1654,
        'r', 1654,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(984);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 985:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(985);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 986:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'R', 1654,
        'r', 1654,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(986);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 987:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(987);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 988:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1693,
        'a', 1693,
        'C', 1752,
        'c', 1752,
        'D', 1645,
        'd', 1645,
        'E', 1824,
        'e', 1824,
        'F', 1647,
        'f', 1647,
        'I', 1724,
        'i', 1724,
        'L', 1675,
        'l', 1675,
        'N', 1746,
        'n', 1746,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'R', 1590,
        'r', 1590,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(988);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 989:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        ',', 1329,
        '-', 1833,
        '/', 1857,
        ';', 1023,
        '<', 1348,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 601,
        'a', 601,
        'C', 738,
        'c', 738,
        'E', 941,
        'e', 941,
        'F', 385,
        'f', 385,
        'G', 785,
        'g', 785,
        'I', 651,
        'i', 651,
        'L', 526,
        'l', 526,
        'N', 717,
        'n', 717,
        'O', 759,
        'o', 759,
        'P', 223,
        'p', 223,
        'S', 747,
        's', 747,
        'T', 541,
        't', 541,
        'W', 515,
        'w', 515,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(989);
      END_STATE();
    case 990:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1667,
        'c', 1667,
        'G', 1775,
        'g', 1775,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1652,
        'p', 1652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(990);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 991:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1748,
        'c', 1748,
        'D', 1778,
        'd', 1778,
        'F', 1757,
        'f', 1757,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1652,
        'p', 1652,
        'S', 1604,
        's', 1604,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(991);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 992:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1748,
        'c', 1748,
        'F', 1757,
        'f', 1757,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(992);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 993:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1748,
        'c', 1748,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1652,
        'p', 1652,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(993);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 994:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'E', 1824,
        'e', 1824,
        'F', 1647,
        'f', 1647,
        'G', 1775,
        'g', 1775,
        'I', 1724,
        'i', 1724,
        'L', 1675,
        'l', 1675,
        'N', 1747,
        'n', 1747,
        'O', 1769,
        'o', 1769,
        'P', 1591,
        'p', 1591,
        'S', 1765,
        's', 1765,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(994);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 995:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'E', 1824,
        'e', 1824,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1591,
        'p', 1591,
        'R', 1654,
        'r', 1654,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(995);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 996:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'F', 1647,
        'f', 1647,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(996);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 997:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1695,
        'a', 1695,
        'C', 1758,
        'c', 1758,
        'I', 1724,
        'i', 1724,
        'L', 1675,
        'l', 1675,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(997);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 998:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1694,
        'a', 1694,
        'C', 1748,
        'c', 1748,
        'D', 1630,
        'd', 1630,
        'F', 1710,
        'f', 1710,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1652,
        'p', 1652,
        'R', 1650,
        'r', 1650,
        'T', 1828,
        't', 1828,
        'V', 1594,
        'v', 1594,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(998);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 999:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '!', 93,
        '#', 1022,
        '%', 1836,
        '&', 47,
        ')', 1331,
        '*', 1356,
        '+', 1853,
        '-', 1835,
        '.', 1357,
        '/', 1857,
        ';', 1023,
        '<', 1347,
        '=', 1328,
        '>', 1350,
        '?', 90,
        '@', 1837,
        '[', 1333,
        '{', 1339,
        '|', 166,
        '}', 1340,
        '~', 1848,
        0xd7, 1856,
        0xf7, 1858,
        0x2208, 1865,
        0x2209, 1866,
        0x220b, 1860,
        0x220c, 1861,
        0x2282, 1868,
        0x2283, 1863,
        0x2284, 1869,
        0x2285, 1864,
        0x2286, 1867,
        0x2287, 1862,
        'A', 1694,
        'a', 1694,
        'C', 1748,
        'c', 1748,
        'D', 1630,
        'd', 1630,
        'F', 1711,
        'f', 1711,
        'I', 1724,
        'i', 1724,
        'N', 1747,
        'n', 1747,
        'O', 1767,
        'o', 1767,
        'P', 1652,
        'p', 1652,
        'R', 1650,
        'r', 1650,
        'T', 1828,
        't', 1828,
        'V', 1594,
        'v', 1594,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(999);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1000:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '#', 1022,
        ')', 1331,
        ',', 1329,
        '-', 55,
        '/', 50,
        ';', 1023,
        '<', 1345,
        '>', 1349,
        ']', 1334,
        '|', 1341,
        '}', 1340,
        'A', 265,
        'a', 265,
        'C', 231,
        'c', 231,
        'D', 172,
        'd', 172,
        'E', 466,
        'e', 466,
        'F', 540,
        'f', 540,
        'H', 673,
        'h', 673,
        'I', 476,
        'i', 476,
        'M', 1309,
        'm', 1309,
        'N', 175,
        'n', 175,
        'P', 232,
        'p', 232,
        'R', 384,
        'r', 384,
        'S', 280,
        's', 280,
        'T', 182,
        't', 182,
        'U', 683,
        'u', 683,
        'V', 199,
        'v', 199,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1000);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1567);
      END_STATE();
    case 1001:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '#', 1022,
        ')', 1331,
        ',', 1329,
        '-', 54,
        '/', 50,
        ';', 1023,
        '|', 1341,
        '}', 1340,
        'A', 811,
        'a', 811,
        'C', 517,
        'c', 517,
        'E', 646,
        'e', 646,
        'F', 775,
        'f', 775,
        'H', 187,
        'h', 187,
        'I', 672,
        'i', 672,
        'J', 197,
        'j', 197,
        'M', 195,
        'm', 195,
        'O', 917,
        'o', 917,
        'P', 331,
        'p', 331,
        'T', 711,
        't', 711,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1001);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1569);
      END_STATE();
    case 1002:
      if (eof) ADVANCE(1003);
      ADVANCE_MAP(
        '#', 1022,
        ')', 1331,
        '-', 54,
        '/', 50,
        ';', 1023,
        '=', 1327,
        '[', 1333,
        '{', 1339,
        '}', 1340,
        'C', 1760,
        'c', 1760,
        'P', 1591,
        'p', 1591,
        'R', 1654,
        'r', 1654,
        'S', 1636,
        's', 1636,
        'T', 1672,
        't', 1672,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1002);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1003:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 1004:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\n') ADVANCE(2);
      if (lookahead == '*') ADVANCE(1);
      if (lookahead != 0) ADVANCE(2);
      END_STATE();
    case 1005:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == ' ') ADVANCE(1012);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1006:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(1005);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1007:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(1006);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1008:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(1007);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1009:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(1008);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1010:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(1009);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1011:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '-') ADVANCE(1010);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1012:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'Q') ADVANCE(1020);
      if (lookahead == 'R') ADVANCE(1013);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1013:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'e') ADVANCE(1017);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1014:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'e') ADVANCE(1016);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1015:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'l') ADVANCE(1018);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1016:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'r') ADVANCE(1021);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1017:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 's') ADVANCE(1019);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1018:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 't') ADVANCE(1022);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'u') ADVANCE(1015);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1020:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'u') ADVANCE(1014);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1021:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == 'y') ADVANCE(1022);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1022:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(1022);
      END_STATE();
    case 1023:
      ACCEPT_TOKEN(sym_semi_colon);
      END_STATE();
    case 1024:
      ACCEPT_TOKEN(sym_keyword_info);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1025:
      ACCEPT_TOKEN(sym_keyword_show);
      END_STATE();
    case 1026:
      ACCEPT_TOKEN(sym_keyword_show);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1027:
      ACCEPT_TOKEN(sym_keyword_changes);
      END_STATE();
    case 1028:
      ACCEPT_TOKEN(sym_keyword_since);
      END_STATE();
    case 1029:
      ACCEPT_TOKEN(sym_keyword_if);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(sym_keyword_if);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1031:
      ACCEPT_TOKEN(sym_keyword_if);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1032:
      ACCEPT_TOKEN(sym_keyword_throw);
      END_STATE();
    case 1033:
      ACCEPT_TOKEN(sym_keyword_throw);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1034:
      ACCEPT_TOKEN(sym_keyword_exists);
      END_STATE();
    case 1035:
      ACCEPT_TOKEN(sym_keyword_tokenizers);
      END_STATE();
    case 1036:
      ACCEPT_TOKEN(sym_keyword_overwrite);
      END_STATE();
    case 1037:
      ACCEPT_TOKEN(sym_keyword_overwrite);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1038:
      ACCEPT_TOKEN(sym_keyword_overwrite);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1039:
      ACCEPT_TOKEN(sym_keyword_on);
      END_STATE();
    case 1040:
      ACCEPT_TOKEN(sym_keyword_on);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1041:
      ACCEPT_TOKEN(sym_keyword_on);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1042:
      ACCEPT_TOKEN(sym_keyword_let);
      END_STATE();
    case 1043:
      ACCEPT_TOKEN(sym_keyword_let);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(sym_keyword_return);
      END_STATE();
    case 1045:
      ACCEPT_TOKEN(sym_keyword_return);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1046:
      ACCEPT_TOKEN(sym_keyword_return);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1047:
      ACCEPT_TOKEN(sym_keyword_else);
      END_STATE();
    case 1048:
      ACCEPT_TOKEN(sym_keyword_select);
      END_STATE();
    case 1049:
      ACCEPT_TOKEN(sym_keyword_select);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1050:
      ACCEPT_TOKEN(sym_keyword_from);
      END_STATE();
    case 1051:
      ACCEPT_TOKEN(sym_keyword_from);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1052:
      ACCEPT_TOKEN(sym_keyword_only);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1053:
      ACCEPT_TOKEN(sym_keyword_value);
      END_STATE();
    case 1054:
      ACCEPT_TOKEN(sym_keyword_value);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1055:
      ACCEPT_TOKEN(sym_keyword_value);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1056:
      ACCEPT_TOKEN(sym_keyword_as);
      END_STATE();
    case 1057:
      ACCEPT_TOKEN(sym_keyword_as);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1058:
      ACCEPT_TOKEN(sym_keyword_omit);
      END_STATE();
    case 1059:
      ACCEPT_TOKEN(sym_keyword_omit);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1060:
      ACCEPT_TOKEN(sym_keyword_explain);
      END_STATE();
    case 1061:
      ACCEPT_TOKEN(sym_keyword_explain);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1062:
      ACCEPT_TOKEN(sym_keyword_full);
      END_STATE();
    case 1063:
      ACCEPT_TOKEN(sym_keyword_parallel);
      END_STATE();
    case 1064:
      ACCEPT_TOKEN(sym_keyword_parallel);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1065:
      ACCEPT_TOKEN(sym_keyword_timeout);
      END_STATE();
    case 1066:
      ACCEPT_TOKEN(sym_keyword_timeout);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1067:
      ACCEPT_TOKEN(sym_keyword_fetch);
      END_STATE();
    case 1068:
      ACCEPT_TOKEN(sym_keyword_fetch);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1069:
      ACCEPT_TOKEN(sym_keyword_limit);
      END_STATE();
    case 1070:
      ACCEPT_TOKEN(sym_keyword_limit);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1071:
      ACCEPT_TOKEN(sym_keyword_by);
      END_STATE();
    case 1072:
      ACCEPT_TOKEN(sym_keyword_by);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1073:
      ACCEPT_TOKEN(sym_keyword_by);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1074:
      ACCEPT_TOKEN(sym_keyword_rand);
      END_STATE();
    case 1075:
      ACCEPT_TOKEN(sym_keyword_rand);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1076:
      ACCEPT_TOKEN(sym_keyword_rand);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1077:
      ACCEPT_TOKEN(sym_keyword_collate);
      END_STATE();
    case 1078:
      ACCEPT_TOKEN(sym_keyword_collate);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1079:
      ACCEPT_TOKEN(sym_keyword_numeric);
      END_STATE();
    case 1080:
      ACCEPT_TOKEN(sym_keyword_numeric);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1081:
      ACCEPT_TOKEN(sym_keyword_asc);
      END_STATE();
    case 1082:
      ACCEPT_TOKEN(sym_keyword_asc);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1083:
      ACCEPT_TOKEN(sym_keyword_desc);
      END_STATE();
    case 1084:
      ACCEPT_TOKEN(sym_keyword_desc);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1085:
      ACCEPT_TOKEN(sym_keyword_order);
      END_STATE();
    case 1086:
      ACCEPT_TOKEN(sym_keyword_order);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1087:
      ACCEPT_TOKEN(sym_keyword_with);
      END_STATE();
    case 1088:
      ACCEPT_TOKEN(sym_keyword_with);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1089:
      ACCEPT_TOKEN(sym_keyword_index);
      END_STATE();
    case 1090:
      ACCEPT_TOKEN(sym_keyword_no_index);
      END_STATE();
    case 1091:
      ACCEPT_TOKEN(sym_keyword_where);
      END_STATE();
    case 1092:
      ACCEPT_TOKEN(sym_keyword_where);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1093:
      ACCEPT_TOKEN(sym_keyword_where);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1094:
      ACCEPT_TOKEN(sym_keyword_split);
      END_STATE();
    case 1095:
      ACCEPT_TOKEN(sym_keyword_split);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1096:
      ACCEPT_TOKEN(sym_keyword_at);
      END_STATE();
    case 1097:
      ACCEPT_TOKEN(sym_keyword_at);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1098:
      ACCEPT_TOKEN(sym_keyword_group);
      END_STATE();
    case 1099:
      ACCEPT_TOKEN(sym_keyword_group);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1100:
      ACCEPT_TOKEN(sym_keyword_true);
      END_STATE();
    case 1101:
      ACCEPT_TOKEN(sym_keyword_true);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1102:
      ACCEPT_TOKEN(sym_keyword_false);
      END_STATE();
    case 1103:
      ACCEPT_TOKEN(sym_keyword_false);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1104:
      ACCEPT_TOKEN(sym_keyword_begin);
      END_STATE();
    case 1105:
      ACCEPT_TOKEN(sym_keyword_begin);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1106:
      ACCEPT_TOKEN(sym_keyword_cancel);
      END_STATE();
    case 1107:
      ACCEPT_TOKEN(sym_keyword_cancel);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1108:
      ACCEPT_TOKEN(sym_keyword_commit);
      END_STATE();
    case 1109:
      ACCEPT_TOKEN(sym_keyword_commit);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1110:
      ACCEPT_TOKEN(sym_keyword_transaction);
      END_STATE();
    case 1111:
      ACCEPT_TOKEN(sym_keyword_none);
      END_STATE();
    case 1112:
      ACCEPT_TOKEN(sym_keyword_none);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1113:
      ACCEPT_TOKEN(sym_keyword_null);
      END_STATE();
    case 1114:
      ACCEPT_TOKEN(sym_keyword_null);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1115:
      ACCEPT_TOKEN(sym_keyword_and);
      END_STATE();
    case 1116:
      ACCEPT_TOKEN(sym_keyword_and);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1117:
      ACCEPT_TOKEN(sym_keyword_or);
      END_STATE();
    case 1118:
      ACCEPT_TOKEN(sym_keyword_or);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1649);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1119:
      ACCEPT_TOKEN(sym_keyword_or);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(431);
      END_STATE();
    case 1120:
      ACCEPT_TOKEN(sym_keyword_or);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1121:
      ACCEPT_TOKEN(sym_keyword_is);
      END_STATE();
    case 1122:
      ACCEPT_TOKEN(sym_keyword_is);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1123:
      ACCEPT_TOKEN(sym_keyword_not);
      END_STATE();
    case 1124:
      ACCEPT_TOKEN(sym_keyword_not);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1125:
      ACCEPT_TOKEN(sym_keyword_not);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(686);
      END_STATE();
    case 1126:
      ACCEPT_TOKEN(sym_keyword_not);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1744);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1127:
      ACCEPT_TOKEN(sym_keyword_contains);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(600);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(714);
      END_STATE();
    case 1128:
      ACCEPT_TOKEN(sym_keyword_contains);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1705);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1750);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1129:
      ACCEPT_TOKEN(sym_keyword_contains_not);
      END_STATE();
    case 1130:
      ACCEPT_TOKEN(sym_keyword_contains_not);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1131:
      ACCEPT_TOKEN(sym_keyword_contains_all);
      END_STATE();
    case 1132:
      ACCEPT_TOKEN(sym_keyword_contains_all);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1133:
      ACCEPT_TOKEN(sym_keyword_contains_any);
      END_STATE();
    case 1134:
      ACCEPT_TOKEN(sym_keyword_contains_any);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1135:
      ACCEPT_TOKEN(sym_keyword_contains_none);
      END_STATE();
    case 1136:
      ACCEPT_TOKEN(sym_keyword_contains_none);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1137:
      ACCEPT_TOKEN(sym_keyword_inside);
      END_STATE();
    case 1138:
      ACCEPT_TOKEN(sym_keyword_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1139:
      ACCEPT_TOKEN(sym_keyword_in);
      END_STATE();
    case 1140:
      ACCEPT_TOKEN(sym_keyword_in);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(547);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(429);
      END_STATE();
    case 1141:
      ACCEPT_TOKEN(sym_keyword_in);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1673);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1639);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1142:
      ACCEPT_TOKEN(sym_keyword_not_inside);
      END_STATE();
    case 1143:
      ACCEPT_TOKEN(sym_keyword_not_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1144:
      ACCEPT_TOKEN(sym_keyword_all_inside);
      END_STATE();
    case 1145:
      ACCEPT_TOKEN(sym_keyword_all_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1146:
      ACCEPT_TOKEN(sym_keyword_any_inside);
      END_STATE();
    case 1147:
      ACCEPT_TOKEN(sym_keyword_any_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1148:
      ACCEPT_TOKEN(sym_keyword_none_inside);
      END_STATE();
    case 1149:
      ACCEPT_TOKEN(sym_keyword_none_inside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1150:
      ACCEPT_TOKEN(sym_keyword_outside);
      END_STATE();
    case 1151:
      ACCEPT_TOKEN(sym_keyword_outside);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1152:
      ACCEPT_TOKEN(sym_keyword_intersects);
      END_STATE();
    case 1153:
      ACCEPT_TOKEN(sym_keyword_intersects);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1154:
      ACCEPT_TOKEN(sym_keyword_chebyshev);
      END_STATE();
    case 1155:
      ACCEPT_TOKEN(sym_keyword_cosine);
      END_STATE();
    case 1156:
      ACCEPT_TOKEN(sym_keyword_euclidean);
      END_STATE();
    case 1157:
      ACCEPT_TOKEN(sym_keyword_hamming);
      END_STATE();
    case 1158:
      ACCEPT_TOKEN(sym_keyword_jaccard);
      END_STATE();
    case 1159:
      ACCEPT_TOKEN(sym_keyword_manhattan);
      END_STATE();
    case 1160:
      ACCEPT_TOKEN(sym_keyword_minkowski);
      END_STATE();
    case 1161:
      ACCEPT_TOKEN(sym_keyword_pearson);
      END_STATE();
    case 1162:
      ACCEPT_TOKEN(sym_keyword_define);
      END_STATE();
    case 1163:
      ACCEPT_TOKEN(sym_keyword_define);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1164:
      ACCEPT_TOKEN(sym_keyword_analyzer);
      END_STATE();
    case 1165:
      ACCEPT_TOKEN(sym_keyword_event);
      END_STATE();
    case 1166:
      ACCEPT_TOKEN(sym_keyword_field);
      END_STATE();
    case 1167:
      ACCEPT_TOKEN(sym_keyword_function);
      END_STATE();
    case 1168:
      ACCEPT_TOKEN(sym_keyword_namespace);
      END_STATE();
    case 1169:
      ACCEPT_TOKEN(sym_keyword_param);
      END_STATE();
    case 1170:
      ACCEPT_TOKEN(sym_keyword_scope);
      END_STATE();
    case 1171:
      ACCEPT_TOKEN(sym_keyword_drop);
      END_STATE();
    case 1172:
      ACCEPT_TOKEN(sym_keyword_drop);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1173:
      ACCEPT_TOKEN(sym_keyword_schemafull);
      END_STATE();
    case 1174:
      ACCEPT_TOKEN(sym_keyword_schemafull);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1175:
      ACCEPT_TOKEN(sym_keyword_schemaless);
      END_STATE();
    case 1176:
      ACCEPT_TOKEN(sym_keyword_schemaless);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1177:
      ACCEPT_TOKEN(sym_keyword_live);
      END_STATE();
    case 1178:
      ACCEPT_TOKEN(sym_keyword_live);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1179:
      ACCEPT_TOKEN(sym_keyword_diff);
      END_STATE();
    case 1180:
      ACCEPT_TOKEN(sym_keyword_diff);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1181:
      ACCEPT_TOKEN(sym_keyword_flexible);
      END_STATE();
    case 1182:
      ACCEPT_TOKEN(sym_keyword_flexible);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1183:
      ACCEPT_TOKEN(sym_keyword_readonly);
      END_STATE();
    case 1184:
      ACCEPT_TOKEN(sym_keyword_readonly);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1185:
      ACCEPT_TOKEN(sym_keyword_jwks);
      END_STATE();
    case 1186:
      ACCEPT_TOKEN(sym_keyword_eddsa);
      END_STATE();
    case 1187:
      ACCEPT_TOKEN(sym_keyword_es256);
      END_STATE();
    case 1188:
      ACCEPT_TOKEN(sym_keyword_es384);
      END_STATE();
    case 1189:
      ACCEPT_TOKEN(sym_keyword_es512);
      END_STATE();
    case 1190:
      ACCEPT_TOKEN(sym_keyword_ps256);
      END_STATE();
    case 1191:
      ACCEPT_TOKEN(sym_keyword_ps384);
      END_STATE();
    case 1192:
      ACCEPT_TOKEN(sym_keyword_ps512);
      END_STATE();
    case 1193:
      ACCEPT_TOKEN(sym_keyword_rs256);
      END_STATE();
    case 1194:
      ACCEPT_TOKEN(sym_keyword_rs384);
      END_STATE();
    case 1195:
      ACCEPT_TOKEN(sym_keyword_rs512);
      END_STATE();
    case 1196:
      ACCEPT_TOKEN(sym_keyword_hs256);
      END_STATE();
    case 1197:
      ACCEPT_TOKEN(sym_keyword_hs384);
      END_STATE();
    case 1198:
      ACCEPT_TOKEN(sym_keyword_hs512);
      END_STATE();
    case 1199:
      ACCEPT_TOKEN(sym_keyword_bm25);
      END_STATE();
    case 1200:
      ACCEPT_TOKEN(sym_keyword_doc_ids_cache);
      END_STATE();
    case 1201:
      ACCEPT_TOKEN(sym_keyword_doc_ids_order);
      END_STATE();
    case 1202:
      ACCEPT_TOKEN(sym_keyword_doc_lengths_cache);
      END_STATE();
    case 1203:
      ACCEPT_TOKEN(sym_keyword_doc_lengths_order);
      END_STATE();
    case 1204:
      ACCEPT_TOKEN(sym_keyword_postings_cache);
      END_STATE();
    case 1205:
      ACCEPT_TOKEN(sym_keyword_postings_order);
      END_STATE();
    case 1206:
      ACCEPT_TOKEN(sym_keyword_terms_cache);
      END_STATE();
    case 1207:
      ACCEPT_TOKEN(sym_keyword_terms_order);
      END_STATE();
    case 1208:
      ACCEPT_TOKEN(sym_keyword_highlights);
      END_STATE();
    case 1209:
      ACCEPT_TOKEN(sym_keyword_any);
      END_STATE();
    case 1210:
      ACCEPT_TOKEN(sym_keyword_any);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(709);
      END_STATE();
    case 1211:
      ACCEPT_TOKEN(sym_keyword_normal);
      END_STATE();
    case 1212:
      ACCEPT_TOKEN(sym_keyword_relation);
      END_STATE();
    case 1213:
      ACCEPT_TOKEN(sym_keyword_out);
      END_STATE();
    case 1214:
      ACCEPT_TOKEN(sym_keyword_to);
      END_STATE();
    case 1215:
      ACCEPT_TOKEN(sym_keyword_changefeed);
      END_STATE();
    case 1216:
      ACCEPT_TOKEN(sym_keyword_changefeed);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1217:
      ACCEPT_TOKEN(sym_keyword_content);
      END_STATE();
    case 1218:
      ACCEPT_TOKEN(sym_keyword_content);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1219:
      ACCEPT_TOKEN(sym_keyword_merge);
      END_STATE();
    case 1220:
      ACCEPT_TOKEN(sym_keyword_merge);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1221:
      ACCEPT_TOKEN(sym_keyword_patch);
      END_STATE();
    case 1222:
      ACCEPT_TOKEN(sym_keyword_patch);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1223:
      ACCEPT_TOKEN(sym_keyword_replace);
      END_STATE();
    case 1224:
      ACCEPT_TOKEN(sym_keyword_replace);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1225:
      ACCEPT_TOKEN(sym_keyword_before);
      END_STATE();
    case 1226:
      ACCEPT_TOKEN(sym_keyword_before);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1227:
      ACCEPT_TOKEN(sym_keyword_after);
      END_STATE();
    case 1228:
      ACCEPT_TOKEN(sym_keyword_after);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1229:
      ACCEPT_TOKEN(sym_keyword_table);
      END_STATE();
    case 1230:
      ACCEPT_TOKEN(sym_keyword_table);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1231:
      ACCEPT_TOKEN(sym_keyword_root);
      END_STATE();
    case 1232:
      ACCEPT_TOKEN(sym_keyword_token);
      END_STATE();
    case 1233:
      ACCEPT_TOKEN(sym_keyword_use);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1234:
      ACCEPT_TOKEN(sym_keyword_use);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1237);
      END_STATE();
    case 1235:
      ACCEPT_TOKEN(sym_keyword_ns);
      END_STATE();
    case 1236:
      ACCEPT_TOKEN(sym_keyword_db);
      END_STATE();
    case 1237:
      ACCEPT_TOKEN(sym_keyword_user);
      END_STATE();
    case 1238:
      ACCEPT_TOKEN(sym_keyword_roles);
      END_STATE();
    case 1239:
      ACCEPT_TOKEN(sym_keyword_remove);
      END_STATE();
    case 1240:
      ACCEPT_TOKEN(sym_keyword_remove);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1241:
      ACCEPT_TOKEN(sym_keyword_create);
      END_STATE();
    case 1242:
      ACCEPT_TOKEN(sym_keyword_create);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1243:
      ACCEPT_TOKEN(sym_keyword_delete);
      END_STATE();
    case 1244:
      ACCEPT_TOKEN(sym_keyword_delete);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1245:
      ACCEPT_TOKEN(sym_keyword_update);
      END_STATE();
    case 1246:
      ACCEPT_TOKEN(sym_keyword_update);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1247:
      ACCEPT_TOKEN(sym_keyword_upsert);
      END_STATE();
    case 1248:
      ACCEPT_TOKEN(sym_keyword_upsert);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1249:
      ACCEPT_TOKEN(sym_keyword_insert);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1250:
      ACCEPT_TOKEN(sym_keyword_into);
      END_STATE();
    case 1251:
      ACCEPT_TOKEN(sym_keyword_filters);
      END_STATE();
    case 1252:
      ACCEPT_TOKEN(sym_keyword_when);
      END_STATE();
    case 1253:
      ACCEPT_TOKEN(sym_keyword_then);
      END_STATE();
    case 1254:
      ACCEPT_TOKEN(sym_keyword_then);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1255:
      ACCEPT_TOKEN(sym_keyword_type);
      END_STATE();
    case 1256:
      ACCEPT_TOKEN(sym_keyword_type);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1257:
      ACCEPT_TOKEN(sym_keyword_default);
      END_STATE();
    case 1258:
      ACCEPT_TOKEN(sym_keyword_default);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1259:
      ACCEPT_TOKEN(sym_keyword_assert);
      END_STATE();
    case 1260:
      ACCEPT_TOKEN(sym_keyword_assert);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1261:
      ACCEPT_TOKEN(sym_keyword_permissions);
      END_STATE();
    case 1262:
      ACCEPT_TOKEN(sym_keyword_permissions);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1263:
      ACCEPT_TOKEN(sym_keyword_relate);
      END_STATE();
    case 1264:
      ACCEPT_TOKEN(sym_keyword_relate);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1265:
      ACCEPT_TOKEN(sym_keyword_ignore);
      END_STATE();
    case 1266:
      ACCEPT_TOKEN(sym_keyword_values);
      END_STATE();
    case 1267:
      ACCEPT_TOKEN(sym_keyword_for);
      END_STATE();
    case 1268:
      ACCEPT_TOKEN(sym_keyword_for);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1269:
      ACCEPT_TOKEN(sym_keyword_for);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1270:
      ACCEPT_TOKEN(sym_keyword_comment);
      END_STATE();
    case 1271:
      ACCEPT_TOKEN(sym_keyword_comment);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1272:
      ACCEPT_TOKEN(sym_keyword_fields);
      END_STATE();
    case 1273:
      ACCEPT_TOKEN(sym_keyword_columns);
      END_STATE();
    case 1274:
      ACCEPT_TOKEN(sym_keyword_unique);
      END_STATE();
    case 1275:
      ACCEPT_TOKEN(sym_keyword_search);
      END_STATE();
    case 1276:
      ACCEPT_TOKEN(sym_keyword_session);
      END_STATE();
    case 1277:
      ACCEPT_TOKEN(sym_keyword_signin);
      END_STATE();
    case 1278:
      ACCEPT_TOKEN(sym_keyword_signup);
      END_STATE();
    case 1279:
      ACCEPT_TOKEN(sym_keyword_database);
      END_STATE();
    case 1280:
      ACCEPT_TOKEN(sym_keyword_password);
      END_STATE();
    case 1281:
      ACCEPT_TOKEN(sym_keyword_password_hash);
      END_STATE();
    case 1282:
      ACCEPT_TOKEN(sym_keyword_on_duplicate_key_update);
      END_STATE();
    case 1283:
      ACCEPT_TOKEN(sym_keyword_count);
      END_STATE();
    case 1284:
      ACCEPT_TOKEN(sym_keyword_count);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1285:
      ACCEPT_TOKEN(sym_keyword_unset);
      END_STATE();
    case 1286:
      ACCEPT_TOKEN(sym_keyword_unset);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1287:
      ACCEPT_TOKEN(sym_keyword_set);
      END_STATE();
    case 1288:
      ACCEPT_TOKEN(sym_keyword_set);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1289:
      ACCEPT_TOKEN(sym_keyword_always);
      END_STATE();
    case 1290:
      ACCEPT_TOKEN(sym_keyword_always);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1291:
      ACCEPT_TOKEN(sym_keyword_alter);
      END_STATE();
    case 1292:
      ACCEPT_TOKEN(sym_keyword_alter);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1293:
      ACCEPT_TOKEN(sym_keyword_break);
      END_STATE();
    case 1294:
      ACCEPT_TOKEN(sym_keyword_break);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1295:
      ACCEPT_TOKEN(sym_keyword_continue);
      END_STATE();
    case 1296:
      ACCEPT_TOKEN(sym_keyword_continue);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1297:
      ACCEPT_TOKEN(sym_keyword_sleep);
      END_STATE();
    case 1298:
      ACCEPT_TOKEN(sym_keyword_sleep);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1299:
      ACCEPT_TOKEN(sym_keyword_kill);
      END_STATE();
    case 1300:
      ACCEPT_TOKEN(sym_keyword_kill);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1301:
      ACCEPT_TOKEN(sym_keyword_rebuild);
      END_STATE();
    case 1302:
      ACCEPT_TOKEN(sym_keyword_rebuild);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1303:
      ACCEPT_TOKEN(sym_keyword_mtree);
      END_STATE();
    case 1304:
      ACCEPT_TOKEN(sym_keyword_dimension);
      END_STATE();
    case 1305:
      ACCEPT_TOKEN(sym_keyword_dist);
      END_STATE();
    case 1306:
      ACCEPT_TOKEN(sym_keyword_efc);
      END_STATE();
    case 1307:
      ACCEPT_TOKEN(sym_keyword_m);
      ADVANCE_MAP(
        'A', 675,
        'a', 675,
        'E', 776,
        'e', 776,
        'I', 653,
        'i', 653,
        'T', 801,
        't', 801,
      );
      END_STATE();
    case 1308:
      ACCEPT_TOKEN(sym_keyword_m);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(776);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(801);
      END_STATE();
    case 1309:
      ACCEPT_TOKEN(sym_keyword_m);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(801);
      END_STATE();
    case 1310:
      ACCEPT_TOKEN(sym_keyword_capacity);
      END_STATE();
    case 1311:
      ACCEPT_TOKEN(sym_keyword_hnsw);
      END_STATE();
    case 1312:
      ACCEPT_TOKEN(sym_keyword_owner);
      END_STATE();
    case 1313:
      ACCEPT_TOKEN(sym_keyword_editor);
      END_STATE();
    case 1314:
      ACCEPT_TOKEN(sym_keyword_viewer);
      END_STATE();
    case 1315:
      ACCEPT_TOKEN(sym_keyword_duration);
      END_STATE();
    case 1316:
      ACCEPT_TOKEN(sym_keyword_enforced);
      END_STATE();
    case 1317:
      ACCEPT_TOKEN(sym_keyword_algorithm);
      END_STATE();
    case 1318:
      ACCEPT_TOKEN(sym_keyword_key);
      END_STATE();
    case 1319:
      ACCEPT_TOKEN(sym_keyword_url);
      END_STATE();
    case 1320:
      ACCEPT_TOKEN(sym_keyword_jwt);
      END_STATE();
    case 1321:
      ACCEPT_TOKEN(sym_keyword_refresh);
      END_STATE();
    case 1322:
      ACCEPT_TOKEN(sym_keyword_record);
      END_STATE();
    case 1323:
      ACCEPT_TOKEN(sym_keyword_bearer);
      END_STATE();
    case 1324:
      ACCEPT_TOKEN(sym_keyword_authenticate);
      END_STATE();
    case 1325:
      ACCEPT_TOKEN(sym_keyword_grant);
      END_STATE();
    case 1326:
      ACCEPT_TOKEN(sym_keyword_access);
      END_STATE();
    case 1327:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 1328:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(1845);
      END_STATE();
    case 1329:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 1330:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 1331:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 1332:
      ACCEPT_TOKEN(anon_sym_DASH_GT);
      END_STATE();
    case 1333:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 1334:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 1335:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 1336:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == ':') ADVANCE(1843);
      if (lookahead == '=') ADVANCE(1846);
      if (lookahead == '?') ADVANCE(1842);
      END_STATE();
    case 1337:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 1338:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(1344);
      END_STATE();
    case 1339:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 1340:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 1341:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 1342:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '>') ADVANCE(1839);
      if (lookahead == '|') ADVANCE(1841);
      END_STATE();
    case 1343:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(1841);
      END_STATE();
    case 1344:
      ACCEPT_TOKEN(anon_sym_COLON_COLON);
      END_STATE();
    case 1345:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 1346:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(1353);
      END_STATE();
    case 1347:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '-') ADVANCE(1353);
      if (lookahead == '=') ADVANCE(1851);
      if (lookahead == '|') ADVANCE(1838);
      END_STATE();
    case 1348:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(1851);
      if (lookahead == '|') ADVANCE(1838);
      END_STATE();
    case 1349:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 1350:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(1852);
      END_STATE();
    case 1351:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 1352:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(1844);
      if (lookahead == '~') ADVANCE(1849);
      END_STATE();
    case 1353:
      ACCEPT_TOKEN(anon_sym_LT_DASH);
      if (lookahead == '>') ADVANCE(1354);
      END_STATE();
    case 1354:
      ACCEPT_TOKEN(anon_sym_LT_DASH_GT);
      END_STATE();
    case 1355:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 1356:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(1859);
      if (lookahead == '=') ADVANCE(1847);
      if (lookahead == '~') ADVANCE(1850);
      END_STATE();
    case 1357:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 1358:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(1830);
      END_STATE();
    case 1359:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1466);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1386);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1360:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1466);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1361:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1432);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1362:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      ADVANCE_MAP(
        '"', 31,
        '\'', 49,
        ':', 92,
        'E', 1462,
        'e', 1462,
        'H', 1477,
        'h', 1477,
        'L', 1422,
        'l', 1422,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1363:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1462);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1477);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1364:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1436);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1365:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1366:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1391);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1367:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1368:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1369:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == '"') ADVANCE(31);
      if (lookahead == '\'') ADVANCE(49);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1370:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(91);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1371:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'n') ADVANCE(1370);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1452);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1490);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1372:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'n') ADVANCE(1370);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1452);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1373:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'n') ADVANCE(1370);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1374:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1466);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1386);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1375:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1466);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1376:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1450);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1377:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1452);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1490);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1378:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1452);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1379:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1467);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1464);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1427);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1380:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1467);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1464);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1381:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1534);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1382:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1463);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1383:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1513);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1384:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1514);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1385:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1515);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1386:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      ADVANCE_MAP(
        ':', 92,
        'B', 1524,
        'b', 1524,
        'L', 1383,
        'l', 1383,
        'M', 1484,
        'm', 1484,
        'T', 1519,
        't', 1519,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1387:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1507);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1388:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1420);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1389:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1075);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1390:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1302);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1391:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1384);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1418);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1392:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1432);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1393:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1438);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1413);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1394:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1233);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1395:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1488);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1396:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1178);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1397:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1112);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1398:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1101);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1399:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1103);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1400:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1092);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1401:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1163);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1402:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1244);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1403:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1264);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1404:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1240);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1405:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1246);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1406:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1242);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1407:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1296);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1408:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1054);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1409:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1226);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1410:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1037);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1411:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1505);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1525);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1412:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1505);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1413:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1376);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1414:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1387);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1415:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1462);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1477);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1416:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1462);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1477);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1417:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1498);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1418:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1496);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1419:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1491);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1420:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1455);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1421:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1492);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1422:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1395);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1423:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1493);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1424:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1512);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1425:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1435);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1426:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1427:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1385);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1428:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1030);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1433);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1429:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1030);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1504);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1430:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1030);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1431:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1180);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1432:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1448);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1424);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1433:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1478);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1426);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1434:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1478);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1435:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1485);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1436:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1431);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1437:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1516);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1438:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1444);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1439:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1500);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1521);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1440:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1417);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1441:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1525);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1442:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1460);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1443:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1436);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1444:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1468);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1445:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1458);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1446:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1476);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1447:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1509);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1448:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1475);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1449:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1517);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1450:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'K' ||
          lookahead == 'k') ADVANCE(1294);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1451:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1511);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1452:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1503);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1453:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1300);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1454:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1114);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1455:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1107);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1456:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1532);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1457:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1422);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1458:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1390);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1459:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1530);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1460:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1453);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1461:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1454);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1462:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1414);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1463:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1523);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1464:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1465);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1518);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1471);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1465:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1447);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1466:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1389);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1467:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1388);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1468:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1105);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1469:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1045);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1470:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1434);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1471:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1506);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1472:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1456);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1473:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1397);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1124);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1474:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1397);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1475:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1401);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1476:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1522);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1477:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1528);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1478:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1024);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1479:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1473);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1461);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1480:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1529);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1481:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1474);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1461);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1482:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1520);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1427);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1483:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1520);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1484:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1526);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1485:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1499);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1486:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1391);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1487:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1391);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1488:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1298);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1489:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1521);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1490:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1268);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1491:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1292);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1492:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1228);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1493:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1531);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1494:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1449);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1495:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1469);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1496:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1508);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1497:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1510);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1498:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1400);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1499:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1409);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1500:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1480);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1501:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1290);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1502:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1394);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1503:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1399);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1504:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1426);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1505:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1043);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1506:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1284);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1507:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1508:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1248);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1509:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1109);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1510:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1249);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1511:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1419);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1512:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1402);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1513:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1403);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1514:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1405);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1515:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1406);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1516:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1421);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1517:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1410);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1518:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1446);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1519:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1495);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1520:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1471);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1521:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1398);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1522:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1407);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1523:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1408);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1524:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1445);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1525:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1396);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1526:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1404);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1527:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1423);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1528:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1026);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1529:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1033);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1530:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1381);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1531:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1494);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1532:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1052);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1533:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1072);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1534:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1501);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1535:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1535);
      END_STATE();
    case 1536:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1537);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1537:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1543);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1538:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1545);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1539:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1038);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1540:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1230);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1541:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1031);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1542:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1548);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1543:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1540);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1544:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1041);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1545:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1550);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1546:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1542);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1547:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1097);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1548:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1539);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1549:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'V' ||
          lookahead == 'v') ADVANCE(1538);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1550:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(1546);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1551:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1073);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1552:
      ACCEPT_TOKEN(aux_sym_type_name_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1552);
      END_STATE();
    case 1553:
      ACCEPT_TOKEN(anon_sym_blank);
      END_STATE();
    case 1554:
      ACCEPT_TOKEN(anon_sym_camel);
      END_STATE();
    case 1555:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 1556:
      ACCEPT_TOKEN(anon_sym_punct);
      END_STATE();
    case 1557:
      ACCEPT_TOKEN(anon_sym_ascii);
      END_STATE();
    case 1558:
      ACCEPT_TOKEN(anon_sym_lowercase);
      END_STATE();
    case 1559:
      ACCEPT_TOKEN(anon_sym_uppercase);
      END_STATE();
    case 1560:
      ACCEPT_TOKEN(anon_sym_edgengram);
      END_STATE();
    case 1561:
      ACCEPT_TOKEN(anon_sym_ngram);
      END_STATE();
    case 1562:
      ACCEPT_TOKEN(anon_sym_snowball);
      END_STATE();
    case 1563:
      ACCEPT_TOKEN(sym_string);
      END_STATE();
    case 1564:
      ACCEPT_TOKEN(sym_prefixed_string);
      END_STATE();
    case 1565:
      ACCEPT_TOKEN(sym_prefixed_string);
      if (lookahead == '"') ADVANCE(1565);
      if (lookahead == '\\') ADVANCE(963);
      if (lookahead != 0 &&
          lookahead != '\'') ADVANCE(32);
      END_STATE();
    case 1566:
      ACCEPT_TOKEN(sym_int);
      ADVANCE_MAP(
        '.', 952,
        'm', 1832,
        'n', 157,
        'u', 157,
        0xb5, 157,
        'd', 1831,
        'h', 1831,
        's', 1831,
        'w', 1831,
        'y', 1831,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1566);
      END_STATE();
    case 1567:
      ACCEPT_TOKEN(sym_int);
      if (lookahead == '.') ADVANCE(952);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1567);
      END_STATE();
    case 1568:
      ACCEPT_TOKEN(sym_int);
      ADVANCE_MAP(
        'm', 1832,
        'n', 157,
        'u', 157,
        0xb5, 157,
        'd', 1831,
        'h', 1831,
        's', 1831,
        'w', 1831,
        'y', 1831,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(137);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1568);
      END_STATE();
    case 1569:
      ACCEPT_TOKEN(sym_int);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1569);
      END_STATE();
    case 1570:
      ACCEPT_TOKEN(sym_int);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1570);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1571:
      ACCEPT_TOKEN(sym_float);
      END_STATE();
    case 1572:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'd') ADVANCE(123);
      if (lookahead == 'f') ADVANCE(1571);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(167);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1572);
      END_STATE();
    case 1573:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'd') ADVANCE(123);
      if (lookahead == 'f') ADVANCE(1571);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1573);
      END_STATE();
    case 1574:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'f') ADVANCE(1571);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(168);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1574);
      END_STATE();
    case 1575:
      ACCEPT_TOKEN(sym_float);
      if (lookahead == 'f') ADVANCE(1571);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1575);
      END_STATE();
    case 1576:
      ACCEPT_TOKEN(sym_decimal);
      END_STATE();
    case 1577:
      ACCEPT_TOKEN(sym_variable_name);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1577);
      END_STATE();
    case 1578:
      ACCEPT_TOKEN(sym_custom_function_name);
      if (lookahead == ':') ADVANCE(91);
      END_STATE();
    case 1579:
      ACCEPT_TOKEN(sym_custom_function_name);
      if (lookahead == ':') ADVANCE(91);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1579);
      END_STATE();
    case 1580:
      ACCEPT_TOKEN(sym_function_name);
      if (lookahead == ':') ADVANCE(92);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1580);
      END_STATE();
    case 1581:
      ACCEPT_TOKEN(sym_version_number);
      if (lookahead == '.') ADVANCE(957);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1581);
      END_STATE();
    case 1582:
      ACCEPT_TOKEN(sym_version_number);
      if (lookahead == '.') ADVANCE(954);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1582);
      END_STATE();
    case 1583:
      ACCEPT_TOKEN(sym_version_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1583);
      END_STATE();
    case 1584:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1772);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1585:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1659);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1586:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1605);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1587:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1703);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1588:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1616);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1589:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1676);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1590:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1730);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1591:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1773);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1592:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1821);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1593:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1740);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1594:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1704);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1595:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1815);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1596:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1685);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1734);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1597:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(1685);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1598:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(1712);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1599:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1082);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1600:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1084);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1601:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1080);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1602:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1664);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1603:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1665);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1604:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1668);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1605:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1623);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1606:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(1813);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1607:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1116);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1690);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1608:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1076);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1609:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1216);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1610:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1621);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1611:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1622);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1612:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1624);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1613:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1625);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1614:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1626);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1615:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1627);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1616:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(1756);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1617:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1768);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1618:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1766);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1619:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1220);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1620:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1093);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1621:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1138);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1622:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1151);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1623:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1224);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1624:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1145);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1625:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1147);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1626:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1143);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1627:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1149);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1628:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1136);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1629:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1078);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1630:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1660);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1631:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1256);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1632:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1055);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1633:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1182);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1634:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1825);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1635:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1777);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1636:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1800);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1637:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1661);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1638:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1751);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1639:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1781);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1640:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1606);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1641:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1802);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1642:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1719);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1643:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1609);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1644:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1696);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1645:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1787);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1646:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1776);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1647:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1816);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1648:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1729);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1649:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1770);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1650:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1588);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1651:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1791);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1652:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1782);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1653:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1780);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1654:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1799);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1655:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1643);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1656:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1734);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1657:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1738);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1658:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1691);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1659:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1823);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1651);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1660:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1592);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1661:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(1655);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1662:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1619);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1663:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(1637);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1664:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1222);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1665:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1068);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1666:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1088);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1667:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1593);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1721);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1668:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1642);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1669:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1648);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1670:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1635);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1812);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1671:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(1635);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1672:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1716);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1673:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1610);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1674:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1598);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1675:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1717);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1676:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1727);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1677:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1601);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1678:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1792);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1679:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1805);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1680:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1806);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1681:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1810);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1682:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1742);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1683:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1611);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1684:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1759);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1685:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1732);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1686:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1612);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1687:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1613);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1688:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1614);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1689:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1615);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1690:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1743);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1691:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(1745);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1692:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1699);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1607);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1057);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1693:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1699);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1607);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1599);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1694:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1699);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1607);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1798);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1695:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1699);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1607);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1696:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1064);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1697:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1132);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1698:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1174);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1699:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1682);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1700:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1589);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1701:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1827);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1702:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1586);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1703:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1708);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1704:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1822);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1705:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1697);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1826);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1706:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1595);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1707:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1698);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1708:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1644);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1709:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1809);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1710:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1634);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1771);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1711:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1634);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1712:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1633);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1713:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1680);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1714:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(1706);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1814);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1715:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1051);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1716:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1638);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1717:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1679);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1718:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1678);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1719:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1585);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1720:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1657);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1721:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1720);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1814);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1722:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1681);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1120);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1811);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1723:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'M' ||
          lookahead == 'm') ADVANCE(1646);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1724:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1141);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1122);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1725:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1788);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1726:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1046);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1727:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1061);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1728:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1040);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1120);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1811);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1729:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1254);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1730:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1608);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1731:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1801);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1732:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1783);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1733:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1658);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1126);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1734:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1803);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1735:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1814);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1736:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1785);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1737:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1701);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1738:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1808);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1739:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1628);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1130);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1740:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1663);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1741:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1817);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1742:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1794);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1743:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1795);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1744:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1796);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1745:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(1797);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1746:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1733);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1723);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1747:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1733);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1748:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1721);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1749:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1731);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1750:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1739);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1751:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1820);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1752:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1714);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1753:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1818);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1754:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1762);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1755:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1715);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1756:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1737);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1757:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1771);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1758:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1735);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1759:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1736);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1760:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(1741);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1761:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1099);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1762:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1172);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1763:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1700);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1764:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1631);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1765:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1713);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1766:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(1702);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1819);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1767:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1120);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1811);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1768:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1662);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1769:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1118);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1811);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1770:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1086);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1771:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1269);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1772:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1587);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1602);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1773:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1587);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1774:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1726);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1775:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1753);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1776:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1677);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1777:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1620);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1778:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1754);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1779:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1755);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1780:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1807);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1781:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1790);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1782:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(1718);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1783:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1128);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1784:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1153);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1785:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1262);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1786:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1176);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1787:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1600);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1788:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1641);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1789:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1684);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1790:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1640);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1791:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1786);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1792:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1789);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1793:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1683);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1794:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1686);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1795:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1687);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1796:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1688);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1797:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1689);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1798:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(1653);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1799:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1819);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1800:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1288);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1801:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1596);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1802:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1286);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1803:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1218);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1804:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1066);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1805:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1070);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1806:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1095);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1807:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1260);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1808:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1271);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1809:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1258);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1810:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1059);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1811:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1793);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1812:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1666);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1813:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1784);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1814:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1597);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1815:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1629);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1816:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1603);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1817:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(1656);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1818:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1761);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1819:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1774);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1820:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1804);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1821:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1709);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1822:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1632);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1823:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(1707);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1824:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1763);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1825:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(1674);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1826:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1134);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1827:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1184);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1828:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(1764);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1829:
      ACCEPT_TOKEN(sym_record_id_ident);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1829);
      END_STATE();
    case 1830:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 1831:
      ACCEPT_TOKEN(sym_duration_part);
      END_STATE();
    case 1832:
      ACCEPT_TOKEN(sym_duration_part);
      if (lookahead == 's') ADVANCE(1831);
      END_STATE();
    case 1833:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(1011);
      if (lookahead == '=') ADVANCE(1855);
      END_STATE();
    case 1834:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(1011);
      if (lookahead == '=') ADVANCE(1855);
      if (lookahead == '>') ADVANCE(1332);
      END_STATE();
    case 1835:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(1011);
      if (lookahead == '=') ADVANCE(1855);
      if (lookahead == '>') ADVANCE(1332);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1569);
      END_STATE();
    case 1836:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 1837:
      ACCEPT_TOKEN(anon_sym_AT);
      if (lookahead == '@') ADVANCE(1870);
      END_STATE();
    case 1838:
      ACCEPT_TOKEN(anon_sym_LT_PIPE);
      END_STATE();
    case 1839:
      ACCEPT_TOKEN(anon_sym_PIPE_GT);
      END_STATE();
    case 1840:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 1841:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 1842:
      ACCEPT_TOKEN(anon_sym_QMARK_QMARK);
      END_STATE();
    case 1843:
      ACCEPT_TOKEN(anon_sym_QMARK_COLON);
      END_STATE();
    case 1844:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 1845:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 1846:
      ACCEPT_TOKEN(anon_sym_QMARK_EQ);
      END_STATE();
    case 1847:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 1848:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 1849:
      ACCEPT_TOKEN(anon_sym_BANG_TILDE);
      END_STATE();
    case 1850:
      ACCEPT_TOKEN(anon_sym_STAR_TILDE);
      END_STATE();
    case 1851:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 1852:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 1853:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(1854);
      END_STATE();
    case 1854:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 1855:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 1856:
      ACCEPT_TOKEN(anon_sym_u00d7);
      END_STATE();
    case 1857:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(2);
      if (lookahead == '/') ADVANCE(1022);
      END_STATE();
    case 1858:
      ACCEPT_TOKEN(anon_sym_u00f7);
      END_STATE();
    case 1859:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 1860:
      ACCEPT_TOKEN(anon_sym_u220b);
      END_STATE();
    case 1861:
      ACCEPT_TOKEN(anon_sym_u220c);
      END_STATE();
    case 1862:
      ACCEPT_TOKEN(anon_sym_u2287);
      END_STATE();
    case 1863:
      ACCEPT_TOKEN(anon_sym_u2283);
      END_STATE();
    case 1864:
      ACCEPT_TOKEN(anon_sym_u2285);
      END_STATE();
    case 1865:
      ACCEPT_TOKEN(anon_sym_u2208);
      END_STATE();
    case 1866:
      ACCEPT_TOKEN(anon_sym_u2209);
      END_STATE();
    case 1867:
      ACCEPT_TOKEN(anon_sym_u2286);
      END_STATE();
    case 1868:
      ACCEPT_TOKEN(anon_sym_u2282);
      END_STATE();
    case 1869:
      ACCEPT_TOKEN(anon_sym_u2284);
      END_STATE();
    case 1870:
      ACCEPT_TOKEN(anon_sym_AT_AT);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 11},
  [2] = {.lex_state = 970},
  [3] = {.lex_state = 966},
  [4] = {.lex_state = 966},
  [5] = {.lex_state = 966},
  [6] = {.lex_state = 966},
  [7] = {.lex_state = 966},
  [8] = {.lex_state = 966},
  [9] = {.lex_state = 966},
  [10] = {.lex_state = 966},
  [11] = {.lex_state = 966},
  [12] = {.lex_state = 966},
  [13] = {.lex_state = 966},
  [14] = {.lex_state = 966},
  [15] = {.lex_state = 966},
  [16] = {.lex_state = 971},
  [17] = {.lex_state = 971},
  [18] = {.lex_state = 967},
  [19] = {.lex_state = 969},
  [20] = {.lex_state = 969},
  [21] = {.lex_state = 20},
  [22] = {.lex_state = 20},
  [23] = {.lex_state = 969},
  [24] = {.lex_state = 20},
  [25] = {.lex_state = 20},
  [26] = {.lex_state = 969},
  [27] = {.lex_state = 20},
  [28] = {.lex_state = 969},
  [29] = {.lex_state = 969},
  [30] = {.lex_state = 969},
  [31] = {.lex_state = 969},
  [32] = {.lex_state = 969},
  [33] = {.lex_state = 969},
  [34] = {.lex_state = 969},
  [35] = {.lex_state = 969},
  [36] = {.lex_state = 969},
  [37] = {.lex_state = 969},
  [38] = {.lex_state = 969},
  [39] = {.lex_state = 969},
  [40] = {.lex_state = 969},
  [41] = {.lex_state = 969},
  [42] = {.lex_state = 969},
  [43] = {.lex_state = 969},
  [44] = {.lex_state = 969},
  [45] = {.lex_state = 969},
  [46] = {.lex_state = 969},
  [47] = {.lex_state = 969},
  [48] = {.lex_state = 969},
  [49] = {.lex_state = 969},
  [50] = {.lex_state = 20},
  [51] = {.lex_state = 20},
  [52] = {.lex_state = 20},
  [53] = {.lex_state = 20},
  [54] = {.lex_state = 969},
  [55] = {.lex_state = 20},
  [56] = {.lex_state = 969},
  [57] = {.lex_state = 969},
  [58] = {.lex_state = 20},
  [59] = {.lex_state = 969},
  [60] = {.lex_state = 969},
  [61] = {.lex_state = 20},
  [62] = {.lex_state = 20},
  [63] = {.lex_state = 969},
  [64] = {.lex_state = 969},
  [65] = {.lex_state = 969},
  [66] = {.lex_state = 969},
  [67] = {.lex_state = 20},
  [68] = {.lex_state = 969},
  [69] = {.lex_state = 20},
  [70] = {.lex_state = 20},
  [71] = {.lex_state = 20},
  [72] = {.lex_state = 20},
  [73] = {.lex_state = 969},
  [74] = {.lex_state = 969},
  [75] = {.lex_state = 969},
  [76] = {.lex_state = 20},
  [77] = {.lex_state = 20},
  [78] = {.lex_state = 20},
  [79] = {.lex_state = 20},
  [80] = {.lex_state = 20},
  [81] = {.lex_state = 20},
  [82] = {.lex_state = 20},
  [83] = {.lex_state = 20},
  [84] = {.lex_state = 20},
  [85] = {.lex_state = 20},
  [86] = {.lex_state = 20},
  [87] = {.lex_state = 20},
  [88] = {.lex_state = 20},
  [89] = {.lex_state = 20},
  [90] = {.lex_state = 20},
  [91] = {.lex_state = 20},
  [92] = {.lex_state = 20},
  [93] = {.lex_state = 20},
  [94] = {.lex_state = 20},
  [95] = {.lex_state = 20},
  [96] = {.lex_state = 20},
  [97] = {.lex_state = 20},
  [98] = {.lex_state = 20},
  [99] = {.lex_state = 20},
  [100] = {.lex_state = 20},
  [101] = {.lex_state = 20},
  [102] = {.lex_state = 20},
  [103] = {.lex_state = 20},
  [104] = {.lex_state = 20},
  [105] = {.lex_state = 20},
  [106] = {.lex_state = 972},
  [107] = {.lex_state = 972},
  [108] = {.lex_state = 972},
  [109] = {.lex_state = 972},
  [110] = {.lex_state = 12},
  [111] = {.lex_state = 12},
  [112] = {.lex_state = 21},
  [113] = {.lex_state = 969},
  [114] = {.lex_state = 969},
  [115] = {.lex_state = 21},
  [116] = {.lex_state = 969},
  [117] = {.lex_state = 21},
  [118] = {.lex_state = 969},
  [119] = {.lex_state = 21},
  [120] = {.lex_state = 969},
  [121] = {.lex_state = 967},
  [122] = {.lex_state = 967},
  [123] = {.lex_state = 967},
  [124] = {.lex_state = 967},
  [125] = {.lex_state = 967},
  [126] = {.lex_state = 967},
  [127] = {.lex_state = 967},
  [128] = {.lex_state = 967},
  [129] = {.lex_state = 967},
  [130] = {.lex_state = 967},
  [131] = {.lex_state = 967},
  [132] = {.lex_state = 967},
  [133] = {.lex_state = 967},
  [134] = {.lex_state = 967},
  [135] = {.lex_state = 967},
  [136] = {.lex_state = 967},
  [137] = {.lex_state = 967},
  [138] = {.lex_state = 967},
  [139] = {.lex_state = 967},
  [140] = {.lex_state = 967},
  [141] = {.lex_state = 968},
  [142] = {.lex_state = 967},
  [143] = {.lex_state = 967},
  [144] = {.lex_state = 967},
  [145] = {.lex_state = 967},
  [146] = {.lex_state = 967},
  [147] = {.lex_state = 967},
  [148] = {.lex_state = 967},
  [149] = {.lex_state = 967},
  [150] = {.lex_state = 967},
  [151] = {.lex_state = 967},
  [152] = {.lex_state = 967},
  [153] = {.lex_state = 967},
  [154] = {.lex_state = 967},
  [155] = {.lex_state = 967},
  [156] = {.lex_state = 967},
  [157] = {.lex_state = 967},
  [158] = {.lex_state = 967},
  [159] = {.lex_state = 967},
  [160] = {.lex_state = 967},
  [161] = {.lex_state = 967},
  [162] = {.lex_state = 967},
  [163] = {.lex_state = 967},
  [164] = {.lex_state = 967},
  [165] = {.lex_state = 967},
  [166] = {.lex_state = 967},
  [167] = {.lex_state = 967},
  [168] = {.lex_state = 967},
  [169] = {.lex_state = 967},
  [170] = {.lex_state = 967},
  [171] = {.lex_state = 967},
  [172] = {.lex_state = 967},
  [173] = {.lex_state = 967},
  [174] = {.lex_state = 967},
  [175] = {.lex_state = 967},
  [176] = {.lex_state = 972},
  [177] = {.lex_state = 989},
  [178] = {.lex_state = 989},
  [179] = {.lex_state = 972},
  [180] = {.lex_state = 989},
  [181] = {.lex_state = 972},
  [182] = {.lex_state = 972},
  [183] = {.lex_state = 974},
  [184] = {.lex_state = 974},
  [185] = {.lex_state = 989},
  [186] = {.lex_state = 972},
  [187] = {.lex_state = 974},
  [188] = {.lex_state = 974},
  [189] = {.lex_state = 988},
  [190] = {.lex_state = 988},
  [191] = {.lex_state = 979},
  [192] = {.lex_state = 979},
  [193] = {.lex_state = 972},
  [194] = {.lex_state = 968},
  [195] = {.lex_state = 968},
  [196] = {.lex_state = 968},
  [197] = {.lex_state = 968},
  [198] = {.lex_state = 972},
  [199] = {.lex_state = 972},
  [200] = {.lex_state = 968},
  [201] = {.lex_state = 979},
  [202] = {.lex_state = 975},
  [203] = {.lex_state = 988},
  [204] = {.lex_state = 988},
  [205] = {.lex_state = 975},
  [206] = {.lex_state = 979},
  [207] = {.lex_state = 978},
  [208] = {.lex_state = 978},
  [209] = {.lex_state = 968},
  [210] = {.lex_state = 968},
  [211] = {.lex_state = 968},
  [212] = {.lex_state = 972},
  [213] = {.lex_state = 968},
  [214] = {.lex_state = 975},
  [215] = {.lex_state = 975},
  [216] = {.lex_state = 972},
  [217] = {.lex_state = 972},
  [218] = {.lex_state = 978},
  [219] = {.lex_state = 978},
  [220] = {.lex_state = 968},
  [221] = {.lex_state = 972},
  [222] = {.lex_state = 998},
  [223] = {.lex_state = 998},
  [224] = {.lex_state = 998},
  [225] = {.lex_state = 998},
  [226] = {.lex_state = 994},
  [227] = {.lex_state = 999},
  [228] = {.lex_state = 999},
  [229] = {.lex_state = 994},
  [230] = {.lex_state = 968},
  [231] = {.lex_state = 968},
  [232] = {.lex_state = 994},
  [233] = {.lex_state = 994},
  [234] = {.lex_state = 999},
  [235] = {.lex_state = 999},
  [236] = {.lex_state = 968},
  [237] = {.lex_state = 968},
  [238] = {.lex_state = 968},
  [239] = {.lex_state = 969},
  [240] = {.lex_state = 968},
  [241] = {.lex_state = 968},
  [242] = {.lex_state = 968},
  [243] = {.lex_state = 968},
  [244] = {.lex_state = 968},
  [245] = {.lex_state = 967},
  [246] = {.lex_state = 968},
  [247] = {.lex_state = 980},
  [248] = {.lex_state = 980},
  [249] = {.lex_state = 968},
  [250] = {.lex_state = 968},
  [251] = {.lex_state = 968},
  [252] = {.lex_state = 968},
  [253] = {.lex_state = 968},
  [254] = {.lex_state = 977},
  [255] = {.lex_state = 977},
  [256] = {.lex_state = 991},
  [257] = {.lex_state = 991},
  [258] = {.lex_state = 968},
  [259] = {.lex_state = 968},
  [260] = {.lex_state = 968},
  [261] = {.lex_state = 969},
  [262] = {.lex_state = 968},
  [263] = {.lex_state = 977},
  [264] = {.lex_state = 968},
  [265] = {.lex_state = 968},
  [266] = {.lex_state = 968},
  [267] = {.lex_state = 968},
  [268] = {.lex_state = 968},
  [269] = {.lex_state = 968},
  [270] = {.lex_state = 968},
  [271] = {.lex_state = 968},
  [272] = {.lex_state = 968},
  [273] = {.lex_state = 968},
  [274] = {.lex_state = 968},
  [275] = {.lex_state = 968},
  [276] = {.lex_state = 968},
  [277] = {.lex_state = 968},
  [278] = {.lex_state = 968},
  [279] = {.lex_state = 968},
  [280] = {.lex_state = 976},
  [281] = {.lex_state = 976},
  [282] = {.lex_state = 983},
  [283] = {.lex_state = 983},
  [284] = {.lex_state = 968},
  [285] = {.lex_state = 968},
  [286] = {.lex_state = 968},
  [287] = {.lex_state = 967},
  [288] = {.lex_state = 968},
  [289] = {.lex_state = 968},
  [290] = {.lex_state = 968},
  [291] = {.lex_state = 968},
  [292] = {.lex_state = 968},
  [293] = {.lex_state = 968},
  [294] = {.lex_state = 968},
  [295] = {.lex_state = 968},
  [296] = {.lex_state = 968},
  [297] = {.lex_state = 980},
  [298] = {.lex_state = 980},
  [299] = {.lex_state = 968},
  [300] = {.lex_state = 968},
  [301] = {.lex_state = 968},
  [302] = {.lex_state = 968},
  [303] = {.lex_state = 968},
  [304] = {.lex_state = 968},
  [305] = {.lex_state = 968},
  [306] = {.lex_state = 968},
  [307] = {.lex_state = 977},
  [308] = {.lex_state = 991},
  [309] = {.lex_state = 991},
  [310] = {.lex_state = 968},
  [311] = {.lex_state = 969},
  [312] = {.lex_state = 968},
  [313] = {.lex_state = 968},
  [314] = {.lex_state = 995},
  [315] = {.lex_state = 968},
  [316] = {.lex_state = 968},
  [317] = {.lex_state = 984},
  [318] = {.lex_state = 984},
  [319] = {.lex_state = 981},
  [320] = {.lex_state = 981},
  [321] = {.lex_state = 968},
  [322] = {.lex_state = 995},
  [323] = {.lex_state = 968},
  [324] = {.lex_state = 983},
  [325] = {.lex_state = 968},
  [326] = {.lex_state = 976},
  [327] = {.lex_state = 968},
  [328] = {.lex_state = 968},
  [329] = {.lex_state = 976},
  [330] = {.lex_state = 968},
  [331] = {.lex_state = 983},
  [332] = {.lex_state = 968},
  [333] = {.lex_state = 968},
  [334] = {.lex_state = 968},
  [335] = {.lex_state = 968},
  [336] = {.lex_state = 968},
  [337] = {.lex_state = 968},
  [338] = {.lex_state = 968},
  [339] = {.lex_state = 968},
  [340] = {.lex_state = 968},
  [341] = {.lex_state = 968},
  [342] = {.lex_state = 968},
  [343] = {.lex_state = 968},
  [344] = {.lex_state = 968},
  [345] = {.lex_state = 968},
  [346] = {.lex_state = 968},
  [347] = {.lex_state = 968},
  [348] = {.lex_state = 968},
  [349] = {.lex_state = 968},
  [350] = {.lex_state = 990},
  [351] = {.lex_state = 990},
  [352] = {.lex_state = 968},
  [353] = {.lex_state = 968},
  [354] = {.lex_state = 967},
  [355] = {.lex_state = 969},
  [356] = {.lex_state = 968},
  [357] = {.lex_state = 968},
  [358] = {.lex_state = 985},
  [359] = {.lex_state = 973},
  [360] = {.lex_state = 990},
  [361] = {.lex_state = 990},
  [362] = {.lex_state = 985},
  [363] = {.lex_state = 972},
  [364] = {.lex_state = 982},
  [365] = {.lex_state = 984},
  [366] = {.lex_state = 984},
  [367] = {.lex_state = 968},
  [368] = {.lex_state = 967},
  [369] = {.lex_state = 986},
  [370] = {.lex_state = 981},
  [371] = {.lex_state = 986},
  [372] = {.lex_state = 982},
  [373] = {.lex_state = 973},
  [374] = {.lex_state = 981},
  [375] = {.lex_state = 995},
  [376] = {.lex_state = 995},
  [377] = {.lex_state = 967},
  [378] = {.lex_state = 972},
  [379] = {.lex_state = 972},
  [380] = {.lex_state = 982},
  [381] = {.lex_state = 972},
  [382] = {.lex_state = 986},
  [383] = {.lex_state = 986},
  [384] = {.lex_state = 972},
  [385] = {.lex_state = 989},
  [386] = {.lex_state = 985},
  [387] = {.lex_state = 985},
  [388] = {.lex_state = 993},
  [389] = {.lex_state = 993},
  [390] = {.lex_state = 972},
  [391] = {.lex_state = 989},
  [392] = {.lex_state = 992},
  [393] = {.lex_state = 992},
  [394] = {.lex_state = 982},
  [395] = {.lex_state = 989},
  [396] = {.lex_state = 987},
  [397] = {.lex_state = 972},
  [398] = {.lex_state = 968},
  [399] = {.lex_state = 987},
  [400] = {.lex_state = 967},
  [401] = {.lex_state = 989},
  [402] = {.lex_state = 972},
  [403] = {.lex_state = 972},
  [404] = {.lex_state = 26},
  [405] = {.lex_state = 993},
  [406] = {.lex_state = 993},
  [407] = {.lex_state = 992},
  [408] = {.lex_state = 992},
  [409] = {.lex_state = 987},
  [410] = {.lex_state = 987},
  [411] = {.lex_state = 997},
  [412] = {.lex_state = 997},
  [413] = {.lex_state = 996},
  [414] = {.lex_state = 996},
  [415] = {.lex_state = 972},
  [416] = {.lex_state = 972},
  [417] = {.lex_state = 972},
  [418] = {.lex_state = 972},
  [419] = {.lex_state = 989},
  [420] = {.lex_state = 989},
  [421] = {.lex_state = 989},
  [422] = {.lex_state = 26},
  [423] = {.lex_state = 967},
  [424] = {.lex_state = 967},
  [425] = {.lex_state = 967},
  [426] = {.lex_state = 972},
  [427] = {.lex_state = 989},
  [428] = {.lex_state = 989},
  [429] = {.lex_state = 989},
  [430] = {.lex_state = 23},
  [431] = {.lex_state = 23},
  [432] = {.lex_state = 989},
  [433] = {.lex_state = 972},
  [434] = {.lex_state = 972},
  [435] = {.lex_state = 972},
  [436] = {.lex_state = 972},
  [437] = {.lex_state = 967},
  [438] = {.lex_state = 972},
  [439] = {.lex_state = 972},
  [440] = {.lex_state = 24},
  [441] = {.lex_state = 997},
  [442] = {.lex_state = 967},
  [443] = {.lex_state = 973},
  [444] = {.lex_state = 967},
  [445] = {.lex_state = 967},
  [446] = {.lex_state = 24},
  [447] = {.lex_state = 989},
  [448] = {.lex_state = 972},
  [449] = {.lex_state = 997},
  [450] = {.lex_state = 989},
  [451] = {.lex_state = 996},
  [452] = {.lex_state = 967},
  [453] = {.lex_state = 989},
  [454] = {.lex_state = 996},
  [455] = {.lex_state = 989},
  [456] = {.lex_state = 972},
  [457] = {.lex_state = 972},
  [458] = {.lex_state = 27},
  [459] = {.lex_state = 972},
  [460] = {.lex_state = 972},
  [461] = {.lex_state = 972},
  [462] = {.lex_state = 27},
  [463] = {.lex_state = 973},
  [464] = {.lex_state = 972},
  [465] = {.lex_state = 989},
  [466] = {.lex_state = 25},
  [467] = {.lex_state = 25},
  [468] = {.lex_state = 989},
  [469] = {.lex_state = 989},
  [470] = {.lex_state = 972},
  [471] = {.lex_state = 967},
  [472] = {.lex_state = 967},
  [473] = {.lex_state = 22},
  [474] = {.lex_state = 972},
  [475] = {.lex_state = 967},
  [476] = {.lex_state = 967},
  [477] = {.lex_state = 972},
  [478] = {.lex_state = 22},
  [479] = {.lex_state = 972},
  [480] = {.lex_state = 972},
  [481] = {.lex_state = 972},
  [482] = {.lex_state = 989},
  [483] = {.lex_state = 989},
  [484] = {.lex_state = 989},
  [485] = {.lex_state = 989},
  [486] = {.lex_state = 972},
  [487] = {.lex_state = 972},
  [488] = {.lex_state = 989},
  [489] = {.lex_state = 989},
  [490] = {.lex_state = 989},
  [491] = {.lex_state = 972},
  [492] = {.lex_state = 967},
  [493] = {.lex_state = 967},
  [494] = {.lex_state = 967},
  [495] = {.lex_state = 972},
  [496] = {.lex_state = 972},
  [497] = {.lex_state = 989},
  [498] = {.lex_state = 989},
  [499] = {.lex_state = 972},
  [500] = {.lex_state = 967},
  [501] = {.lex_state = 967},
  [502] = {.lex_state = 989},
  [503] = {.lex_state = 967},
  [504] = {.lex_state = 967},
  [505] = {.lex_state = 967},
  [506] = {.lex_state = 972},
  [507] = {.lex_state = 972},
  [508] = {.lex_state = 972},
  [509] = {.lex_state = 28},
  [510] = {.lex_state = 972},
  [511] = {.lex_state = 28},
  [512] = {.lex_state = 967},
  [513] = {.lex_state = 972},
  [514] = {.lex_state = 967},
  [515] = {.lex_state = 14},
  [516] = {.lex_state = 972},
  [517] = {.lex_state = 14},
  [518] = {.lex_state = 14},
  [519] = {.lex_state = 7},
  [520] = {.lex_state = 972},
  [521] = {.lex_state = 7},
  [522] = {.lex_state = 7},
  [523] = {.lex_state = 7},
  [524] = {.lex_state = 7},
  [525] = {.lex_state = 967},
  [526] = {.lex_state = 967},
  [527] = {.lex_state = 967},
  [528] = {.lex_state = 967},
  [529] = {.lex_state = 967},
  [530] = {.lex_state = 967},
  [531] = {.lex_state = 972},
  [532] = {.lex_state = 14},
  [533] = {.lex_state = 972},
  [534] = {.lex_state = 972},
  [535] = {.lex_state = 972},
  [536] = {.lex_state = 972},
  [537] = {.lex_state = 972},
  [538] = {.lex_state = 972},
  [539] = {.lex_state = 972},
  [540] = {.lex_state = 972},
  [541] = {.lex_state = 7},
  [542] = {.lex_state = 967},
  [543] = {.lex_state = 967},
  [544] = {.lex_state = 967},
  [545] = {.lex_state = 967},
  [546] = {.lex_state = 7},
  [547] = {.lex_state = 7},
  [548] = {.lex_state = 967},
  [549] = {.lex_state = 972},
  [550] = {.lex_state = 972},
  [551] = {.lex_state = 972},
  [552] = {.lex_state = 972},
  [553] = {.lex_state = 972},
  [554] = {.lex_state = 972},
  [555] = {.lex_state = 972},
  [556] = {.lex_state = 972},
  [557] = {.lex_state = 972},
  [558] = {.lex_state = 972},
  [559] = {.lex_state = 972},
  [560] = {.lex_state = 972},
  [561] = {.lex_state = 20},
  [562] = {.lex_state = 972},
  [563] = {.lex_state = 20},
  [564] = {.lex_state = 972},
  [565] = {.lex_state = 972},
  [566] = {.lex_state = 972},
  [567] = {.lex_state = 972},
  [568] = {.lex_state = 972},
  [569] = {.lex_state = 972},
  [570] = {.lex_state = 972},
  [571] = {.lex_state = 7},
  [572] = {.lex_state = 972},
  [573] = {.lex_state = 972},
  [574] = {.lex_state = 972},
  [575] = {.lex_state = 972},
  [576] = {.lex_state = 972},
  [577] = {.lex_state = 972},
  [578] = {.lex_state = 972},
  [579] = {.lex_state = 972},
  [580] = {.lex_state = 972},
  [581] = {.lex_state = 972},
  [582] = {.lex_state = 972},
  [583] = {.lex_state = 972},
  [584] = {.lex_state = 972},
  [585] = {.lex_state = 967},
  [586] = {.lex_state = 972},
  [587] = {.lex_state = 972},
  [588] = {.lex_state = 20},
  [589] = {.lex_state = 20},
  [590] = {.lex_state = 967},
  [591] = {.lex_state = 972},
  [592] = {.lex_state = 972},
  [593] = {.lex_state = 972},
  [594] = {.lex_state = 972},
  [595] = {.lex_state = 972},
  [596] = {.lex_state = 972},
  [597] = {.lex_state = 20},
  [598] = {.lex_state = 972},
  [599] = {.lex_state = 972},
  [600] = {.lex_state = 972},
  [601] = {.lex_state = 967},
  [602] = {.lex_state = 967},
  [603] = {.lex_state = 972},
  [604] = {.lex_state = 972},
  [605] = {.lex_state = 972},
  [606] = {.lex_state = 972},
  [607] = {.lex_state = 972},
  [608] = {.lex_state = 972},
  [609] = {.lex_state = 972},
  [610] = {.lex_state = 972},
  [611] = {.lex_state = 972},
  [612] = {.lex_state = 972},
  [613] = {.lex_state = 972},
  [614] = {.lex_state = 972},
  [615] = {.lex_state = 972},
  [616] = {.lex_state = 972},
  [617] = {.lex_state = 972},
  [618] = {.lex_state = 972},
  [619] = {.lex_state = 972},
  [620] = {.lex_state = 972},
  [621] = {.lex_state = 972},
  [622] = {.lex_state = 972},
  [623] = {.lex_state = 972},
  [624] = {.lex_state = 972},
  [625] = {.lex_state = 972},
  [626] = {.lex_state = 972},
  [627] = {.lex_state = 972},
  [628] = {.lex_state = 972},
  [629] = {.lex_state = 972},
  [630] = {.lex_state = 972},
  [631] = {.lex_state = 972},
  [632] = {.lex_state = 972},
  [633] = {.lex_state = 967},
  [634] = {.lex_state = 967},
  [635] = {.lex_state = 967},
  [636] = {.lex_state = 967},
  [637] = {.lex_state = 972},
  [638] = {.lex_state = 972},
  [639] = {.lex_state = 972},
  [640] = {.lex_state = 972},
  [641] = {.lex_state = 972},
  [642] = {.lex_state = 972},
  [643] = {.lex_state = 972},
  [644] = {.lex_state = 972},
  [645] = {.lex_state = 972},
  [646] = {.lex_state = 972},
  [647] = {.lex_state = 21},
  [648] = {.lex_state = 972},
  [649] = {.lex_state = 972},
  [650] = {.lex_state = 967},
  [651] = {.lex_state = 972},
  [652] = {.lex_state = 972},
  [653] = {.lex_state = 967},
  [654] = {.lex_state = 972},
  [655] = {.lex_state = 972},
  [656] = {.lex_state = 972},
  [657] = {.lex_state = 972},
  [658] = {.lex_state = 972},
  [659] = {.lex_state = 972},
  [660] = {.lex_state = 972},
  [661] = {.lex_state = 972},
  [662] = {.lex_state = 972},
  [663] = {.lex_state = 21},
  [664] = {.lex_state = 972},
  [665] = {.lex_state = 972},
  [666] = {.lex_state = 972},
  [667] = {.lex_state = 972},
  [668] = {.lex_state = 21},
  [669] = {.lex_state = 21},
  [670] = {.lex_state = 21},
  [671] = {.lex_state = 972},
  [672] = {.lex_state = 972},
  [673] = {.lex_state = 972},
  [674] = {.lex_state = 972},
  [675] = {.lex_state = 972},
  [676] = {.lex_state = 21},
  [677] = {.lex_state = 972},
  [678] = {.lex_state = 972},
  [679] = {.lex_state = 972},
  [680] = {.lex_state = 972},
  [681] = {.lex_state = 972},
  [682] = {.lex_state = 972},
  [683] = {.lex_state = 972},
  [684] = {.lex_state = 972},
  [685] = {.lex_state = 972},
  [686] = {.lex_state = 972},
  [687] = {.lex_state = 972},
  [688] = {.lex_state = 972},
  [689] = {.lex_state = 21},
  [690] = {.lex_state = 21},
  [691] = {.lex_state = 972},
  [692] = {.lex_state = 972},
  [693] = {.lex_state = 972},
  [694] = {.lex_state = 972},
  [695] = {.lex_state = 21},
  [696] = {.lex_state = 21},
  [697] = {.lex_state = 972},
  [698] = {.lex_state = 972},
  [699] = {.lex_state = 972},
  [700] = {.lex_state = 972},
  [701] = {.lex_state = 972},
  [702] = {.lex_state = 972},
  [703] = {.lex_state = 972},
  [704] = {.lex_state = 972},
  [705] = {.lex_state = 972},
  [706] = {.lex_state = 972},
  [707] = {.lex_state = 972},
  [708] = {.lex_state = 972},
  [709] = {.lex_state = 972},
  [710] = {.lex_state = 972},
  [711] = {.lex_state = 972},
  [712] = {.lex_state = 21},
  [713] = {.lex_state = 21},
  [714] = {.lex_state = 972},
  [715] = {.lex_state = 21},
  [716] = {.lex_state = 972},
  [717] = {.lex_state = 972},
  [718] = {.lex_state = 972},
  [719] = {.lex_state = 972},
  [720] = {.lex_state = 21},
  [721] = {.lex_state = 972},
  [722] = {.lex_state = 972},
  [723] = {.lex_state = 972},
  [724] = {.lex_state = 21},
  [725] = {.lex_state = 972},
  [726] = {.lex_state = 972},
  [727] = {.lex_state = 972},
  [728] = {.lex_state = 972},
  [729] = {.lex_state = 972},
  [730] = {.lex_state = 972},
  [731] = {.lex_state = 972},
  [732] = {.lex_state = 972},
  [733] = {.lex_state = 972},
  [734] = {.lex_state = 972},
  [735] = {.lex_state = 972},
  [736] = {.lex_state = 972},
  [737] = {.lex_state = 972},
  [738] = {.lex_state = 972},
  [739] = {.lex_state = 972},
  [740] = {.lex_state = 972},
  [741] = {.lex_state = 972},
  [742] = {.lex_state = 972},
  [743] = {.lex_state = 972},
  [744] = {.lex_state = 972},
  [745] = {.lex_state = 972},
  [746] = {.lex_state = 972},
  [747] = {.lex_state = 972},
  [748] = {.lex_state = 972},
  [749] = {.lex_state = 972},
  [750] = {.lex_state = 972},
  [751] = {.lex_state = 972},
  [752] = {.lex_state = 972},
  [753] = {.lex_state = 972},
  [754] = {.lex_state = 972},
  [755] = {.lex_state = 972},
  [756] = {.lex_state = 972},
  [757] = {.lex_state = 972},
  [758] = {.lex_state = 972},
  [759] = {.lex_state = 13},
  [760] = {.lex_state = 13},
  [761] = {.lex_state = 13},
  [762] = {.lex_state = 13},
  [763] = {.lex_state = 13},
  [764] = {.lex_state = 9},
  [765] = {.lex_state = 13},
  [766] = {.lex_state = 13},
  [767] = {.lex_state = 9},
  [768] = {.lex_state = 13},
  [769] = {.lex_state = 8},
  [770] = {.lex_state = 8},
  [771] = {.lex_state = 15},
  [772] = {.lex_state = 10},
  [773] = {.lex_state = 15},
  [774] = {.lex_state = 6},
  [775] = {.lex_state = 6},
  [776] = {.lex_state = 6},
  [777] = {.lex_state = 6},
  [778] = {.lex_state = 6},
  [779] = {.lex_state = 6},
  [780] = {.lex_state = 6},
  [781] = {.lex_state = 6},
  [782] = {.lex_state = 6},
  [783] = {.lex_state = 6},
  [784] = {.lex_state = 6},
  [785] = {.lex_state = 6},
  [786] = {.lex_state = 6},
  [787] = {.lex_state = 18},
  [788] = {.lex_state = 6},
  [789] = {.lex_state = 18},
  [790] = {.lex_state = 18},
  [791] = {.lex_state = 17},
  [792] = {.lex_state = 18},
  [793] = {.lex_state = 18},
  [794] = {.lex_state = 17},
  [795] = {.lex_state = 6},
  [796] = {.lex_state = 15},
  [797] = {.lex_state = 6},
  [798] = {.lex_state = 6},
  [799] = {.lex_state = 6},
  [800] = {.lex_state = 6},
  [801] = {.lex_state = 6},
  [802] = {.lex_state = 6},
  [803] = {.lex_state = 6},
  [804] = {.lex_state = 6},
  [805] = {.lex_state = 6},
  [806] = {.lex_state = 6},
  [807] = {.lex_state = 6},
  [808] = {.lex_state = 6},
  [809] = {.lex_state = 6},
  [810] = {.lex_state = 6},
  [811] = {.lex_state = 15},
  [812] = {.lex_state = 6},
  [813] = {.lex_state = 6},
  [814] = {.lex_state = 6},
  [815] = {.lex_state = 6},
  [816] = {.lex_state = 6},
  [817] = {.lex_state = 15},
  [818] = {.lex_state = 6},
  [819] = {.lex_state = 6},
  [820] = {.lex_state = 16},
  [821] = {.lex_state = 15},
  [822] = {.lex_state = 6},
  [823] = {.lex_state = 16},
  [824] = {.lex_state = 6},
  [825] = {.lex_state = 6},
  [826] = {.lex_state = 6},
  [827] = {.lex_state = 6},
  [828] = {.lex_state = 6},
  [829] = {.lex_state = 6},
  [830] = {.lex_state = 6},
  [831] = {.lex_state = 6},
  [832] = {.lex_state = 6},
  [833] = {.lex_state = 6},
  [834] = {.lex_state = 6},
  [835] = {.lex_state = 6},
  [836] = {.lex_state = 6},
  [837] = {.lex_state = 6},
  [838] = {.lex_state = 6},
  [839] = {.lex_state = 6},
  [840] = {.lex_state = 6},
  [841] = {.lex_state = 6},
  [842] = {.lex_state = 6},
  [843] = {.lex_state = 6},
  [844] = {.lex_state = 6},
  [845] = {.lex_state = 6},
  [846] = {.lex_state = 6},
  [847] = {.lex_state = 6},
  [848] = {.lex_state = 6},
  [849] = {.lex_state = 6},
  [850] = {.lex_state = 6},
  [851] = {.lex_state = 6},
  [852] = {.lex_state = 6},
  [853] = {.lex_state = 6},
  [854] = {.lex_state = 6},
  [855] = {.lex_state = 6},
  [856] = {.lex_state = 6},
  [857] = {.lex_state = 6},
  [858] = {.lex_state = 6},
  [859] = {.lex_state = 6},
  [860] = {.lex_state = 6},
  [861] = {.lex_state = 6},
  [862] = {.lex_state = 6},
  [863] = {.lex_state = 6},
  [864] = {.lex_state = 6},
  [865] = {.lex_state = 6},
  [866] = {.lex_state = 6},
  [867] = {.lex_state = 6},
  [868] = {.lex_state = 6},
  [869] = {.lex_state = 6},
  [870] = {.lex_state = 6},
  [871] = {.lex_state = 6},
  [872] = {.lex_state = 6},
  [873] = {.lex_state = 6},
  [874] = {.lex_state = 6},
  [875] = {.lex_state = 6},
  [876] = {.lex_state = 6},
  [877] = {.lex_state = 6},
  [878] = {.lex_state = 6},
  [879] = {.lex_state = 6},
  [880] = {.lex_state = 6},
  [881] = {.lex_state = 6},
  [882] = {.lex_state = 6},
  [883] = {.lex_state = 6},
  [884] = {.lex_state = 6},
  [885] = {.lex_state = 6},
  [886] = {.lex_state = 6},
  [887] = {.lex_state = 6},
  [888] = {.lex_state = 6},
  [889] = {.lex_state = 6},
  [890] = {.lex_state = 6},
  [891] = {.lex_state = 6},
  [892] = {.lex_state = 6},
  [893] = {.lex_state = 6},
  [894] = {.lex_state = 6},
  [895] = {.lex_state = 6},
  [896] = {.lex_state = 6},
  [897] = {.lex_state = 6},
  [898] = {.lex_state = 6},
  [899] = {.lex_state = 6},
  [900] = {.lex_state = 6},
  [901] = {.lex_state = 6},
  [902] = {.lex_state = 6},
  [903] = {.lex_state = 6},
  [904] = {.lex_state = 6},
  [905] = {.lex_state = 6},
  [906] = {.lex_state = 6},
  [907] = {.lex_state = 6},
  [908] = {.lex_state = 6},
  [909] = {.lex_state = 6},
  [910] = {.lex_state = 6},
  [911] = {.lex_state = 6},
  [912] = {.lex_state = 6},
  [913] = {.lex_state = 6},
  [914] = {.lex_state = 6},
  [915] = {.lex_state = 6},
  [916] = {.lex_state = 6},
  [917] = {.lex_state = 6},
  [918] = {.lex_state = 6},
  [919] = {.lex_state = 6},
  [920] = {.lex_state = 6},
  [921] = {.lex_state = 6},
  [922] = {.lex_state = 6},
  [923] = {.lex_state = 6},
  [924] = {.lex_state = 6},
  [925] = {.lex_state = 6},
  [926] = {.lex_state = 6},
  [927] = {.lex_state = 6},
  [928] = {.lex_state = 6},
  [929] = {.lex_state = 6},
  [930] = {.lex_state = 6},
  [931] = {.lex_state = 6},
  [932] = {.lex_state = 6},
  [933] = {.lex_state = 6},
  [934] = {.lex_state = 6},
  [935] = {.lex_state = 6},
  [936] = {.lex_state = 6},
  [937] = {.lex_state = 6},
  [938] = {.lex_state = 6},
  [939] = {.lex_state = 6},
  [940] = {.lex_state = 6},
  [941] = {.lex_state = 6},
  [942] = {.lex_state = 6},
  [943] = {.lex_state = 6},
  [944] = {.lex_state = 6},
  [945] = {.lex_state = 6},
  [946] = {.lex_state = 6},
  [947] = {.lex_state = 6},
  [948] = {.lex_state = 6},
  [949] = {.lex_state = 6},
  [950] = {.lex_state = 6},
  [951] = {.lex_state = 6},
  [952] = {.lex_state = 6},
  [953] = {.lex_state = 6},
  [954] = {.lex_state = 6},
  [955] = {.lex_state = 6},
  [956] = {.lex_state = 6},
  [957] = {.lex_state = 6},
  [958] = {.lex_state = 6},
  [959] = {.lex_state = 6},
  [960] = {.lex_state = 6},
  [961] = {.lex_state = 6},
  [962] = {.lex_state = 6},
  [963] = {.lex_state = 6},
  [964] = {.lex_state = 6},
  [965] = {.lex_state = 6},
  [966] = {.lex_state = 6},
  [967] = {.lex_state = 6},
  [968] = {.lex_state = 6},
  [969] = {.lex_state = 6},
  [970] = {.lex_state = 6},
  [971] = {.lex_state = 6},
  [972] = {.lex_state = 6},
  [973] = {.lex_state = 6},
  [974] = {.lex_state = 6},
  [975] = {.lex_state = 6},
  [976] = {.lex_state = 6},
  [977] = {.lex_state = 6},
  [978] = {.lex_state = 6},
  [979] = {.lex_state = 6},
  [980] = {.lex_state = 6},
  [981] = {.lex_state = 6},
  [982] = {.lex_state = 6},
  [983] = {.lex_state = 6},
  [984] = {.lex_state = 6},
  [985] = {.lex_state = 6},
  [986] = {.lex_state = 6},
  [987] = {.lex_state = 6},
  [988] = {.lex_state = 6},
  [989] = {.lex_state = 6},
  [990] = {.lex_state = 6},
  [991] = {.lex_state = 6},
  [992] = {.lex_state = 6},
  [993] = {.lex_state = 6},
  [994] = {.lex_state = 6},
  [995] = {.lex_state = 6},
  [996] = {.lex_state = 6},
  [997] = {.lex_state = 6},
  [998] = {.lex_state = 6},
  [999] = {.lex_state = 6},
  [1000] = {.lex_state = 6},
  [1001] = {.lex_state = 6},
  [1002] = {.lex_state = 6},
  [1003] = {.lex_state = 6},
  [1004] = {.lex_state = 6},
  [1005] = {.lex_state = 6},
  [1006] = {.lex_state = 6},
  [1007] = {.lex_state = 6},
  [1008] = {.lex_state = 6},
  [1009] = {.lex_state = 6},
  [1010] = {.lex_state = 6},
  [1011] = {.lex_state = 6},
  [1012] = {.lex_state = 6},
  [1013] = {.lex_state = 6},
  [1014] = {.lex_state = 6},
  [1015] = {.lex_state = 6},
  [1016] = {.lex_state = 6},
  [1017] = {.lex_state = 6},
  [1018] = {.lex_state = 6},
  [1019] = {.lex_state = 6},
  [1020] = {.lex_state = 6},
  [1021] = {.lex_state = 6},
  [1022] = {.lex_state = 6},
  [1023] = {.lex_state = 6},
  [1024] = {.lex_state = 6},
  [1025] = {.lex_state = 6},
  [1026] = {.lex_state = 6},
  [1027] = {.lex_state = 6},
  [1028] = {.lex_state = 6},
  [1029] = {.lex_state = 6},
  [1030] = {.lex_state = 6},
  [1031] = {.lex_state = 6},
  [1032] = {.lex_state = 6},
  [1033] = {.lex_state = 6},
  [1034] = {.lex_state = 6},
  [1035] = {.lex_state = 6},
  [1036] = {.lex_state = 6},
  [1037] = {.lex_state = 6},
  [1038] = {.lex_state = 6},
  [1039] = {.lex_state = 6},
  [1040] = {.lex_state = 6},
  [1041] = {.lex_state = 6},
  [1042] = {.lex_state = 6},
  [1043] = {.lex_state = 6},
  [1044] = {.lex_state = 6},
  [1045] = {.lex_state = 6},
  [1046] = {.lex_state = 6},
  [1047] = {.lex_state = 6},
  [1048] = {.lex_state = 6},
  [1049] = {.lex_state = 6},
  [1050] = {.lex_state = 6},
  [1051] = {.lex_state = 6},
  [1052] = {.lex_state = 6},
  [1053] = {.lex_state = 6},
  [1054] = {.lex_state = 6},
  [1055] = {.lex_state = 6},
  [1056] = {.lex_state = 6},
  [1057] = {.lex_state = 6},
  [1058] = {.lex_state = 6},
  [1059] = {.lex_state = 6},
  [1060] = {.lex_state = 6},
  [1061] = {.lex_state = 6},
  [1062] = {.lex_state = 6},
  [1063] = {.lex_state = 6},
  [1064] = {.lex_state = 6},
  [1065] = {.lex_state = 6},
  [1066] = {.lex_state = 6},
  [1067] = {.lex_state = 6},
  [1068] = {.lex_state = 6},
  [1069] = {.lex_state = 6},
  [1070] = {.lex_state = 6},
  [1071] = {.lex_state = 6},
  [1072] = {.lex_state = 6},
  [1073] = {.lex_state = 6},
  [1074] = {.lex_state = 6},
  [1075] = {.lex_state = 6},
  [1076] = {.lex_state = 6},
  [1077] = {.lex_state = 6},
  [1078] = {.lex_state = 6},
  [1079] = {.lex_state = 6},
  [1080] = {.lex_state = 6},
  [1081] = {.lex_state = 6},
  [1082] = {.lex_state = 6},
  [1083] = {.lex_state = 6},
  [1084] = {.lex_state = 6},
  [1085] = {.lex_state = 6},
  [1086] = {.lex_state = 6},
  [1087] = {.lex_state = 6},
  [1088] = {.lex_state = 6},
  [1089] = {.lex_state = 6},
  [1090] = {.lex_state = 6},
  [1091] = {.lex_state = 6},
  [1092] = {.lex_state = 6},
  [1093] = {.lex_state = 6},
  [1094] = {.lex_state = 6},
  [1095] = {.lex_state = 6},
  [1096] = {.lex_state = 6},
  [1097] = {.lex_state = 6},
  [1098] = {.lex_state = 6},
  [1099] = {.lex_state = 6},
  [1100] = {.lex_state = 6},
  [1101] = {.lex_state = 6},
  [1102] = {.lex_state = 6},
  [1103] = {.lex_state = 6},
  [1104] = {.lex_state = 6},
  [1105] = {.lex_state = 6},
  [1106] = {.lex_state = 6},
  [1107] = {.lex_state = 6},
  [1108] = {.lex_state = 6},
  [1109] = {.lex_state = 6},
  [1110] = {.lex_state = 6},
  [1111] = {.lex_state = 6},
  [1112] = {.lex_state = 6},
  [1113] = {.lex_state = 0},
  [1114] = {.lex_state = 0},
  [1115] = {.lex_state = 0},
  [1116] = {.lex_state = 1000},
  [1117] = {.lex_state = 1000},
  [1118] = {.lex_state = 970},
  [1119] = {.lex_state = 0},
  [1120] = {.lex_state = 0},
  [1121] = {.lex_state = 6},
  [1122] = {.lex_state = 19},
  [1123] = {.lex_state = 1000},
  [1124] = {.lex_state = 970},
  [1125] = {.lex_state = 1000},
  [1126] = {.lex_state = 1000},
  [1127] = {.lex_state = 970},
  [1128] = {.lex_state = 6},
  [1129] = {.lex_state = 1000},
  [1130] = {.lex_state = 0},
  [1131] = {.lex_state = 0},
  [1132] = {.lex_state = 6},
  [1133] = {.lex_state = 6},
  [1134] = {.lex_state = 6},
  [1135] = {.lex_state = 6},
  [1136] = {.lex_state = 970},
  [1137] = {.lex_state = 6},
  [1138] = {.lex_state = 970},
  [1139] = {.lex_state = 968},
  [1140] = {.lex_state = 968},
  [1141] = {.lex_state = 968},
  [1142] = {.lex_state = 968},
  [1143] = {.lex_state = 968},
  [1144] = {.lex_state = 968},
  [1145] = {.lex_state = 968},
  [1146] = {.lex_state = 970},
  [1147] = {.lex_state = 970},
  [1148] = {.lex_state = 970},
  [1149] = {.lex_state = 971},
  [1150] = {.lex_state = 0},
  [1151] = {.lex_state = 0},
  [1152] = {.lex_state = 0},
  [1153] = {.lex_state = 0},
  [1154] = {.lex_state = 0},
  [1155] = {.lex_state = 0},
  [1156] = {.lex_state = 0},
  [1157] = {.lex_state = 0},
  [1158] = {.lex_state = 971},
  [1159] = {.lex_state = 971},
  [1160] = {.lex_state = 971},
  [1161] = {.lex_state = 971},
  [1162] = {.lex_state = 971},
  [1163] = {.lex_state = 971},
  [1164] = {.lex_state = 0},
  [1165] = {.lex_state = 0},
  [1166] = {.lex_state = 971},
  [1167] = {.lex_state = 0},
  [1168] = {.lex_state = 0},
  [1169] = {.lex_state = 0},
  [1170] = {.lex_state = 971},
  [1171] = {.lex_state = 0},
  [1172] = {.lex_state = 971},
  [1173] = {.lex_state = 0},
  [1174] = {.lex_state = 0},
  [1175] = {.lex_state = 0},
  [1176] = {.lex_state = 971},
  [1177] = {.lex_state = 971},
  [1178] = {.lex_state = 0},
  [1179] = {.lex_state = 0},
  [1180] = {.lex_state = 0},
  [1181] = {.lex_state = 971},
  [1182] = {.lex_state = 971},
  [1183] = {.lex_state = 0},
  [1184] = {.lex_state = 971},
  [1185] = {.lex_state = 0},
  [1186] = {.lex_state = 0},
  [1187] = {.lex_state = 0},
  [1188] = {.lex_state = 0},
  [1189] = {.lex_state = 0},
  [1190] = {.lex_state = 971},
  [1191] = {.lex_state = 971},
  [1192] = {.lex_state = 1002},
  [1193] = {.lex_state = 1002},
  [1194] = {.lex_state = 0},
  [1195] = {.lex_state = 0},
  [1196] = {.lex_state = 0},
  [1197] = {.lex_state = 0},
  [1198] = {.lex_state = 0},
  [1199] = {.lex_state = 0},
  [1200] = {.lex_state = 0},
  [1201] = {.lex_state = 0},
  [1202] = {.lex_state = 0},
  [1203] = {.lex_state = 971},
  [1204] = {.lex_state = 970},
  [1205] = {.lex_state = 971},
  [1206] = {.lex_state = 0},
  [1207] = {.lex_state = 0},
  [1208] = {.lex_state = 0},
  [1209] = {.lex_state = 0},
  [1210] = {.lex_state = 0},
  [1211] = {.lex_state = 0},
  [1212] = {.lex_state = 0},
  [1213] = {.lex_state = 0},
  [1214] = {.lex_state = 0},
  [1215] = {.lex_state = 0},
  [1216] = {.lex_state = 29},
  [1217] = {.lex_state = 29},
  [1218] = {.lex_state = 971},
  [1219] = {.lex_state = 0},
  [1220] = {.lex_state = 29},
  [1221] = {.lex_state = 970},
  [1222] = {.lex_state = 0},
  [1223] = {.lex_state = 0},
  [1224] = {.lex_state = 29},
  [1225] = {.lex_state = 0},
  [1226] = {.lex_state = 0},
  [1227] = {.lex_state = 0},
  [1228] = {.lex_state = 0},
  [1229] = {.lex_state = 29},
  [1230] = {.lex_state = 0},
  [1231] = {.lex_state = 0},
  [1232] = {.lex_state = 0},
  [1233] = {.lex_state = 29},
  [1234] = {.lex_state = 0},
  [1235] = {.lex_state = 0},
  [1236] = {.lex_state = 29},
  [1237] = {.lex_state = 29},
  [1238] = {.lex_state = 0},
  [1239] = {.lex_state = 0},
  [1240] = {.lex_state = 0},
  [1241] = {.lex_state = 0},
  [1242] = {.lex_state = 0},
  [1243] = {.lex_state = 29},
  [1244] = {.lex_state = 29},
  [1245] = {.lex_state = 29},
  [1246] = {.lex_state = 0},
  [1247] = {.lex_state = 0},
  [1248] = {.lex_state = 0},
  [1249] = {.lex_state = 0},
  [1250] = {.lex_state = 0},
  [1251] = {.lex_state = 0},
  [1252] = {.lex_state = 0},
  [1253] = {.lex_state = 0},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 0},
  [1256] = {.lex_state = 0},
  [1257] = {.lex_state = 970},
  [1258] = {.lex_state = 0},
  [1259] = {.lex_state = 37},
  [1260] = {.lex_state = 0},
  [1261] = {.lex_state = 0},
  [1262] = {.lex_state = 0},
  [1263] = {.lex_state = 0},
  [1264] = {.lex_state = 1001},
  [1265] = {.lex_state = 0},
  [1266] = {.lex_state = 0},
  [1267] = {.lex_state = 0},
  [1268] = {.lex_state = 0},
  [1269] = {.lex_state = 0},
  [1270] = {.lex_state = 0},
  [1271] = {.lex_state = 0},
  [1272] = {.lex_state = 1001},
  [1273] = {.lex_state = 0},
  [1274] = {.lex_state = 0},
  [1275] = {.lex_state = 0},
  [1276] = {.lex_state = 0},
  [1277] = {.lex_state = 0},
  [1278] = {.lex_state = 0},
  [1279] = {.lex_state = 0},
  [1280] = {.lex_state = 0},
  [1281] = {.lex_state = 1001},
  [1282] = {.lex_state = 37},
  [1283] = {.lex_state = 0},
  [1284] = {.lex_state = 0},
  [1285] = {.lex_state = 0},
  [1286] = {.lex_state = 1001},
  [1287] = {.lex_state = 0},
  [1288] = {.lex_state = 0},
  [1289] = {.lex_state = 0},
  [1290] = {.lex_state = 1001},
  [1291] = {.lex_state = 0},
  [1292] = {.lex_state = 0},
  [1293] = {.lex_state = 0},
  [1294] = {.lex_state = 0},
  [1295] = {.lex_state = 971},
  [1296] = {.lex_state = 38},
  [1297] = {.lex_state = 970},
  [1298] = {.lex_state = 38},
  [1299] = {.lex_state = 970},
  [1300] = {.lex_state = 0},
  [1301] = {.lex_state = 970},
  [1302] = {.lex_state = 970},
  [1303] = {.lex_state = 0},
  [1304] = {.lex_state = 0},
  [1305] = {.lex_state = 971},
  [1306] = {.lex_state = 1000},
  [1307] = {.lex_state = 0},
  [1308] = {.lex_state = 1001},
  [1309] = {.lex_state = 0},
  [1310] = {.lex_state = 970},
  [1311] = {.lex_state = 0},
  [1312] = {.lex_state = 38},
  [1313] = {.lex_state = 38},
  [1314] = {.lex_state = 970},
  [1315] = {.lex_state = 0},
  [1316] = {.lex_state = 0},
  [1317] = {.lex_state = 0},
  [1318] = {.lex_state = 970},
  [1319] = {.lex_state = 38},
  [1320] = {.lex_state = 38},
  [1321] = {.lex_state = 1000},
  [1322] = {.lex_state = 0},
  [1323] = {.lex_state = 0},
  [1324] = {.lex_state = 38},
  [1325] = {.lex_state = 0},
  [1326] = {.lex_state = 38},
  [1327] = {.lex_state = 38},
  [1328] = {.lex_state = 38},
  [1329] = {.lex_state = 0},
  [1330] = {.lex_state = 0},
  [1331] = {.lex_state = 0},
  [1332] = {.lex_state = 0},
  [1333] = {.lex_state = 0},
  [1334] = {.lex_state = 0},
  [1335] = {.lex_state = 0},
  [1336] = {.lex_state = 0},
  [1337] = {.lex_state = 0},
  [1338] = {.lex_state = 0},
  [1339] = {.lex_state = 0},
  [1340] = {.lex_state = 971},
  [1341] = {.lex_state = 1001},
  [1342] = {.lex_state = 0},
  [1343] = {.lex_state = 971},
  [1344] = {.lex_state = 968},
  [1345] = {.lex_state = 0},
  [1346] = {.lex_state = 1001},
  [1347] = {.lex_state = 0},
  [1348] = {.lex_state = 0},
  [1349] = {.lex_state = 0},
  [1350] = {.lex_state = 0},
  [1351] = {.lex_state = 0},
  [1352] = {.lex_state = 1000},
  [1353] = {.lex_state = 0},
  [1354] = {.lex_state = 0},
  [1355] = {.lex_state = 1001},
  [1356] = {.lex_state = 0},
  [1357] = {.lex_state = 0},
  [1358] = {.lex_state = 0},
  [1359] = {.lex_state = 0},
  [1360] = {.lex_state = 0},
  [1361] = {.lex_state = 0},
  [1362] = {.lex_state = 0},
  [1363] = {.lex_state = 0},
  [1364] = {.lex_state = 0},
  [1365] = {.lex_state = 0},
  [1366] = {.lex_state = 0},
  [1367] = {.lex_state = 971},
  [1368] = {.lex_state = 0},
  [1369] = {.lex_state = 0},
  [1370] = {.lex_state = 0},
  [1371] = {.lex_state = 0},
  [1372] = {.lex_state = 971},
  [1373] = {.lex_state = 971},
  [1374] = {.lex_state = 971},
  [1375] = {.lex_state = 0},
  [1376] = {.lex_state = 0},
  [1377] = {.lex_state = 0},
  [1378] = {.lex_state = 0},
  [1379] = {.lex_state = 0},
  [1380] = {.lex_state = 0},
  [1381] = {.lex_state = 0},
  [1382] = {.lex_state = 0},
  [1383] = {.lex_state = 0},
  [1384] = {.lex_state = 0},
  [1385] = {.lex_state = 0},
  [1386] = {.lex_state = 0},
  [1387] = {.lex_state = 0},
  [1388] = {.lex_state = 0},
  [1389] = {.lex_state = 0},
  [1390] = {.lex_state = 0},
  [1391] = {.lex_state = 0},
  [1392] = {.lex_state = 0},
  [1393] = {.lex_state = 968},
  [1394] = {.lex_state = 0},
  [1395] = {.lex_state = 0},
  [1396] = {.lex_state = 0},
  [1397] = {.lex_state = 0},
  [1398] = {.lex_state = 0},
  [1399] = {.lex_state = 0},
  [1400] = {.lex_state = 0},
  [1401] = {.lex_state = 0},
  [1402] = {.lex_state = 0},
  [1403] = {.lex_state = 0},
  [1404] = {.lex_state = 0},
  [1405] = {.lex_state = 0},
  [1406] = {.lex_state = 0},
  [1407] = {.lex_state = 0},
  [1408] = {.lex_state = 0},
  [1409] = {.lex_state = 0},
  [1410] = {.lex_state = 0},
  [1411] = {.lex_state = 0},
  [1412] = {.lex_state = 0},
  [1413] = {.lex_state = 0},
  [1414] = {.lex_state = 0},
  [1415] = {.lex_state = 0},
  [1416] = {.lex_state = 968},
  [1417] = {.lex_state = 0},
  [1418] = {.lex_state = 0},
  [1419] = {.lex_state = 0},
  [1420] = {.lex_state = 0},
  [1421] = {.lex_state = 0},
  [1422] = {.lex_state = 0},
  [1423] = {.lex_state = 0},
  [1424] = {.lex_state = 0},
  [1425] = {.lex_state = 0},
  [1426] = {.lex_state = 0},
  [1427] = {.lex_state = 0},
  [1428] = {.lex_state = 0},
  [1429] = {.lex_state = 0},
  [1430] = {.lex_state = 0},
  [1431] = {.lex_state = 0},
  [1432] = {.lex_state = 0},
  [1433] = {.lex_state = 0},
  [1434] = {.lex_state = 0},
  [1435] = {.lex_state = 0},
  [1436] = {.lex_state = 0},
  [1437] = {.lex_state = 0},
  [1438] = {.lex_state = 0},
  [1439] = {.lex_state = 0},
  [1440] = {.lex_state = 0},
  [1441] = {.lex_state = 0},
  [1442] = {.lex_state = 0},
  [1443] = {.lex_state = 0},
  [1444] = {.lex_state = 0},
  [1445] = {.lex_state = 0},
  [1446] = {.lex_state = 967},
  [1447] = {.lex_state = 0},
  [1448] = {.lex_state = 1001},
  [1449] = {.lex_state = 0},
  [1450] = {.lex_state = 0},
  [1451] = {.lex_state = 0},
  [1452] = {.lex_state = 0},
  [1453] = {.lex_state = 0},
  [1454] = {.lex_state = 0},
  [1455] = {.lex_state = 0},
  [1456] = {.lex_state = 0},
  [1457] = {.lex_state = 0},
  [1458] = {.lex_state = 0},
  [1459] = {.lex_state = 0},
  [1460] = {.lex_state = 0},
  [1461] = {.lex_state = 0},
  [1462] = {.lex_state = 1001},
  [1463] = {.lex_state = 967},
  [1464] = {.lex_state = 0},
  [1465] = {.lex_state = 0},
  [1466] = {.lex_state = 0},
  [1467] = {.lex_state = 968},
  [1468] = {.lex_state = 0},
  [1469] = {.lex_state = 0},
  [1470] = {.lex_state = 0},
  [1471] = {.lex_state = 0},
  [1472] = {.lex_state = 970},
  [1473] = {.lex_state = 0},
  [1474] = {.lex_state = 970},
  [1475] = {.lex_state = 0},
  [1476] = {.lex_state = 970},
  [1477] = {.lex_state = 0},
  [1478] = {.lex_state = 970},
  [1479] = {.lex_state = 970},
  [1480] = {.lex_state = 0},
  [1481] = {.lex_state = 0},
  [1482] = {.lex_state = 970},
  [1483] = {.lex_state = 0},
  [1484] = {.lex_state = 0},
  [1485] = {.lex_state = 0},
  [1486] = {.lex_state = 1001},
  [1487] = {.lex_state = 0},
  [1488] = {.lex_state = 0},
  [1489] = {.lex_state = 0},
  [1490] = {.lex_state = 46},
  [1491] = {.lex_state = 46},
  [1492] = {.lex_state = 46},
  [1493] = {.lex_state = 46},
  [1494] = {.lex_state = 46},
  [1495] = {.lex_state = 46},
  [1496] = {.lex_state = 46},
  [1497] = {.lex_state = 46},
  [1498] = {.lex_state = 46},
  [1499] = {.lex_state = 46},
  [1500] = {.lex_state = 46},
  [1501] = {.lex_state = 0},
  [1502] = {.lex_state = 46},
  [1503] = {.lex_state = 46},
  [1504] = {.lex_state = 46},
  [1505] = {.lex_state = 46},
  [1506] = {.lex_state = 46},
  [1507] = {.lex_state = 46},
  [1508] = {.lex_state = 46},
  [1509] = {.lex_state = 46},
  [1510] = {.lex_state = 46},
  [1511] = {.lex_state = 46},
  [1512] = {.lex_state = 46},
  [1513] = {.lex_state = 0},
  [1514] = {.lex_state = 0},
  [1515] = {.lex_state = 46},
  [1516] = {.lex_state = 46},
  [1517] = {.lex_state = 46},
  [1518] = {.lex_state = 46},
  [1519] = {.lex_state = 46},
  [1520] = {.lex_state = 0},
  [1521] = {.lex_state = 46},
  [1522] = {.lex_state = 968},
  [1523] = {.lex_state = 970},
  [1524] = {.lex_state = 46},
  [1525] = {.lex_state = 0},
  [1526] = {.lex_state = 46},
  [1527] = {.lex_state = 0},
  [1528] = {.lex_state = 46},
  [1529] = {.lex_state = 46},
  [1530] = {.lex_state = 0},
  [1531] = {.lex_state = 0},
  [1532] = {.lex_state = 46},
  [1533] = {.lex_state = 0},
  [1534] = {.lex_state = 46},
  [1535] = {.lex_state = 0},
  [1536] = {.lex_state = 0},
  [1537] = {.lex_state = 46},
  [1538] = {.lex_state = 0},
  [1539] = {.lex_state = 0},
  [1540] = {.lex_state = 46},
  [1541] = {.lex_state = 0},
  [1542] = {.lex_state = 46},
  [1543] = {.lex_state = 0},
  [1544] = {.lex_state = 46},
  [1545] = {.lex_state = 0},
  [1546] = {.lex_state = 0},
  [1547] = {.lex_state = 0},
  [1548] = {.lex_state = 46},
  [1549] = {.lex_state = 0},
  [1550] = {.lex_state = 0},
  [1551] = {.lex_state = 46},
  [1552] = {.lex_state = 46},
  [1553] = {.lex_state = 46},
  [1554] = {.lex_state = 0},
  [1555] = {.lex_state = 0},
  [1556] = {.lex_state = 0},
  [1557] = {.lex_state = 0},
  [1558] = {.lex_state = 46},
  [1559] = {.lex_state = 0},
  [1560] = {.lex_state = 0},
  [1561] = {.lex_state = 46},
  [1562] = {.lex_state = 46},
  [1563] = {.lex_state = 46},
  [1564] = {.lex_state = 0},
  [1565] = {.lex_state = 968},
  [1566] = {.lex_state = 0},
  [1567] = {.lex_state = 0},
  [1568] = {.lex_state = 0},
  [1569] = {.lex_state = 46},
  [1570] = {.lex_state = 46},
  [1571] = {.lex_state = 0},
  [1572] = {.lex_state = 0},
  [1573] = {.lex_state = 0},
  [1574] = {.lex_state = 0},
  [1575] = {.lex_state = 46},
  [1576] = {.lex_state = 970},
  [1577] = {.lex_state = 46},
  [1578] = {.lex_state = 0},
  [1579] = {.lex_state = 46},
  [1580] = {.lex_state = 0},
  [1581] = {.lex_state = 0},
  [1582] = {.lex_state = 970},
  [1583] = {.lex_state = 0},
  [1584] = {.lex_state = 970},
  [1585] = {.lex_state = 0},
  [1586] = {.lex_state = 0},
  [1587] = {.lex_state = 968},
  [1588] = {.lex_state = 46},
  [1589] = {.lex_state = 970},
  [1590] = {.lex_state = 46},
  [1591] = {.lex_state = 970},
  [1592] = {.lex_state = 46},
  [1593] = {.lex_state = 46},
  [1594] = {.lex_state = 46},
  [1595] = {.lex_state = 46},
  [1596] = {.lex_state = 0},
  [1597] = {.lex_state = 0},
  [1598] = {.lex_state = 46},
  [1599] = {.lex_state = 46},
  [1600] = {.lex_state = 0},
  [1601] = {.lex_state = 0},
  [1602] = {.lex_state = 0},
  [1603] = {.lex_state = 46},
  [1604] = {.lex_state = 46},
  [1605] = {.lex_state = 0},
  [1606] = {.lex_state = 0},
  [1607] = {.lex_state = 46},
  [1608] = {.lex_state = 46},
  [1609] = {.lex_state = 0},
  [1610] = {.lex_state = 0},
  [1611] = {.lex_state = 0},
  [1612] = {.lex_state = 0},
  [1613] = {.lex_state = 0},
  [1614] = {.lex_state = 0},
  [1615] = {.lex_state = 0},
  [1616] = {.lex_state = 0},
  [1617] = {.lex_state = 0},
  [1618] = {.lex_state = 0},
  [1619] = {.lex_state = 0},
  [1620] = {.lex_state = 0},
  [1621] = {.lex_state = 0},
  [1622] = {.lex_state = 0},
  [1623] = {.lex_state = 970},
  [1624] = {.lex_state = 0},
  [1625] = {.lex_state = 0},
  [1626] = {.lex_state = 0},
  [1627] = {.lex_state = 0},
  [1628] = {.lex_state = 0},
  [1629] = {.lex_state = 0},
  [1630] = {.lex_state = 0},
  [1631] = {.lex_state = 0},
  [1632] = {.lex_state = 0},
  [1633] = {.lex_state = 0},
  [1634] = {.lex_state = 0},
  [1635] = {.lex_state = 0},
  [1636] = {.lex_state = 0},
  [1637] = {.lex_state = 0},
  [1638] = {.lex_state = 0},
  [1639] = {.lex_state = 0},
  [1640] = {.lex_state = 0},
  [1641] = {.lex_state = 0},
  [1642] = {.lex_state = 0},
  [1643] = {.lex_state = 0},
  [1644] = {.lex_state = 0},
  [1645] = {.lex_state = 0},
  [1646] = {.lex_state = 0},
  [1647] = {.lex_state = 0},
  [1648] = {.lex_state = 0},
  [1649] = {.lex_state = 0},
  [1650] = {.lex_state = 0},
  [1651] = {.lex_state = 0},
  [1652] = {.lex_state = 0},
  [1653] = {.lex_state = 0},
  [1654] = {.lex_state = 0},
  [1655] = {.lex_state = 0},
  [1656] = {.lex_state = 0},
  [1657] = {.lex_state = 0},
  [1658] = {.lex_state = 0},
  [1659] = {.lex_state = 0},
  [1660] = {.lex_state = 0},
  [1661] = {.lex_state = 0},
  [1662] = {.lex_state = 0},
  [1663] = {.lex_state = 0},
  [1664] = {.lex_state = 0},
  [1665] = {.lex_state = 0},
  [1666] = {.lex_state = 0},
  [1667] = {.lex_state = 0},
  [1668] = {.lex_state = 0},
  [1669] = {.lex_state = 0},
  [1670] = {.lex_state = 0},
  [1671] = {.lex_state = 0},
  [1672] = {.lex_state = 0},
  [1673] = {.lex_state = 0},
  [1674] = {.lex_state = 0},
  [1675] = {.lex_state = 0},
  [1676] = {.lex_state = 0},
  [1677] = {.lex_state = 0},
  [1678] = {.lex_state = 0},
  [1679] = {.lex_state = 0},
  [1680] = {.lex_state = 0},
  [1681] = {.lex_state = 0},
  [1682] = {.lex_state = 0},
  [1683] = {.lex_state = 0},
  [1684] = {.lex_state = 0},
  [1685] = {.lex_state = 0},
  [1686] = {.lex_state = 0},
  [1687] = {.lex_state = 0},
  [1688] = {.lex_state = 0},
  [1689] = {.lex_state = 0},
  [1690] = {.lex_state = 0},
  [1691] = {.lex_state = 0},
  [1692] = {.lex_state = 0},
  [1693] = {.lex_state = 0},
  [1694] = {.lex_state = 0},
  [1695] = {.lex_state = 29},
  [1696] = {.lex_state = 0},
  [1697] = {.lex_state = 0},
  [1698] = {.lex_state = 0},
  [1699] = {.lex_state = 0},
  [1700] = {.lex_state = 0},
  [1701] = {.lex_state = 0},
  [1702] = {.lex_state = 46},
  [1703] = {.lex_state = 46},
  [1704] = {.lex_state = 46},
  [1705] = {.lex_state = 0},
  [1706] = {.lex_state = 0},
  [1707] = {.lex_state = 0},
  [1708] = {.lex_state = 0},
  [1709] = {.lex_state = 0},
  [1710] = {.lex_state = 0},
  [1711] = {.lex_state = 0},
  [1712] = {.lex_state = 0},
  [1713] = {.lex_state = 46},
  [1714] = {.lex_state = 0},
  [1715] = {.lex_state = 0},
  [1716] = {.lex_state = 0},
  [1717] = {.lex_state = 0},
  [1718] = {.lex_state = 0},
  [1719] = {.lex_state = 0},
  [1720] = {.lex_state = 0},
  [1721] = {.lex_state = 0},
  [1722] = {.lex_state = 0},
  [1723] = {.lex_state = 0},
  [1724] = {.lex_state = 0},
  [1725] = {.lex_state = 0},
  [1726] = {.lex_state = 46},
  [1727] = {.lex_state = 0},
  [1728] = {.lex_state = 0},
  [1729] = {.lex_state = 0},
  [1730] = {.lex_state = 0},
  [1731] = {.lex_state = 0},
  [1732] = {.lex_state = 0},
  [1733] = {.lex_state = 968},
  [1734] = {.lex_state = 0},
  [1735] = {.lex_state = 0},
  [1736] = {.lex_state = 0},
  [1737] = {.lex_state = 0},
  [1738] = {.lex_state = 0},
  [1739] = {.lex_state = 46},
  [1740] = {.lex_state = 0},
  [1741] = {.lex_state = 0},
  [1742] = {.lex_state = 0},
  [1743] = {.lex_state = 46},
  [1744] = {.lex_state = 0},
  [1745] = {.lex_state = 0},
  [1746] = {.lex_state = 0},
  [1747] = {.lex_state = 46},
  [1748] = {.lex_state = 0},
  [1749] = {.lex_state = 0},
  [1750] = {.lex_state = 0},
  [1751] = {.lex_state = 0},
  [1752] = {.lex_state = 0},
  [1753] = {.lex_state = 0},
  [1754] = {.lex_state = 0},
  [1755] = {.lex_state = 0},
  [1756] = {.lex_state = 0},
  [1757] = {.lex_state = 0},
  [1758] = {.lex_state = 46},
  [1759] = {.lex_state = 46},
  [1760] = {.lex_state = 46},
  [1761] = {.lex_state = 0},
  [1762] = {.lex_state = 0},
  [1763] = {.lex_state = 46},
  [1764] = {.lex_state = 968},
  [1765] = {.lex_state = 46},
  [1766] = {.lex_state = 0},
  [1767] = {.lex_state = 46},
  [1768] = {.lex_state = 46},
  [1769] = {.lex_state = 0},
  [1770] = {.lex_state = 0},
  [1771] = {.lex_state = 0},
  [1772] = {.lex_state = 0},
  [1773] = {.lex_state = 0},
  [1774] = {.lex_state = 0},
  [1775] = {.lex_state = 0},
  [1776] = {.lex_state = 0},
  [1777] = {.lex_state = 0},
  [1778] = {.lex_state = 0},
  [1779] = {.lex_state = 0},
  [1780] = {.lex_state = 0},
  [1781] = {.lex_state = 0},
  [1782] = {.lex_state = 0},
  [1783] = {.lex_state = 0},
  [1784] = {.lex_state = 0},
  [1785] = {.lex_state = 0},
  [1786] = {.lex_state = 972},
  [1787] = {.lex_state = 0},
  [1788] = {.lex_state = 0},
  [1789] = {.lex_state = 0},
  [1790] = {.lex_state = 0},
  [1791] = {.lex_state = 0},
  [1792] = {.lex_state = 0},
  [1793] = {.lex_state = 0},
  [1794] = {.lex_state = 0},
  [1795] = {.lex_state = 29},
  [1796] = {.lex_state = 0},
  [1797] = {.lex_state = 0},
  [1798] = {.lex_state = 0},
  [1799] = {.lex_state = 972},
  [1800] = {.lex_state = 0},
  [1801] = {.lex_state = 0},
  [1802] = {.lex_state = 972},
  [1803] = {.lex_state = 0},
  [1804] = {.lex_state = 0},
  [1805] = {.lex_state = 0},
  [1806] = {.lex_state = 0},
  [1807] = {.lex_state = 0},
  [1808] = {.lex_state = 0},
  [1809] = {.lex_state = 0},
  [1810] = {.lex_state = 0},
  [1811] = {.lex_state = 0},
  [1812] = {.lex_state = 0},
  [1813] = {.lex_state = 0},
  [1814] = {.lex_state = 0},
  [1815] = {.lex_state = 0},
  [1816] = {.lex_state = 0},
  [1817] = {.lex_state = 0},
  [1818] = {.lex_state = 0},
  [1819] = {.lex_state = 0},
  [1820] = {.lex_state = 0},
  [1821] = {.lex_state = 0},
  [1822] = {.lex_state = 0},
  [1823] = {.lex_state = 0},
  [1824] = {.lex_state = 0},
  [1825] = {.lex_state = 0},
  [1826] = {.lex_state = 0},
  [1827] = {.lex_state = 0},
  [1828] = {.lex_state = 0},
  [1829] = {.lex_state = 0},
  [1830] = {.lex_state = 0},
  [1831] = {.lex_state = 0},
  [1832] = {.lex_state = 0},
  [1833] = {.lex_state = 0},
  [1834] = {.lex_state = 0},
  [1835] = {.lex_state = 0},
  [1836] = {.lex_state = 0},
  [1837] = {.lex_state = 0},
  [1838] = {.lex_state = 0},
  [1839] = {.lex_state = 0},
  [1840] = {.lex_state = 0},
  [1841] = {.lex_state = 0},
  [1842] = {.lex_state = 0},
  [1843] = {.lex_state = 0},
  [1844] = {.lex_state = 0},
  [1845] = {.lex_state = 0},
  [1846] = {.lex_state = 0},
  [1847] = {.lex_state = 29},
  [1848] = {.lex_state = 0},
  [1849] = {.lex_state = 0},
  [1850] = {.lex_state = 0},
  [1851] = {.lex_state = 0},
  [1852] = {.lex_state = 0},
  [1853] = {.lex_state = 0},
  [1854] = {.lex_state = 0},
  [1855] = {.lex_state = 0},
  [1856] = {.lex_state = 0},
  [1857] = {.lex_state = 972},
  [1858] = {.lex_state = 0},
  [1859] = {.lex_state = 0},
  [1860] = {.lex_state = 0},
  [1861] = {.lex_state = 0},
  [1862] = {.lex_state = 0},
  [1863] = {.lex_state = 0},
  [1864] = {.lex_state = 0},
  [1865] = {.lex_state = 0},
  [1866] = {.lex_state = 0},
  [1867] = {.lex_state = 0},
  [1868] = {.lex_state = 0},
  [1869] = {.lex_state = 0},
  [1870] = {.lex_state = 0},
  [1871] = {.lex_state = 0},
  [1872] = {.lex_state = 0},
  [1873] = {.lex_state = 0},
  [1874] = {.lex_state = 0},
  [1875] = {.lex_state = 0},
  [1876] = {.lex_state = 0},
  [1877] = {.lex_state = 0},
  [1878] = {.lex_state = 0},
  [1879] = {.lex_state = 0},
  [1880] = {.lex_state = 0},
  [1881] = {.lex_state = 0},
  [1882] = {.lex_state = 0},
  [1883] = {.lex_state = 29},
  [1884] = {.lex_state = 0},
  [1885] = {.lex_state = 0},
  [1886] = {.lex_state = 0},
  [1887] = {.lex_state = 0},
  [1888] = {.lex_state = 0},
  [1889] = {.lex_state = 0},
  [1890] = {.lex_state = 0},
  [1891] = {.lex_state = 0},
  [1892] = {.lex_state = 0},
  [1893] = {.lex_state = 29},
  [1894] = {.lex_state = 29},
  [1895] = {.lex_state = 0},
  [1896] = {.lex_state = 0},
  [1897] = {.lex_state = 972},
  [1898] = {.lex_state = 0},
  [1899] = {.lex_state = 0},
  [1900] = {.lex_state = 0},
  [1901] = {.lex_state = 0},
  [1902] = {.lex_state = 0},
  [1903] = {.lex_state = 0},
  [1904] = {.lex_state = 0},
  [1905] = {.lex_state = 0},
  [1906] = {.lex_state = 0},
  [1907] = {.lex_state = 0},
  [1908] = {.lex_state = 0},
  [1909] = {.lex_state = 0},
  [1910] = {.lex_state = 29},
  [1911] = {.lex_state = 0},
  [1912] = {.lex_state = 0},
  [1913] = {.lex_state = 11},
  [1914] = {.lex_state = 29},
  [1915] = {.lex_state = 0},
  [1916] = {.lex_state = 0},
  [1917] = {.lex_state = 0},
  [1918] = {.lex_state = 0},
  [1919] = {.lex_state = 0},
  [1920] = {.lex_state = 0},
  [1921] = {.lex_state = 43},
  [1922] = {.lex_state = 43},
  [1923] = {.lex_state = 43},
  [1924] = {.lex_state = 0},
  [1925] = {.lex_state = 0},
  [1926] = {.lex_state = 43},
  [1927] = {.lex_state = 43},
  [1928] = {.lex_state = 0},
  [1929] = {.lex_state = 0},
  [1930] = {.lex_state = 0},
  [1931] = {.lex_state = 39},
  [1932] = {.lex_state = 0},
  [1933] = {.lex_state = 43},
  [1934] = {.lex_state = 0},
  [1935] = {.lex_state = 0},
  [1936] = {.lex_state = 43},
  [1937] = {.lex_state = 43},
  [1938] = {.lex_state = 0},
  [1939] = {.lex_state = 0},
  [1940] = {.lex_state = 43},
  [1941] = {.lex_state = 0},
  [1942] = {.lex_state = 0},
  [1943] = {.lex_state = 0},
  [1944] = {.lex_state = 43},
  [1945] = {.lex_state = 0},
  [1946] = {.lex_state = 0},
  [1947] = {.lex_state = 0},
  [1948] = {.lex_state = 43},
  [1949] = {.lex_state = 0},
  [1950] = {.lex_state = 0},
  [1951] = {.lex_state = 0},
  [1952] = {.lex_state = 972},
  [1953] = {.lex_state = 0},
  [1954] = {.lex_state = 29},
  [1955] = {.lex_state = 44},
  [1956] = {.lex_state = 0},
  [1957] = {.lex_state = 1000},
  [1958] = {.lex_state = 1000},
  [1959] = {.lex_state = 1000},
  [1960] = {.lex_state = 0},
  [1961] = {.lex_state = 0},
  [1962] = {.lex_state = 972},
  [1963] = {.lex_state = 29},
  [1964] = {.lex_state = 40},
  [1965] = {.lex_state = 0},
  [1966] = {.lex_state = 0},
  [1967] = {.lex_state = 0},
  [1968] = {.lex_state = 0},
  [1969] = {.lex_state = 0},
  [1970] = {.lex_state = 0},
  [1971] = {.lex_state = 29},
  [1972] = {.lex_state = 0},
  [1973] = {.lex_state = 0},
  [1974] = {.lex_state = 0},
  [1975] = {.lex_state = 0},
  [1976] = {.lex_state = 0},
  [1977] = {.lex_state = 0},
  [1978] = {.lex_state = 0},
  [1979] = {.lex_state = 0},
  [1980] = {.lex_state = 0},
  [1981] = {.lex_state = 29},
  [1982] = {.lex_state = 0},
  [1983] = {.lex_state = 0},
  [1984] = {.lex_state = 0},
  [1985] = {.lex_state = 1000},
  [1986] = {.lex_state = 0},
  [1987] = {.lex_state = 0},
  [1988] = {.lex_state = 0},
  [1989] = {.lex_state = 0},
  [1990] = {.lex_state = 0},
  [1991] = {.lex_state = 0},
  [1992] = {.lex_state = 0},
  [1993] = {.lex_state = 0},
  [1994] = {.lex_state = 0},
  [1995] = {.lex_state = 0},
  [1996] = {.lex_state = 0},
  [1997] = {.lex_state = 0},
  [1998] = {.lex_state = 0},
  [1999] = {.lex_state = 0},
  [2000] = {.lex_state = 0},
  [2001] = {.lex_state = 0},
  [2002] = {.lex_state = 0},
  [2003] = {.lex_state = 0},
  [2004] = {.lex_state = 0},
  [2005] = {.lex_state = 0},
  [2006] = {.lex_state = 1000},
  [2007] = {.lex_state = 1000},
  [2008] = {.lex_state = 0},
  [2009] = {.lex_state = 0},
  [2010] = {.lex_state = 972},
  [2011] = {.lex_state = 0},
  [2012] = {.lex_state = 1000},
  [2013] = {.lex_state = 0},
  [2014] = {.lex_state = 0},
  [2015] = {.lex_state = 1000},
  [2016] = {.lex_state = 0},
  [2017] = {.lex_state = 0},
  [2018] = {.lex_state = 0},
  [2019] = {.lex_state = 0},
  [2020] = {.lex_state = 0},
  [2021] = {.lex_state = 0},
  [2022] = {.lex_state = 1000},
  [2023] = {.lex_state = 0},
  [2024] = {.lex_state = 0},
  [2025] = {.lex_state = 0},
  [2026] = {.lex_state = 0},
  [2027] = {.lex_state = 0},
  [2028] = {.lex_state = 972},
  [2029] = {.lex_state = 0},
  [2030] = {.lex_state = 29},
  [2031] = {.lex_state = 0},
  [2032] = {.lex_state = 0},
  [2033] = {.lex_state = 0},
  [2034] = {.lex_state = 0},
  [2035] = {.lex_state = 0},
  [2036] = {.lex_state = 44},
  [2037] = {.lex_state = 0},
  [2038] = {.lex_state = 0},
  [2039] = {.lex_state = 40},
  [2040] = {.lex_state = 0},
  [2041] = {.lex_state = 0},
  [2042] = {.lex_state = 0},
  [2043] = {.lex_state = 0},
  [2044] = {.lex_state = 0},
  [2045] = {.lex_state = 0},
  [2046] = {.lex_state = 0},
  [2047] = {.lex_state = 0},
  [2048] = {.lex_state = 0},
  [2049] = {.lex_state = 0},
  [2050] = {.lex_state = 0},
  [2051] = {.lex_state = 0},
  [2052] = {.lex_state = 0},
  [2053] = {.lex_state = 0},
  [2054] = {.lex_state = 0},
  [2055] = {.lex_state = 40},
  [2056] = {.lex_state = 0},
  [2057] = {.lex_state = 0},
  [2058] = {.lex_state = 0},
  [2059] = {.lex_state = 0},
  [2060] = {.lex_state = 0},
  [2061] = {.lex_state = 0},
  [2062] = {.lex_state = 0},
  [2063] = {.lex_state = 0},
  [2064] = {.lex_state = 0},
  [2065] = {.lex_state = 0},
  [2066] = {.lex_state = 0},
  [2067] = {.lex_state = 0},
  [2068] = {.lex_state = 0},
  [2069] = {.lex_state = 0},
  [2070] = {.lex_state = 0},
  [2071] = {.lex_state = 1000},
  [2072] = {.lex_state = 44},
  [2073] = {.lex_state = 0},
  [2074] = {.lex_state = 1000},
  [2075] = {.lex_state = 1000},
  [2076] = {.lex_state = 1000},
  [2077] = {.lex_state = 0},
  [2078] = {.lex_state = 0},
  [2079] = {.lex_state = 0},
  [2080] = {.lex_state = 0},
  [2081] = {.lex_state = 0},
  [2082] = {.lex_state = 0},
  [2083] = {.lex_state = 0},
  [2084] = {.lex_state = 0},
  [2085] = {.lex_state = 0},
  [2086] = {.lex_state = 0},
  [2087] = {.lex_state = 0},
  [2088] = {.lex_state = 0},
  [2089] = {.lex_state = 0},
  [2090] = {.lex_state = 0},
  [2091] = {.lex_state = 0},
  [2092] = {.lex_state = 0},
  [2093] = {.lex_state = 0},
  [2094] = {.lex_state = 0},
  [2095] = {.lex_state = 0},
  [2096] = {.lex_state = 0},
  [2097] = {.lex_state = 0},
  [2098] = {.lex_state = 29},
  [2099] = {.lex_state = 0},
  [2100] = {.lex_state = 0},
  [2101] = {.lex_state = 0},
  [2102] = {.lex_state = 0},
  [2103] = {.lex_state = 0},
  [2104] = {.lex_state = 0},
  [2105] = {.lex_state = 0},
  [2106] = {.lex_state = 0},
  [2107] = {.lex_state = 0},
  [2108] = {.lex_state = 0},
  [2109] = {.lex_state = 0},
  [2110] = {.lex_state = 0},
  [2111] = {.lex_state = 0},
  [2112] = {.lex_state = 0},
  [2113] = {.lex_state = 0},
  [2114] = {.lex_state = 0},
  [2115] = {.lex_state = 0},
  [2116] = {.lex_state = 40},
  [2117] = {.lex_state = 44},
  [2118] = {.lex_state = 0},
  [2119] = {.lex_state = 0},
  [2120] = {.lex_state = 0},
  [2121] = {.lex_state = 0},
  [2122] = {.lex_state = 0},
  [2123] = {.lex_state = 0},
  [2124] = {.lex_state = 0},
  [2125] = {.lex_state = 0},
  [2126] = {.lex_state = 0},
  [2127] = {.lex_state = 44},
  [2128] = {.lex_state = 0},
  [2129] = {.lex_state = 0},
  [2130] = {.lex_state = 0},
  [2131] = {.lex_state = 0},
  [2132] = {.lex_state = 0},
  [2133] = {.lex_state = 0},
  [2134] = {.lex_state = 0},
  [2135] = {.lex_state = 0},
  [2136] = {.lex_state = 0},
  [2137] = {.lex_state = 0},
  [2138] = {.lex_state = 0},
  [2139] = {.lex_state = 0},
  [2140] = {.lex_state = 0},
  [2141] = {.lex_state = 972},
  [2142] = {.lex_state = 1000},
  [2143] = {.lex_state = 0},
  [2144] = {.lex_state = 44},
  [2145] = {.lex_state = 0},
  [2146] = {.lex_state = 40},
  [2147] = {.lex_state = 0},
  [2148] = {.lex_state = 0},
  [2149] = {.lex_state = 0},
  [2150] = {.lex_state = 0},
  [2151] = {.lex_state = 0},
  [2152] = {.lex_state = 0},
  [2153] = {.lex_state = 0},
  [2154] = {.lex_state = 0},
  [2155] = {.lex_state = 1000},
  [2156] = {.lex_state = 1000},
  [2157] = {.lex_state = 0},
  [2158] = {.lex_state = 40},
  [2159] = {.lex_state = 0},
  [2160] = {.lex_state = 0},
  [2161] = {.lex_state = 0},
  [2162] = {.lex_state = 0},
  [2163] = {.lex_state = 972},
  [2164] = {.lex_state = 0},
  [2165] = {.lex_state = 0},
  [2166] = {.lex_state = 29},
  [2167] = {.lex_state = 0},
  [2168] = {.lex_state = 0},
  [2169] = {.lex_state = 0},
  [2170] = {.lex_state = 0},
  [2171] = {.lex_state = 0},
  [2172] = {.lex_state = 0},
  [2173] = {.lex_state = 0},
  [2174] = {.lex_state = 0},
  [2175] = {.lex_state = 11},
  [2176] = {.lex_state = 0},
  [2177] = {.lex_state = 0},
  [2178] = {.lex_state = 0},
  [2179] = {.lex_state = 0},
  [2180] = {.lex_state = 0},
  [2181] = {.lex_state = 0},
  [2182] = {.lex_state = 0},
  [2183] = {.lex_state = 0},
  [2184] = {.lex_state = 0},
  [2185] = {.lex_state = 0},
  [2186] = {.lex_state = 44},
  [2187] = {.lex_state = 0},
  [2188] = {.lex_state = 0},
  [2189] = {.lex_state = 0},
  [2190] = {.lex_state = 0},
  [2191] = {.lex_state = 0},
  [2192] = {.lex_state = 0},
  [2193] = {.lex_state = 29},
  [2194] = {.lex_state = 0},
  [2195] = {.lex_state = 0},
  [2196] = {.lex_state = 0},
  [2197] = {.lex_state = 0},
  [2198] = {.lex_state = 0},
  [2199] = {.lex_state = 29},
  [2200] = {.lex_state = 971},
  [2201] = {.lex_state = 29},
  [2202] = {.lex_state = 29},
  [2203] = {.lex_state = 0},
  [2204] = {.lex_state = 29},
  [2205] = {.lex_state = 29},
  [2206] = {.lex_state = 29},
  [2207] = {.lex_state = 29},
  [2208] = {.lex_state = 29},
  [2209] = {.lex_state = 0},
  [2210] = {.lex_state = 0},
  [2211] = {.lex_state = 0},
  [2212] = {.lex_state = 29},
  [2213] = {.lex_state = 0},
  [2214] = {.lex_state = 0},
  [2215] = {.lex_state = 0},
  [2216] = {.lex_state = 0},
  [2217] = {.lex_state = 967},
  [2218] = {.lex_state = 0},
  [2219] = {.lex_state = 0},
  [2220] = {.lex_state = 0},
  [2221] = {.lex_state = 29},
  [2222] = {.lex_state = 0},
  [2223] = {.lex_state = 0},
  [2224] = {.lex_state = 0},
  [2225] = {.lex_state = 39},
  [2226] = {.lex_state = 0},
  [2227] = {.lex_state = 967},
  [2228] = {.lex_state = 971},
  [2229] = {.lex_state = 0},
  [2230] = {.lex_state = 0},
  [2231] = {.lex_state = 0},
  [2232] = {.lex_state = 29},
  [2233] = {.lex_state = 29},
  [2234] = {.lex_state = 0},
  [2235] = {.lex_state = 29},
  [2236] = {.lex_state = 29},
  [2237] = {.lex_state = 0},
  [2238] = {.lex_state = 0},
  [2239] = {.lex_state = 0},
  [2240] = {.lex_state = 0},
  [2241] = {.lex_state = 45},
  [2242] = {.lex_state = 0},
  [2243] = {.lex_state = 29},
  [2244] = {.lex_state = 0},
  [2245] = {.lex_state = 0},
  [2246] = {.lex_state = 0},
  [2247] = {.lex_state = 0},
  [2248] = {.lex_state = 0},
  [2249] = {.lex_state = 0},
  [2250] = {.lex_state = 0},
  [2251] = {.lex_state = 0},
  [2252] = {.lex_state = 971},
  [2253] = {.lex_state = 971},
  [2254] = {.lex_state = 0},
  [2255] = {.lex_state = 0},
  [2256] = {.lex_state = 971},
  [2257] = {.lex_state = 42},
  [2258] = {.lex_state = 971},
  [2259] = {.lex_state = 971},
  [2260] = {.lex_state = 971},
  [2261] = {.lex_state = 971},
  [2262] = {.lex_state = 0},
  [2263] = {.lex_state = 29},
  [2264] = {.lex_state = 971},
  [2265] = {.lex_state = 972},
  [2266] = {.lex_state = 29},
  [2267] = {.lex_state = 0},
  [2268] = {.lex_state = 971},
  [2269] = {.lex_state = 29},
  [2270] = {.lex_state = 971},
  [2271] = {.lex_state = 0},
  [2272] = {.lex_state = 29},
  [2273] = {.lex_state = 0},
  [2274] = {.lex_state = 41},
  [2275] = {.lex_state = 42},
  [2276] = {.lex_state = 29},
  [2277] = {.lex_state = 0},
  [2278] = {.lex_state = 29},
  [2279] = {.lex_state = 0},
  [2280] = {.lex_state = 0},
  [2281] = {.lex_state = 0},
  [2282] = {.lex_state = 39},
  [2283] = {.lex_state = 0},
  [2284] = {.lex_state = 0},
  [2285] = {.lex_state = 0},
  [2286] = {.lex_state = 0},
  [2287] = {.lex_state = 0},
  [2288] = {.lex_state = 0},
  [2289] = {.lex_state = 0},
  [2290] = {.lex_state = 45},
  [2291] = {.lex_state = 970},
  [2292] = {.lex_state = 0},
  [2293] = {.lex_state = 0},
  [2294] = {.lex_state = 0},
  [2295] = {.lex_state = 29},
  [2296] = {.lex_state = 0},
  [2297] = {.lex_state = 0},
  [2298] = {.lex_state = 29},
  [2299] = {.lex_state = 971},
  [2300] = {.lex_state = 29},
  [2301] = {.lex_state = 0},
  [2302] = {.lex_state = 0},
  [2303] = {.lex_state = 0},
  [2304] = {.lex_state = 0},
  [2305] = {.lex_state = 29},
  [2306] = {.lex_state = 0},
  [2307] = {.lex_state = 971},
  [2308] = {.lex_state = 29},
  [2309] = {.lex_state = 0},
  [2310] = {.lex_state = 970},
  [2311] = {.lex_state = 971},
  [2312] = {.lex_state = 0},
  [2313] = {.lex_state = 0},
  [2314] = {.lex_state = 0},
  [2315] = {.lex_state = 0},
  [2316] = {.lex_state = 0},
  [2317] = {.lex_state = 0},
  [2318] = {.lex_state = 29},
  [2319] = {.lex_state = 0},
  [2320] = {.lex_state = 0},
  [2321] = {.lex_state = 0},
  [2322] = {.lex_state = 29},
  [2323] = {.lex_state = 0},
  [2324] = {.lex_state = 0},
  [2325] = {.lex_state = 0},
  [2326] = {.lex_state = 29},
  [2327] = {.lex_state = 29},
  [2328] = {.lex_state = 0},
  [2329] = {.lex_state = 0},
  [2330] = {.lex_state = 0},
  [2331] = {.lex_state = 0},
  [2332] = {.lex_state = 0},
  [2333] = {.lex_state = 0},
  [2334] = {.lex_state = 0},
  [2335] = {.lex_state = 0},
  [2336] = {.lex_state = 29},
  [2337] = {.lex_state = 0},
  [2338] = {.lex_state = 0},
  [2339] = {.lex_state = 1000},
  [2340] = {.lex_state = 0},
  [2341] = {.lex_state = 29},
  [2342] = {.lex_state = 0},
  [2343] = {.lex_state = 29},
  [2344] = {.lex_state = 29},
  [2345] = {.lex_state = 0},
  [2346] = {.lex_state = 29},
  [2347] = {.lex_state = 0},
  [2348] = {.lex_state = 0},
  [2349] = {.lex_state = 971},
  [2350] = {.lex_state = 29},
  [2351] = {.lex_state = 0},
  [2352] = {.lex_state = 971},
  [2353] = {.lex_state = 29},
  [2354] = {.lex_state = 0},
  [2355] = {.lex_state = 29},
  [2356] = {.lex_state = 0},
  [2357] = {.lex_state = 0},
  [2358] = {.lex_state = 0},
  [2359] = {.lex_state = 0},
  [2360] = {.lex_state = 0},
  [2361] = {.lex_state = 0},
  [2362] = {.lex_state = 29},
  [2363] = {.lex_state = 0},
  [2364] = {.lex_state = 0},
  [2365] = {.lex_state = 0},
  [2366] = {.lex_state = 29},
  [2367] = {.lex_state = 0},
  [2368] = {.lex_state = 0},
  [2369] = {.lex_state = 29},
  [2370] = {.lex_state = 29},
  [2371] = {.lex_state = 0},
  [2372] = {.lex_state = 0},
  [2373] = {.lex_state = 11},
  [2374] = {.lex_state = 29},
  [2375] = {.lex_state = 29},
  [2376] = {.lex_state = 29},
  [2377] = {.lex_state = 29},
  [2378] = {.lex_state = 29},
  [2379] = {.lex_state = 0},
  [2380] = {.lex_state = 29},
  [2381] = {.lex_state = 0},
  [2382] = {.lex_state = 29},
  [2383] = {.lex_state = 29},
  [2384] = {.lex_state = 29},
  [2385] = {.lex_state = 29},
  [2386] = {.lex_state = 0},
  [2387] = {.lex_state = 0},
  [2388] = {.lex_state = 29},
  [2389] = {.lex_state = 29},
  [2390] = {.lex_state = 29},
  [2391] = {.lex_state = 29},
  [2392] = {.lex_state = 0},
  [2393] = {.lex_state = 29},
  [2394] = {.lex_state = 29},
  [2395] = {.lex_state = 37},
  [2396] = {.lex_state = 0},
  [2397] = {.lex_state = 29},
  [2398] = {.lex_state = 29},
  [2399] = {.lex_state = 29},
  [2400] = {.lex_state = 29},
  [2401] = {.lex_state = 29},
  [2402] = {.lex_state = 29},
  [2403] = {.lex_state = 29},
  [2404] = {.lex_state = 0},
  [2405] = {.lex_state = 29},
  [2406] = {.lex_state = 29},
  [2407] = {.lex_state = 29},
  [2408] = {.lex_state = 29},
  [2409] = {.lex_state = 29},
  [2410] = {.lex_state = 29},
  [2411] = {.lex_state = 37},
  [2412] = {.lex_state = 0},
  [2413] = {.lex_state = 11},
  [2414] = {.lex_state = 29},
  [2415] = {.lex_state = 29},
  [2416] = {.lex_state = 0},
  [2417] = {.lex_state = 29},
  [2418] = {.lex_state = 0},
  [2419] = {.lex_state = 29},
  [2420] = {.lex_state = 0},
  [2421] = {.lex_state = 29},
  [2422] = {.lex_state = 0},
  [2423] = {.lex_state = 1000},
  [2424] = {.lex_state = 0},
  [2425] = {.lex_state = 29},
  [2426] = {.lex_state = 29},
  [2427] = {.lex_state = 0},
  [2428] = {.lex_state = 0},
  [2429] = {.lex_state = 0},
  [2430] = {.lex_state = 29},
  [2431] = {.lex_state = 29},
  [2432] = {.lex_state = 0},
  [2433] = {.lex_state = 0},
  [2434] = {.lex_state = 11},
  [2435] = {.lex_state = 971},
  [2436] = {.lex_state = 0},
  [2437] = {.lex_state = 11},
  [2438] = {.lex_state = 29},
  [2439] = {.lex_state = 0},
  [2440] = {.lex_state = 29},
  [2441] = {.lex_state = 29},
  [2442] = {.lex_state = 29},
  [2443] = {.lex_state = 0},
  [2444] = {.lex_state = 0},
  [2445] = {.lex_state = 0},
  [2446] = {.lex_state = 29},
  [2447] = {.lex_state = 29},
  [2448] = {.lex_state = 0},
  [2449] = {.lex_state = 29},
  [2450] = {.lex_state = 29},
  [2451] = {.lex_state = 0},
  [2452] = {.lex_state = 0},
  [2453] = {.lex_state = 29},
  [2454] = {.lex_state = 0},
  [2455] = {.lex_state = 29},
  [2456] = {.lex_state = 970},
  [2457] = {.lex_state = 29},
  [2458] = {.lex_state = 0},
  [2459] = {.lex_state = 29},
  [2460] = {.lex_state = 0},
  [2461] = {.lex_state = 0},
  [2462] = {.lex_state = 0},
  [2463] = {.lex_state = 29},
  [2464] = {.lex_state = 29},
  [2465] = {.lex_state = 0},
  [2466] = {.lex_state = 29},
  [2467] = {.lex_state = 0},
  [2468] = {.lex_state = 29},
  [2469] = {.lex_state = 29},
  [2470] = {.lex_state = 0},
  [2471] = {.lex_state = 0},
  [2472] = {.lex_state = 29},
  [2473] = {.lex_state = 29},
  [2474] = {.lex_state = 970},
  [2475] = {.lex_state = 29},
  [2476] = {.lex_state = 0},
  [2477] = {.lex_state = 29},
  [2478] = {.lex_state = 0},
  [2479] = {.lex_state = 1000},
  [2480] = {.lex_state = 29},
  [2481] = {.lex_state = 0},
  [2482] = {.lex_state = 29},
  [2483] = {.lex_state = 29},
  [2484] = {.lex_state = 0},
  [2485] = {.lex_state = 29},
  [2486] = {.lex_state = 29},
  [2487] = {.lex_state = 1000},
  [2488] = {.lex_state = 0},
  [2489] = {.lex_state = 29},
  [2490] = {.lex_state = 0},
  [2491] = {.lex_state = 0},
  [2492] = {.lex_state = 29},
  [2493] = {.lex_state = 29},
  [2494] = {.lex_state = 966},
  [2495] = {.lex_state = 11},
  [2496] = {.lex_state = 29},
  [2497] = {.lex_state = 0},
  [2498] = {.lex_state = 0},
  [2499] = {.lex_state = 29},
  [2500] = {.lex_state = 1000},
  [2501] = {.lex_state = 29},
  [2502] = {.lex_state = 29},
  [2503] = {.lex_state = 29},
  [2504] = {.lex_state = 0},
  [2505] = {.lex_state = 29},
  [2506] = {.lex_state = 29},
  [2507] = {.lex_state = 29},
  [2508] = {.lex_state = 0},
  [2509] = {.lex_state = 29},
  [2510] = {.lex_state = 0},
  [2511] = {.lex_state = 0},
  [2512] = {.lex_state = 29},
  [2513] = {.lex_state = 29},
  [2514] = {.lex_state = 971},
  [2515] = {.lex_state = 29},
  [2516] = {.lex_state = 29},
  [2517] = {.lex_state = 0},
  [2518] = {.lex_state = 29},
  [2519] = {.lex_state = 0},
  [2520] = {.lex_state = 37},
  [2521] = {.lex_state = 29},
  [2522] = {.lex_state = 29},
  [2523] = {.lex_state = 0},
  [2524] = {.lex_state = 0},
  [2525] = {.lex_state = 29},
  [2526] = {.lex_state = 29},
  [2527] = {.lex_state = 0},
  [2528] = {.lex_state = 0},
  [2529] = {.lex_state = 29},
  [2530] = {.lex_state = 0},
  [2531] = {.lex_state = 0},
  [2532] = {.lex_state = 29},
  [2533] = {.lex_state = 0},
  [2534] = {.lex_state = 0},
  [2535] = {.lex_state = 0},
  [2536] = {.lex_state = 0},
  [2537] = {.lex_state = 0},
  [2538] = {.lex_state = 0},
  [2539] = {.lex_state = 29},
  [2540] = {.lex_state = 29},
  [2541] = {.lex_state = 0},
  [2542] = {.lex_state = 0},
  [2543] = {.lex_state = 37},
  [2544] = {.lex_state = 0},
  [2545] = {.lex_state = 37},
  [2546] = {.lex_state = 0},
  [2547] = {.lex_state = 29},
  [2548] = {.lex_state = 0},
  [2549] = {.lex_state = 0},
  [2550] = {.lex_state = 0},
  [2551] = {.lex_state = 0},
  [2552] = {.lex_state = 29},
  [2553] = {.lex_state = 29},
  [2554] = {.lex_state = 29},
  [2555] = {.lex_state = 29},
  [2556] = {.lex_state = 11},
  [2557] = {.lex_state = 0},
  [2558] = {.lex_state = 0},
  [2559] = {.lex_state = 29},
  [2560] = {.lex_state = 29},
  [2561] = {.lex_state = 29},
  [2562] = {.lex_state = 29},
  [2563] = {.lex_state = 0},
  [2564] = {.lex_state = 29},
  [2565] = {.lex_state = 29},
  [2566] = {.lex_state = 29},
  [2567] = {.lex_state = 29},
  [2568] = {.lex_state = 29},
  [2569] = {.lex_state = 29},
  [2570] = {.lex_state = 29},
  [2571] = {.lex_state = 29},
  [2572] = {.lex_state = 29},
  [2573] = {.lex_state = 29},
  [2574] = {.lex_state = 29},
  [2575] = {.lex_state = 29},
  [2576] = {.lex_state = 29},
  [2577] = {.lex_state = 29},
  [2578] = {.lex_state = 29},
  [2579] = {.lex_state = 29},
  [2580] = {.lex_state = 29},
  [2581] = {.lex_state = 0},
  [2582] = {.lex_state = 29},
  [2583] = {.lex_state = 29},
  [2584] = {.lex_state = 29},
  [2585] = {.lex_state = 29},
  [2586] = {.lex_state = 29},
  [2587] = {.lex_state = 0},
  [2588] = {.lex_state = 29},
  [2589] = {.lex_state = 29},
  [2590] = {.lex_state = 0},
  [2591] = {.lex_state = 0},
  [2592] = {.lex_state = 0},
  [2593] = {.lex_state = 0},
  [2594] = {.lex_state = 0},
  [2595] = {.lex_state = 0},
  [2596] = {.lex_state = 0},
  [2597] = {.lex_state = 0},
  [2598] = {.lex_state = 0},
  [2599] = {.lex_state = 0},
  [2600] = {.lex_state = 0},
  [2601] = {.lex_state = 0},
  [2602] = {.lex_state = 0},
  [2603] = {.lex_state = 0},
  [2604] = {.lex_state = 0},
  [2605] = {.lex_state = 0},
  [2606] = {.lex_state = 0},
  [2607] = {.lex_state = 0},
  [2608] = {.lex_state = 0},
  [2609] = {.lex_state = 0},
  [2610] = {.lex_state = 0},
  [2611] = {.lex_state = 0},
  [2612] = {.lex_state = 0},
  [2613] = {.lex_state = 0},
  [2614] = {.lex_state = 0},
  [2615] = {.lex_state = 0},
  [2616] = {.lex_state = 0},
  [2617] = {.lex_state = 0},
  [2618] = {.lex_state = 0},
  [2619] = {.lex_state = 0},
  [2620] = {.lex_state = 0},
  [2621] = {.lex_state = 0},
  [2622] = {.lex_state = 0},
  [2623] = {.lex_state = 0},
  [2624] = {.lex_state = 0},
  [2625] = {.lex_state = 970},
  [2626] = {.lex_state = 0},
  [2627] = {.lex_state = 0},
  [2628] = {.lex_state = 0},
  [2629] = {.lex_state = 0},
  [2630] = {.lex_state = 0},
  [2631] = {.lex_state = 0},
  [2632] = {.lex_state = 0},
  [2633] = {.lex_state = 0},
  [2634] = {.lex_state = 0},
  [2635] = {.lex_state = 0},
  [2636] = {.lex_state = 0},
  [2637] = {.lex_state = 0},
  [2638] = {.lex_state = 0},
  [2639] = {.lex_state = 0},
  [2640] = {.lex_state = 0},
  [2641] = {.lex_state = 0},
  [2642] = {.lex_state = 11},
  [2643] = {.lex_state = 0},
  [2644] = {.lex_state = 0},
  [2645] = {.lex_state = 0},
  [2646] = {.lex_state = 0},
  [2647] = {.lex_state = 0},
  [2648] = {.lex_state = 0},
  [2649] = {.lex_state = 0},
  [2650] = {.lex_state = 0},
  [2651] = {.lex_state = 0},
  [2652] = {.lex_state = 970},
  [2653] = {.lex_state = 0},
  [2654] = {.lex_state = 0},
  [2655] = {.lex_state = 0},
  [2656] = {.lex_state = 0},
  [2657] = {.lex_state = 0},
  [2658] = {.lex_state = 0},
  [2659] = {.lex_state = 0},
  [2660] = {.lex_state = 0},
  [2661] = {.lex_state = 0},
  [2662] = {.lex_state = 0},
  [2663] = {.lex_state = 0},
  [2664] = {.lex_state = 37},
  [2665] = {.lex_state = 0},
  [2666] = {.lex_state = 0},
  [2667] = {.lex_state = 0},
  [2668] = {.lex_state = 0},
  [2669] = {.lex_state = 0},
  [2670] = {.lex_state = 0},
  [2671] = {.lex_state = 0},
  [2672] = {.lex_state = 0},
  [2673] = {.lex_state = 0},
  [2674] = {.lex_state = 0},
  [2675] = {.lex_state = 0},
  [2676] = {.lex_state = 0},
  [2677] = {.lex_state = 0},
  [2678] = {.lex_state = 0},
  [2679] = {.lex_state = 0},
  [2680] = {.lex_state = 0},
  [2681] = {.lex_state = 0},
  [2682] = {.lex_state = 0},
  [2683] = {.lex_state = 0},
  [2684] = {.lex_state = 0},
  [2685] = {.lex_state = 966},
  [2686] = {.lex_state = 0},
  [2687] = {.lex_state = 0},
  [2688] = {.lex_state = 37},
  [2689] = {.lex_state = 0},
  [2690] = {.lex_state = 0},
  [2691] = {.lex_state = 0},
  [2692] = {.lex_state = 0},
  [2693] = {.lex_state = 0},
  [2694] = {.lex_state = 0},
  [2695] = {.lex_state = 0},
  [2696] = {.lex_state = 0},
  [2697] = {.lex_state = 0},
  [2698] = {.lex_state = 0},
  [2699] = {.lex_state = 0},
  [2700] = {.lex_state = 0},
  [2701] = {.lex_state = 0},
  [2702] = {.lex_state = 0},
  [2703] = {.lex_state = 0},
  [2704] = {.lex_state = 0},
  [2705] = {.lex_state = 0},
  [2706] = {.lex_state = 0},
  [2707] = {.lex_state = 0},
  [2708] = {.lex_state = 0},
  [2709] = {.lex_state = 0},
  [2710] = {.lex_state = 0},
  [2711] = {.lex_state = 0},
  [2712] = {.lex_state = 0},
  [2713] = {.lex_state = 0},
  [2714] = {.lex_state = 0},
  [2715] = {.lex_state = 0},
  [2716] = {.lex_state = 0},
  [2717] = {.lex_state = 0},
  [2718] = {.lex_state = 0},
  [2719] = {.lex_state = 1000},
  [2720] = {.lex_state = 0},
  [2721] = {.lex_state = 0},
  [2722] = {.lex_state = 0},
  [2723] = {.lex_state = 0},
  [2724] = {.lex_state = 0},
  [2725] = {.lex_state = 0},
  [2726] = {.lex_state = 0},
  [2727] = {.lex_state = 38},
  [2728] = {.lex_state = 0},
  [2729] = {.lex_state = 0},
  [2730] = {.lex_state = 0},
  [2731] = {.lex_state = 0},
  [2732] = {.lex_state = 0},
  [2733] = {.lex_state = 0},
  [2734] = {.lex_state = 0},
  [2735] = {.lex_state = 0},
  [2736] = {.lex_state = 0},
  [2737] = {.lex_state = 0},
  [2738] = {.lex_state = 0},
  [2739] = {.lex_state = 0},
  [2740] = {.lex_state = 0},
  [2741] = {.lex_state = 0},
  [2742] = {.lex_state = 0},
  [2743] = {.lex_state = 0},
  [2744] = {.lex_state = 0},
  [2745] = {.lex_state = 0},
  [2746] = {.lex_state = 0},
  [2747] = {.lex_state = 0},
  [2748] = {.lex_state = 0},
  [2749] = {.lex_state = 0},
  [2750] = {.lex_state = 0},
  [2751] = {.lex_state = 0},
  [2752] = {.lex_state = 0},
  [2753] = {.lex_state = 0},
  [2754] = {.lex_state = 0},
  [2755] = {.lex_state = 0},
  [2756] = {.lex_state = 0},
  [2757] = {.lex_state = 0},
  [2758] = {.lex_state = 0},
  [2759] = {.lex_state = 0},
  [2760] = {.lex_state = 0},
  [2761] = {.lex_state = 0},
  [2762] = {.lex_state = 0},
  [2763] = {.lex_state = 0},
  [2764] = {.lex_state = 0},
  [2765] = {.lex_state = 0},
  [2766] = {.lex_state = 0},
  [2767] = {.lex_state = 0},
  [2768] = {.lex_state = 0},
  [2769] = {.lex_state = 0},
  [2770] = {.lex_state = 0},
  [2771] = {.lex_state = 0},
  [2772] = {.lex_state = 37},
  [2773] = {.lex_state = 0},
  [2774] = {.lex_state = 1000},
  [2775] = {.lex_state = 0},
  [2776] = {.lex_state = 0},
  [2777] = {.lex_state = 0},
  [2778] = {.lex_state = 0},
  [2779] = {.lex_state = 0},
  [2780] = {.lex_state = 0},
  [2781] = {.lex_state = 0},
  [2782] = {.lex_state = 0},
  [2783] = {.lex_state = 0},
  [2784] = {.lex_state = 0},
  [2785] = {.lex_state = 0},
  [2786] = {.lex_state = 0},
  [2787] = {.lex_state = 0},
  [2788] = {.lex_state = 0},
  [2789] = {.lex_state = 0},
  [2790] = {.lex_state = 0},
  [2791] = {.lex_state = 0},
  [2792] = {.lex_state = 0},
  [2793] = {.lex_state = 0},
  [2794] = {.lex_state = 1000},
  [2795] = {.lex_state = 0},
  [2796] = {.lex_state = 11},
  [2797] = {.lex_state = 0},
  [2798] = {.lex_state = 11},
  [2799] = {.lex_state = 0},
  [2800] = {.lex_state = 0},
  [2801] = {.lex_state = 0},
  [2802] = {.lex_state = 0},
  [2803] = {.lex_state = 0},
  [2804] = {.lex_state = 0},
  [2805] = {.lex_state = 0},
  [2806] = {.lex_state = 970},
  [2807] = {.lex_state = 0},
  [2808] = {.lex_state = 0},
  [2809] = {.lex_state = 0},
  [2810] = {.lex_state = 0},
  [2811] = {.lex_state = 0},
  [2812] = {.lex_state = 0},
  [2813] = {.lex_state = 1001},
  [2814] = {.lex_state = 0},
  [2815] = {.lex_state = 0},
  [2816] = {.lex_state = 0},
  [2817] = {.lex_state = 0},
  [2818] = {.lex_state = 0},
  [2819] = {.lex_state = 0},
  [2820] = {.lex_state = 37},
  [2821] = {.lex_state = 0},
  [2822] = {.lex_state = 1000},
  [2823] = {.lex_state = 0},
  [2824] = {.lex_state = 0},
  [2825] = {.lex_state = 0},
  [2826] = {.lex_state = 11},
  [2827] = {.lex_state = 0},
  [2828] = {.lex_state = 37},
  [2829] = {.lex_state = 0},
  [2830] = {.lex_state = 37},
  [2831] = {.lex_state = 0},
  [2832] = {.lex_state = 0},
  [2833] = {.lex_state = 0},
  [2834] = {.lex_state = 0},
  [2835] = {.lex_state = 0},
  [2836] = {.lex_state = 37},
  [2837] = {.lex_state = 0},
  [2838] = {.lex_state = 0},
  [2839] = {.lex_state = 0},
  [2840] = {.lex_state = 0},
  [2841] = {.lex_state = 0},
  [2842] = {.lex_state = 0},
  [2843] = {.lex_state = 0},
  [2844] = {.lex_state = 0},
  [2845] = {.lex_state = 0},
  [2846] = {.lex_state = 0},
  [2847] = {.lex_state = 37},
  [2848] = {.lex_state = 0},
  [2849] = {.lex_state = 0},
  [2850] = {.lex_state = 0},
  [2851] = {.lex_state = 37},
  [2852] = {.lex_state = 0},
  [2853] = {.lex_state = 0},
  [2854] = {.lex_state = 0},
  [2855] = {.lex_state = 0},
  [2856] = {.lex_state = 37},
  [2857] = {.lex_state = 37},
  [2858] = {.lex_state = 0},
  [2859] = {.lex_state = 0},
  [2860] = {.lex_state = 0},
  [2861] = {.lex_state = 0},
  [2862] = {.lex_state = 0},
  [2863] = {.lex_state = 11},
  [2864] = {.lex_state = 0},
  [2865] = {.lex_state = 0},
  [2866] = {.lex_state = 0},
  [2867] = {.lex_state = 0},
  [2868] = {.lex_state = 0},
  [2869] = {.lex_state = 0},
  [2870] = {.lex_state = 0},
  [2871] = {.lex_state = 37},
  [2872] = {.lex_state = 38},
  [2873] = {.lex_state = 0},
  [2874] = {.lex_state = 37},
  [2875] = {.lex_state = 37},
  [2876] = {.lex_state = 0},
  [2877] = {.lex_state = 0},
  [2878] = {.lex_state = 0},
  [2879] = {.lex_state = 0},
  [2880] = {.lex_state = 0},
  [2881] = {.lex_state = 970},
  [2882] = {.lex_state = 0},
  [2883] = {.lex_state = 37},
  [2884] = {.lex_state = 0},
  [2885] = {.lex_state = 0},
  [2886] = {.lex_state = 0},
  [2887] = {.lex_state = 0},
  [2888] = {.lex_state = 0},
  [2889] = {.lex_state = 0},
  [2890] = {.lex_state = 0},
  [2891] = {.lex_state = 0},
  [2892] = {.lex_state = 1000},
  [2893] = {.lex_state = 0},
  [2894] = {.lex_state = 0},
  [2895] = {.lex_state = 0},
  [2896] = {.lex_state = 0},
  [2897] = {.lex_state = 0},
  [2898] = {.lex_state = 0},
  [2899] = {.lex_state = 0},
  [2900] = {.lex_state = 0},
  [2901] = {.lex_state = 0},
  [2902] = {.lex_state = 0},
  [2903] = {.lex_state = 37},
  [2904] = {.lex_state = 970},
  [2905] = {.lex_state = 970},
  [2906] = {.lex_state = 970},
  [2907] = {.lex_state = 11},
  [2908] = {.lex_state = 0},
  [2909] = {.lex_state = 37},
  [2910] = {.lex_state = 0},
  [2911] = {.lex_state = 37},
  [2912] = {.lex_state = 0},
  [2913] = {.lex_state = 0},
  [2914] = {.lex_state = 0},
  [2915] = {.lex_state = 0},
  [2916] = {.lex_state = 0},
  [2917] = {.lex_state = 0},
  [2918] = {.lex_state = 1000},
  [2919] = {.lex_state = 1001},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(1),
    [sym_keyword_show] = ACTIONS(1),
    [sym_keyword_changes] = ACTIONS(1),
    [sym_keyword_since] = ACTIONS(1),
    [sym_keyword_if] = ACTIONS(1),
    [sym_keyword_throw] = ACTIONS(1),
    [sym_keyword_exists] = ACTIONS(1),
    [sym_keyword_overwrite] = ACTIONS(1),
    [sym_keyword_on] = ACTIONS(1),
    [sym_keyword_let] = ACTIONS(1),
    [sym_keyword_return] = ACTIONS(1),
    [sym_keyword_else] = ACTIONS(1),
    [sym_keyword_select] = ACTIONS(1),
    [sym_keyword_from] = ACTIONS(1),
    [sym_keyword_value] = ACTIONS(1),
    [sym_keyword_as] = ACTIONS(1),
    [sym_keyword_omit] = ACTIONS(1),
    [sym_keyword_explain] = ACTIONS(1),
    [sym_keyword_full] = ACTIONS(1),
    [sym_keyword_parallel] = ACTIONS(1),
    [sym_keyword_timeout] = ACTIONS(1),
    [sym_keyword_fetch] = ACTIONS(1),
    [sym_keyword_limit] = ACTIONS(1),
    [sym_keyword_by] = ACTIONS(1),
    [sym_keyword_rand] = ACTIONS(1),
    [sym_keyword_collate] = ACTIONS(1),
    [sym_keyword_numeric] = ACTIONS(1),
    [sym_keyword_desc] = ACTIONS(1),
    [sym_keyword_order] = ACTIONS(1),
    [sym_keyword_with] = ACTIONS(1),
    [sym_keyword_no_index] = ACTIONS(1),
    [sym_keyword_where] = ACTIONS(1),
    [sym_keyword_split] = ACTIONS(1),
    [sym_keyword_at] = ACTIONS(1),
    [sym_keyword_group] = ACTIONS(1),
    [sym_keyword_true] = ACTIONS(1),
    [sym_keyword_false] = ACTIONS(1),
    [sym_keyword_begin] = ACTIONS(1),
    [sym_keyword_cancel] = ACTIONS(1),
    [sym_keyword_commit] = ACTIONS(1),
    [sym_keyword_transaction] = ACTIONS(1),
    [sym_keyword_none] = ACTIONS(1),
    [sym_keyword_null] = ACTIONS(1),
    [sym_keyword_and] = ACTIONS(1),
    [sym_keyword_or] = ACTIONS(1),
    [sym_keyword_is] = ACTIONS(1),
    [sym_keyword_not] = ACTIONS(1),
    [sym_keyword_contains] = ACTIONS(1),
    [sym_keyword_contains_not] = ACTIONS(1),
    [sym_keyword_contains_all] = ACTIONS(1),
    [sym_keyword_contains_any] = ACTIONS(1),
    [sym_keyword_contains_none] = ACTIONS(1),
    [sym_keyword_inside] = ACTIONS(1),
    [sym_keyword_in] = ACTIONS(1),
    [sym_keyword_not_inside] = ACTIONS(1),
    [sym_keyword_all_inside] = ACTIONS(1),
    [sym_keyword_any_inside] = ACTIONS(1),
    [sym_keyword_intersects] = ACTIONS(1),
    [sym_keyword_chebyshev] = ACTIONS(1),
    [sym_keyword_cosine] = ACTIONS(1),
    [sym_keyword_euclidean] = ACTIONS(1),
    [sym_keyword_hamming] = ACTIONS(1),
    [sym_keyword_jaccard] = ACTIONS(1),
    [sym_keyword_manhattan] = ACTIONS(1),
    [sym_keyword_minkowski] = ACTIONS(1),
    [sym_keyword_pearson] = ACTIONS(1),
    [sym_keyword_define] = ACTIONS(1),
    [sym_keyword_analyzer] = ACTIONS(1),
    [sym_keyword_event] = ACTIONS(1),
    [sym_keyword_field] = ACTIONS(1),
    [sym_keyword_function] = ACTIONS(1),
    [sym_keyword_namespace] = ACTIONS(1),
    [sym_keyword_param] = ACTIONS(1),
    [sym_keyword_scope] = ACTIONS(1),
    [sym_keyword_drop] = ACTIONS(1),
    [sym_keyword_schemafull] = ACTIONS(1),
    [sym_keyword_schemaless] = ACTIONS(1),
    [sym_keyword_live] = ACTIONS(1),
    [sym_keyword_diff] = ACTIONS(1),
    [sym_keyword_flexible] = ACTIONS(1),
    [sym_keyword_readonly] = ACTIONS(1),
    [sym_keyword_jwks] = ACTIONS(1),
    [sym_keyword_eddsa] = ACTIONS(1),
    [sym_keyword_es256] = ACTIONS(1),
    [sym_keyword_es384] = ACTIONS(1),
    [sym_keyword_es512] = ACTIONS(1),
    [sym_keyword_ps256] = ACTIONS(1),
    [sym_keyword_ps384] = ACTIONS(1),
    [sym_keyword_ps512] = ACTIONS(1),
    [sym_keyword_rs256] = ACTIONS(1),
    [sym_keyword_rs384] = ACTIONS(1),
    [sym_keyword_rs512] = ACTIONS(1),
    [sym_keyword_hs256] = ACTIONS(1),
    [sym_keyword_hs384] = ACTIONS(1),
    [sym_keyword_hs512] = ACTIONS(1),
    [sym_keyword_bm25] = ACTIONS(1),
    [sym_keyword_doc_ids_cache] = ACTIONS(1),
    [sym_keyword_doc_ids_order] = ACTIONS(1),
    [sym_keyword_doc_lengths_cache] = ACTIONS(1),
    [sym_keyword_doc_lengths_order] = ACTIONS(1),
    [sym_keyword_postings_cache] = ACTIONS(1),
    [sym_keyword_postings_order] = ACTIONS(1),
    [sym_keyword_terms_cache] = ACTIONS(1),
    [sym_keyword_terms_order] = ACTIONS(1),
    [sym_keyword_highlights] = ACTIONS(1),
    [sym_keyword_any] = ACTIONS(1),
    [sym_keyword_normal] = ACTIONS(1),
    [sym_keyword_relation] = ACTIONS(1),
    [sym_keyword_out] = ACTIONS(1),
    [sym_keyword_to] = ACTIONS(1),
    [sym_keyword_changefeed] = ACTIONS(1),
    [sym_keyword_content] = ACTIONS(1),
    [sym_keyword_merge] = ACTIONS(1),
    [sym_keyword_patch] = ACTIONS(1),
    [sym_keyword_replace] = ACTIONS(1),
    [sym_keyword_before] = ACTIONS(1),
    [sym_keyword_after] = ACTIONS(1),
    [sym_keyword_table] = ACTIONS(1),
    [sym_keyword_root] = ACTIONS(1),
    [sym_keyword_use] = ACTIONS(1),
    [sym_keyword_ns] = ACTIONS(1),
    [sym_keyword_db] = ACTIONS(1),
    [sym_keyword_user] = ACTIONS(1),
    [sym_keyword_roles] = ACTIONS(1),
    [sym_keyword_remove] = ACTIONS(1),
    [sym_keyword_create] = ACTIONS(1),
    [sym_keyword_delete] = ACTIONS(1),
    [sym_keyword_update] = ACTIONS(1),
    [sym_keyword_upsert] = ACTIONS(1),
    [sym_keyword_filters] = ACTIONS(1),
    [sym_keyword_when] = ACTIONS(1),
    [sym_keyword_then] = ACTIONS(1),
    [sym_keyword_type] = ACTIONS(1),
    [sym_keyword_default] = ACTIONS(1),
    [sym_keyword_permissions] = ACTIONS(1),
    [sym_keyword_relate] = ACTIONS(1),
    [sym_keyword_ignore] = ACTIONS(1),
    [sym_keyword_for] = ACTIONS(1),
    [sym_keyword_comment] = ACTIONS(1),
    [sym_keyword_columns] = ACTIONS(1),
    [sym_keyword_unique] = ACTIONS(1),
    [sym_keyword_search] = ACTIONS(1),
    [sym_keyword_session] = ACTIONS(1),
    [sym_keyword_signin] = ACTIONS(1),
    [sym_keyword_signup] = ACTIONS(1),
    [sym_keyword_database] = ACTIONS(1),
    [sym_keyword_password] = ACTIONS(1),
    [sym_keyword_password_hash] = ACTIONS(1),
    [sym_keyword_count] = ACTIONS(1),
    [sym_keyword_unset] = ACTIONS(1),
    [sym_keyword_set] = ACTIONS(1),
    [sym_keyword_always] = ACTIONS(1),
    [sym_keyword_alter] = ACTIONS(1),
    [sym_keyword_break] = ACTIONS(1),
    [sym_keyword_continue] = ACTIONS(1),
    [sym_keyword_sleep] = ACTIONS(1),
    [sym_keyword_kill] = ACTIONS(1),
    [sym_keyword_rebuild] = ACTIONS(1),
    [sym_keyword_mtree] = ACTIONS(1),
    [sym_keyword_dimension] = ACTIONS(1),
    [sym_keyword_dist] = ACTIONS(1),
    [sym_keyword_efc] = ACTIONS(1),
    [sym_keyword_m] = ACTIONS(1),
    [sym_keyword_capacity] = ACTIONS(1),
    [sym_keyword_hnsw] = ACTIONS(1),
    [sym_keyword_owner] = ACTIONS(1),
    [sym_keyword_editor] = ACTIONS(1),
    [sym_keyword_viewer] = ACTIONS(1),
    [sym_keyword_duration] = ACTIONS(1),
    [sym_keyword_enforced] = ACTIONS(1),
    [sym_keyword_algorithm] = ACTIONS(1),
    [sym_keyword_key] = ACTIONS(1),
    [sym_keyword_url] = ACTIONS(1),
    [sym_keyword_jwt] = ACTIONS(1),
    [sym_keyword_refresh] = ACTIONS(1),
    [sym_keyword_record] = ACTIONS(1),
    [sym_keyword_bearer] = ACTIONS(1),
    [sym_keyword_authenticate] = ACTIONS(1),
    [sym_keyword_grant] = ACTIONS(1),
    [sym_keyword_access] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_DASH_GT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_COLON_COLON] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_LT_DASH] = ACTIONS(1),
    [anon_sym_LT_DASH_GT] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_blank] = ACTIONS(1),
    [anon_sym_camel] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_punct] = ACTIONS(1),
    [anon_sym_lowercase] = ACTIONS(1),
    [anon_sym_uppercase] = ACTIONS(1),
    [anon_sym_edgengram] = ACTIONS(1),
    [anon_sym_ngram] = ACTIONS(1),
    [anon_sym_snowball] = ACTIONS(1),
    [sym_string] = ACTIONS(1),
    [sym_prefixed_string] = ACTIONS(1),
    [sym_int] = ACTIONS(1),
    [sym_variable_name] = ACTIONS(1),
    [sym_custom_function_name] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [sym_duration_part] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT_PIPE] = ACTIONS(1),
    [anon_sym_PIPE_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_QMARK_QMARK] = ACTIONS(1),
    [anon_sym_QMARK_COLON] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_QMARK_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_BANG_TILDE] = ACTIONS(1),
    [anon_sym_STAR_TILDE] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_u00d7] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_u00f7] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_u220b] = ACTIONS(1),
    [anon_sym_u220c] = ACTIONS(1),
    [anon_sym_u2287] = ACTIONS(1),
    [anon_sym_u2283] = ACTIONS(1),
    [anon_sym_u2285] = ACTIONS(1),
    [anon_sym_u2208] = ACTIONS(1),
    [anon_sym_u2209] = ACTIONS(1),
    [anon_sym_u2286] = ACTIONS(1),
    [anon_sym_u2282] = ACTIONS(1),
    [anon_sym_u2284] = ACTIONS(1),
    [anon_sym_AT_AT] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(2735),
    [sym_expressions] = STATE(2742),
    [sym_expression] = STATE(2289),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2018),
    [sym_where_clause] = STATE(2742),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(741),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2809),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(7),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_let] = ACTIONS(13),
    [sym_keyword_return] = ACTIONS(15),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_where] = ACTIONS(21),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_define] = ACTIONS(31),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(39),
    [sym_keyword_delete] = ACTIONS(41),
    [sym_keyword_update] = ACTIONS(43),
    [sym_keyword_upsert] = ACTIONS(45),
    [sym_keyword_insert] = ACTIONS(47),
    [sym_keyword_relate] = ACTIONS(49),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_alter] = ACTIONS(55),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(75),
    [anon_sym_BANG] = ACTIONS(77),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(2)] = {
    [ts_builtin_sym_end] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_since] = ACTIONS(93),
    [sym_keyword_tokenizers] = ACTIONS(93),
    [sym_keyword_on] = ACTIONS(93),
    [sym_keyword_return] = ACTIONS(93),
    [sym_keyword_from] = ACTIONS(93),
    [sym_keyword_as] = ACTIONS(93),
    [sym_keyword_omit] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_function] = ACTIONS(93),
    [sym_keyword_drop] = ACTIONS(93),
    [sym_keyword_schemafull] = ACTIONS(93),
    [sym_keyword_schemaless] = ACTIONS(93),
    [sym_keyword_bm25] = ACTIONS(93),
    [sym_keyword_doc_ids_cache] = ACTIONS(93),
    [sym_keyword_doc_ids_order] = ACTIONS(93),
    [sym_keyword_doc_lengths_cache] = ACTIONS(93),
    [sym_keyword_doc_lengths_order] = ACTIONS(93),
    [sym_keyword_postings_cache] = ACTIONS(93),
    [sym_keyword_postings_order] = ACTIONS(93),
    [sym_keyword_terms_cache] = ACTIONS(93),
    [sym_keyword_terms_order] = ACTIONS(93),
    [sym_keyword_highlights] = ACTIONS(93),
    [sym_keyword_changefeed] = ACTIONS(93),
    [sym_keyword_content] = ACTIONS(93),
    [sym_keyword_merge] = ACTIONS(93),
    [sym_keyword_patch] = ACTIONS(93),
    [sym_keyword_replace] = ACTIONS(93),
    [sym_keyword_db] = ACTIONS(93),
    [sym_keyword_filters] = ACTIONS(93),
    [sym_keyword_when] = ACTIONS(93),
    [sym_keyword_then] = ACTIONS(93),
    [sym_keyword_type] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [sym_keyword_fields] = ACTIONS(93),
    [sym_keyword_columns] = ACTIONS(93),
    [sym_keyword_unique] = ACTIONS(93),
    [sym_keyword_search] = ACTIONS(93),
    [sym_keyword_session] = ACTIONS(93),
    [sym_keyword_signin] = ACTIONS(93),
    [sym_keyword_signup] = ACTIONS(93),
    [sym_keyword_unset] = ACTIONS(93),
    [sym_keyword_set] = ACTIONS(93),
    [sym_keyword_mtree] = ACTIONS(93),
    [sym_keyword_hnsw] = ACTIONS(93),
    [sym_keyword_enforced] = ACTIONS(93),
    [sym_keyword_key] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(93),
    [anon_sym_LBRACE] = ACTIONS(93),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_PIPE] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(3)] = {
    [sym_expressions] = STATE(2720),
    [sym_expression] = STATE(2273),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(4)] = {
    [sym_expression] = STATE(2250),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2018),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(741),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2809),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [ts_builtin_sym_end] = ACTIONS(159),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(7),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_let] = ACTIONS(13),
    [sym_keyword_return] = ACTIONS(15),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_define] = ACTIONS(31),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(39),
    [sym_keyword_delete] = ACTIONS(41),
    [sym_keyword_update] = ACTIONS(43),
    [sym_keyword_upsert] = ACTIONS(45),
    [sym_keyword_insert] = ACTIONS(47),
    [sym_keyword_relate] = ACTIONS(49),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_alter] = ACTIONS(55),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(75),
    [anon_sym_BANG] = ACTIONS(77),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(5)] = {
    [sym_expression] = STATE(2250),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2018),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(741),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2809),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(7),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_let] = ACTIONS(13),
    [sym_keyword_return] = ACTIONS(15),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_define] = ACTIONS(31),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(39),
    [sym_keyword_delete] = ACTIONS(41),
    [sym_keyword_update] = ACTIONS(43),
    [sym_keyword_upsert] = ACTIONS(45),
    [sym_keyword_insert] = ACTIONS(47),
    [sym_keyword_relate] = ACTIONS(49),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_alter] = ACTIONS(55),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(75),
    [anon_sym_BANG] = ACTIONS(77),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(6)] = {
    [sym_expression] = STATE(2250),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(161),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(7)] = {
    [sym_expression] = STATE(2250),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(159),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(8)] = {
    [sym_expression] = STATE(2639),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(163),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(9)] = {
    [sym_expression] = STATE(2639),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(10)] = {
    [sym_expression] = STATE(2250),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2018),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(741),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2809),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(7),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_let] = ACTIONS(13),
    [sym_keyword_return] = ACTIONS(15),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_define] = ACTIONS(31),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(39),
    [sym_keyword_delete] = ACTIONS(41),
    [sym_keyword_update] = ACTIONS(43),
    [sym_keyword_upsert] = ACTIONS(45),
    [sym_keyword_insert] = ACTIONS(47),
    [sym_keyword_relate] = ACTIONS(49),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_alter] = ACTIONS(55),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(75),
    [anon_sym_BANG] = ACTIONS(77),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(11)] = {
    [sym_expression] = STATE(2250),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(12)] = {
    [sym_expression] = STATE(2789),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(165),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(13)] = {
    [sym_expression] = STATE(2808),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(167),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(14)] = {
    [sym_expression] = STATE(2715),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(169),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(15)] = {
    [sym_expression] = STATE(2908),
    [sym_primary_statement] = STATE(2096),
    [sym_subquery_statement] = STATE(2096),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_throw_statement] = STATE(1973),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_live_select_statement] = STATE(1973),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(723),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(171),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(16)] = {
    [aux_sym_duration_repeat1] = STATE(17),
    [ts_builtin_sym_end] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(173),
    [sym_keyword_return] = ACTIONS(173),
    [sym_keyword_value] = ACTIONS(173),
    [sym_keyword_explain] = ACTIONS(173),
    [sym_keyword_parallel] = ACTIONS(173),
    [sym_keyword_timeout] = ACTIONS(173),
    [sym_keyword_fetch] = ACTIONS(173),
    [sym_keyword_limit] = ACTIONS(173),
    [sym_keyword_rand] = ACTIONS(173),
    [sym_keyword_collate] = ACTIONS(173),
    [sym_keyword_numeric] = ACTIONS(173),
    [sym_keyword_asc] = ACTIONS(173),
    [sym_keyword_desc] = ACTIONS(173),
    [sym_keyword_where] = ACTIONS(173),
    [sym_keyword_group] = ACTIONS(173),
    [sym_keyword_and] = ACTIONS(173),
    [sym_keyword_or] = ACTIONS(173),
    [sym_keyword_is] = ACTIONS(173),
    [sym_keyword_not] = ACTIONS(175),
    [sym_keyword_contains] = ACTIONS(175),
    [sym_keyword_contains_not] = ACTIONS(173),
    [sym_keyword_contains_all] = ACTIONS(173),
    [sym_keyword_contains_any] = ACTIONS(173),
    [sym_keyword_contains_none] = ACTIONS(173),
    [sym_keyword_inside] = ACTIONS(173),
    [sym_keyword_in] = ACTIONS(175),
    [sym_keyword_not_inside] = ACTIONS(173),
    [sym_keyword_all_inside] = ACTIONS(173),
    [sym_keyword_any_inside] = ACTIONS(173),
    [sym_keyword_none_inside] = ACTIONS(173),
    [sym_keyword_outside] = ACTIONS(173),
    [sym_keyword_intersects] = ACTIONS(173),
    [sym_keyword_drop] = ACTIONS(173),
    [sym_keyword_schemafull] = ACTIONS(173),
    [sym_keyword_schemaless] = ACTIONS(173),
    [sym_keyword_flexible] = ACTIONS(173),
    [sym_keyword_readonly] = ACTIONS(173),
    [sym_keyword_changefeed] = ACTIONS(173),
    [sym_keyword_content] = ACTIONS(173),
    [sym_keyword_merge] = ACTIONS(173),
    [sym_keyword_patch] = ACTIONS(173),
    [sym_keyword_replace] = ACTIONS(173),
    [sym_keyword_type] = ACTIONS(173),
    [sym_keyword_default] = ACTIONS(173),
    [sym_keyword_assert] = ACTIONS(173),
    [sym_keyword_permissions] = ACTIONS(173),
    [sym_keyword_for] = ACTIONS(173),
    [sym_keyword_comment] = ACTIONS(173),
    [sym_keyword_unique] = ACTIONS(173),
    [sym_keyword_search] = ACTIONS(173),
    [sym_keyword_session] = ACTIONS(173),
    [sym_keyword_signin] = ACTIONS(173),
    [sym_keyword_signup] = ACTIONS(173),
    [sym_keyword_unset] = ACTIONS(173),
    [sym_keyword_set] = ACTIONS(173),
    [sym_keyword_mtree] = ACTIONS(173),
    [sym_keyword_dist] = ACTIONS(173),
    [sym_keyword_efc] = ACTIONS(173),
    [sym_keyword_m] = ACTIONS(175),
    [sym_keyword_capacity] = ACTIONS(173),
    [sym_keyword_hnsw] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(175),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_RPAREN] = ACTIONS(173),
    [anon_sym_DASH_GT] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(173),
    [anon_sym_RBRACK] = ACTIONS(173),
    [anon_sym_RBRACE] = ACTIONS(173),
    [anon_sym_PIPE] = ACTIONS(175),
    [anon_sym_LT] = ACTIONS(175),
    [anon_sym_GT] = ACTIONS(175),
    [anon_sym_LT_DASH] = ACTIONS(175),
    [anon_sym_LT_DASH_GT] = ACTIONS(173),
    [anon_sym_STAR] = ACTIONS(175),
    [anon_sym_DOT] = ACTIONS(173),
    [sym_duration_part] = ACTIONS(177),
    [anon_sym_DASH] = ACTIONS(175),
    [anon_sym_PERCENT] = ACTIONS(173),
    [anon_sym_AT] = ACTIONS(175),
    [anon_sym_LT_PIPE] = ACTIONS(173),
    [anon_sym_AMP_AMP] = ACTIONS(173),
    [anon_sym_PIPE_PIPE] = ACTIONS(173),
    [anon_sym_QMARK_QMARK] = ACTIONS(173),
    [anon_sym_QMARK_COLON] = ACTIONS(173),
    [anon_sym_BANG_EQ] = ACTIONS(173),
    [anon_sym_EQ_EQ] = ACTIONS(173),
    [anon_sym_QMARK_EQ] = ACTIONS(173),
    [anon_sym_STAR_EQ] = ACTIONS(173),
    [anon_sym_TILDE] = ACTIONS(173),
    [anon_sym_BANG_TILDE] = ACTIONS(173),
    [anon_sym_STAR_TILDE] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(173),
    [anon_sym_GT_EQ] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(175),
    [anon_sym_PLUS_EQ] = ACTIONS(173),
    [anon_sym_DASH_EQ] = ACTIONS(173),
    [anon_sym_u00d7] = ACTIONS(173),
    [anon_sym_SLASH] = ACTIONS(175),
    [anon_sym_u00f7] = ACTIONS(173),
    [anon_sym_STAR_STAR] = ACTIONS(173),
    [anon_sym_u220b] = ACTIONS(173),
    [anon_sym_u220c] = ACTIONS(173),
    [anon_sym_u2287] = ACTIONS(173),
    [anon_sym_u2283] = ACTIONS(173),
    [anon_sym_u2285] = ACTIONS(173),
    [anon_sym_u2208] = ACTIONS(173),
    [anon_sym_u2209] = ACTIONS(173),
    [anon_sym_u2286] = ACTIONS(173),
    [anon_sym_u2282] = ACTIONS(173),
    [anon_sym_u2284] = ACTIONS(173),
    [anon_sym_AT_AT] = ACTIONS(173),
  },
  [STATE(17)] = {
    [aux_sym_duration_repeat1] = STATE(17),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(179),
    [sym_keyword_return] = ACTIONS(179),
    [sym_keyword_value] = ACTIONS(179),
    [sym_keyword_explain] = ACTIONS(179),
    [sym_keyword_parallel] = ACTIONS(179),
    [sym_keyword_timeout] = ACTIONS(179),
    [sym_keyword_fetch] = ACTIONS(179),
    [sym_keyword_limit] = ACTIONS(179),
    [sym_keyword_rand] = ACTIONS(179),
    [sym_keyword_collate] = ACTIONS(179),
    [sym_keyword_numeric] = ACTIONS(179),
    [sym_keyword_asc] = ACTIONS(179),
    [sym_keyword_desc] = ACTIONS(179),
    [sym_keyword_where] = ACTIONS(179),
    [sym_keyword_group] = ACTIONS(179),
    [sym_keyword_and] = ACTIONS(179),
    [sym_keyword_or] = ACTIONS(179),
    [sym_keyword_is] = ACTIONS(179),
    [sym_keyword_not] = ACTIONS(181),
    [sym_keyword_contains] = ACTIONS(181),
    [sym_keyword_contains_not] = ACTIONS(179),
    [sym_keyword_contains_all] = ACTIONS(179),
    [sym_keyword_contains_any] = ACTIONS(179),
    [sym_keyword_contains_none] = ACTIONS(179),
    [sym_keyword_inside] = ACTIONS(179),
    [sym_keyword_in] = ACTIONS(181),
    [sym_keyword_not_inside] = ACTIONS(179),
    [sym_keyword_all_inside] = ACTIONS(179),
    [sym_keyword_any_inside] = ACTIONS(179),
    [sym_keyword_none_inside] = ACTIONS(179),
    [sym_keyword_outside] = ACTIONS(179),
    [sym_keyword_intersects] = ACTIONS(179),
    [sym_keyword_drop] = ACTIONS(179),
    [sym_keyword_schemafull] = ACTIONS(179),
    [sym_keyword_schemaless] = ACTIONS(179),
    [sym_keyword_flexible] = ACTIONS(179),
    [sym_keyword_readonly] = ACTIONS(179),
    [sym_keyword_changefeed] = ACTIONS(179),
    [sym_keyword_content] = ACTIONS(179),
    [sym_keyword_merge] = ACTIONS(179),
    [sym_keyword_patch] = ACTIONS(179),
    [sym_keyword_replace] = ACTIONS(179),
    [sym_keyword_type] = ACTIONS(179),
    [sym_keyword_default] = ACTIONS(179),
    [sym_keyword_assert] = ACTIONS(179),
    [sym_keyword_permissions] = ACTIONS(179),
    [sym_keyword_for] = ACTIONS(179),
    [sym_keyword_comment] = ACTIONS(179),
    [sym_keyword_unique] = ACTIONS(179),
    [sym_keyword_search] = ACTIONS(179),
    [sym_keyword_session] = ACTIONS(179),
    [sym_keyword_signin] = ACTIONS(179),
    [sym_keyword_signup] = ACTIONS(179),
    [sym_keyword_unset] = ACTIONS(179),
    [sym_keyword_set] = ACTIONS(179),
    [sym_keyword_mtree] = ACTIONS(179),
    [sym_keyword_dist] = ACTIONS(179),
    [sym_keyword_efc] = ACTIONS(179),
    [sym_keyword_m] = ACTIONS(181),
    [sym_keyword_capacity] = ACTIONS(179),
    [sym_keyword_hnsw] = ACTIONS(179),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_COMMA] = ACTIONS(179),
    [anon_sym_RPAREN] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(179),
    [anon_sym_LBRACK] = ACTIONS(179),
    [anon_sym_RBRACK] = ACTIONS(179),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_PIPE] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH_GT] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_DOT] = ACTIONS(179),
    [sym_duration_part] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_PERCENT] = ACTIONS(179),
    [anon_sym_AT] = ACTIONS(181),
    [anon_sym_LT_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_QMARK_QMARK] = ACTIONS(179),
    [anon_sym_QMARK_COLON] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_QMARK_EQ] = ACTIONS(179),
    [anon_sym_STAR_EQ] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG_TILDE] = ACTIONS(179),
    [anon_sym_STAR_TILDE] = ACTIONS(179),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_PLUS] = ACTIONS(181),
    [anon_sym_PLUS_EQ] = ACTIONS(179),
    [anon_sym_DASH_EQ] = ACTIONS(179),
    [anon_sym_u00d7] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(181),
    [anon_sym_u00f7] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(179),
    [anon_sym_u220b] = ACTIONS(179),
    [anon_sym_u220c] = ACTIONS(179),
    [anon_sym_u2287] = ACTIONS(179),
    [anon_sym_u2283] = ACTIONS(179),
    [anon_sym_u2285] = ACTIONS(179),
    [anon_sym_u2208] = ACTIONS(179),
    [anon_sym_u2209] = ACTIONS(179),
    [anon_sym_u2286] = ACTIONS(179),
    [anon_sym_u2282] = ACTIONS(179),
    [anon_sym_u2284] = ACTIONS(179),
    [anon_sym_AT_AT] = ACTIONS(179),
  },
  [STATE(18)] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_return] = ACTIONS(186),
    [sym_keyword_value] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_rand] = ACTIONS(186),
    [sym_keyword_collate] = ACTIONS(186),
    [sym_keyword_numeric] = ACTIONS(186),
    [sym_keyword_asc] = ACTIONS(186),
    [sym_keyword_desc] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_drop] = ACTIONS(186),
    [sym_keyword_schemafull] = ACTIONS(186),
    [sym_keyword_schemaless] = ACTIONS(186),
    [sym_keyword_flexible] = ACTIONS(186),
    [sym_keyword_readonly] = ACTIONS(186),
    [sym_keyword_changefeed] = ACTIONS(186),
    [sym_keyword_content] = ACTIONS(186),
    [sym_keyword_merge] = ACTIONS(186),
    [sym_keyword_patch] = ACTIONS(186),
    [sym_keyword_replace] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_default] = ACTIONS(186),
    [sym_keyword_assert] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [sym_keyword_unique] = ACTIONS(186),
    [sym_keyword_search] = ACTIONS(186),
    [sym_keyword_unset] = ACTIONS(186),
    [sym_keyword_set] = ACTIONS(186),
    [sym_keyword_mtree] = ACTIONS(186),
    [sym_keyword_dist] = ACTIONS(186),
    [sym_keyword_efc] = ACTIONS(186),
    [sym_keyword_m] = ACTIONS(188),
    [sym_keyword_capacity] = ACTIONS(186),
    [sym_keyword_hnsw] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_PIPE_GT] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(19)] = {
    [ts_builtin_sym_end] = ACTIONS(190),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_return] = ACTIONS(190),
    [sym_keyword_value] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_rand] = ACTIONS(190),
    [sym_keyword_collate] = ACTIONS(190),
    [sym_keyword_numeric] = ACTIONS(190),
    [sym_keyword_asc] = ACTIONS(190),
    [sym_keyword_desc] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(192),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_drop] = ACTIONS(190),
    [sym_keyword_schemafull] = ACTIONS(190),
    [sym_keyword_schemaless] = ACTIONS(190),
    [sym_keyword_flexible] = ACTIONS(190),
    [sym_keyword_readonly] = ACTIONS(190),
    [sym_keyword_changefeed] = ACTIONS(190),
    [sym_keyword_content] = ACTIONS(190),
    [sym_keyword_merge] = ACTIONS(190),
    [sym_keyword_patch] = ACTIONS(190),
    [sym_keyword_replace] = ACTIONS(190),
    [sym_keyword_type] = ACTIONS(190),
    [sym_keyword_default] = ACTIONS(190),
    [sym_keyword_assert] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [sym_keyword_session] = ACTIONS(190),
    [sym_keyword_signin] = ACTIONS(190),
    [sym_keyword_signup] = ACTIONS(190),
    [sym_keyword_unset] = ACTIONS(190),
    [sym_keyword_set] = ACTIONS(190),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_PERCENT] = ACTIONS(190),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [STATE(20)] = {
    [ts_builtin_sym_end] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_return] = ACTIONS(93),
    [sym_keyword_value] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_rand] = ACTIONS(93),
    [sym_keyword_collate] = ACTIONS(93),
    [sym_keyword_numeric] = ACTIONS(93),
    [sym_keyword_asc] = ACTIONS(93),
    [sym_keyword_desc] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_drop] = ACTIONS(93),
    [sym_keyword_schemafull] = ACTIONS(93),
    [sym_keyword_schemaless] = ACTIONS(93),
    [sym_keyword_flexible] = ACTIONS(93),
    [sym_keyword_readonly] = ACTIONS(93),
    [sym_keyword_changefeed] = ACTIONS(93),
    [sym_keyword_content] = ACTIONS(93),
    [sym_keyword_merge] = ACTIONS(93),
    [sym_keyword_patch] = ACTIONS(93),
    [sym_keyword_replace] = ACTIONS(93),
    [sym_keyword_type] = ACTIONS(93),
    [sym_keyword_default] = ACTIONS(93),
    [sym_keyword_assert] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [sym_keyword_unset] = ACTIONS(93),
    [sym_keyword_set] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(194),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_COLON_COLON] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(21)] = {
    [sym_filter] = STATE(90),
    [sym_path_element] = STATE(24),
    [sym_graph_path] = STATE(90),
    [sym_subscript] = STATE(90),
    [aux_sym_path_repeat1] = STATE(24),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(196),
    [sym_keyword_on] = ACTIONS(196),
    [sym_keyword_return] = ACTIONS(196),
    [sym_keyword_from] = ACTIONS(196),
    [sym_keyword_as] = ACTIONS(196),
    [sym_keyword_omit] = ACTIONS(196),
    [sym_keyword_explain] = ACTIONS(196),
    [sym_keyword_parallel] = ACTIONS(196),
    [sym_keyword_timeout] = ACTIONS(196),
    [sym_keyword_fetch] = ACTIONS(196),
    [sym_keyword_limit] = ACTIONS(196),
    [sym_keyword_where] = ACTIONS(196),
    [sym_keyword_group] = ACTIONS(196),
    [sym_keyword_and] = ACTIONS(196),
    [sym_keyword_or] = ACTIONS(196),
    [sym_keyword_is] = ACTIONS(196),
    [sym_keyword_not] = ACTIONS(198),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(196),
    [sym_keyword_contains_all] = ACTIONS(196),
    [sym_keyword_contains_any] = ACTIONS(196),
    [sym_keyword_contains_none] = ACTIONS(196),
    [sym_keyword_inside] = ACTIONS(196),
    [sym_keyword_in] = ACTIONS(198),
    [sym_keyword_not_inside] = ACTIONS(196),
    [sym_keyword_all_inside] = ACTIONS(196),
    [sym_keyword_any_inside] = ACTIONS(196),
    [sym_keyword_none_inside] = ACTIONS(196),
    [sym_keyword_outside] = ACTIONS(196),
    [sym_keyword_intersects] = ACTIONS(196),
    [sym_keyword_drop] = ACTIONS(196),
    [sym_keyword_schemafull] = ACTIONS(196),
    [sym_keyword_schemaless] = ACTIONS(196),
    [sym_keyword_changefeed] = ACTIONS(196),
    [sym_keyword_content] = ACTIONS(196),
    [sym_keyword_merge] = ACTIONS(196),
    [sym_keyword_patch] = ACTIONS(196),
    [sym_keyword_replace] = ACTIONS(196),
    [sym_keyword_then] = ACTIONS(196),
    [sym_keyword_permissions] = ACTIONS(196),
    [sym_keyword_for] = ACTIONS(196),
    [sym_keyword_comment] = ACTIONS(196),
    [sym_keyword_unset] = ACTIONS(196),
    [sym_keyword_set] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(196),
    [anon_sym_LPAREN] = ACTIONS(196),
    [anon_sym_RPAREN] = ACTIONS(196),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(200),
    [anon_sym_RBRACK] = ACTIONS(196),
    [anon_sym_QMARK] = ACTIONS(198),
    [anon_sym_LBRACE] = ACTIONS(196),
    [anon_sym_RBRACE] = ACTIONS(196),
    [anon_sym_LT] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [anon_sym_STAR] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_DASH] = ACTIONS(198),
    [anon_sym_PERCENT] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(198),
    [anon_sym_LT_PIPE] = ACTIONS(196),
    [anon_sym_AMP_AMP] = ACTIONS(196),
    [anon_sym_PIPE_PIPE] = ACTIONS(196),
    [anon_sym_QMARK_QMARK] = ACTIONS(196),
    [anon_sym_QMARK_COLON] = ACTIONS(196),
    [anon_sym_BANG_EQ] = ACTIONS(196),
    [anon_sym_EQ_EQ] = ACTIONS(196),
    [anon_sym_QMARK_EQ] = ACTIONS(196),
    [anon_sym_STAR_EQ] = ACTIONS(196),
    [anon_sym_TILDE] = ACTIONS(196),
    [anon_sym_BANG_TILDE] = ACTIONS(196),
    [anon_sym_STAR_TILDE] = ACTIONS(196),
    [anon_sym_LT_EQ] = ACTIONS(196),
    [anon_sym_GT_EQ] = ACTIONS(196),
    [anon_sym_PLUS] = ACTIONS(198),
    [anon_sym_PLUS_EQ] = ACTIONS(196),
    [anon_sym_DASH_EQ] = ACTIONS(196),
    [anon_sym_u00d7] = ACTIONS(196),
    [anon_sym_SLASH] = ACTIONS(198),
    [anon_sym_u00f7] = ACTIONS(196),
    [anon_sym_STAR_STAR] = ACTIONS(196),
    [anon_sym_u220b] = ACTIONS(196),
    [anon_sym_u220c] = ACTIONS(196),
    [anon_sym_u2287] = ACTIONS(196),
    [anon_sym_u2283] = ACTIONS(196),
    [anon_sym_u2285] = ACTIONS(196),
    [anon_sym_u2208] = ACTIONS(196),
    [anon_sym_u2209] = ACTIONS(196),
    [anon_sym_u2286] = ACTIONS(196),
    [anon_sym_u2282] = ACTIONS(196),
    [anon_sym_u2284] = ACTIONS(196),
    [anon_sym_AT_AT] = ACTIONS(196),
  },
  [STATE(22)] = {
    [sym_filter] = STATE(90),
    [sym_path_element] = STATE(24),
    [sym_graph_path] = STATE(90),
    [sym_subscript] = STATE(90),
    [aux_sym_path_repeat1] = STATE(24),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_on] = ACTIONS(204),
    [sym_keyword_return] = ACTIONS(204),
    [sym_keyword_from] = ACTIONS(204),
    [sym_keyword_as] = ACTIONS(204),
    [sym_keyword_omit] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_drop] = ACTIONS(204),
    [sym_keyword_schemafull] = ACTIONS(204),
    [sym_keyword_schemaless] = ACTIONS(204),
    [sym_keyword_changefeed] = ACTIONS(204),
    [sym_keyword_content] = ACTIONS(204),
    [sym_keyword_merge] = ACTIONS(204),
    [sym_keyword_patch] = ACTIONS(204),
    [sym_keyword_replace] = ACTIONS(204),
    [sym_keyword_then] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [sym_keyword_unset] = ACTIONS(204),
    [sym_keyword_set] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_LPAREN] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(200),
    [anon_sym_RBRACK] = ACTIONS(204),
    [anon_sym_QMARK] = ACTIONS(206),
    [anon_sym_LBRACE] = ACTIONS(204),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(23)] = {
    [ts_builtin_sym_end] = ACTIONS(208),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(208),
    [sym_keyword_return] = ACTIONS(208),
    [sym_keyword_value] = ACTIONS(208),
    [sym_keyword_explain] = ACTIONS(208),
    [sym_keyword_parallel] = ACTIONS(208),
    [sym_keyword_timeout] = ACTIONS(208),
    [sym_keyword_fetch] = ACTIONS(208),
    [sym_keyword_limit] = ACTIONS(208),
    [sym_keyword_rand] = ACTIONS(208),
    [sym_keyword_collate] = ACTIONS(208),
    [sym_keyword_numeric] = ACTIONS(208),
    [sym_keyword_asc] = ACTIONS(208),
    [sym_keyword_desc] = ACTIONS(208),
    [sym_keyword_where] = ACTIONS(208),
    [sym_keyword_group] = ACTIONS(208),
    [sym_keyword_and] = ACTIONS(208),
    [sym_keyword_or] = ACTIONS(208),
    [sym_keyword_is] = ACTIONS(208),
    [sym_keyword_not] = ACTIONS(210),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(208),
    [sym_keyword_contains_all] = ACTIONS(208),
    [sym_keyword_contains_any] = ACTIONS(208),
    [sym_keyword_contains_none] = ACTIONS(208),
    [sym_keyword_inside] = ACTIONS(208),
    [sym_keyword_in] = ACTIONS(210),
    [sym_keyword_not_inside] = ACTIONS(208),
    [sym_keyword_all_inside] = ACTIONS(208),
    [sym_keyword_any_inside] = ACTIONS(208),
    [sym_keyword_none_inside] = ACTIONS(208),
    [sym_keyword_outside] = ACTIONS(208),
    [sym_keyword_intersects] = ACTIONS(208),
    [sym_keyword_drop] = ACTIONS(208),
    [sym_keyword_schemafull] = ACTIONS(208),
    [sym_keyword_schemaless] = ACTIONS(208),
    [sym_keyword_flexible] = ACTIONS(208),
    [sym_keyword_readonly] = ACTIONS(208),
    [sym_keyword_changefeed] = ACTIONS(208),
    [sym_keyword_content] = ACTIONS(208),
    [sym_keyword_merge] = ACTIONS(208),
    [sym_keyword_patch] = ACTIONS(208),
    [sym_keyword_replace] = ACTIONS(208),
    [sym_keyword_type] = ACTIONS(208),
    [sym_keyword_default] = ACTIONS(208),
    [sym_keyword_assert] = ACTIONS(208),
    [sym_keyword_permissions] = ACTIONS(208),
    [sym_keyword_for] = ACTIONS(208),
    [sym_keyword_comment] = ACTIONS(208),
    [sym_keyword_unset] = ACTIONS(208),
    [sym_keyword_set] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(208),
    [anon_sym_RPAREN] = ACTIONS(208),
    [anon_sym_DASH_GT] = ACTIONS(208),
    [anon_sym_LBRACK] = ACTIONS(208),
    [anon_sym_RBRACK] = ACTIONS(208),
    [anon_sym_RBRACE] = ACTIONS(208),
    [anon_sym_LT] = ACTIONS(210),
    [anon_sym_GT] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(210),
    [anon_sym_LT_DASH_GT] = ACTIONS(208),
    [anon_sym_STAR] = ACTIONS(210),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_DOT_DOT] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(210),
    [anon_sym_PERCENT] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(210),
    [anon_sym_LT_PIPE] = ACTIONS(208),
    [anon_sym_AMP_AMP] = ACTIONS(208),
    [anon_sym_PIPE_PIPE] = ACTIONS(208),
    [anon_sym_QMARK_QMARK] = ACTIONS(208),
    [anon_sym_QMARK_COLON] = ACTIONS(208),
    [anon_sym_BANG_EQ] = ACTIONS(208),
    [anon_sym_EQ_EQ] = ACTIONS(208),
    [anon_sym_QMARK_EQ] = ACTIONS(208),
    [anon_sym_STAR_EQ] = ACTIONS(208),
    [anon_sym_TILDE] = ACTIONS(208),
    [anon_sym_BANG_TILDE] = ACTIONS(208),
    [anon_sym_STAR_TILDE] = ACTIONS(208),
    [anon_sym_LT_EQ] = ACTIONS(208),
    [anon_sym_GT_EQ] = ACTIONS(208),
    [anon_sym_PLUS] = ACTIONS(210),
    [anon_sym_PLUS_EQ] = ACTIONS(208),
    [anon_sym_DASH_EQ] = ACTIONS(208),
    [anon_sym_u00d7] = ACTIONS(208),
    [anon_sym_SLASH] = ACTIONS(210),
    [anon_sym_u00f7] = ACTIONS(208),
    [anon_sym_STAR_STAR] = ACTIONS(208),
    [anon_sym_u220b] = ACTIONS(208),
    [anon_sym_u220c] = ACTIONS(208),
    [anon_sym_u2287] = ACTIONS(208),
    [anon_sym_u2283] = ACTIONS(208),
    [anon_sym_u2285] = ACTIONS(208),
    [anon_sym_u2208] = ACTIONS(208),
    [anon_sym_u2209] = ACTIONS(208),
    [anon_sym_u2286] = ACTIONS(208),
    [anon_sym_u2282] = ACTIONS(208),
    [anon_sym_u2284] = ACTIONS(208),
    [anon_sym_AT_AT] = ACTIONS(208),
  },
  [STATE(24)] = {
    [sym_filter] = STATE(90),
    [sym_path_element] = STATE(25),
    [sym_graph_path] = STATE(90),
    [sym_subscript] = STATE(90),
    [aux_sym_path_repeat1] = STATE(25),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(212),
    [sym_keyword_on] = ACTIONS(212),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_from] = ACTIONS(212),
    [sym_keyword_as] = ACTIONS(212),
    [sym_keyword_omit] = ACTIONS(212),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(214),
    [sym_keyword_contains] = ACTIONS(214),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(214),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_content] = ACTIONS(212),
    [sym_keyword_merge] = ACTIONS(212),
    [sym_keyword_patch] = ACTIONS(212),
    [sym_keyword_replace] = ACTIONS(212),
    [sym_keyword_then] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [sym_keyword_unset] = ACTIONS(212),
    [sym_keyword_set] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(214),
    [anon_sym_COMMA] = ACTIONS(212),
    [anon_sym_LPAREN] = ACTIONS(212),
    [anon_sym_RPAREN] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(200),
    [anon_sym_RBRACK] = ACTIONS(212),
    [anon_sym_QMARK] = ACTIONS(214),
    [anon_sym_LBRACE] = ACTIONS(212),
    [anon_sym_RBRACE] = ACTIONS(212),
    [anon_sym_LT] = ACTIONS(214),
    [anon_sym_GT] = ACTIONS(214),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [anon_sym_STAR] = ACTIONS(214),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_DASH] = ACTIONS(214),
    [anon_sym_PERCENT] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(214),
    [anon_sym_LT_PIPE] = ACTIONS(212),
    [anon_sym_AMP_AMP] = ACTIONS(212),
    [anon_sym_PIPE_PIPE] = ACTIONS(212),
    [anon_sym_QMARK_QMARK] = ACTIONS(212),
    [anon_sym_QMARK_COLON] = ACTIONS(212),
    [anon_sym_BANG_EQ] = ACTIONS(212),
    [anon_sym_EQ_EQ] = ACTIONS(212),
    [anon_sym_QMARK_EQ] = ACTIONS(212),
    [anon_sym_STAR_EQ] = ACTIONS(212),
    [anon_sym_TILDE] = ACTIONS(212),
    [anon_sym_BANG_TILDE] = ACTIONS(212),
    [anon_sym_STAR_TILDE] = ACTIONS(212),
    [anon_sym_LT_EQ] = ACTIONS(212),
    [anon_sym_GT_EQ] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(214),
    [anon_sym_PLUS_EQ] = ACTIONS(212),
    [anon_sym_DASH_EQ] = ACTIONS(212),
    [anon_sym_u00d7] = ACTIONS(212),
    [anon_sym_SLASH] = ACTIONS(214),
    [anon_sym_u00f7] = ACTIONS(212),
    [anon_sym_STAR_STAR] = ACTIONS(212),
    [anon_sym_u220b] = ACTIONS(212),
    [anon_sym_u220c] = ACTIONS(212),
    [anon_sym_u2287] = ACTIONS(212),
    [anon_sym_u2283] = ACTIONS(212),
    [anon_sym_u2285] = ACTIONS(212),
    [anon_sym_u2208] = ACTIONS(212),
    [anon_sym_u2209] = ACTIONS(212),
    [anon_sym_u2286] = ACTIONS(212),
    [anon_sym_u2282] = ACTIONS(212),
    [anon_sym_u2284] = ACTIONS(212),
    [anon_sym_AT_AT] = ACTIONS(212),
  },
  [STATE(25)] = {
    [sym_filter] = STATE(90),
    [sym_path_element] = STATE(25),
    [sym_graph_path] = STATE(90),
    [sym_subscript] = STATE(90),
    [aux_sym_path_repeat1] = STATE(25),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(216),
    [sym_keyword_on] = ACTIONS(216),
    [sym_keyword_return] = ACTIONS(216),
    [sym_keyword_from] = ACTIONS(216),
    [sym_keyword_as] = ACTIONS(216),
    [sym_keyword_omit] = ACTIONS(216),
    [sym_keyword_explain] = ACTIONS(216),
    [sym_keyword_parallel] = ACTIONS(216),
    [sym_keyword_timeout] = ACTIONS(216),
    [sym_keyword_fetch] = ACTIONS(216),
    [sym_keyword_limit] = ACTIONS(216),
    [sym_keyword_where] = ACTIONS(216),
    [sym_keyword_group] = ACTIONS(216),
    [sym_keyword_and] = ACTIONS(216),
    [sym_keyword_or] = ACTIONS(216),
    [sym_keyword_is] = ACTIONS(216),
    [sym_keyword_not] = ACTIONS(218),
    [sym_keyword_contains] = ACTIONS(218),
    [sym_keyword_contains_not] = ACTIONS(216),
    [sym_keyword_contains_all] = ACTIONS(216),
    [sym_keyword_contains_any] = ACTIONS(216),
    [sym_keyword_contains_none] = ACTIONS(216),
    [sym_keyword_inside] = ACTIONS(216),
    [sym_keyword_in] = ACTIONS(218),
    [sym_keyword_not_inside] = ACTIONS(216),
    [sym_keyword_all_inside] = ACTIONS(216),
    [sym_keyword_any_inside] = ACTIONS(216),
    [sym_keyword_none_inside] = ACTIONS(216),
    [sym_keyword_outside] = ACTIONS(216),
    [sym_keyword_intersects] = ACTIONS(216),
    [sym_keyword_drop] = ACTIONS(216),
    [sym_keyword_schemafull] = ACTIONS(216),
    [sym_keyword_schemaless] = ACTIONS(216),
    [sym_keyword_changefeed] = ACTIONS(216),
    [sym_keyword_content] = ACTIONS(216),
    [sym_keyword_merge] = ACTIONS(216),
    [sym_keyword_patch] = ACTIONS(216),
    [sym_keyword_replace] = ACTIONS(216),
    [sym_keyword_then] = ACTIONS(216),
    [sym_keyword_permissions] = ACTIONS(216),
    [sym_keyword_for] = ACTIONS(216),
    [sym_keyword_comment] = ACTIONS(216),
    [sym_keyword_unset] = ACTIONS(216),
    [sym_keyword_set] = ACTIONS(216),
    [anon_sym_EQ] = ACTIONS(218),
    [anon_sym_COMMA] = ACTIONS(216),
    [anon_sym_LPAREN] = ACTIONS(216),
    [anon_sym_RPAREN] = ACTIONS(216),
    [anon_sym_DASH_GT] = ACTIONS(220),
    [anon_sym_LBRACK] = ACTIONS(223),
    [anon_sym_RBRACK] = ACTIONS(216),
    [anon_sym_QMARK] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(216),
    [anon_sym_RBRACE] = ACTIONS(216),
    [anon_sym_LT] = ACTIONS(218),
    [anon_sym_GT] = ACTIONS(218),
    [anon_sym_LT_DASH] = ACTIONS(226),
    [anon_sym_LT_DASH_GT] = ACTIONS(220),
    [anon_sym_STAR] = ACTIONS(218),
    [anon_sym_DOT] = ACTIONS(229),
    [anon_sym_DASH] = ACTIONS(218),
    [anon_sym_PERCENT] = ACTIONS(216),
    [anon_sym_AT] = ACTIONS(218),
    [anon_sym_LT_PIPE] = ACTIONS(216),
    [anon_sym_AMP_AMP] = ACTIONS(216),
    [anon_sym_PIPE_PIPE] = ACTIONS(216),
    [anon_sym_QMARK_QMARK] = ACTIONS(216),
    [anon_sym_QMARK_COLON] = ACTIONS(216),
    [anon_sym_BANG_EQ] = ACTIONS(216),
    [anon_sym_EQ_EQ] = ACTIONS(216),
    [anon_sym_QMARK_EQ] = ACTIONS(216),
    [anon_sym_STAR_EQ] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(216),
    [anon_sym_BANG_TILDE] = ACTIONS(216),
    [anon_sym_STAR_TILDE] = ACTIONS(216),
    [anon_sym_LT_EQ] = ACTIONS(216),
    [anon_sym_GT_EQ] = ACTIONS(216),
    [anon_sym_PLUS] = ACTIONS(218),
    [anon_sym_PLUS_EQ] = ACTIONS(216),
    [anon_sym_DASH_EQ] = ACTIONS(216),
    [anon_sym_u00d7] = ACTIONS(216),
    [anon_sym_SLASH] = ACTIONS(218),
    [anon_sym_u00f7] = ACTIONS(216),
    [anon_sym_STAR_STAR] = ACTIONS(216),
    [anon_sym_u220b] = ACTIONS(216),
    [anon_sym_u220c] = ACTIONS(216),
    [anon_sym_u2287] = ACTIONS(216),
    [anon_sym_u2283] = ACTIONS(216),
    [anon_sym_u2285] = ACTIONS(216),
    [anon_sym_u2208] = ACTIONS(216),
    [anon_sym_u2209] = ACTIONS(216),
    [anon_sym_u2286] = ACTIONS(216),
    [anon_sym_u2282] = ACTIONS(216),
    [anon_sym_u2284] = ACTIONS(216),
    [anon_sym_AT_AT] = ACTIONS(216),
  },
  [STATE(26)] = {
    [ts_builtin_sym_end] = ACTIONS(232),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(232),
    [sym_keyword_return] = ACTIONS(232),
    [sym_keyword_value] = ACTIONS(232),
    [sym_keyword_explain] = ACTIONS(232),
    [sym_keyword_parallel] = ACTIONS(232),
    [sym_keyword_timeout] = ACTIONS(232),
    [sym_keyword_fetch] = ACTIONS(232),
    [sym_keyword_limit] = ACTIONS(232),
    [sym_keyword_rand] = ACTIONS(232),
    [sym_keyword_collate] = ACTIONS(232),
    [sym_keyword_numeric] = ACTIONS(232),
    [sym_keyword_asc] = ACTIONS(232),
    [sym_keyword_desc] = ACTIONS(232),
    [sym_keyword_where] = ACTIONS(232),
    [sym_keyword_group] = ACTIONS(232),
    [sym_keyword_and] = ACTIONS(232),
    [sym_keyword_or] = ACTIONS(232),
    [sym_keyword_is] = ACTIONS(232),
    [sym_keyword_not] = ACTIONS(234),
    [sym_keyword_contains] = ACTIONS(234),
    [sym_keyword_contains_not] = ACTIONS(232),
    [sym_keyword_contains_all] = ACTIONS(232),
    [sym_keyword_contains_any] = ACTIONS(232),
    [sym_keyword_contains_none] = ACTIONS(232),
    [sym_keyword_inside] = ACTIONS(232),
    [sym_keyword_in] = ACTIONS(234),
    [sym_keyword_not_inside] = ACTIONS(232),
    [sym_keyword_all_inside] = ACTIONS(232),
    [sym_keyword_any_inside] = ACTIONS(232),
    [sym_keyword_none_inside] = ACTIONS(232),
    [sym_keyword_outside] = ACTIONS(232),
    [sym_keyword_intersects] = ACTIONS(232),
    [sym_keyword_drop] = ACTIONS(232),
    [sym_keyword_schemafull] = ACTIONS(232),
    [sym_keyword_schemaless] = ACTIONS(232),
    [sym_keyword_flexible] = ACTIONS(232),
    [sym_keyword_readonly] = ACTIONS(232),
    [sym_keyword_changefeed] = ACTIONS(232),
    [sym_keyword_content] = ACTIONS(232),
    [sym_keyword_merge] = ACTIONS(232),
    [sym_keyword_patch] = ACTIONS(232),
    [sym_keyword_replace] = ACTIONS(232),
    [sym_keyword_type] = ACTIONS(232),
    [sym_keyword_default] = ACTIONS(232),
    [sym_keyword_assert] = ACTIONS(232),
    [sym_keyword_permissions] = ACTIONS(232),
    [sym_keyword_for] = ACTIONS(232),
    [sym_keyword_comment] = ACTIONS(232),
    [sym_keyword_unset] = ACTIONS(232),
    [sym_keyword_set] = ACTIONS(232),
    [anon_sym_EQ] = ACTIONS(234),
    [anon_sym_COMMA] = ACTIONS(232),
    [anon_sym_RPAREN] = ACTIONS(232),
    [anon_sym_DASH_GT] = ACTIONS(232),
    [anon_sym_LBRACK] = ACTIONS(232),
    [anon_sym_RBRACK] = ACTIONS(232),
    [anon_sym_RBRACE] = ACTIONS(232),
    [anon_sym_LT] = ACTIONS(234),
    [anon_sym_GT] = ACTIONS(234),
    [anon_sym_LT_DASH] = ACTIONS(234),
    [anon_sym_LT_DASH_GT] = ACTIONS(232),
    [anon_sym_STAR] = ACTIONS(234),
    [anon_sym_DOT] = ACTIONS(234),
    [anon_sym_DOT_DOT] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(234),
    [anon_sym_PERCENT] = ACTIONS(232),
    [anon_sym_AT] = ACTIONS(234),
    [anon_sym_LT_PIPE] = ACTIONS(232),
    [anon_sym_AMP_AMP] = ACTIONS(232),
    [anon_sym_PIPE_PIPE] = ACTIONS(232),
    [anon_sym_QMARK_QMARK] = ACTIONS(232),
    [anon_sym_QMARK_COLON] = ACTIONS(232),
    [anon_sym_BANG_EQ] = ACTIONS(232),
    [anon_sym_EQ_EQ] = ACTIONS(232),
    [anon_sym_QMARK_EQ] = ACTIONS(232),
    [anon_sym_STAR_EQ] = ACTIONS(232),
    [anon_sym_TILDE] = ACTIONS(232),
    [anon_sym_BANG_TILDE] = ACTIONS(232),
    [anon_sym_STAR_TILDE] = ACTIONS(232),
    [anon_sym_LT_EQ] = ACTIONS(232),
    [anon_sym_GT_EQ] = ACTIONS(232),
    [anon_sym_PLUS] = ACTIONS(234),
    [anon_sym_PLUS_EQ] = ACTIONS(232),
    [anon_sym_DASH_EQ] = ACTIONS(232),
    [anon_sym_u00d7] = ACTIONS(232),
    [anon_sym_SLASH] = ACTIONS(234),
    [anon_sym_u00f7] = ACTIONS(232),
    [anon_sym_STAR_STAR] = ACTIONS(232),
    [anon_sym_u220b] = ACTIONS(232),
    [anon_sym_u220c] = ACTIONS(232),
    [anon_sym_u2287] = ACTIONS(232),
    [anon_sym_u2283] = ACTIONS(232),
    [anon_sym_u2285] = ACTIONS(232),
    [anon_sym_u2208] = ACTIONS(232),
    [anon_sym_u2209] = ACTIONS(232),
    [anon_sym_u2286] = ACTIONS(232),
    [anon_sym_u2282] = ACTIONS(232),
    [anon_sym_u2284] = ACTIONS(232),
    [anon_sym_AT_AT] = ACTIONS(232),
  },
  [STATE(27)] = {
    [sym_filter] = STATE(90),
    [sym_path_element] = STATE(24),
    [sym_graph_path] = STATE(90),
    [sym_subscript] = STATE(90),
    [aux_sym_path_repeat1] = STATE(24),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_on] = ACTIONS(236),
    [sym_keyword_return] = ACTIONS(236),
    [sym_keyword_from] = ACTIONS(236),
    [sym_keyword_as] = ACTIONS(236),
    [sym_keyword_omit] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_drop] = ACTIONS(236),
    [sym_keyword_schemafull] = ACTIONS(236),
    [sym_keyword_schemaless] = ACTIONS(236),
    [sym_keyword_changefeed] = ACTIONS(236),
    [sym_keyword_content] = ACTIONS(236),
    [sym_keyword_merge] = ACTIONS(236),
    [sym_keyword_patch] = ACTIONS(236),
    [sym_keyword_replace] = ACTIONS(236),
    [sym_keyword_then] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [sym_keyword_unset] = ACTIONS(236),
    [sym_keyword_set] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_LPAREN] = ACTIONS(236),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(200),
    [anon_sym_RBRACK] = ACTIONS(236),
    [anon_sym_QMARK] = ACTIONS(238),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_RBRACE] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DOT] = ACTIONS(202),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(28)] = {
    [ts_builtin_sym_end] = ACTIONS(240),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(240),
    [sym_keyword_return] = ACTIONS(240),
    [sym_keyword_value] = ACTIONS(240),
    [sym_keyword_explain] = ACTIONS(240),
    [sym_keyword_parallel] = ACTIONS(240),
    [sym_keyword_timeout] = ACTIONS(240),
    [sym_keyword_fetch] = ACTIONS(240),
    [sym_keyword_limit] = ACTIONS(240),
    [sym_keyword_rand] = ACTIONS(240),
    [sym_keyword_collate] = ACTIONS(240),
    [sym_keyword_numeric] = ACTIONS(240),
    [sym_keyword_asc] = ACTIONS(240),
    [sym_keyword_desc] = ACTIONS(240),
    [sym_keyword_where] = ACTIONS(240),
    [sym_keyword_group] = ACTIONS(240),
    [sym_keyword_and] = ACTIONS(240),
    [sym_keyword_or] = ACTIONS(240),
    [sym_keyword_is] = ACTIONS(240),
    [sym_keyword_not] = ACTIONS(242),
    [sym_keyword_contains] = ACTIONS(242),
    [sym_keyword_contains_not] = ACTIONS(240),
    [sym_keyword_contains_all] = ACTIONS(240),
    [sym_keyword_contains_any] = ACTIONS(240),
    [sym_keyword_contains_none] = ACTIONS(240),
    [sym_keyword_inside] = ACTIONS(240),
    [sym_keyword_in] = ACTIONS(242),
    [sym_keyword_not_inside] = ACTIONS(240),
    [sym_keyword_all_inside] = ACTIONS(240),
    [sym_keyword_any_inside] = ACTIONS(240),
    [sym_keyword_none_inside] = ACTIONS(240),
    [sym_keyword_outside] = ACTIONS(240),
    [sym_keyword_intersects] = ACTIONS(240),
    [sym_keyword_drop] = ACTIONS(240),
    [sym_keyword_schemafull] = ACTIONS(240),
    [sym_keyword_schemaless] = ACTIONS(240),
    [sym_keyword_flexible] = ACTIONS(240),
    [sym_keyword_readonly] = ACTIONS(240),
    [sym_keyword_changefeed] = ACTIONS(240),
    [sym_keyword_content] = ACTIONS(240),
    [sym_keyword_merge] = ACTIONS(240),
    [sym_keyword_patch] = ACTIONS(240),
    [sym_keyword_replace] = ACTIONS(240),
    [sym_keyword_type] = ACTIONS(240),
    [sym_keyword_default] = ACTIONS(240),
    [sym_keyword_assert] = ACTIONS(240),
    [sym_keyword_permissions] = ACTIONS(240),
    [sym_keyword_for] = ACTIONS(240),
    [sym_keyword_comment] = ACTIONS(240),
    [sym_keyword_unset] = ACTIONS(240),
    [sym_keyword_set] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_DASH_GT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(240),
    [anon_sym_RBRACE] = ACTIONS(240),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_DASH] = ACTIONS(242),
    [anon_sym_LT_DASH_GT] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_DOT_DOT] = ACTIONS(240),
    [anon_sym_DASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LT_PIPE] = ACTIONS(240),
    [anon_sym_AMP_AMP] = ACTIONS(240),
    [anon_sym_PIPE_PIPE] = ACTIONS(240),
    [anon_sym_QMARK_QMARK] = ACTIONS(240),
    [anon_sym_QMARK_COLON] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_QMARK_EQ] = ACTIONS(240),
    [anon_sym_STAR_EQ] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(240),
    [anon_sym_BANG_TILDE] = ACTIONS(240),
    [anon_sym_STAR_TILDE] = ACTIONS(240),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_PLUS] = ACTIONS(242),
    [anon_sym_PLUS_EQ] = ACTIONS(240),
    [anon_sym_DASH_EQ] = ACTIONS(240),
    [anon_sym_u00d7] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_u00f7] = ACTIONS(240),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_u220b] = ACTIONS(240),
    [anon_sym_u220c] = ACTIONS(240),
    [anon_sym_u2287] = ACTIONS(240),
    [anon_sym_u2283] = ACTIONS(240),
    [anon_sym_u2285] = ACTIONS(240),
    [anon_sym_u2208] = ACTIONS(240),
    [anon_sym_u2209] = ACTIONS(240),
    [anon_sym_u2286] = ACTIONS(240),
    [anon_sym_u2282] = ACTIONS(240),
    [anon_sym_u2284] = ACTIONS(240),
    [anon_sym_AT_AT] = ACTIONS(240),
  },
  [STATE(29)] = {
    [ts_builtin_sym_end] = ACTIONS(244),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(244),
    [sym_keyword_return] = ACTIONS(244),
    [sym_keyword_value] = ACTIONS(244),
    [sym_keyword_explain] = ACTIONS(244),
    [sym_keyword_parallel] = ACTIONS(244),
    [sym_keyword_timeout] = ACTIONS(244),
    [sym_keyword_fetch] = ACTIONS(244),
    [sym_keyword_limit] = ACTIONS(244),
    [sym_keyword_rand] = ACTIONS(244),
    [sym_keyword_collate] = ACTIONS(244),
    [sym_keyword_numeric] = ACTIONS(244),
    [sym_keyword_asc] = ACTIONS(244),
    [sym_keyword_desc] = ACTIONS(244),
    [sym_keyword_where] = ACTIONS(244),
    [sym_keyword_group] = ACTIONS(244),
    [sym_keyword_and] = ACTIONS(244),
    [sym_keyword_or] = ACTIONS(244),
    [sym_keyword_is] = ACTIONS(244),
    [sym_keyword_not] = ACTIONS(246),
    [sym_keyword_contains] = ACTIONS(246),
    [sym_keyword_contains_not] = ACTIONS(244),
    [sym_keyword_contains_all] = ACTIONS(244),
    [sym_keyword_contains_any] = ACTIONS(244),
    [sym_keyword_contains_none] = ACTIONS(244),
    [sym_keyword_inside] = ACTIONS(244),
    [sym_keyword_in] = ACTIONS(246),
    [sym_keyword_not_inside] = ACTIONS(244),
    [sym_keyword_all_inside] = ACTIONS(244),
    [sym_keyword_any_inside] = ACTIONS(244),
    [sym_keyword_none_inside] = ACTIONS(244),
    [sym_keyword_outside] = ACTIONS(244),
    [sym_keyword_intersects] = ACTIONS(244),
    [sym_keyword_drop] = ACTIONS(244),
    [sym_keyword_schemafull] = ACTIONS(244),
    [sym_keyword_schemaless] = ACTIONS(244),
    [sym_keyword_flexible] = ACTIONS(244),
    [sym_keyword_readonly] = ACTIONS(244),
    [sym_keyword_changefeed] = ACTIONS(244),
    [sym_keyword_content] = ACTIONS(244),
    [sym_keyword_merge] = ACTIONS(244),
    [sym_keyword_patch] = ACTIONS(244),
    [sym_keyword_replace] = ACTIONS(244),
    [sym_keyword_type] = ACTIONS(244),
    [sym_keyword_default] = ACTIONS(244),
    [sym_keyword_assert] = ACTIONS(244),
    [sym_keyword_permissions] = ACTIONS(244),
    [sym_keyword_for] = ACTIONS(244),
    [sym_keyword_comment] = ACTIONS(244),
    [sym_keyword_unset] = ACTIONS(244),
    [sym_keyword_set] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(246),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_DASH_GT] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(244),
    [anon_sym_RBRACE] = ACTIONS(244),
    [anon_sym_LT] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(246),
    [anon_sym_LT_DASH] = ACTIONS(246),
    [anon_sym_LT_DASH_GT] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(246),
    [anon_sym_DOT_DOT] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(246),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_AT] = ACTIONS(246),
    [anon_sym_LT_PIPE] = ACTIONS(244),
    [anon_sym_AMP_AMP] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(244),
    [anon_sym_QMARK_QMARK] = ACTIONS(244),
    [anon_sym_QMARK_COLON] = ACTIONS(244),
    [anon_sym_BANG_EQ] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(244),
    [anon_sym_QMARK_EQ] = ACTIONS(244),
    [anon_sym_STAR_EQ] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_BANG_TILDE] = ACTIONS(244),
    [anon_sym_STAR_TILDE] = ACTIONS(244),
    [anon_sym_LT_EQ] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(246),
    [anon_sym_PLUS_EQ] = ACTIONS(244),
    [anon_sym_DASH_EQ] = ACTIONS(244),
    [anon_sym_u00d7] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(246),
    [anon_sym_u00f7] = ACTIONS(244),
    [anon_sym_STAR_STAR] = ACTIONS(244),
    [anon_sym_u220b] = ACTIONS(244),
    [anon_sym_u220c] = ACTIONS(244),
    [anon_sym_u2287] = ACTIONS(244),
    [anon_sym_u2283] = ACTIONS(244),
    [anon_sym_u2285] = ACTIONS(244),
    [anon_sym_u2208] = ACTIONS(244),
    [anon_sym_u2209] = ACTIONS(244),
    [anon_sym_u2286] = ACTIONS(244),
    [anon_sym_u2282] = ACTIONS(244),
    [anon_sym_u2284] = ACTIONS(244),
    [anon_sym_AT_AT] = ACTIONS(244),
  },
  [STATE(30)] = {
    [ts_builtin_sym_end] = ACTIONS(248),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(248),
    [sym_keyword_return] = ACTIONS(248),
    [sym_keyword_value] = ACTIONS(248),
    [sym_keyword_explain] = ACTIONS(248),
    [sym_keyword_parallel] = ACTIONS(248),
    [sym_keyword_timeout] = ACTIONS(248),
    [sym_keyword_fetch] = ACTIONS(248),
    [sym_keyword_limit] = ACTIONS(248),
    [sym_keyword_rand] = ACTIONS(248),
    [sym_keyword_collate] = ACTIONS(248),
    [sym_keyword_numeric] = ACTIONS(248),
    [sym_keyword_asc] = ACTIONS(248),
    [sym_keyword_desc] = ACTIONS(248),
    [sym_keyword_where] = ACTIONS(248),
    [sym_keyword_group] = ACTIONS(248),
    [sym_keyword_and] = ACTIONS(248),
    [sym_keyword_or] = ACTIONS(248),
    [sym_keyword_is] = ACTIONS(248),
    [sym_keyword_not] = ACTIONS(250),
    [sym_keyword_contains] = ACTIONS(250),
    [sym_keyword_contains_not] = ACTIONS(248),
    [sym_keyword_contains_all] = ACTIONS(248),
    [sym_keyword_contains_any] = ACTIONS(248),
    [sym_keyword_contains_none] = ACTIONS(248),
    [sym_keyword_inside] = ACTIONS(248),
    [sym_keyword_in] = ACTIONS(250),
    [sym_keyword_not_inside] = ACTIONS(248),
    [sym_keyword_all_inside] = ACTIONS(248),
    [sym_keyword_any_inside] = ACTIONS(248),
    [sym_keyword_none_inside] = ACTIONS(248),
    [sym_keyword_outside] = ACTIONS(248),
    [sym_keyword_intersects] = ACTIONS(248),
    [sym_keyword_drop] = ACTIONS(248),
    [sym_keyword_schemafull] = ACTIONS(248),
    [sym_keyword_schemaless] = ACTIONS(248),
    [sym_keyword_flexible] = ACTIONS(248),
    [sym_keyword_readonly] = ACTIONS(248),
    [sym_keyword_changefeed] = ACTIONS(248),
    [sym_keyword_content] = ACTIONS(248),
    [sym_keyword_merge] = ACTIONS(248),
    [sym_keyword_patch] = ACTIONS(248),
    [sym_keyword_replace] = ACTIONS(248),
    [sym_keyword_type] = ACTIONS(248),
    [sym_keyword_default] = ACTIONS(248),
    [sym_keyword_assert] = ACTIONS(248),
    [sym_keyword_permissions] = ACTIONS(248),
    [sym_keyword_for] = ACTIONS(248),
    [sym_keyword_comment] = ACTIONS(248),
    [sym_keyword_unset] = ACTIONS(248),
    [sym_keyword_set] = ACTIONS(248),
    [anon_sym_EQ] = ACTIONS(250),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_RPAREN] = ACTIONS(248),
    [anon_sym_DASH_GT] = ACTIONS(248),
    [anon_sym_LBRACK] = ACTIONS(248),
    [anon_sym_RBRACE] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_LT_DASH] = ACTIONS(250),
    [anon_sym_LT_DASH_GT] = ACTIONS(248),
    [anon_sym_STAR] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(250),
    [anon_sym_DOT_DOT] = ACTIONS(248),
    [anon_sym_DASH] = ACTIONS(250),
    [anon_sym_PERCENT] = ACTIONS(248),
    [anon_sym_AT] = ACTIONS(250),
    [anon_sym_LT_PIPE] = ACTIONS(248),
    [anon_sym_AMP_AMP] = ACTIONS(248),
    [anon_sym_PIPE_PIPE] = ACTIONS(248),
    [anon_sym_QMARK_QMARK] = ACTIONS(248),
    [anon_sym_QMARK_COLON] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_QMARK_EQ] = ACTIONS(248),
    [anon_sym_STAR_EQ] = ACTIONS(248),
    [anon_sym_TILDE] = ACTIONS(248),
    [anon_sym_BANG_TILDE] = ACTIONS(248),
    [anon_sym_STAR_TILDE] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(250),
    [anon_sym_PLUS_EQ] = ACTIONS(248),
    [anon_sym_DASH_EQ] = ACTIONS(248),
    [anon_sym_u00d7] = ACTIONS(248),
    [anon_sym_SLASH] = ACTIONS(250),
    [anon_sym_u00f7] = ACTIONS(248),
    [anon_sym_STAR_STAR] = ACTIONS(248),
    [anon_sym_u220b] = ACTIONS(248),
    [anon_sym_u220c] = ACTIONS(248),
    [anon_sym_u2287] = ACTIONS(248),
    [anon_sym_u2283] = ACTIONS(248),
    [anon_sym_u2285] = ACTIONS(248),
    [anon_sym_u2208] = ACTIONS(248),
    [anon_sym_u2209] = ACTIONS(248),
    [anon_sym_u2286] = ACTIONS(248),
    [anon_sym_u2282] = ACTIONS(248),
    [anon_sym_u2284] = ACTIONS(248),
    [anon_sym_AT_AT] = ACTIONS(248),
  },
  [STATE(31)] = {
    [ts_builtin_sym_end] = ACTIONS(252),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(252),
    [sym_keyword_return] = ACTIONS(252),
    [sym_keyword_value] = ACTIONS(252),
    [sym_keyword_explain] = ACTIONS(252),
    [sym_keyword_parallel] = ACTIONS(252),
    [sym_keyword_timeout] = ACTIONS(252),
    [sym_keyword_fetch] = ACTIONS(252),
    [sym_keyword_limit] = ACTIONS(252),
    [sym_keyword_rand] = ACTIONS(252),
    [sym_keyword_collate] = ACTIONS(252),
    [sym_keyword_numeric] = ACTIONS(252),
    [sym_keyword_asc] = ACTIONS(252),
    [sym_keyword_desc] = ACTIONS(252),
    [sym_keyword_where] = ACTIONS(252),
    [sym_keyword_group] = ACTIONS(252),
    [sym_keyword_and] = ACTIONS(252),
    [sym_keyword_or] = ACTIONS(252),
    [sym_keyword_is] = ACTIONS(252),
    [sym_keyword_not] = ACTIONS(254),
    [sym_keyword_contains] = ACTIONS(254),
    [sym_keyword_contains_not] = ACTIONS(252),
    [sym_keyword_contains_all] = ACTIONS(252),
    [sym_keyword_contains_any] = ACTIONS(252),
    [sym_keyword_contains_none] = ACTIONS(252),
    [sym_keyword_inside] = ACTIONS(252),
    [sym_keyword_in] = ACTIONS(254),
    [sym_keyword_not_inside] = ACTIONS(252),
    [sym_keyword_all_inside] = ACTIONS(252),
    [sym_keyword_any_inside] = ACTIONS(252),
    [sym_keyword_none_inside] = ACTIONS(252),
    [sym_keyword_outside] = ACTIONS(252),
    [sym_keyword_intersects] = ACTIONS(252),
    [sym_keyword_drop] = ACTIONS(252),
    [sym_keyword_schemafull] = ACTIONS(252),
    [sym_keyword_schemaless] = ACTIONS(252),
    [sym_keyword_flexible] = ACTIONS(252),
    [sym_keyword_readonly] = ACTIONS(252),
    [sym_keyword_changefeed] = ACTIONS(252),
    [sym_keyword_content] = ACTIONS(252),
    [sym_keyword_merge] = ACTIONS(252),
    [sym_keyword_patch] = ACTIONS(252),
    [sym_keyword_replace] = ACTIONS(252),
    [sym_keyword_type] = ACTIONS(252),
    [sym_keyword_default] = ACTIONS(252),
    [sym_keyword_assert] = ACTIONS(252),
    [sym_keyword_permissions] = ACTIONS(252),
    [sym_keyword_for] = ACTIONS(252),
    [sym_keyword_comment] = ACTIONS(252),
    [sym_keyword_unset] = ACTIONS(252),
    [sym_keyword_set] = ACTIONS(252),
    [anon_sym_EQ] = ACTIONS(254),
    [anon_sym_COMMA] = ACTIONS(252),
    [anon_sym_RPAREN] = ACTIONS(252),
    [anon_sym_DASH_GT] = ACTIONS(252),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_RBRACE] = ACTIONS(252),
    [anon_sym_LT] = ACTIONS(254),
    [anon_sym_GT] = ACTIONS(254),
    [anon_sym_LT_DASH] = ACTIONS(254),
    [anon_sym_LT_DASH_GT] = ACTIONS(252),
    [anon_sym_STAR] = ACTIONS(254),
    [anon_sym_DOT] = ACTIONS(254),
    [anon_sym_DOT_DOT] = ACTIONS(252),
    [anon_sym_DASH] = ACTIONS(254),
    [anon_sym_PERCENT] = ACTIONS(252),
    [anon_sym_AT] = ACTIONS(254),
    [anon_sym_LT_PIPE] = ACTIONS(252),
    [anon_sym_AMP_AMP] = ACTIONS(252),
    [anon_sym_PIPE_PIPE] = ACTIONS(252),
    [anon_sym_QMARK_QMARK] = ACTIONS(252),
    [anon_sym_QMARK_COLON] = ACTIONS(252),
    [anon_sym_BANG_EQ] = ACTIONS(252),
    [anon_sym_EQ_EQ] = ACTIONS(252),
    [anon_sym_QMARK_EQ] = ACTIONS(252),
    [anon_sym_STAR_EQ] = ACTIONS(252),
    [anon_sym_TILDE] = ACTIONS(252),
    [anon_sym_BANG_TILDE] = ACTIONS(252),
    [anon_sym_STAR_TILDE] = ACTIONS(252),
    [anon_sym_LT_EQ] = ACTIONS(252),
    [anon_sym_GT_EQ] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(254),
    [anon_sym_PLUS_EQ] = ACTIONS(252),
    [anon_sym_DASH_EQ] = ACTIONS(252),
    [anon_sym_u00d7] = ACTIONS(252),
    [anon_sym_SLASH] = ACTIONS(254),
    [anon_sym_u00f7] = ACTIONS(252),
    [anon_sym_STAR_STAR] = ACTIONS(252),
    [anon_sym_u220b] = ACTIONS(252),
    [anon_sym_u220c] = ACTIONS(252),
    [anon_sym_u2287] = ACTIONS(252),
    [anon_sym_u2283] = ACTIONS(252),
    [anon_sym_u2285] = ACTIONS(252),
    [anon_sym_u2208] = ACTIONS(252),
    [anon_sym_u2209] = ACTIONS(252),
    [anon_sym_u2286] = ACTIONS(252),
    [anon_sym_u2282] = ACTIONS(252),
    [anon_sym_u2284] = ACTIONS(252),
    [anon_sym_AT_AT] = ACTIONS(252),
  },
  [STATE(32)] = {
    [ts_builtin_sym_end] = ACTIONS(256),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(256),
    [sym_keyword_return] = ACTIONS(256),
    [sym_keyword_value] = ACTIONS(256),
    [sym_keyword_explain] = ACTIONS(256),
    [sym_keyword_parallel] = ACTIONS(256),
    [sym_keyword_timeout] = ACTIONS(256),
    [sym_keyword_fetch] = ACTIONS(256),
    [sym_keyword_limit] = ACTIONS(256),
    [sym_keyword_rand] = ACTIONS(256),
    [sym_keyword_collate] = ACTIONS(256),
    [sym_keyword_numeric] = ACTIONS(256),
    [sym_keyword_asc] = ACTIONS(256),
    [sym_keyword_desc] = ACTIONS(256),
    [sym_keyword_where] = ACTIONS(256),
    [sym_keyword_group] = ACTIONS(256),
    [sym_keyword_and] = ACTIONS(256),
    [sym_keyword_or] = ACTIONS(256),
    [sym_keyword_is] = ACTIONS(256),
    [sym_keyword_not] = ACTIONS(258),
    [sym_keyword_contains] = ACTIONS(258),
    [sym_keyword_contains_not] = ACTIONS(256),
    [sym_keyword_contains_all] = ACTIONS(256),
    [sym_keyword_contains_any] = ACTIONS(256),
    [sym_keyword_contains_none] = ACTIONS(256),
    [sym_keyword_inside] = ACTIONS(256),
    [sym_keyword_in] = ACTIONS(258),
    [sym_keyword_not_inside] = ACTIONS(256),
    [sym_keyword_all_inside] = ACTIONS(256),
    [sym_keyword_any_inside] = ACTIONS(256),
    [sym_keyword_none_inside] = ACTIONS(256),
    [sym_keyword_outside] = ACTIONS(256),
    [sym_keyword_intersects] = ACTIONS(256),
    [sym_keyword_drop] = ACTIONS(256),
    [sym_keyword_schemafull] = ACTIONS(256),
    [sym_keyword_schemaless] = ACTIONS(256),
    [sym_keyword_flexible] = ACTIONS(256),
    [sym_keyword_readonly] = ACTIONS(256),
    [sym_keyword_changefeed] = ACTIONS(256),
    [sym_keyword_content] = ACTIONS(256),
    [sym_keyword_merge] = ACTIONS(256),
    [sym_keyword_patch] = ACTIONS(256),
    [sym_keyword_replace] = ACTIONS(256),
    [sym_keyword_type] = ACTIONS(256),
    [sym_keyword_default] = ACTIONS(256),
    [sym_keyword_assert] = ACTIONS(256),
    [sym_keyword_permissions] = ACTIONS(256),
    [sym_keyword_for] = ACTIONS(256),
    [sym_keyword_comment] = ACTIONS(256),
    [sym_keyword_unset] = ACTIONS(256),
    [sym_keyword_set] = ACTIONS(256),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_COMMA] = ACTIONS(256),
    [anon_sym_RPAREN] = ACTIONS(256),
    [anon_sym_DASH_GT] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(256),
    [anon_sym_RBRACE] = ACTIONS(256),
    [anon_sym_LT] = ACTIONS(258),
    [anon_sym_GT] = ACTIONS(258),
    [anon_sym_LT_DASH] = ACTIONS(258),
    [anon_sym_LT_DASH_GT] = ACTIONS(256),
    [anon_sym_STAR] = ACTIONS(258),
    [anon_sym_DOT] = ACTIONS(258),
    [anon_sym_DOT_DOT] = ACTIONS(256),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_PERCENT] = ACTIONS(256),
    [anon_sym_AT] = ACTIONS(258),
    [anon_sym_LT_PIPE] = ACTIONS(256),
    [anon_sym_AMP_AMP] = ACTIONS(256),
    [anon_sym_PIPE_PIPE] = ACTIONS(256),
    [anon_sym_QMARK_QMARK] = ACTIONS(256),
    [anon_sym_QMARK_COLON] = ACTIONS(256),
    [anon_sym_BANG_EQ] = ACTIONS(256),
    [anon_sym_EQ_EQ] = ACTIONS(256),
    [anon_sym_QMARK_EQ] = ACTIONS(256),
    [anon_sym_STAR_EQ] = ACTIONS(256),
    [anon_sym_TILDE] = ACTIONS(256),
    [anon_sym_BANG_TILDE] = ACTIONS(256),
    [anon_sym_STAR_TILDE] = ACTIONS(256),
    [anon_sym_LT_EQ] = ACTIONS(256),
    [anon_sym_GT_EQ] = ACTIONS(256),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_PLUS_EQ] = ACTIONS(256),
    [anon_sym_DASH_EQ] = ACTIONS(256),
    [anon_sym_u00d7] = ACTIONS(256),
    [anon_sym_SLASH] = ACTIONS(258),
    [anon_sym_u00f7] = ACTIONS(256),
    [anon_sym_STAR_STAR] = ACTIONS(256),
    [anon_sym_u220b] = ACTIONS(256),
    [anon_sym_u220c] = ACTIONS(256),
    [anon_sym_u2287] = ACTIONS(256),
    [anon_sym_u2283] = ACTIONS(256),
    [anon_sym_u2285] = ACTIONS(256),
    [anon_sym_u2208] = ACTIONS(256),
    [anon_sym_u2209] = ACTIONS(256),
    [anon_sym_u2286] = ACTIONS(256),
    [anon_sym_u2282] = ACTIONS(256),
    [anon_sym_u2284] = ACTIONS(256),
    [anon_sym_AT_AT] = ACTIONS(256),
  },
  [STATE(33)] = {
    [ts_builtin_sym_end] = ACTIONS(260),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(260),
    [sym_keyword_return] = ACTIONS(260),
    [sym_keyword_value] = ACTIONS(260),
    [sym_keyword_explain] = ACTIONS(260),
    [sym_keyword_parallel] = ACTIONS(260),
    [sym_keyword_timeout] = ACTIONS(260),
    [sym_keyword_fetch] = ACTIONS(260),
    [sym_keyword_limit] = ACTIONS(260),
    [sym_keyword_rand] = ACTIONS(260),
    [sym_keyword_collate] = ACTIONS(260),
    [sym_keyword_numeric] = ACTIONS(260),
    [sym_keyword_asc] = ACTIONS(260),
    [sym_keyword_desc] = ACTIONS(260),
    [sym_keyword_where] = ACTIONS(260),
    [sym_keyword_group] = ACTIONS(260),
    [sym_keyword_and] = ACTIONS(260),
    [sym_keyword_or] = ACTIONS(260),
    [sym_keyword_is] = ACTIONS(260),
    [sym_keyword_not] = ACTIONS(262),
    [sym_keyword_contains] = ACTIONS(262),
    [sym_keyword_contains_not] = ACTIONS(260),
    [sym_keyword_contains_all] = ACTIONS(260),
    [sym_keyword_contains_any] = ACTIONS(260),
    [sym_keyword_contains_none] = ACTIONS(260),
    [sym_keyword_inside] = ACTIONS(260),
    [sym_keyword_in] = ACTIONS(262),
    [sym_keyword_not_inside] = ACTIONS(260),
    [sym_keyword_all_inside] = ACTIONS(260),
    [sym_keyword_any_inside] = ACTIONS(260),
    [sym_keyword_none_inside] = ACTIONS(260),
    [sym_keyword_outside] = ACTIONS(260),
    [sym_keyword_intersects] = ACTIONS(260),
    [sym_keyword_drop] = ACTIONS(260),
    [sym_keyword_schemafull] = ACTIONS(260),
    [sym_keyword_schemaless] = ACTIONS(260),
    [sym_keyword_flexible] = ACTIONS(260),
    [sym_keyword_readonly] = ACTIONS(260),
    [sym_keyword_changefeed] = ACTIONS(260),
    [sym_keyword_content] = ACTIONS(260),
    [sym_keyword_merge] = ACTIONS(260),
    [sym_keyword_patch] = ACTIONS(260),
    [sym_keyword_replace] = ACTIONS(260),
    [sym_keyword_type] = ACTIONS(260),
    [sym_keyword_default] = ACTIONS(260),
    [sym_keyword_assert] = ACTIONS(260),
    [sym_keyword_permissions] = ACTIONS(260),
    [sym_keyword_for] = ACTIONS(260),
    [sym_keyword_comment] = ACTIONS(260),
    [sym_keyword_unset] = ACTIONS(260),
    [sym_keyword_set] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(262),
    [anon_sym_COMMA] = ACTIONS(260),
    [anon_sym_RPAREN] = ACTIONS(260),
    [anon_sym_DASH_GT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(260),
    [anon_sym_RBRACE] = ACTIONS(260),
    [anon_sym_LT] = ACTIONS(262),
    [anon_sym_GT] = ACTIONS(262),
    [anon_sym_LT_DASH] = ACTIONS(262),
    [anon_sym_LT_DASH_GT] = ACTIONS(260),
    [anon_sym_STAR] = ACTIONS(262),
    [anon_sym_DOT] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(262),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_AT] = ACTIONS(262),
    [anon_sym_LT_PIPE] = ACTIONS(260),
    [anon_sym_AMP_AMP] = ACTIONS(260),
    [anon_sym_PIPE_PIPE] = ACTIONS(260),
    [anon_sym_QMARK_QMARK] = ACTIONS(260),
    [anon_sym_QMARK_COLON] = ACTIONS(260),
    [anon_sym_BANG_EQ] = ACTIONS(260),
    [anon_sym_EQ_EQ] = ACTIONS(260),
    [anon_sym_QMARK_EQ] = ACTIONS(260),
    [anon_sym_STAR_EQ] = ACTIONS(260),
    [anon_sym_TILDE] = ACTIONS(260),
    [anon_sym_BANG_TILDE] = ACTIONS(260),
    [anon_sym_STAR_TILDE] = ACTIONS(260),
    [anon_sym_LT_EQ] = ACTIONS(260),
    [anon_sym_GT_EQ] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(262),
    [anon_sym_PLUS_EQ] = ACTIONS(260),
    [anon_sym_DASH_EQ] = ACTIONS(260),
    [anon_sym_u00d7] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(262),
    [anon_sym_u00f7] = ACTIONS(260),
    [anon_sym_STAR_STAR] = ACTIONS(260),
    [anon_sym_u220b] = ACTIONS(260),
    [anon_sym_u220c] = ACTIONS(260),
    [anon_sym_u2287] = ACTIONS(260),
    [anon_sym_u2283] = ACTIONS(260),
    [anon_sym_u2285] = ACTIONS(260),
    [anon_sym_u2208] = ACTIONS(260),
    [anon_sym_u2209] = ACTIONS(260),
    [anon_sym_u2286] = ACTIONS(260),
    [anon_sym_u2282] = ACTIONS(260),
    [anon_sym_u2284] = ACTIONS(260),
    [anon_sym_AT_AT] = ACTIONS(260),
  },
  [STATE(34)] = {
    [ts_builtin_sym_end] = ACTIONS(264),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_return] = ACTIONS(264),
    [sym_keyword_value] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_rand] = ACTIONS(264),
    [sym_keyword_collate] = ACTIONS(264),
    [sym_keyword_numeric] = ACTIONS(264),
    [sym_keyword_asc] = ACTIONS(264),
    [sym_keyword_desc] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(264),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [sym_keyword_drop] = ACTIONS(264),
    [sym_keyword_schemafull] = ACTIONS(264),
    [sym_keyword_schemaless] = ACTIONS(264),
    [sym_keyword_flexible] = ACTIONS(264),
    [sym_keyword_readonly] = ACTIONS(264),
    [sym_keyword_changefeed] = ACTIONS(264),
    [sym_keyword_content] = ACTIONS(264),
    [sym_keyword_merge] = ACTIONS(264),
    [sym_keyword_patch] = ACTIONS(264),
    [sym_keyword_replace] = ACTIONS(264),
    [sym_keyword_type] = ACTIONS(264),
    [sym_keyword_default] = ACTIONS(264),
    [sym_keyword_assert] = ACTIONS(264),
    [sym_keyword_permissions] = ACTIONS(264),
    [sym_keyword_for] = ACTIONS(264),
    [sym_keyword_comment] = ACTIONS(264),
    [sym_keyword_unset] = ACTIONS(264),
    [sym_keyword_set] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(266),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(35)] = {
    [ts_builtin_sym_end] = ACTIONS(264),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_return] = ACTIONS(264),
    [sym_keyword_value] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_rand] = ACTIONS(264),
    [sym_keyword_collate] = ACTIONS(264),
    [sym_keyword_numeric] = ACTIONS(264),
    [sym_keyword_asc] = ACTIONS(264),
    [sym_keyword_desc] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(264),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [sym_keyword_drop] = ACTIONS(264),
    [sym_keyword_schemafull] = ACTIONS(264),
    [sym_keyword_schemaless] = ACTIONS(264),
    [sym_keyword_flexible] = ACTIONS(264),
    [sym_keyword_readonly] = ACTIONS(264),
    [sym_keyword_changefeed] = ACTIONS(264),
    [sym_keyword_content] = ACTIONS(264),
    [sym_keyword_merge] = ACTIONS(264),
    [sym_keyword_patch] = ACTIONS(264),
    [sym_keyword_replace] = ACTIONS(264),
    [sym_keyword_type] = ACTIONS(264),
    [sym_keyword_default] = ACTIONS(264),
    [sym_keyword_assert] = ACTIONS(264),
    [sym_keyword_permissions] = ACTIONS(264),
    [sym_keyword_for] = ACTIONS(264),
    [sym_keyword_comment] = ACTIONS(264),
    [sym_keyword_unset] = ACTIONS(264),
    [sym_keyword_set] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(268),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(36)] = {
    [ts_builtin_sym_end] = ACTIONS(270),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(270),
    [sym_keyword_return] = ACTIONS(270),
    [sym_keyword_value] = ACTIONS(270),
    [sym_keyword_explain] = ACTIONS(270),
    [sym_keyword_parallel] = ACTIONS(270),
    [sym_keyword_timeout] = ACTIONS(270),
    [sym_keyword_fetch] = ACTIONS(270),
    [sym_keyword_limit] = ACTIONS(270),
    [sym_keyword_rand] = ACTIONS(270),
    [sym_keyword_collate] = ACTIONS(270),
    [sym_keyword_numeric] = ACTIONS(270),
    [sym_keyword_asc] = ACTIONS(270),
    [sym_keyword_desc] = ACTIONS(270),
    [sym_keyword_where] = ACTIONS(270),
    [sym_keyword_group] = ACTIONS(270),
    [sym_keyword_and] = ACTIONS(270),
    [sym_keyword_or] = ACTIONS(270),
    [sym_keyword_is] = ACTIONS(270),
    [sym_keyword_not] = ACTIONS(272),
    [sym_keyword_contains] = ACTIONS(272),
    [sym_keyword_contains_not] = ACTIONS(270),
    [sym_keyword_contains_all] = ACTIONS(270),
    [sym_keyword_contains_any] = ACTIONS(270),
    [sym_keyword_contains_none] = ACTIONS(270),
    [sym_keyword_inside] = ACTIONS(270),
    [sym_keyword_in] = ACTIONS(272),
    [sym_keyword_not_inside] = ACTIONS(270),
    [sym_keyword_all_inside] = ACTIONS(270),
    [sym_keyword_any_inside] = ACTIONS(270),
    [sym_keyword_none_inside] = ACTIONS(270),
    [sym_keyword_outside] = ACTIONS(270),
    [sym_keyword_intersects] = ACTIONS(270),
    [sym_keyword_drop] = ACTIONS(270),
    [sym_keyword_schemafull] = ACTIONS(270),
    [sym_keyword_schemaless] = ACTIONS(270),
    [sym_keyword_flexible] = ACTIONS(270),
    [sym_keyword_readonly] = ACTIONS(270),
    [sym_keyword_changefeed] = ACTIONS(270),
    [sym_keyword_content] = ACTIONS(270),
    [sym_keyword_merge] = ACTIONS(270),
    [sym_keyword_patch] = ACTIONS(270),
    [sym_keyword_replace] = ACTIONS(270),
    [sym_keyword_type] = ACTIONS(270),
    [sym_keyword_default] = ACTIONS(270),
    [sym_keyword_assert] = ACTIONS(270),
    [sym_keyword_permissions] = ACTIONS(270),
    [sym_keyword_for] = ACTIONS(270),
    [sym_keyword_comment] = ACTIONS(270),
    [sym_keyword_unset] = ACTIONS(270),
    [sym_keyword_set] = ACTIONS(270),
    [anon_sym_EQ] = ACTIONS(272),
    [anon_sym_COMMA] = ACTIONS(270),
    [anon_sym_RPAREN] = ACTIONS(270),
    [anon_sym_DASH_GT] = ACTIONS(270),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_RBRACE] = ACTIONS(270),
    [anon_sym_LT] = ACTIONS(272),
    [anon_sym_GT] = ACTIONS(272),
    [anon_sym_LT_DASH] = ACTIONS(272),
    [anon_sym_LT_DASH_GT] = ACTIONS(270),
    [anon_sym_STAR] = ACTIONS(272),
    [anon_sym_DOT] = ACTIONS(270),
    [anon_sym_DASH] = ACTIONS(272),
    [anon_sym_PERCENT] = ACTIONS(270),
    [anon_sym_AT] = ACTIONS(272),
    [anon_sym_LT_PIPE] = ACTIONS(270),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_PIPE_PIPE] = ACTIONS(270),
    [anon_sym_QMARK_QMARK] = ACTIONS(270),
    [anon_sym_QMARK_COLON] = ACTIONS(270),
    [anon_sym_BANG_EQ] = ACTIONS(270),
    [anon_sym_EQ_EQ] = ACTIONS(270),
    [anon_sym_QMARK_EQ] = ACTIONS(270),
    [anon_sym_STAR_EQ] = ACTIONS(270),
    [anon_sym_TILDE] = ACTIONS(270),
    [anon_sym_BANG_TILDE] = ACTIONS(270),
    [anon_sym_STAR_TILDE] = ACTIONS(270),
    [anon_sym_LT_EQ] = ACTIONS(270),
    [anon_sym_GT_EQ] = ACTIONS(270),
    [anon_sym_PLUS] = ACTIONS(272),
    [anon_sym_PLUS_EQ] = ACTIONS(270),
    [anon_sym_DASH_EQ] = ACTIONS(270),
    [anon_sym_u00d7] = ACTIONS(270),
    [anon_sym_SLASH] = ACTIONS(272),
    [anon_sym_u00f7] = ACTIONS(270),
    [anon_sym_STAR_STAR] = ACTIONS(270),
    [anon_sym_u220b] = ACTIONS(270),
    [anon_sym_u220c] = ACTIONS(270),
    [anon_sym_u2287] = ACTIONS(270),
    [anon_sym_u2283] = ACTIONS(270),
    [anon_sym_u2285] = ACTIONS(270),
    [anon_sym_u2208] = ACTIONS(270),
    [anon_sym_u2209] = ACTIONS(270),
    [anon_sym_u2286] = ACTIONS(270),
    [anon_sym_u2282] = ACTIONS(270),
    [anon_sym_u2284] = ACTIONS(270),
    [anon_sym_AT_AT] = ACTIONS(270),
  },
  [STATE(37)] = {
    [ts_builtin_sym_end] = ACTIONS(274),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(274),
    [sym_keyword_return] = ACTIONS(274),
    [sym_keyword_value] = ACTIONS(274),
    [sym_keyword_explain] = ACTIONS(274),
    [sym_keyword_parallel] = ACTIONS(274),
    [sym_keyword_timeout] = ACTIONS(274),
    [sym_keyword_fetch] = ACTIONS(274),
    [sym_keyword_limit] = ACTIONS(274),
    [sym_keyword_rand] = ACTIONS(274),
    [sym_keyword_collate] = ACTIONS(274),
    [sym_keyword_numeric] = ACTIONS(274),
    [sym_keyword_asc] = ACTIONS(274),
    [sym_keyword_desc] = ACTIONS(274),
    [sym_keyword_where] = ACTIONS(274),
    [sym_keyword_group] = ACTIONS(274),
    [sym_keyword_and] = ACTIONS(274),
    [sym_keyword_or] = ACTIONS(274),
    [sym_keyword_is] = ACTIONS(274),
    [sym_keyword_not] = ACTIONS(276),
    [sym_keyword_contains] = ACTIONS(276),
    [sym_keyword_contains_not] = ACTIONS(274),
    [sym_keyword_contains_all] = ACTIONS(274),
    [sym_keyword_contains_any] = ACTIONS(274),
    [sym_keyword_contains_none] = ACTIONS(274),
    [sym_keyword_inside] = ACTIONS(274),
    [sym_keyword_in] = ACTIONS(276),
    [sym_keyword_not_inside] = ACTIONS(274),
    [sym_keyword_all_inside] = ACTIONS(274),
    [sym_keyword_any_inside] = ACTIONS(274),
    [sym_keyword_none_inside] = ACTIONS(274),
    [sym_keyword_outside] = ACTIONS(274),
    [sym_keyword_intersects] = ACTIONS(274),
    [sym_keyword_drop] = ACTIONS(274),
    [sym_keyword_schemafull] = ACTIONS(274),
    [sym_keyword_schemaless] = ACTIONS(274),
    [sym_keyword_flexible] = ACTIONS(274),
    [sym_keyword_readonly] = ACTIONS(274),
    [sym_keyword_changefeed] = ACTIONS(274),
    [sym_keyword_content] = ACTIONS(274),
    [sym_keyword_merge] = ACTIONS(274),
    [sym_keyword_patch] = ACTIONS(274),
    [sym_keyword_replace] = ACTIONS(274),
    [sym_keyword_type] = ACTIONS(274),
    [sym_keyword_default] = ACTIONS(274),
    [sym_keyword_assert] = ACTIONS(274),
    [sym_keyword_permissions] = ACTIONS(274),
    [sym_keyword_for] = ACTIONS(274),
    [sym_keyword_comment] = ACTIONS(274),
    [sym_keyword_unset] = ACTIONS(274),
    [sym_keyword_set] = ACTIONS(274),
    [anon_sym_EQ] = ACTIONS(276),
    [anon_sym_COMMA] = ACTIONS(274),
    [anon_sym_RPAREN] = ACTIONS(274),
    [anon_sym_DASH_GT] = ACTIONS(274),
    [anon_sym_LBRACK] = ACTIONS(274),
    [anon_sym_RBRACE] = ACTIONS(274),
    [anon_sym_LT] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(276),
    [anon_sym_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_DASH_GT] = ACTIONS(274),
    [anon_sym_STAR] = ACTIONS(276),
    [anon_sym_DOT] = ACTIONS(274),
    [anon_sym_DASH] = ACTIONS(276),
    [anon_sym_PERCENT] = ACTIONS(274),
    [anon_sym_AT] = ACTIONS(276),
    [anon_sym_LT_PIPE] = ACTIONS(274),
    [anon_sym_AMP_AMP] = ACTIONS(274),
    [anon_sym_PIPE_PIPE] = ACTIONS(274),
    [anon_sym_QMARK_QMARK] = ACTIONS(274),
    [anon_sym_QMARK_COLON] = ACTIONS(274),
    [anon_sym_BANG_EQ] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(274),
    [anon_sym_QMARK_EQ] = ACTIONS(274),
    [anon_sym_STAR_EQ] = ACTIONS(274),
    [anon_sym_TILDE] = ACTIONS(274),
    [anon_sym_BANG_TILDE] = ACTIONS(274),
    [anon_sym_STAR_TILDE] = ACTIONS(274),
    [anon_sym_LT_EQ] = ACTIONS(274),
    [anon_sym_GT_EQ] = ACTIONS(274),
    [anon_sym_PLUS] = ACTIONS(276),
    [anon_sym_PLUS_EQ] = ACTIONS(274),
    [anon_sym_DASH_EQ] = ACTIONS(274),
    [anon_sym_u00d7] = ACTIONS(274),
    [anon_sym_SLASH] = ACTIONS(276),
    [anon_sym_u00f7] = ACTIONS(274),
    [anon_sym_STAR_STAR] = ACTIONS(274),
    [anon_sym_u220b] = ACTIONS(274),
    [anon_sym_u220c] = ACTIONS(274),
    [anon_sym_u2287] = ACTIONS(274),
    [anon_sym_u2283] = ACTIONS(274),
    [anon_sym_u2285] = ACTIONS(274),
    [anon_sym_u2208] = ACTIONS(274),
    [anon_sym_u2209] = ACTIONS(274),
    [anon_sym_u2286] = ACTIONS(274),
    [anon_sym_u2282] = ACTIONS(274),
    [anon_sym_u2284] = ACTIONS(274),
    [anon_sym_AT_AT] = ACTIONS(274),
  },
  [STATE(38)] = {
    [sym_argument_list] = STATE(65),
    [ts_builtin_sym_end] = ACTIONS(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_return] = ACTIONS(278),
    [sym_keyword_value] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_rand] = ACTIONS(278),
    [sym_keyword_collate] = ACTIONS(278),
    [sym_keyword_numeric] = ACTIONS(278),
    [sym_keyword_asc] = ACTIONS(278),
    [sym_keyword_desc] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(278),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [sym_keyword_drop] = ACTIONS(278),
    [sym_keyword_schemafull] = ACTIONS(278),
    [sym_keyword_schemaless] = ACTIONS(278),
    [sym_keyword_flexible] = ACTIONS(278),
    [sym_keyword_readonly] = ACTIONS(278),
    [sym_keyword_changefeed] = ACTIONS(278),
    [sym_keyword_content] = ACTIONS(278),
    [sym_keyword_merge] = ACTIONS(278),
    [sym_keyword_patch] = ACTIONS(278),
    [sym_keyword_replace] = ACTIONS(278),
    [sym_keyword_type] = ACTIONS(278),
    [sym_keyword_default] = ACTIONS(278),
    [sym_keyword_assert] = ACTIONS(278),
    [sym_keyword_permissions] = ACTIONS(278),
    [sym_keyword_for] = ACTIONS(278),
    [sym_keyword_comment] = ACTIONS(278),
    [sym_keyword_unset] = ACTIONS(278),
    [sym_keyword_set] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_LPAREN] = ACTIONS(282),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(39)] = {
    [ts_builtin_sym_end] = ACTIONS(284),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(284),
    [sym_keyword_return] = ACTIONS(284),
    [sym_keyword_value] = ACTIONS(284),
    [sym_keyword_explain] = ACTIONS(284),
    [sym_keyword_parallel] = ACTIONS(284),
    [sym_keyword_timeout] = ACTIONS(284),
    [sym_keyword_fetch] = ACTIONS(284),
    [sym_keyword_limit] = ACTIONS(284),
    [sym_keyword_rand] = ACTIONS(284),
    [sym_keyword_collate] = ACTIONS(284),
    [sym_keyword_numeric] = ACTIONS(284),
    [sym_keyword_asc] = ACTIONS(284),
    [sym_keyword_desc] = ACTIONS(284),
    [sym_keyword_where] = ACTIONS(284),
    [sym_keyword_group] = ACTIONS(284),
    [sym_keyword_and] = ACTIONS(284),
    [sym_keyword_or] = ACTIONS(284),
    [sym_keyword_is] = ACTIONS(284),
    [sym_keyword_not] = ACTIONS(286),
    [sym_keyword_contains] = ACTIONS(286),
    [sym_keyword_contains_not] = ACTIONS(284),
    [sym_keyword_contains_all] = ACTIONS(284),
    [sym_keyword_contains_any] = ACTIONS(284),
    [sym_keyword_contains_none] = ACTIONS(284),
    [sym_keyword_inside] = ACTIONS(284),
    [sym_keyword_in] = ACTIONS(286),
    [sym_keyword_not_inside] = ACTIONS(284),
    [sym_keyword_all_inside] = ACTIONS(284),
    [sym_keyword_any_inside] = ACTIONS(284),
    [sym_keyword_none_inside] = ACTIONS(284),
    [sym_keyword_outside] = ACTIONS(284),
    [sym_keyword_intersects] = ACTIONS(284),
    [sym_keyword_drop] = ACTIONS(284),
    [sym_keyword_schemafull] = ACTIONS(284),
    [sym_keyword_schemaless] = ACTIONS(284),
    [sym_keyword_flexible] = ACTIONS(284),
    [sym_keyword_readonly] = ACTIONS(284),
    [sym_keyword_changefeed] = ACTIONS(284),
    [sym_keyword_content] = ACTIONS(284),
    [sym_keyword_merge] = ACTIONS(284),
    [sym_keyword_patch] = ACTIONS(284),
    [sym_keyword_replace] = ACTIONS(284),
    [sym_keyword_type] = ACTIONS(284),
    [sym_keyword_default] = ACTIONS(284),
    [sym_keyword_assert] = ACTIONS(284),
    [sym_keyword_permissions] = ACTIONS(284),
    [sym_keyword_for] = ACTIONS(284),
    [sym_keyword_comment] = ACTIONS(284),
    [sym_keyword_unset] = ACTIONS(284),
    [sym_keyword_set] = ACTIONS(284),
    [anon_sym_EQ] = ACTIONS(286),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_DASH_GT] = ACTIONS(284),
    [anon_sym_LBRACK] = ACTIONS(284),
    [anon_sym_RBRACE] = ACTIONS(284),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_LT_DASH] = ACTIONS(286),
    [anon_sym_LT_DASH_GT] = ACTIONS(284),
    [anon_sym_STAR] = ACTIONS(286),
    [anon_sym_DOT] = ACTIONS(284),
    [anon_sym_DASH] = ACTIONS(286),
    [anon_sym_PERCENT] = ACTIONS(284),
    [anon_sym_AT] = ACTIONS(286),
    [anon_sym_LT_PIPE] = ACTIONS(284),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_PIPE_PIPE] = ACTIONS(284),
    [anon_sym_QMARK_QMARK] = ACTIONS(284),
    [anon_sym_QMARK_COLON] = ACTIONS(284),
    [anon_sym_BANG_EQ] = ACTIONS(284),
    [anon_sym_EQ_EQ] = ACTIONS(284),
    [anon_sym_QMARK_EQ] = ACTIONS(284),
    [anon_sym_STAR_EQ] = ACTIONS(284),
    [anon_sym_TILDE] = ACTIONS(284),
    [anon_sym_BANG_TILDE] = ACTIONS(284),
    [anon_sym_STAR_TILDE] = ACTIONS(284),
    [anon_sym_LT_EQ] = ACTIONS(284),
    [anon_sym_GT_EQ] = ACTIONS(284),
    [anon_sym_PLUS] = ACTIONS(286),
    [anon_sym_PLUS_EQ] = ACTIONS(284),
    [anon_sym_DASH_EQ] = ACTIONS(284),
    [anon_sym_u00d7] = ACTIONS(284),
    [anon_sym_SLASH] = ACTIONS(286),
    [anon_sym_u00f7] = ACTIONS(284),
    [anon_sym_STAR_STAR] = ACTIONS(284),
    [anon_sym_u220b] = ACTIONS(284),
    [anon_sym_u220c] = ACTIONS(284),
    [anon_sym_u2287] = ACTIONS(284),
    [anon_sym_u2283] = ACTIONS(284),
    [anon_sym_u2285] = ACTIONS(284),
    [anon_sym_u2208] = ACTIONS(284),
    [anon_sym_u2209] = ACTIONS(284),
    [anon_sym_u2286] = ACTIONS(284),
    [anon_sym_u2282] = ACTIONS(284),
    [anon_sym_u2284] = ACTIONS(284),
    [anon_sym_AT_AT] = ACTIONS(284),
  },
  [STATE(40)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_value] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_rand] = ACTIONS(288),
    [sym_keyword_collate] = ACTIONS(288),
    [sym_keyword_numeric] = ACTIONS(288),
    [sym_keyword_asc] = ACTIONS(288),
    [sym_keyword_desc] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_drop] = ACTIONS(288),
    [sym_keyword_schemafull] = ACTIONS(288),
    [sym_keyword_schemaless] = ACTIONS(288),
    [sym_keyword_flexible] = ACTIONS(288),
    [sym_keyword_readonly] = ACTIONS(288),
    [sym_keyword_changefeed] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_merge] = ACTIONS(288),
    [sym_keyword_patch] = ACTIONS(288),
    [sym_keyword_replace] = ACTIONS(288),
    [sym_keyword_type] = ACTIONS(288),
    [sym_keyword_default] = ACTIONS(288),
    [sym_keyword_assert] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [sym_keyword_unset] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(290),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(288),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(41)] = {
    [ts_builtin_sym_end] = ACTIONS(292),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(292),
    [sym_keyword_return] = ACTIONS(292),
    [sym_keyword_value] = ACTIONS(292),
    [sym_keyword_explain] = ACTIONS(292),
    [sym_keyword_parallel] = ACTIONS(292),
    [sym_keyword_timeout] = ACTIONS(292),
    [sym_keyword_fetch] = ACTIONS(292),
    [sym_keyword_limit] = ACTIONS(292),
    [sym_keyword_rand] = ACTIONS(292),
    [sym_keyword_collate] = ACTIONS(292),
    [sym_keyword_numeric] = ACTIONS(292),
    [sym_keyword_asc] = ACTIONS(292),
    [sym_keyword_desc] = ACTIONS(292),
    [sym_keyword_where] = ACTIONS(292),
    [sym_keyword_group] = ACTIONS(292),
    [sym_keyword_and] = ACTIONS(292),
    [sym_keyword_or] = ACTIONS(292),
    [sym_keyword_is] = ACTIONS(292),
    [sym_keyword_not] = ACTIONS(294),
    [sym_keyword_contains] = ACTIONS(294),
    [sym_keyword_contains_not] = ACTIONS(292),
    [sym_keyword_contains_all] = ACTIONS(292),
    [sym_keyword_contains_any] = ACTIONS(292),
    [sym_keyword_contains_none] = ACTIONS(292),
    [sym_keyword_inside] = ACTIONS(292),
    [sym_keyword_in] = ACTIONS(294),
    [sym_keyword_not_inside] = ACTIONS(292),
    [sym_keyword_all_inside] = ACTIONS(292),
    [sym_keyword_any_inside] = ACTIONS(292),
    [sym_keyword_none_inside] = ACTIONS(292),
    [sym_keyword_outside] = ACTIONS(292),
    [sym_keyword_intersects] = ACTIONS(292),
    [sym_keyword_drop] = ACTIONS(292),
    [sym_keyword_schemafull] = ACTIONS(292),
    [sym_keyword_schemaless] = ACTIONS(292),
    [sym_keyword_flexible] = ACTIONS(292),
    [sym_keyword_readonly] = ACTIONS(292),
    [sym_keyword_changefeed] = ACTIONS(292),
    [sym_keyword_content] = ACTIONS(292),
    [sym_keyword_merge] = ACTIONS(292),
    [sym_keyword_patch] = ACTIONS(292),
    [sym_keyword_replace] = ACTIONS(292),
    [sym_keyword_type] = ACTIONS(292),
    [sym_keyword_default] = ACTIONS(292),
    [sym_keyword_assert] = ACTIONS(292),
    [sym_keyword_permissions] = ACTIONS(292),
    [sym_keyword_for] = ACTIONS(292),
    [sym_keyword_comment] = ACTIONS(292),
    [sym_keyword_unset] = ACTIONS(292),
    [sym_keyword_set] = ACTIONS(292),
    [anon_sym_EQ] = ACTIONS(294),
    [anon_sym_COMMA] = ACTIONS(292),
    [anon_sym_RPAREN] = ACTIONS(292),
    [anon_sym_DASH_GT] = ACTIONS(292),
    [anon_sym_LBRACK] = ACTIONS(292),
    [anon_sym_RBRACE] = ACTIONS(292),
    [anon_sym_LT] = ACTIONS(294),
    [anon_sym_GT] = ACTIONS(294),
    [anon_sym_LT_DASH] = ACTIONS(294),
    [anon_sym_LT_DASH_GT] = ACTIONS(292),
    [anon_sym_STAR] = ACTIONS(294),
    [anon_sym_DOT] = ACTIONS(292),
    [anon_sym_DASH] = ACTIONS(294),
    [anon_sym_PERCENT] = ACTIONS(292),
    [anon_sym_AT] = ACTIONS(294),
    [anon_sym_LT_PIPE] = ACTIONS(292),
    [anon_sym_AMP_AMP] = ACTIONS(292),
    [anon_sym_PIPE_PIPE] = ACTIONS(292),
    [anon_sym_QMARK_QMARK] = ACTIONS(292),
    [anon_sym_QMARK_COLON] = ACTIONS(292),
    [anon_sym_BANG_EQ] = ACTIONS(292),
    [anon_sym_EQ_EQ] = ACTIONS(292),
    [anon_sym_QMARK_EQ] = ACTIONS(292),
    [anon_sym_STAR_EQ] = ACTIONS(292),
    [anon_sym_TILDE] = ACTIONS(292),
    [anon_sym_BANG_TILDE] = ACTIONS(292),
    [anon_sym_STAR_TILDE] = ACTIONS(292),
    [anon_sym_LT_EQ] = ACTIONS(292),
    [anon_sym_GT_EQ] = ACTIONS(292),
    [anon_sym_PLUS] = ACTIONS(294),
    [anon_sym_PLUS_EQ] = ACTIONS(292),
    [anon_sym_DASH_EQ] = ACTIONS(292),
    [anon_sym_u00d7] = ACTIONS(292),
    [anon_sym_SLASH] = ACTIONS(294),
    [anon_sym_u00f7] = ACTIONS(292),
    [anon_sym_STAR_STAR] = ACTIONS(292),
    [anon_sym_u220b] = ACTIONS(292),
    [anon_sym_u220c] = ACTIONS(292),
    [anon_sym_u2287] = ACTIONS(292),
    [anon_sym_u2283] = ACTIONS(292),
    [anon_sym_u2285] = ACTIONS(292),
    [anon_sym_u2208] = ACTIONS(292),
    [anon_sym_u2209] = ACTIONS(292),
    [anon_sym_u2286] = ACTIONS(292),
    [anon_sym_u2282] = ACTIONS(292),
    [anon_sym_u2284] = ACTIONS(292),
    [anon_sym_AT_AT] = ACTIONS(292),
  },
  [STATE(42)] = {
    [ts_builtin_sym_end] = ACTIONS(296),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(296),
    [sym_keyword_return] = ACTIONS(296),
    [sym_keyword_value] = ACTIONS(296),
    [sym_keyword_explain] = ACTIONS(296),
    [sym_keyword_parallel] = ACTIONS(296),
    [sym_keyword_timeout] = ACTIONS(296),
    [sym_keyword_fetch] = ACTIONS(296),
    [sym_keyword_limit] = ACTIONS(296),
    [sym_keyword_rand] = ACTIONS(296),
    [sym_keyword_collate] = ACTIONS(296),
    [sym_keyword_numeric] = ACTIONS(296),
    [sym_keyword_asc] = ACTIONS(296),
    [sym_keyword_desc] = ACTIONS(296),
    [sym_keyword_where] = ACTIONS(296),
    [sym_keyword_group] = ACTIONS(296),
    [sym_keyword_and] = ACTIONS(296),
    [sym_keyword_or] = ACTIONS(296),
    [sym_keyword_is] = ACTIONS(296),
    [sym_keyword_not] = ACTIONS(298),
    [sym_keyword_contains] = ACTIONS(298),
    [sym_keyword_contains_not] = ACTIONS(296),
    [sym_keyword_contains_all] = ACTIONS(296),
    [sym_keyword_contains_any] = ACTIONS(296),
    [sym_keyword_contains_none] = ACTIONS(296),
    [sym_keyword_inside] = ACTIONS(296),
    [sym_keyword_in] = ACTIONS(298),
    [sym_keyword_not_inside] = ACTIONS(296),
    [sym_keyword_all_inside] = ACTIONS(296),
    [sym_keyword_any_inside] = ACTIONS(296),
    [sym_keyword_none_inside] = ACTIONS(296),
    [sym_keyword_outside] = ACTIONS(296),
    [sym_keyword_intersects] = ACTIONS(296),
    [sym_keyword_drop] = ACTIONS(296),
    [sym_keyword_schemafull] = ACTIONS(296),
    [sym_keyword_schemaless] = ACTIONS(296),
    [sym_keyword_flexible] = ACTIONS(296),
    [sym_keyword_readonly] = ACTIONS(296),
    [sym_keyword_changefeed] = ACTIONS(296),
    [sym_keyword_content] = ACTIONS(296),
    [sym_keyword_merge] = ACTIONS(296),
    [sym_keyword_patch] = ACTIONS(296),
    [sym_keyword_replace] = ACTIONS(296),
    [sym_keyword_type] = ACTIONS(296),
    [sym_keyword_default] = ACTIONS(296),
    [sym_keyword_assert] = ACTIONS(296),
    [sym_keyword_permissions] = ACTIONS(296),
    [sym_keyword_for] = ACTIONS(296),
    [sym_keyword_comment] = ACTIONS(296),
    [sym_keyword_unset] = ACTIONS(296),
    [sym_keyword_set] = ACTIONS(296),
    [anon_sym_EQ] = ACTIONS(298),
    [anon_sym_COMMA] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(296),
    [anon_sym_DASH_GT] = ACTIONS(296),
    [anon_sym_LBRACK] = ACTIONS(296),
    [anon_sym_RBRACE] = ACTIONS(296),
    [anon_sym_LT] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(298),
    [anon_sym_LT_DASH] = ACTIONS(298),
    [anon_sym_LT_DASH_GT] = ACTIONS(296),
    [anon_sym_STAR] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(296),
    [anon_sym_DASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(296),
    [anon_sym_AT] = ACTIONS(298),
    [anon_sym_LT_PIPE] = ACTIONS(296),
    [anon_sym_AMP_AMP] = ACTIONS(296),
    [anon_sym_PIPE_PIPE] = ACTIONS(296),
    [anon_sym_QMARK_QMARK] = ACTIONS(296),
    [anon_sym_QMARK_COLON] = ACTIONS(296),
    [anon_sym_BANG_EQ] = ACTIONS(296),
    [anon_sym_EQ_EQ] = ACTIONS(296),
    [anon_sym_QMARK_EQ] = ACTIONS(296),
    [anon_sym_STAR_EQ] = ACTIONS(296),
    [anon_sym_TILDE] = ACTIONS(296),
    [anon_sym_BANG_TILDE] = ACTIONS(296),
    [anon_sym_STAR_TILDE] = ACTIONS(296),
    [anon_sym_LT_EQ] = ACTIONS(296),
    [anon_sym_GT_EQ] = ACTIONS(296),
    [anon_sym_PLUS] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(296),
    [anon_sym_DASH_EQ] = ACTIONS(296),
    [anon_sym_u00d7] = ACTIONS(296),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_u00f7] = ACTIONS(296),
    [anon_sym_STAR_STAR] = ACTIONS(296),
    [anon_sym_u220b] = ACTIONS(296),
    [anon_sym_u220c] = ACTIONS(296),
    [anon_sym_u2287] = ACTIONS(296),
    [anon_sym_u2283] = ACTIONS(296),
    [anon_sym_u2285] = ACTIONS(296),
    [anon_sym_u2208] = ACTIONS(296),
    [anon_sym_u2209] = ACTIONS(296),
    [anon_sym_u2286] = ACTIONS(296),
    [anon_sym_u2282] = ACTIONS(296),
    [anon_sym_u2284] = ACTIONS(296),
    [anon_sym_AT_AT] = ACTIONS(296),
  },
  [STATE(43)] = {
    [ts_builtin_sym_end] = ACTIONS(300),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(300),
    [sym_keyword_return] = ACTIONS(300),
    [sym_keyword_value] = ACTIONS(300),
    [sym_keyword_explain] = ACTIONS(300),
    [sym_keyword_parallel] = ACTIONS(300),
    [sym_keyword_timeout] = ACTIONS(300),
    [sym_keyword_fetch] = ACTIONS(300),
    [sym_keyword_limit] = ACTIONS(300),
    [sym_keyword_rand] = ACTIONS(300),
    [sym_keyword_collate] = ACTIONS(300),
    [sym_keyword_numeric] = ACTIONS(300),
    [sym_keyword_asc] = ACTIONS(300),
    [sym_keyword_desc] = ACTIONS(300),
    [sym_keyword_where] = ACTIONS(300),
    [sym_keyword_group] = ACTIONS(300),
    [sym_keyword_and] = ACTIONS(300),
    [sym_keyword_or] = ACTIONS(300),
    [sym_keyword_is] = ACTIONS(300),
    [sym_keyword_not] = ACTIONS(302),
    [sym_keyword_contains] = ACTIONS(302),
    [sym_keyword_contains_not] = ACTIONS(300),
    [sym_keyword_contains_all] = ACTIONS(300),
    [sym_keyword_contains_any] = ACTIONS(300),
    [sym_keyword_contains_none] = ACTIONS(300),
    [sym_keyword_inside] = ACTIONS(300),
    [sym_keyword_in] = ACTIONS(302),
    [sym_keyword_not_inside] = ACTIONS(300),
    [sym_keyword_all_inside] = ACTIONS(300),
    [sym_keyword_any_inside] = ACTIONS(300),
    [sym_keyword_none_inside] = ACTIONS(300),
    [sym_keyword_outside] = ACTIONS(300),
    [sym_keyword_intersects] = ACTIONS(300),
    [sym_keyword_drop] = ACTIONS(300),
    [sym_keyword_schemafull] = ACTIONS(300),
    [sym_keyword_schemaless] = ACTIONS(300),
    [sym_keyword_flexible] = ACTIONS(300),
    [sym_keyword_readonly] = ACTIONS(300),
    [sym_keyword_changefeed] = ACTIONS(300),
    [sym_keyword_content] = ACTIONS(300),
    [sym_keyword_merge] = ACTIONS(300),
    [sym_keyword_patch] = ACTIONS(300),
    [sym_keyword_replace] = ACTIONS(300),
    [sym_keyword_type] = ACTIONS(300),
    [sym_keyword_default] = ACTIONS(300),
    [sym_keyword_assert] = ACTIONS(300),
    [sym_keyword_permissions] = ACTIONS(300),
    [sym_keyword_for] = ACTIONS(300),
    [sym_keyword_comment] = ACTIONS(300),
    [sym_keyword_unset] = ACTIONS(300),
    [sym_keyword_set] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(300),
    [anon_sym_DASH_GT] = ACTIONS(300),
    [anon_sym_LBRACK] = ACTIONS(300),
    [anon_sym_RBRACE] = ACTIONS(300),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_LT_DASH] = ACTIONS(302),
    [anon_sym_LT_DASH_GT] = ACTIONS(300),
    [anon_sym_STAR] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(300),
    [anon_sym_DASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(300),
    [anon_sym_AT] = ACTIONS(302),
    [anon_sym_LT_PIPE] = ACTIONS(300),
    [anon_sym_AMP_AMP] = ACTIONS(300),
    [anon_sym_PIPE_PIPE] = ACTIONS(300),
    [anon_sym_QMARK_QMARK] = ACTIONS(300),
    [anon_sym_QMARK_COLON] = ACTIONS(300),
    [anon_sym_BANG_EQ] = ACTIONS(300),
    [anon_sym_EQ_EQ] = ACTIONS(300),
    [anon_sym_QMARK_EQ] = ACTIONS(300),
    [anon_sym_STAR_EQ] = ACTIONS(300),
    [anon_sym_TILDE] = ACTIONS(300),
    [anon_sym_BANG_TILDE] = ACTIONS(300),
    [anon_sym_STAR_TILDE] = ACTIONS(300),
    [anon_sym_LT_EQ] = ACTIONS(300),
    [anon_sym_GT_EQ] = ACTIONS(300),
    [anon_sym_PLUS] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(300),
    [anon_sym_DASH_EQ] = ACTIONS(300),
    [anon_sym_u00d7] = ACTIONS(300),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_u00f7] = ACTIONS(300),
    [anon_sym_STAR_STAR] = ACTIONS(300),
    [anon_sym_u220b] = ACTIONS(300),
    [anon_sym_u220c] = ACTIONS(300),
    [anon_sym_u2287] = ACTIONS(300),
    [anon_sym_u2283] = ACTIONS(300),
    [anon_sym_u2285] = ACTIONS(300),
    [anon_sym_u2208] = ACTIONS(300),
    [anon_sym_u2209] = ACTIONS(300),
    [anon_sym_u2286] = ACTIONS(300),
    [anon_sym_u2282] = ACTIONS(300),
    [anon_sym_u2284] = ACTIONS(300),
    [anon_sym_AT_AT] = ACTIONS(300),
  },
  [STATE(44)] = {
    [aux_sym_function_call_repeat1] = STATE(1786),
    [ts_builtin_sym_end] = ACTIONS(304),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_return] = ACTIONS(304),
    [sym_keyword_value] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_rand] = ACTIONS(304),
    [sym_keyword_collate] = ACTIONS(304),
    [sym_keyword_numeric] = ACTIONS(304),
    [sym_keyword_asc] = ACTIONS(304),
    [sym_keyword_desc] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(304),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [sym_keyword_drop] = ACTIONS(304),
    [sym_keyword_schemafull] = ACTIONS(304),
    [sym_keyword_schemaless] = ACTIONS(304),
    [sym_keyword_flexible] = ACTIONS(304),
    [sym_keyword_readonly] = ACTIONS(304),
    [sym_keyword_changefeed] = ACTIONS(304),
    [sym_keyword_content] = ACTIONS(304),
    [sym_keyword_merge] = ACTIONS(304),
    [sym_keyword_patch] = ACTIONS(304),
    [sym_keyword_replace] = ACTIONS(304),
    [sym_keyword_type] = ACTIONS(304),
    [sym_keyword_default] = ACTIONS(304),
    [sym_keyword_assert] = ACTIONS(304),
    [sym_keyword_permissions] = ACTIONS(304),
    [sym_keyword_for] = ACTIONS(304),
    [sym_keyword_comment] = ACTIONS(304),
    [sym_keyword_unset] = ACTIONS(304),
    [sym_keyword_set] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_COLON_COLON] = ACTIONS(308),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(45)] = {
    [ts_builtin_sym_end] = ACTIONS(310),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(310),
    [sym_keyword_return] = ACTIONS(310),
    [sym_keyword_value] = ACTIONS(310),
    [sym_keyword_explain] = ACTIONS(310),
    [sym_keyword_parallel] = ACTIONS(310),
    [sym_keyword_timeout] = ACTIONS(310),
    [sym_keyword_fetch] = ACTIONS(310),
    [sym_keyword_limit] = ACTIONS(310),
    [sym_keyword_rand] = ACTIONS(310),
    [sym_keyword_collate] = ACTIONS(310),
    [sym_keyword_numeric] = ACTIONS(310),
    [sym_keyword_asc] = ACTIONS(310),
    [sym_keyword_desc] = ACTIONS(310),
    [sym_keyword_where] = ACTIONS(310),
    [sym_keyword_group] = ACTIONS(310),
    [sym_keyword_and] = ACTIONS(310),
    [sym_keyword_or] = ACTIONS(310),
    [sym_keyword_is] = ACTIONS(310),
    [sym_keyword_not] = ACTIONS(312),
    [sym_keyword_contains] = ACTIONS(312),
    [sym_keyword_contains_not] = ACTIONS(310),
    [sym_keyword_contains_all] = ACTIONS(310),
    [sym_keyword_contains_any] = ACTIONS(310),
    [sym_keyword_contains_none] = ACTIONS(310),
    [sym_keyword_inside] = ACTIONS(310),
    [sym_keyword_in] = ACTIONS(312),
    [sym_keyword_not_inside] = ACTIONS(310),
    [sym_keyword_all_inside] = ACTIONS(310),
    [sym_keyword_any_inside] = ACTIONS(310),
    [sym_keyword_none_inside] = ACTIONS(310),
    [sym_keyword_outside] = ACTIONS(310),
    [sym_keyword_intersects] = ACTIONS(310),
    [sym_keyword_drop] = ACTIONS(310),
    [sym_keyword_schemafull] = ACTIONS(310),
    [sym_keyword_schemaless] = ACTIONS(310),
    [sym_keyword_flexible] = ACTIONS(310),
    [sym_keyword_readonly] = ACTIONS(310),
    [sym_keyword_changefeed] = ACTIONS(310),
    [sym_keyword_content] = ACTIONS(310),
    [sym_keyword_merge] = ACTIONS(310),
    [sym_keyword_patch] = ACTIONS(310),
    [sym_keyword_replace] = ACTIONS(310),
    [sym_keyword_type] = ACTIONS(310),
    [sym_keyword_default] = ACTIONS(310),
    [sym_keyword_assert] = ACTIONS(310),
    [sym_keyword_permissions] = ACTIONS(310),
    [sym_keyword_for] = ACTIONS(310),
    [sym_keyword_comment] = ACTIONS(310),
    [sym_keyword_unset] = ACTIONS(310),
    [sym_keyword_set] = ACTIONS(310),
    [anon_sym_EQ] = ACTIONS(312),
    [anon_sym_COMMA] = ACTIONS(310),
    [anon_sym_RPAREN] = ACTIONS(310),
    [anon_sym_DASH_GT] = ACTIONS(310),
    [anon_sym_LBRACK] = ACTIONS(310),
    [anon_sym_RBRACE] = ACTIONS(310),
    [anon_sym_LT] = ACTIONS(312),
    [anon_sym_GT] = ACTIONS(312),
    [anon_sym_LT_DASH] = ACTIONS(312),
    [anon_sym_LT_DASH_GT] = ACTIONS(310),
    [anon_sym_STAR] = ACTIONS(312),
    [anon_sym_DOT] = ACTIONS(310),
    [anon_sym_DASH] = ACTIONS(312),
    [anon_sym_PERCENT] = ACTIONS(310),
    [anon_sym_AT] = ACTIONS(312),
    [anon_sym_LT_PIPE] = ACTIONS(310),
    [anon_sym_AMP_AMP] = ACTIONS(310),
    [anon_sym_PIPE_PIPE] = ACTIONS(310),
    [anon_sym_QMARK_QMARK] = ACTIONS(310),
    [anon_sym_QMARK_COLON] = ACTIONS(310),
    [anon_sym_BANG_EQ] = ACTIONS(310),
    [anon_sym_EQ_EQ] = ACTIONS(310),
    [anon_sym_QMARK_EQ] = ACTIONS(310),
    [anon_sym_STAR_EQ] = ACTIONS(310),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG_TILDE] = ACTIONS(310),
    [anon_sym_STAR_TILDE] = ACTIONS(310),
    [anon_sym_LT_EQ] = ACTIONS(310),
    [anon_sym_GT_EQ] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(312),
    [anon_sym_PLUS_EQ] = ACTIONS(310),
    [anon_sym_DASH_EQ] = ACTIONS(310),
    [anon_sym_u00d7] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(312),
    [anon_sym_u00f7] = ACTIONS(310),
    [anon_sym_STAR_STAR] = ACTIONS(310),
    [anon_sym_u220b] = ACTIONS(310),
    [anon_sym_u220c] = ACTIONS(310),
    [anon_sym_u2287] = ACTIONS(310),
    [anon_sym_u2283] = ACTIONS(310),
    [anon_sym_u2285] = ACTIONS(310),
    [anon_sym_u2208] = ACTIONS(310),
    [anon_sym_u2209] = ACTIONS(310),
    [anon_sym_u2286] = ACTIONS(310),
    [anon_sym_u2282] = ACTIONS(310),
    [anon_sym_u2284] = ACTIONS(310),
    [anon_sym_AT_AT] = ACTIONS(310),
  },
  [STATE(46)] = {
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(314),
    [sym_keyword_value] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(314),
    [sym_keyword_rand] = ACTIONS(314),
    [sym_keyword_collate] = ACTIONS(314),
    [sym_keyword_numeric] = ACTIONS(314),
    [sym_keyword_asc] = ACTIONS(314),
    [sym_keyword_desc] = ACTIONS(314),
    [sym_keyword_where] = ACTIONS(314),
    [sym_keyword_group] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(314),
    [sym_keyword_or] = ACTIONS(314),
    [sym_keyword_is] = ACTIONS(314),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(314),
    [sym_keyword_contains_all] = ACTIONS(314),
    [sym_keyword_contains_any] = ACTIONS(314),
    [sym_keyword_contains_none] = ACTIONS(314),
    [sym_keyword_inside] = ACTIONS(314),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(314),
    [sym_keyword_all_inside] = ACTIONS(314),
    [sym_keyword_any_inside] = ACTIONS(314),
    [sym_keyword_none_inside] = ACTIONS(314),
    [sym_keyword_outside] = ACTIONS(314),
    [sym_keyword_intersects] = ACTIONS(314),
    [sym_keyword_drop] = ACTIONS(314),
    [sym_keyword_schemafull] = ACTIONS(314),
    [sym_keyword_schemaless] = ACTIONS(314),
    [sym_keyword_flexible] = ACTIONS(314),
    [sym_keyword_readonly] = ACTIONS(314),
    [sym_keyword_changefeed] = ACTIONS(314),
    [sym_keyword_content] = ACTIONS(314),
    [sym_keyword_merge] = ACTIONS(314),
    [sym_keyword_patch] = ACTIONS(314),
    [sym_keyword_replace] = ACTIONS(314),
    [sym_keyword_type] = ACTIONS(314),
    [sym_keyword_default] = ACTIONS(314),
    [sym_keyword_assert] = ACTIONS(314),
    [sym_keyword_permissions] = ACTIONS(314),
    [sym_keyword_for] = ACTIONS(314),
    [sym_keyword_comment] = ACTIONS(314),
    [sym_keyword_unset] = ACTIONS(314),
    [sym_keyword_set] = ACTIONS(314),
    [anon_sym_EQ] = ACTIONS(316),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(314),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(47)] = {
    [ts_builtin_sym_end] = ACTIONS(318),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(318),
    [sym_keyword_return] = ACTIONS(318),
    [sym_keyword_value] = ACTIONS(318),
    [sym_keyword_explain] = ACTIONS(318),
    [sym_keyword_parallel] = ACTIONS(318),
    [sym_keyword_timeout] = ACTIONS(318),
    [sym_keyword_fetch] = ACTIONS(318),
    [sym_keyword_limit] = ACTIONS(318),
    [sym_keyword_rand] = ACTIONS(318),
    [sym_keyword_collate] = ACTIONS(318),
    [sym_keyword_numeric] = ACTIONS(318),
    [sym_keyword_asc] = ACTIONS(318),
    [sym_keyword_desc] = ACTIONS(318),
    [sym_keyword_where] = ACTIONS(318),
    [sym_keyword_group] = ACTIONS(318),
    [sym_keyword_and] = ACTIONS(318),
    [sym_keyword_or] = ACTIONS(318),
    [sym_keyword_is] = ACTIONS(318),
    [sym_keyword_not] = ACTIONS(320),
    [sym_keyword_contains] = ACTIONS(320),
    [sym_keyword_contains_not] = ACTIONS(318),
    [sym_keyword_contains_all] = ACTIONS(318),
    [sym_keyword_contains_any] = ACTIONS(318),
    [sym_keyword_contains_none] = ACTIONS(318),
    [sym_keyword_inside] = ACTIONS(318),
    [sym_keyword_in] = ACTIONS(320),
    [sym_keyword_not_inside] = ACTIONS(318),
    [sym_keyword_all_inside] = ACTIONS(318),
    [sym_keyword_any_inside] = ACTIONS(318),
    [sym_keyword_none_inside] = ACTIONS(318),
    [sym_keyword_outside] = ACTIONS(318),
    [sym_keyword_intersects] = ACTIONS(318),
    [sym_keyword_drop] = ACTIONS(318),
    [sym_keyword_schemafull] = ACTIONS(318),
    [sym_keyword_schemaless] = ACTIONS(318),
    [sym_keyword_flexible] = ACTIONS(318),
    [sym_keyword_readonly] = ACTIONS(318),
    [sym_keyword_changefeed] = ACTIONS(318),
    [sym_keyword_content] = ACTIONS(318),
    [sym_keyword_merge] = ACTIONS(318),
    [sym_keyword_patch] = ACTIONS(318),
    [sym_keyword_replace] = ACTIONS(318),
    [sym_keyword_type] = ACTIONS(318),
    [sym_keyword_default] = ACTIONS(318),
    [sym_keyword_assert] = ACTIONS(318),
    [sym_keyword_permissions] = ACTIONS(318),
    [sym_keyword_for] = ACTIONS(318),
    [sym_keyword_comment] = ACTIONS(318),
    [sym_keyword_unset] = ACTIONS(318),
    [sym_keyword_set] = ACTIONS(318),
    [anon_sym_EQ] = ACTIONS(320),
    [anon_sym_COMMA] = ACTIONS(318),
    [anon_sym_RPAREN] = ACTIONS(318),
    [anon_sym_DASH_GT] = ACTIONS(318),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_RBRACE] = ACTIONS(318),
    [anon_sym_LT] = ACTIONS(320),
    [anon_sym_GT] = ACTIONS(320),
    [anon_sym_LT_DASH] = ACTIONS(320),
    [anon_sym_LT_DASH_GT] = ACTIONS(318),
    [anon_sym_STAR] = ACTIONS(320),
    [anon_sym_DOT] = ACTIONS(318),
    [anon_sym_DASH] = ACTIONS(320),
    [anon_sym_PERCENT] = ACTIONS(318),
    [anon_sym_AT] = ACTIONS(320),
    [anon_sym_LT_PIPE] = ACTIONS(318),
    [anon_sym_AMP_AMP] = ACTIONS(318),
    [anon_sym_PIPE_PIPE] = ACTIONS(318),
    [anon_sym_QMARK_QMARK] = ACTIONS(318),
    [anon_sym_QMARK_COLON] = ACTIONS(318),
    [anon_sym_BANG_EQ] = ACTIONS(318),
    [anon_sym_EQ_EQ] = ACTIONS(318),
    [anon_sym_QMARK_EQ] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(318),
    [anon_sym_TILDE] = ACTIONS(318),
    [anon_sym_BANG_TILDE] = ACTIONS(318),
    [anon_sym_STAR_TILDE] = ACTIONS(318),
    [anon_sym_LT_EQ] = ACTIONS(318),
    [anon_sym_GT_EQ] = ACTIONS(318),
    [anon_sym_PLUS] = ACTIONS(320),
    [anon_sym_PLUS_EQ] = ACTIONS(318),
    [anon_sym_DASH_EQ] = ACTIONS(318),
    [anon_sym_u00d7] = ACTIONS(318),
    [anon_sym_SLASH] = ACTIONS(320),
    [anon_sym_u00f7] = ACTIONS(318),
    [anon_sym_STAR_STAR] = ACTIONS(318),
    [anon_sym_u220b] = ACTIONS(318),
    [anon_sym_u220c] = ACTIONS(318),
    [anon_sym_u2287] = ACTIONS(318),
    [anon_sym_u2283] = ACTIONS(318),
    [anon_sym_u2285] = ACTIONS(318),
    [anon_sym_u2208] = ACTIONS(318),
    [anon_sym_u2209] = ACTIONS(318),
    [anon_sym_u2286] = ACTIONS(318),
    [anon_sym_u2282] = ACTIONS(318),
    [anon_sym_u2284] = ACTIONS(318),
    [anon_sym_AT_AT] = ACTIONS(318),
  },
  [STATE(48)] = {
    [ts_builtin_sym_end] = ACTIONS(322),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(322),
    [sym_keyword_return] = ACTIONS(322),
    [sym_keyword_value] = ACTIONS(322),
    [sym_keyword_explain] = ACTIONS(322),
    [sym_keyword_parallel] = ACTIONS(322),
    [sym_keyword_timeout] = ACTIONS(322),
    [sym_keyword_fetch] = ACTIONS(322),
    [sym_keyword_limit] = ACTIONS(322),
    [sym_keyword_rand] = ACTIONS(322),
    [sym_keyword_collate] = ACTIONS(322),
    [sym_keyword_numeric] = ACTIONS(322),
    [sym_keyword_asc] = ACTIONS(322),
    [sym_keyword_desc] = ACTIONS(322),
    [sym_keyword_where] = ACTIONS(322),
    [sym_keyword_group] = ACTIONS(322),
    [sym_keyword_and] = ACTIONS(322),
    [sym_keyword_or] = ACTIONS(322),
    [sym_keyword_is] = ACTIONS(322),
    [sym_keyword_not] = ACTIONS(324),
    [sym_keyword_contains] = ACTIONS(324),
    [sym_keyword_contains_not] = ACTIONS(322),
    [sym_keyword_contains_all] = ACTIONS(322),
    [sym_keyword_contains_any] = ACTIONS(322),
    [sym_keyword_contains_none] = ACTIONS(322),
    [sym_keyword_inside] = ACTIONS(322),
    [sym_keyword_in] = ACTIONS(324),
    [sym_keyword_not_inside] = ACTIONS(322),
    [sym_keyword_all_inside] = ACTIONS(322),
    [sym_keyword_any_inside] = ACTIONS(322),
    [sym_keyword_none_inside] = ACTIONS(322),
    [sym_keyword_outside] = ACTIONS(322),
    [sym_keyword_intersects] = ACTIONS(322),
    [sym_keyword_drop] = ACTIONS(322),
    [sym_keyword_schemafull] = ACTIONS(322),
    [sym_keyword_schemaless] = ACTIONS(322),
    [sym_keyword_flexible] = ACTIONS(322),
    [sym_keyword_readonly] = ACTIONS(322),
    [sym_keyword_changefeed] = ACTIONS(322),
    [sym_keyword_content] = ACTIONS(322),
    [sym_keyword_merge] = ACTIONS(322),
    [sym_keyword_patch] = ACTIONS(322),
    [sym_keyword_replace] = ACTIONS(322),
    [sym_keyword_type] = ACTIONS(322),
    [sym_keyword_default] = ACTIONS(322),
    [sym_keyword_assert] = ACTIONS(322),
    [sym_keyword_permissions] = ACTIONS(322),
    [sym_keyword_for] = ACTIONS(322),
    [sym_keyword_comment] = ACTIONS(322),
    [sym_keyword_unset] = ACTIONS(322),
    [sym_keyword_set] = ACTIONS(322),
    [anon_sym_EQ] = ACTIONS(324),
    [anon_sym_COMMA] = ACTIONS(322),
    [anon_sym_RPAREN] = ACTIONS(322),
    [anon_sym_DASH_GT] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(322),
    [anon_sym_RBRACE] = ACTIONS(322),
    [anon_sym_LT] = ACTIONS(324),
    [anon_sym_GT] = ACTIONS(324),
    [anon_sym_LT_DASH] = ACTIONS(324),
    [anon_sym_LT_DASH_GT] = ACTIONS(322),
    [anon_sym_STAR] = ACTIONS(324),
    [anon_sym_DOT] = ACTIONS(322),
    [anon_sym_DASH] = ACTIONS(324),
    [anon_sym_PERCENT] = ACTIONS(322),
    [anon_sym_AT] = ACTIONS(324),
    [anon_sym_LT_PIPE] = ACTIONS(322),
    [anon_sym_AMP_AMP] = ACTIONS(322),
    [anon_sym_PIPE_PIPE] = ACTIONS(322),
    [anon_sym_QMARK_QMARK] = ACTIONS(322),
    [anon_sym_QMARK_COLON] = ACTIONS(322),
    [anon_sym_BANG_EQ] = ACTIONS(322),
    [anon_sym_EQ_EQ] = ACTIONS(322),
    [anon_sym_QMARK_EQ] = ACTIONS(322),
    [anon_sym_STAR_EQ] = ACTIONS(322),
    [anon_sym_TILDE] = ACTIONS(322),
    [anon_sym_BANG_TILDE] = ACTIONS(322),
    [anon_sym_STAR_TILDE] = ACTIONS(322),
    [anon_sym_LT_EQ] = ACTIONS(322),
    [anon_sym_GT_EQ] = ACTIONS(322),
    [anon_sym_PLUS] = ACTIONS(324),
    [anon_sym_PLUS_EQ] = ACTIONS(322),
    [anon_sym_DASH_EQ] = ACTIONS(322),
    [anon_sym_u00d7] = ACTIONS(322),
    [anon_sym_SLASH] = ACTIONS(324),
    [anon_sym_u00f7] = ACTIONS(322),
    [anon_sym_STAR_STAR] = ACTIONS(322),
    [anon_sym_u220b] = ACTIONS(322),
    [anon_sym_u220c] = ACTIONS(322),
    [anon_sym_u2287] = ACTIONS(322),
    [anon_sym_u2283] = ACTIONS(322),
    [anon_sym_u2285] = ACTIONS(322),
    [anon_sym_u2208] = ACTIONS(322),
    [anon_sym_u2209] = ACTIONS(322),
    [anon_sym_u2286] = ACTIONS(322),
    [anon_sym_u2282] = ACTIONS(322),
    [anon_sym_u2284] = ACTIONS(322),
    [anon_sym_AT_AT] = ACTIONS(322),
  },
  [STATE(49)] = {
    [ts_builtin_sym_end] = ACTIONS(326),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(326),
    [sym_keyword_return] = ACTIONS(326),
    [sym_keyword_value] = ACTIONS(326),
    [sym_keyword_explain] = ACTIONS(326),
    [sym_keyword_parallel] = ACTIONS(326),
    [sym_keyword_timeout] = ACTIONS(326),
    [sym_keyword_fetch] = ACTIONS(326),
    [sym_keyword_limit] = ACTIONS(326),
    [sym_keyword_rand] = ACTIONS(326),
    [sym_keyword_collate] = ACTIONS(326),
    [sym_keyword_numeric] = ACTIONS(326),
    [sym_keyword_asc] = ACTIONS(326),
    [sym_keyword_desc] = ACTIONS(326),
    [sym_keyword_where] = ACTIONS(326),
    [sym_keyword_group] = ACTIONS(326),
    [sym_keyword_and] = ACTIONS(326),
    [sym_keyword_or] = ACTIONS(326),
    [sym_keyword_is] = ACTIONS(326),
    [sym_keyword_not] = ACTIONS(328),
    [sym_keyword_contains] = ACTIONS(328),
    [sym_keyword_contains_not] = ACTIONS(326),
    [sym_keyword_contains_all] = ACTIONS(326),
    [sym_keyword_contains_any] = ACTIONS(326),
    [sym_keyword_contains_none] = ACTIONS(326),
    [sym_keyword_inside] = ACTIONS(326),
    [sym_keyword_in] = ACTIONS(328),
    [sym_keyword_not_inside] = ACTIONS(326),
    [sym_keyword_all_inside] = ACTIONS(326),
    [sym_keyword_any_inside] = ACTIONS(326),
    [sym_keyword_none_inside] = ACTIONS(326),
    [sym_keyword_outside] = ACTIONS(326),
    [sym_keyword_intersects] = ACTIONS(326),
    [sym_keyword_drop] = ACTIONS(326),
    [sym_keyword_schemafull] = ACTIONS(326),
    [sym_keyword_schemaless] = ACTIONS(326),
    [sym_keyword_flexible] = ACTIONS(326),
    [sym_keyword_readonly] = ACTIONS(326),
    [sym_keyword_changefeed] = ACTIONS(326),
    [sym_keyword_content] = ACTIONS(326),
    [sym_keyword_merge] = ACTIONS(326),
    [sym_keyword_patch] = ACTIONS(326),
    [sym_keyword_replace] = ACTIONS(326),
    [sym_keyword_type] = ACTIONS(326),
    [sym_keyword_default] = ACTIONS(326),
    [sym_keyword_assert] = ACTIONS(326),
    [sym_keyword_permissions] = ACTIONS(326),
    [sym_keyword_for] = ACTIONS(326),
    [sym_keyword_comment] = ACTIONS(326),
    [sym_keyword_unset] = ACTIONS(326),
    [sym_keyword_set] = ACTIONS(326),
    [anon_sym_EQ] = ACTIONS(328),
    [anon_sym_COMMA] = ACTIONS(326),
    [anon_sym_RPAREN] = ACTIONS(326),
    [anon_sym_DASH_GT] = ACTIONS(326),
    [anon_sym_LBRACK] = ACTIONS(326),
    [anon_sym_RBRACE] = ACTIONS(326),
    [anon_sym_LT] = ACTIONS(328),
    [anon_sym_GT] = ACTIONS(328),
    [anon_sym_LT_DASH] = ACTIONS(328),
    [anon_sym_LT_DASH_GT] = ACTIONS(326),
    [anon_sym_STAR] = ACTIONS(328),
    [anon_sym_DOT] = ACTIONS(326),
    [anon_sym_DASH] = ACTIONS(328),
    [anon_sym_PERCENT] = ACTIONS(326),
    [anon_sym_AT] = ACTIONS(328),
    [anon_sym_LT_PIPE] = ACTIONS(326),
    [anon_sym_AMP_AMP] = ACTIONS(326),
    [anon_sym_PIPE_PIPE] = ACTIONS(326),
    [anon_sym_QMARK_QMARK] = ACTIONS(326),
    [anon_sym_QMARK_COLON] = ACTIONS(326),
    [anon_sym_BANG_EQ] = ACTIONS(326),
    [anon_sym_EQ_EQ] = ACTIONS(326),
    [anon_sym_QMARK_EQ] = ACTIONS(326),
    [anon_sym_STAR_EQ] = ACTIONS(326),
    [anon_sym_TILDE] = ACTIONS(326),
    [anon_sym_BANG_TILDE] = ACTIONS(326),
    [anon_sym_STAR_TILDE] = ACTIONS(326),
    [anon_sym_LT_EQ] = ACTIONS(326),
    [anon_sym_GT_EQ] = ACTIONS(326),
    [anon_sym_PLUS] = ACTIONS(328),
    [anon_sym_PLUS_EQ] = ACTIONS(326),
    [anon_sym_DASH_EQ] = ACTIONS(326),
    [anon_sym_u00d7] = ACTIONS(326),
    [anon_sym_SLASH] = ACTIONS(328),
    [anon_sym_u00f7] = ACTIONS(326),
    [anon_sym_STAR_STAR] = ACTIONS(326),
    [anon_sym_u220b] = ACTIONS(326),
    [anon_sym_u220c] = ACTIONS(326),
    [anon_sym_u2287] = ACTIONS(326),
    [anon_sym_u2283] = ACTIONS(326),
    [anon_sym_u2285] = ACTIONS(326),
    [anon_sym_u2208] = ACTIONS(326),
    [anon_sym_u2209] = ACTIONS(326),
    [anon_sym_u2286] = ACTIONS(326),
    [anon_sym_u2282] = ACTIONS(326),
    [anon_sym_u2284] = ACTIONS(326),
    [anon_sym_AT_AT] = ACTIONS(326),
  },
  [STATE(50)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_on] = ACTIONS(93),
    [sym_keyword_return] = ACTIONS(93),
    [sym_keyword_from] = ACTIONS(93),
    [sym_keyword_as] = ACTIONS(93),
    [sym_keyword_omit] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_drop] = ACTIONS(93),
    [sym_keyword_schemafull] = ACTIONS(93),
    [sym_keyword_schemaless] = ACTIONS(93),
    [sym_keyword_changefeed] = ACTIONS(93),
    [sym_keyword_content] = ACTIONS(93),
    [sym_keyword_merge] = ACTIONS(93),
    [sym_keyword_patch] = ACTIONS(93),
    [sym_keyword_replace] = ACTIONS(93),
    [sym_keyword_then] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [sym_keyword_unset] = ACTIONS(93),
    [sym_keyword_set] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_RBRACK] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_COLON] = ACTIONS(194),
    [anon_sym_LBRACE] = ACTIONS(93),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_COLON_COLON] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(51)] = {
    [aux_sym_function_call_repeat1] = STATE(1802),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_on] = ACTIONS(304),
    [sym_keyword_return] = ACTIONS(304),
    [sym_keyword_from] = ACTIONS(304),
    [sym_keyword_as] = ACTIONS(304),
    [sym_keyword_omit] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(304),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [sym_keyword_drop] = ACTIONS(304),
    [sym_keyword_schemafull] = ACTIONS(304),
    [sym_keyword_schemaless] = ACTIONS(304),
    [sym_keyword_changefeed] = ACTIONS(304),
    [sym_keyword_content] = ACTIONS(304),
    [sym_keyword_merge] = ACTIONS(304),
    [sym_keyword_patch] = ACTIONS(304),
    [sym_keyword_replace] = ACTIONS(304),
    [sym_keyword_then] = ACTIONS(304),
    [sym_keyword_permissions] = ACTIONS(304),
    [sym_keyword_for] = ACTIONS(304),
    [sym_keyword_comment] = ACTIONS(304),
    [sym_keyword_unset] = ACTIONS(304),
    [sym_keyword_set] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_LPAREN] = ACTIONS(304),
    [anon_sym_RPAREN] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACK] = ACTIONS(304),
    [anon_sym_QMARK] = ACTIONS(306),
    [anon_sym_LBRACE] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(304),
    [anon_sym_COLON_COLON] = ACTIONS(308),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(52)] = {
    [aux_sym_duration_repeat1] = STATE(53),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(173),
    [sym_keyword_on] = ACTIONS(173),
    [sym_keyword_return] = ACTIONS(173),
    [sym_keyword_from] = ACTIONS(173),
    [sym_keyword_as] = ACTIONS(173),
    [sym_keyword_omit] = ACTIONS(173),
    [sym_keyword_explain] = ACTIONS(173),
    [sym_keyword_parallel] = ACTIONS(173),
    [sym_keyword_timeout] = ACTIONS(173),
    [sym_keyword_fetch] = ACTIONS(173),
    [sym_keyword_limit] = ACTIONS(173),
    [sym_keyword_where] = ACTIONS(173),
    [sym_keyword_group] = ACTIONS(173),
    [sym_keyword_and] = ACTIONS(173),
    [sym_keyword_or] = ACTIONS(173),
    [sym_keyword_is] = ACTIONS(173),
    [sym_keyword_not] = ACTIONS(175),
    [sym_keyword_contains] = ACTIONS(175),
    [sym_keyword_contains_not] = ACTIONS(173),
    [sym_keyword_contains_all] = ACTIONS(173),
    [sym_keyword_contains_any] = ACTIONS(173),
    [sym_keyword_contains_none] = ACTIONS(173),
    [sym_keyword_inside] = ACTIONS(173),
    [sym_keyword_in] = ACTIONS(175),
    [sym_keyword_not_inside] = ACTIONS(173),
    [sym_keyword_all_inside] = ACTIONS(173),
    [sym_keyword_any_inside] = ACTIONS(173),
    [sym_keyword_none_inside] = ACTIONS(173),
    [sym_keyword_outside] = ACTIONS(173),
    [sym_keyword_intersects] = ACTIONS(173),
    [sym_keyword_drop] = ACTIONS(173),
    [sym_keyword_schemafull] = ACTIONS(173),
    [sym_keyword_schemaless] = ACTIONS(173),
    [sym_keyword_changefeed] = ACTIONS(173),
    [sym_keyword_content] = ACTIONS(173),
    [sym_keyword_merge] = ACTIONS(173),
    [sym_keyword_patch] = ACTIONS(173),
    [sym_keyword_replace] = ACTIONS(173),
    [sym_keyword_then] = ACTIONS(173),
    [sym_keyword_permissions] = ACTIONS(173),
    [sym_keyword_for] = ACTIONS(173),
    [sym_keyword_comment] = ACTIONS(173),
    [sym_keyword_unset] = ACTIONS(173),
    [sym_keyword_set] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(175),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_LPAREN] = ACTIONS(173),
    [anon_sym_RPAREN] = ACTIONS(173),
    [anon_sym_DASH_GT] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(173),
    [anon_sym_RBRACK] = ACTIONS(173),
    [anon_sym_QMARK] = ACTIONS(175),
    [anon_sym_LBRACE] = ACTIONS(173),
    [anon_sym_RBRACE] = ACTIONS(173),
    [anon_sym_LT] = ACTIONS(175),
    [anon_sym_GT] = ACTIONS(175),
    [anon_sym_LT_DASH] = ACTIONS(175),
    [anon_sym_LT_DASH_GT] = ACTIONS(173),
    [anon_sym_STAR] = ACTIONS(175),
    [anon_sym_DOT] = ACTIONS(173),
    [sym_duration_part] = ACTIONS(330),
    [anon_sym_DASH] = ACTIONS(175),
    [anon_sym_PERCENT] = ACTIONS(173),
    [anon_sym_AT] = ACTIONS(175),
    [anon_sym_LT_PIPE] = ACTIONS(173),
    [anon_sym_AMP_AMP] = ACTIONS(173),
    [anon_sym_PIPE_PIPE] = ACTIONS(173),
    [anon_sym_QMARK_QMARK] = ACTIONS(173),
    [anon_sym_QMARK_COLON] = ACTIONS(173),
    [anon_sym_BANG_EQ] = ACTIONS(173),
    [anon_sym_EQ_EQ] = ACTIONS(173),
    [anon_sym_QMARK_EQ] = ACTIONS(173),
    [anon_sym_STAR_EQ] = ACTIONS(173),
    [anon_sym_TILDE] = ACTIONS(173),
    [anon_sym_BANG_TILDE] = ACTIONS(173),
    [anon_sym_STAR_TILDE] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(173),
    [anon_sym_GT_EQ] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(175),
    [anon_sym_PLUS_EQ] = ACTIONS(173),
    [anon_sym_DASH_EQ] = ACTIONS(173),
    [anon_sym_u00d7] = ACTIONS(173),
    [anon_sym_SLASH] = ACTIONS(175),
    [anon_sym_u00f7] = ACTIONS(173),
    [anon_sym_STAR_STAR] = ACTIONS(173),
    [anon_sym_u220b] = ACTIONS(173),
    [anon_sym_u220c] = ACTIONS(173),
    [anon_sym_u2287] = ACTIONS(173),
    [anon_sym_u2283] = ACTIONS(173),
    [anon_sym_u2285] = ACTIONS(173),
    [anon_sym_u2208] = ACTIONS(173),
    [anon_sym_u2209] = ACTIONS(173),
    [anon_sym_u2286] = ACTIONS(173),
    [anon_sym_u2282] = ACTIONS(173),
    [anon_sym_u2284] = ACTIONS(173),
    [anon_sym_AT_AT] = ACTIONS(173),
  },
  [STATE(53)] = {
    [aux_sym_duration_repeat1] = STATE(53),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(179),
    [sym_keyword_on] = ACTIONS(179),
    [sym_keyword_return] = ACTIONS(179),
    [sym_keyword_from] = ACTIONS(179),
    [sym_keyword_as] = ACTIONS(179),
    [sym_keyword_omit] = ACTIONS(179),
    [sym_keyword_explain] = ACTIONS(179),
    [sym_keyword_parallel] = ACTIONS(179),
    [sym_keyword_timeout] = ACTIONS(179),
    [sym_keyword_fetch] = ACTIONS(179),
    [sym_keyword_limit] = ACTIONS(179),
    [sym_keyword_where] = ACTIONS(179),
    [sym_keyword_group] = ACTIONS(179),
    [sym_keyword_and] = ACTIONS(179),
    [sym_keyword_or] = ACTIONS(179),
    [sym_keyword_is] = ACTIONS(179),
    [sym_keyword_not] = ACTIONS(181),
    [sym_keyword_contains] = ACTIONS(181),
    [sym_keyword_contains_not] = ACTIONS(179),
    [sym_keyword_contains_all] = ACTIONS(179),
    [sym_keyword_contains_any] = ACTIONS(179),
    [sym_keyword_contains_none] = ACTIONS(179),
    [sym_keyword_inside] = ACTIONS(179),
    [sym_keyword_in] = ACTIONS(181),
    [sym_keyword_not_inside] = ACTIONS(179),
    [sym_keyword_all_inside] = ACTIONS(179),
    [sym_keyword_any_inside] = ACTIONS(179),
    [sym_keyword_none_inside] = ACTIONS(179),
    [sym_keyword_outside] = ACTIONS(179),
    [sym_keyword_intersects] = ACTIONS(179),
    [sym_keyword_drop] = ACTIONS(179),
    [sym_keyword_schemafull] = ACTIONS(179),
    [sym_keyword_schemaless] = ACTIONS(179),
    [sym_keyword_changefeed] = ACTIONS(179),
    [sym_keyword_content] = ACTIONS(179),
    [sym_keyword_merge] = ACTIONS(179),
    [sym_keyword_patch] = ACTIONS(179),
    [sym_keyword_replace] = ACTIONS(179),
    [sym_keyword_then] = ACTIONS(179),
    [sym_keyword_permissions] = ACTIONS(179),
    [sym_keyword_for] = ACTIONS(179),
    [sym_keyword_comment] = ACTIONS(179),
    [sym_keyword_unset] = ACTIONS(179),
    [sym_keyword_set] = ACTIONS(179),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_COMMA] = ACTIONS(179),
    [anon_sym_LPAREN] = ACTIONS(179),
    [anon_sym_RPAREN] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(179),
    [anon_sym_LBRACK] = ACTIONS(179),
    [anon_sym_RBRACK] = ACTIONS(179),
    [anon_sym_QMARK] = ACTIONS(181),
    [anon_sym_LBRACE] = ACTIONS(179),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH_GT] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_DOT] = ACTIONS(179),
    [sym_duration_part] = ACTIONS(332),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_PERCENT] = ACTIONS(179),
    [anon_sym_AT] = ACTIONS(181),
    [anon_sym_LT_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_QMARK_QMARK] = ACTIONS(179),
    [anon_sym_QMARK_COLON] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_QMARK_EQ] = ACTIONS(179),
    [anon_sym_STAR_EQ] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG_TILDE] = ACTIONS(179),
    [anon_sym_STAR_TILDE] = ACTIONS(179),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_PLUS] = ACTIONS(181),
    [anon_sym_PLUS_EQ] = ACTIONS(179),
    [anon_sym_DASH_EQ] = ACTIONS(179),
    [anon_sym_u00d7] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(181),
    [anon_sym_u00f7] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(179),
    [anon_sym_u220b] = ACTIONS(179),
    [anon_sym_u220c] = ACTIONS(179),
    [anon_sym_u2287] = ACTIONS(179),
    [anon_sym_u2283] = ACTIONS(179),
    [anon_sym_u2285] = ACTIONS(179),
    [anon_sym_u2208] = ACTIONS(179),
    [anon_sym_u2209] = ACTIONS(179),
    [anon_sym_u2286] = ACTIONS(179),
    [anon_sym_u2282] = ACTIONS(179),
    [anon_sym_u2284] = ACTIONS(179),
    [anon_sym_AT_AT] = ACTIONS(179),
  },
  [STATE(54)] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_return] = ACTIONS(186),
    [sym_keyword_value] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_rand] = ACTIONS(186),
    [sym_keyword_collate] = ACTIONS(186),
    [sym_keyword_numeric] = ACTIONS(186),
    [sym_keyword_asc] = ACTIONS(186),
    [sym_keyword_desc] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_drop] = ACTIONS(186),
    [sym_keyword_schemafull] = ACTIONS(186),
    [sym_keyword_schemaless] = ACTIONS(186),
    [sym_keyword_flexible] = ACTIONS(186),
    [sym_keyword_readonly] = ACTIONS(186),
    [sym_keyword_changefeed] = ACTIONS(186),
    [sym_keyword_content] = ACTIONS(186),
    [sym_keyword_merge] = ACTIONS(186),
    [sym_keyword_patch] = ACTIONS(186),
    [sym_keyword_replace] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_default] = ACTIONS(186),
    [sym_keyword_assert] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [sym_keyword_unset] = ACTIONS(186),
    [sym_keyword_set] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(188),
    [anon_sym_DOT_DOT] = ACTIONS(335),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(55)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(252),
    [sym_keyword_on] = ACTIONS(252),
    [sym_keyword_return] = ACTIONS(252),
    [sym_keyword_from] = ACTIONS(252),
    [sym_keyword_as] = ACTIONS(252),
    [sym_keyword_omit] = ACTIONS(252),
    [sym_keyword_explain] = ACTIONS(252),
    [sym_keyword_parallel] = ACTIONS(252),
    [sym_keyword_timeout] = ACTIONS(252),
    [sym_keyword_fetch] = ACTIONS(252),
    [sym_keyword_limit] = ACTIONS(252),
    [sym_keyword_where] = ACTIONS(252),
    [sym_keyword_group] = ACTIONS(252),
    [sym_keyword_and] = ACTIONS(252),
    [sym_keyword_or] = ACTIONS(252),
    [sym_keyword_is] = ACTIONS(252),
    [sym_keyword_not] = ACTIONS(254),
    [sym_keyword_contains] = ACTIONS(254),
    [sym_keyword_contains_not] = ACTIONS(252),
    [sym_keyword_contains_all] = ACTIONS(252),
    [sym_keyword_contains_any] = ACTIONS(252),
    [sym_keyword_contains_none] = ACTIONS(252),
    [sym_keyword_inside] = ACTIONS(252),
    [sym_keyword_in] = ACTIONS(254),
    [sym_keyword_not_inside] = ACTIONS(252),
    [sym_keyword_all_inside] = ACTIONS(252),
    [sym_keyword_any_inside] = ACTIONS(252),
    [sym_keyword_none_inside] = ACTIONS(252),
    [sym_keyword_outside] = ACTIONS(252),
    [sym_keyword_intersects] = ACTIONS(252),
    [sym_keyword_drop] = ACTIONS(252),
    [sym_keyword_schemafull] = ACTIONS(252),
    [sym_keyword_schemaless] = ACTIONS(252),
    [sym_keyword_changefeed] = ACTIONS(252),
    [sym_keyword_content] = ACTIONS(252),
    [sym_keyword_merge] = ACTIONS(252),
    [sym_keyword_patch] = ACTIONS(252),
    [sym_keyword_replace] = ACTIONS(252),
    [sym_keyword_then] = ACTIONS(252),
    [sym_keyword_permissions] = ACTIONS(252),
    [sym_keyword_for] = ACTIONS(252),
    [sym_keyword_comment] = ACTIONS(252),
    [sym_keyword_unset] = ACTIONS(252),
    [sym_keyword_set] = ACTIONS(252),
    [anon_sym_EQ] = ACTIONS(254),
    [anon_sym_COMMA] = ACTIONS(252),
    [anon_sym_LPAREN] = ACTIONS(252),
    [anon_sym_RPAREN] = ACTIONS(252),
    [anon_sym_DASH_GT] = ACTIONS(252),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_RBRACK] = ACTIONS(252),
    [anon_sym_QMARK] = ACTIONS(254),
    [anon_sym_LBRACE] = ACTIONS(252),
    [anon_sym_RBRACE] = ACTIONS(252),
    [anon_sym_LT] = ACTIONS(254),
    [anon_sym_GT] = ACTIONS(254),
    [anon_sym_LT_DASH] = ACTIONS(254),
    [anon_sym_LT_DASH_GT] = ACTIONS(252),
    [anon_sym_STAR] = ACTIONS(254),
    [anon_sym_DOT] = ACTIONS(254),
    [anon_sym_DOT_DOT] = ACTIONS(252),
    [anon_sym_DASH] = ACTIONS(254),
    [anon_sym_PERCENT] = ACTIONS(252),
    [anon_sym_AT] = ACTIONS(254),
    [anon_sym_LT_PIPE] = ACTIONS(252),
    [anon_sym_AMP_AMP] = ACTIONS(252),
    [anon_sym_PIPE_PIPE] = ACTIONS(252),
    [anon_sym_QMARK_QMARK] = ACTIONS(252),
    [anon_sym_QMARK_COLON] = ACTIONS(252),
    [anon_sym_BANG_EQ] = ACTIONS(252),
    [anon_sym_EQ_EQ] = ACTIONS(252),
    [anon_sym_QMARK_EQ] = ACTIONS(252),
    [anon_sym_STAR_EQ] = ACTIONS(252),
    [anon_sym_TILDE] = ACTIONS(252),
    [anon_sym_BANG_TILDE] = ACTIONS(252),
    [anon_sym_STAR_TILDE] = ACTIONS(252),
    [anon_sym_LT_EQ] = ACTIONS(252),
    [anon_sym_GT_EQ] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(254),
    [anon_sym_PLUS_EQ] = ACTIONS(252),
    [anon_sym_DASH_EQ] = ACTIONS(252),
    [anon_sym_u00d7] = ACTIONS(252),
    [anon_sym_SLASH] = ACTIONS(254),
    [anon_sym_u00f7] = ACTIONS(252),
    [anon_sym_STAR_STAR] = ACTIONS(252),
    [anon_sym_u220b] = ACTIONS(252),
    [anon_sym_u220c] = ACTIONS(252),
    [anon_sym_u2287] = ACTIONS(252),
    [anon_sym_u2283] = ACTIONS(252),
    [anon_sym_u2285] = ACTIONS(252),
    [anon_sym_u2208] = ACTIONS(252),
    [anon_sym_u2209] = ACTIONS(252),
    [anon_sym_u2286] = ACTIONS(252),
    [anon_sym_u2282] = ACTIONS(252),
    [anon_sym_u2284] = ACTIONS(252),
    [anon_sym_AT_AT] = ACTIONS(252),
  },
  [STATE(56)] = {
    [ts_builtin_sym_end] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(337),
    [sym_keyword_return] = ACTIONS(337),
    [sym_keyword_value] = ACTIONS(337),
    [sym_keyword_explain] = ACTIONS(337),
    [sym_keyword_parallel] = ACTIONS(337),
    [sym_keyword_timeout] = ACTIONS(337),
    [sym_keyword_fetch] = ACTIONS(337),
    [sym_keyword_limit] = ACTIONS(337),
    [sym_keyword_rand] = ACTIONS(337),
    [sym_keyword_collate] = ACTIONS(337),
    [sym_keyword_numeric] = ACTIONS(337),
    [sym_keyword_asc] = ACTIONS(337),
    [sym_keyword_desc] = ACTIONS(337),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_group] = ACTIONS(337),
    [sym_keyword_and] = ACTIONS(337),
    [sym_keyword_or] = ACTIONS(337),
    [sym_keyword_is] = ACTIONS(337),
    [sym_keyword_not] = ACTIONS(339),
    [sym_keyword_contains] = ACTIONS(339),
    [sym_keyword_contains_not] = ACTIONS(337),
    [sym_keyword_contains_all] = ACTIONS(337),
    [sym_keyword_contains_any] = ACTIONS(337),
    [sym_keyword_contains_none] = ACTIONS(337),
    [sym_keyword_inside] = ACTIONS(337),
    [sym_keyword_in] = ACTIONS(339),
    [sym_keyword_not_inside] = ACTIONS(337),
    [sym_keyword_all_inside] = ACTIONS(337),
    [sym_keyword_any_inside] = ACTIONS(337),
    [sym_keyword_none_inside] = ACTIONS(337),
    [sym_keyword_outside] = ACTIONS(337),
    [sym_keyword_intersects] = ACTIONS(337),
    [sym_keyword_drop] = ACTIONS(337),
    [sym_keyword_schemafull] = ACTIONS(337),
    [sym_keyword_schemaless] = ACTIONS(337),
    [sym_keyword_flexible] = ACTIONS(337),
    [sym_keyword_readonly] = ACTIONS(337),
    [sym_keyword_changefeed] = ACTIONS(337),
    [sym_keyword_content] = ACTIONS(337),
    [sym_keyword_merge] = ACTIONS(337),
    [sym_keyword_patch] = ACTIONS(337),
    [sym_keyword_replace] = ACTIONS(337),
    [sym_keyword_type] = ACTIONS(337),
    [sym_keyword_default] = ACTIONS(337),
    [sym_keyword_assert] = ACTIONS(337),
    [sym_keyword_permissions] = ACTIONS(337),
    [sym_keyword_for] = ACTIONS(337),
    [sym_keyword_comment] = ACTIONS(337),
    [sym_keyword_unset] = ACTIONS(337),
    [sym_keyword_set] = ACTIONS(337),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_COMMA] = ACTIONS(337),
    [anon_sym_DASH_GT] = ACTIONS(337),
    [anon_sym_LBRACK] = ACTIONS(337),
    [anon_sym_LT] = ACTIONS(339),
    [anon_sym_GT] = ACTIONS(339),
    [anon_sym_LT_DASH] = ACTIONS(339),
    [anon_sym_LT_DASH_GT] = ACTIONS(337),
    [anon_sym_STAR] = ACTIONS(339),
    [anon_sym_DOT] = ACTIONS(337),
    [anon_sym_DASH] = ACTIONS(339),
    [anon_sym_PERCENT] = ACTIONS(337),
    [anon_sym_AT] = ACTIONS(339),
    [anon_sym_LT_PIPE] = ACTIONS(337),
    [anon_sym_AMP_AMP] = ACTIONS(337),
    [anon_sym_PIPE_PIPE] = ACTIONS(337),
    [anon_sym_QMARK_QMARK] = ACTIONS(337),
    [anon_sym_QMARK_COLON] = ACTIONS(337),
    [anon_sym_BANG_EQ] = ACTIONS(337),
    [anon_sym_EQ_EQ] = ACTIONS(337),
    [anon_sym_QMARK_EQ] = ACTIONS(337),
    [anon_sym_STAR_EQ] = ACTIONS(337),
    [anon_sym_TILDE] = ACTIONS(337),
    [anon_sym_BANG_TILDE] = ACTIONS(337),
    [anon_sym_STAR_TILDE] = ACTIONS(337),
    [anon_sym_LT_EQ] = ACTIONS(337),
    [anon_sym_GT_EQ] = ACTIONS(337),
    [anon_sym_PLUS] = ACTIONS(339),
    [anon_sym_PLUS_EQ] = ACTIONS(337),
    [anon_sym_DASH_EQ] = ACTIONS(337),
    [anon_sym_u00d7] = ACTIONS(337),
    [anon_sym_SLASH] = ACTIONS(339),
    [anon_sym_u00f7] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(337),
    [anon_sym_u220b] = ACTIONS(337),
    [anon_sym_u220c] = ACTIONS(337),
    [anon_sym_u2287] = ACTIONS(337),
    [anon_sym_u2283] = ACTIONS(337),
    [anon_sym_u2285] = ACTIONS(337),
    [anon_sym_u2208] = ACTIONS(337),
    [anon_sym_u2209] = ACTIONS(337),
    [anon_sym_u2286] = ACTIONS(337),
    [anon_sym_u2282] = ACTIONS(337),
    [anon_sym_u2284] = ACTIONS(337),
    [anon_sym_AT_AT] = ACTIONS(337),
  },
  [STATE(57)] = {
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_return] = ACTIONS(204),
    [sym_keyword_value] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_rand] = ACTIONS(204),
    [sym_keyword_collate] = ACTIONS(204),
    [sym_keyword_numeric] = ACTIONS(204),
    [sym_keyword_asc] = ACTIONS(204),
    [sym_keyword_desc] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_drop] = ACTIONS(204),
    [sym_keyword_schemafull] = ACTIONS(204),
    [sym_keyword_schemaless] = ACTIONS(204),
    [sym_keyword_flexible] = ACTIONS(204),
    [sym_keyword_readonly] = ACTIONS(204),
    [sym_keyword_changefeed] = ACTIONS(204),
    [sym_keyword_content] = ACTIONS(204),
    [sym_keyword_merge] = ACTIONS(204),
    [sym_keyword_patch] = ACTIONS(204),
    [sym_keyword_replace] = ACTIONS(204),
    [sym_keyword_type] = ACTIONS(204),
    [sym_keyword_default] = ACTIONS(204),
    [sym_keyword_assert] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [sym_keyword_unset] = ACTIONS(204),
    [sym_keyword_set] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(58)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_on] = ACTIONS(186),
    [sym_keyword_return] = ACTIONS(186),
    [sym_keyword_from] = ACTIONS(186),
    [sym_keyword_as] = ACTIONS(186),
    [sym_keyword_omit] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_drop] = ACTIONS(186),
    [sym_keyword_schemafull] = ACTIONS(186),
    [sym_keyword_schemaless] = ACTIONS(186),
    [sym_keyword_changefeed] = ACTIONS(186),
    [sym_keyword_content] = ACTIONS(186),
    [sym_keyword_merge] = ACTIONS(186),
    [sym_keyword_patch] = ACTIONS(186),
    [sym_keyword_replace] = ACTIONS(186),
    [sym_keyword_then] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [sym_keyword_unset] = ACTIONS(186),
    [sym_keyword_set] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_LPAREN] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACK] = ACTIONS(186),
    [anon_sym_QMARK] = ACTIONS(188),
    [anon_sym_LBRACE] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(188),
    [anon_sym_DOT_DOT] = ACTIONS(341),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(59)] = {
    [ts_builtin_sym_end] = ACTIONS(343),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(343),
    [sym_keyword_return] = ACTIONS(343),
    [sym_keyword_value] = ACTIONS(343),
    [sym_keyword_explain] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(343),
    [sym_keyword_timeout] = ACTIONS(343),
    [sym_keyword_fetch] = ACTIONS(343),
    [sym_keyword_limit] = ACTIONS(343),
    [sym_keyword_rand] = ACTIONS(343),
    [sym_keyword_collate] = ACTIONS(343),
    [sym_keyword_numeric] = ACTIONS(343),
    [sym_keyword_asc] = ACTIONS(343),
    [sym_keyword_desc] = ACTIONS(343),
    [sym_keyword_where] = ACTIONS(343),
    [sym_keyword_group] = ACTIONS(343),
    [sym_keyword_and] = ACTIONS(343),
    [sym_keyword_or] = ACTIONS(343),
    [sym_keyword_is] = ACTIONS(343),
    [sym_keyword_not] = ACTIONS(345),
    [sym_keyword_contains] = ACTIONS(345),
    [sym_keyword_contains_not] = ACTIONS(343),
    [sym_keyword_contains_all] = ACTIONS(343),
    [sym_keyword_contains_any] = ACTIONS(343),
    [sym_keyword_contains_none] = ACTIONS(343),
    [sym_keyword_inside] = ACTIONS(343),
    [sym_keyword_in] = ACTIONS(345),
    [sym_keyword_not_inside] = ACTIONS(343),
    [sym_keyword_all_inside] = ACTIONS(343),
    [sym_keyword_any_inside] = ACTIONS(343),
    [sym_keyword_none_inside] = ACTIONS(343),
    [sym_keyword_outside] = ACTIONS(343),
    [sym_keyword_intersects] = ACTIONS(343),
    [sym_keyword_drop] = ACTIONS(343),
    [sym_keyword_schemafull] = ACTIONS(343),
    [sym_keyword_schemaless] = ACTIONS(343),
    [sym_keyword_flexible] = ACTIONS(343),
    [sym_keyword_readonly] = ACTIONS(343),
    [sym_keyword_changefeed] = ACTIONS(343),
    [sym_keyword_content] = ACTIONS(343),
    [sym_keyword_merge] = ACTIONS(343),
    [sym_keyword_patch] = ACTIONS(343),
    [sym_keyword_replace] = ACTIONS(343),
    [sym_keyword_type] = ACTIONS(343),
    [sym_keyword_default] = ACTIONS(343),
    [sym_keyword_assert] = ACTIONS(343),
    [sym_keyword_permissions] = ACTIONS(343),
    [sym_keyword_for] = ACTIONS(343),
    [sym_keyword_comment] = ACTIONS(343),
    [sym_keyword_unset] = ACTIONS(343),
    [sym_keyword_set] = ACTIONS(343),
    [anon_sym_EQ] = ACTIONS(345),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(343),
    [anon_sym_LT] = ACTIONS(345),
    [anon_sym_GT] = ACTIONS(345),
    [anon_sym_LT_DASH] = ACTIONS(345),
    [anon_sym_LT_DASH_GT] = ACTIONS(343),
    [anon_sym_STAR] = ACTIONS(345),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_PERCENT] = ACTIONS(343),
    [anon_sym_AT] = ACTIONS(345),
    [anon_sym_LT_PIPE] = ACTIONS(343),
    [anon_sym_AMP_AMP] = ACTIONS(343),
    [anon_sym_PIPE_PIPE] = ACTIONS(343),
    [anon_sym_QMARK_QMARK] = ACTIONS(343),
    [anon_sym_QMARK_COLON] = ACTIONS(343),
    [anon_sym_BANG_EQ] = ACTIONS(343),
    [anon_sym_EQ_EQ] = ACTIONS(343),
    [anon_sym_QMARK_EQ] = ACTIONS(343),
    [anon_sym_STAR_EQ] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(343),
    [anon_sym_BANG_TILDE] = ACTIONS(343),
    [anon_sym_STAR_TILDE] = ACTIONS(343),
    [anon_sym_LT_EQ] = ACTIONS(343),
    [anon_sym_GT_EQ] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_PLUS_EQ] = ACTIONS(343),
    [anon_sym_DASH_EQ] = ACTIONS(343),
    [anon_sym_u00d7] = ACTIONS(343),
    [anon_sym_SLASH] = ACTIONS(345),
    [anon_sym_u00f7] = ACTIONS(343),
    [anon_sym_STAR_STAR] = ACTIONS(343),
    [anon_sym_u220b] = ACTIONS(343),
    [anon_sym_u220c] = ACTIONS(343),
    [anon_sym_u2287] = ACTIONS(343),
    [anon_sym_u2283] = ACTIONS(343),
    [anon_sym_u2285] = ACTIONS(343),
    [anon_sym_u2208] = ACTIONS(343),
    [anon_sym_u2209] = ACTIONS(343),
    [anon_sym_u2286] = ACTIONS(343),
    [anon_sym_u2282] = ACTIONS(343),
    [anon_sym_u2284] = ACTIONS(343),
    [anon_sym_AT_AT] = ACTIONS(343),
  },
  [STATE(60)] = {
    [ts_builtin_sym_end] = ACTIONS(347),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(347),
    [sym_keyword_return] = ACTIONS(347),
    [sym_keyword_value] = ACTIONS(347),
    [sym_keyword_explain] = ACTIONS(347),
    [sym_keyword_parallel] = ACTIONS(347),
    [sym_keyword_timeout] = ACTIONS(347),
    [sym_keyword_fetch] = ACTIONS(347),
    [sym_keyword_limit] = ACTIONS(347),
    [sym_keyword_rand] = ACTIONS(347),
    [sym_keyword_collate] = ACTIONS(347),
    [sym_keyword_numeric] = ACTIONS(347),
    [sym_keyword_asc] = ACTIONS(347),
    [sym_keyword_desc] = ACTIONS(347),
    [sym_keyword_where] = ACTIONS(347),
    [sym_keyword_group] = ACTIONS(347),
    [sym_keyword_and] = ACTIONS(347),
    [sym_keyword_or] = ACTIONS(347),
    [sym_keyword_is] = ACTIONS(347),
    [sym_keyword_not] = ACTIONS(349),
    [sym_keyword_contains] = ACTIONS(349),
    [sym_keyword_contains_not] = ACTIONS(347),
    [sym_keyword_contains_all] = ACTIONS(347),
    [sym_keyword_contains_any] = ACTIONS(347),
    [sym_keyword_contains_none] = ACTIONS(347),
    [sym_keyword_inside] = ACTIONS(347),
    [sym_keyword_in] = ACTIONS(349),
    [sym_keyword_not_inside] = ACTIONS(347),
    [sym_keyword_all_inside] = ACTIONS(347),
    [sym_keyword_any_inside] = ACTIONS(347),
    [sym_keyword_none_inside] = ACTIONS(347),
    [sym_keyword_outside] = ACTIONS(347),
    [sym_keyword_intersects] = ACTIONS(347),
    [sym_keyword_drop] = ACTIONS(347),
    [sym_keyword_schemafull] = ACTIONS(347),
    [sym_keyword_schemaless] = ACTIONS(347),
    [sym_keyword_flexible] = ACTIONS(347),
    [sym_keyword_readonly] = ACTIONS(347),
    [sym_keyword_changefeed] = ACTIONS(347),
    [sym_keyword_content] = ACTIONS(347),
    [sym_keyword_merge] = ACTIONS(347),
    [sym_keyword_patch] = ACTIONS(347),
    [sym_keyword_replace] = ACTIONS(347),
    [sym_keyword_type] = ACTIONS(347),
    [sym_keyword_default] = ACTIONS(347),
    [sym_keyword_assert] = ACTIONS(347),
    [sym_keyword_permissions] = ACTIONS(347),
    [sym_keyword_for] = ACTIONS(347),
    [sym_keyword_comment] = ACTIONS(347),
    [sym_keyword_unset] = ACTIONS(347),
    [sym_keyword_set] = ACTIONS(347),
    [anon_sym_EQ] = ACTIONS(349),
    [anon_sym_COMMA] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(347),
    [anon_sym_LBRACK] = ACTIONS(347),
    [anon_sym_LT] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(349),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_DASH_GT] = ACTIONS(347),
    [anon_sym_STAR] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_AT] = ACTIONS(349),
    [anon_sym_LT_PIPE] = ACTIONS(347),
    [anon_sym_AMP_AMP] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(347),
    [anon_sym_QMARK_QMARK] = ACTIONS(347),
    [anon_sym_QMARK_COLON] = ACTIONS(347),
    [anon_sym_BANG_EQ] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(347),
    [anon_sym_QMARK_EQ] = ACTIONS(347),
    [anon_sym_STAR_EQ] = ACTIONS(347),
    [anon_sym_TILDE] = ACTIONS(347),
    [anon_sym_BANG_TILDE] = ACTIONS(347),
    [anon_sym_STAR_TILDE] = ACTIONS(347),
    [anon_sym_LT_EQ] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_PLUS_EQ] = ACTIONS(347),
    [anon_sym_DASH_EQ] = ACTIONS(347),
    [anon_sym_u00d7] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_u00f7] = ACTIONS(347),
    [anon_sym_STAR_STAR] = ACTIONS(347),
    [anon_sym_u220b] = ACTIONS(347),
    [anon_sym_u220c] = ACTIONS(347),
    [anon_sym_u2287] = ACTIONS(347),
    [anon_sym_u2283] = ACTIONS(347),
    [anon_sym_u2285] = ACTIONS(347),
    [anon_sym_u2208] = ACTIONS(347),
    [anon_sym_u2209] = ACTIONS(347),
    [anon_sym_u2286] = ACTIONS(347),
    [anon_sym_u2282] = ACTIONS(347),
    [anon_sym_u2284] = ACTIONS(347),
    [anon_sym_AT_AT] = ACTIONS(347),
  },
  [STATE(61)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(244),
    [sym_keyword_on] = ACTIONS(244),
    [sym_keyword_return] = ACTIONS(244),
    [sym_keyword_from] = ACTIONS(244),
    [sym_keyword_as] = ACTIONS(244),
    [sym_keyword_omit] = ACTIONS(244),
    [sym_keyword_explain] = ACTIONS(244),
    [sym_keyword_parallel] = ACTIONS(244),
    [sym_keyword_timeout] = ACTIONS(244),
    [sym_keyword_fetch] = ACTIONS(244),
    [sym_keyword_limit] = ACTIONS(244),
    [sym_keyword_where] = ACTIONS(244),
    [sym_keyword_group] = ACTIONS(244),
    [sym_keyword_and] = ACTIONS(244),
    [sym_keyword_or] = ACTIONS(244),
    [sym_keyword_is] = ACTIONS(244),
    [sym_keyword_not] = ACTIONS(246),
    [sym_keyword_contains] = ACTIONS(246),
    [sym_keyword_contains_not] = ACTIONS(244),
    [sym_keyword_contains_all] = ACTIONS(244),
    [sym_keyword_contains_any] = ACTIONS(244),
    [sym_keyword_contains_none] = ACTIONS(244),
    [sym_keyword_inside] = ACTIONS(244),
    [sym_keyword_in] = ACTIONS(246),
    [sym_keyword_not_inside] = ACTIONS(244),
    [sym_keyword_all_inside] = ACTIONS(244),
    [sym_keyword_any_inside] = ACTIONS(244),
    [sym_keyword_none_inside] = ACTIONS(244),
    [sym_keyword_outside] = ACTIONS(244),
    [sym_keyword_intersects] = ACTIONS(244),
    [sym_keyword_drop] = ACTIONS(244),
    [sym_keyword_schemafull] = ACTIONS(244),
    [sym_keyword_schemaless] = ACTIONS(244),
    [sym_keyword_changefeed] = ACTIONS(244),
    [sym_keyword_content] = ACTIONS(244),
    [sym_keyword_merge] = ACTIONS(244),
    [sym_keyword_patch] = ACTIONS(244),
    [sym_keyword_replace] = ACTIONS(244),
    [sym_keyword_then] = ACTIONS(244),
    [sym_keyword_permissions] = ACTIONS(244),
    [sym_keyword_for] = ACTIONS(244),
    [sym_keyword_comment] = ACTIONS(244),
    [sym_keyword_unset] = ACTIONS(244),
    [sym_keyword_set] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(246),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_LPAREN] = ACTIONS(244),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_DASH_GT] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(244),
    [anon_sym_RBRACK] = ACTIONS(244),
    [anon_sym_QMARK] = ACTIONS(246),
    [anon_sym_LBRACE] = ACTIONS(244),
    [anon_sym_RBRACE] = ACTIONS(244),
    [anon_sym_LT] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(246),
    [anon_sym_LT_DASH] = ACTIONS(246),
    [anon_sym_LT_DASH_GT] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(246),
    [anon_sym_DOT_DOT] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(246),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_AT] = ACTIONS(246),
    [anon_sym_LT_PIPE] = ACTIONS(244),
    [anon_sym_AMP_AMP] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(244),
    [anon_sym_QMARK_QMARK] = ACTIONS(244),
    [anon_sym_QMARK_COLON] = ACTIONS(244),
    [anon_sym_BANG_EQ] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(244),
    [anon_sym_QMARK_EQ] = ACTIONS(244),
    [anon_sym_STAR_EQ] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_BANG_TILDE] = ACTIONS(244),
    [anon_sym_STAR_TILDE] = ACTIONS(244),
    [anon_sym_LT_EQ] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(246),
    [anon_sym_PLUS_EQ] = ACTIONS(244),
    [anon_sym_DASH_EQ] = ACTIONS(244),
    [anon_sym_u00d7] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(246),
    [anon_sym_u00f7] = ACTIONS(244),
    [anon_sym_STAR_STAR] = ACTIONS(244),
    [anon_sym_u220b] = ACTIONS(244),
    [anon_sym_u220c] = ACTIONS(244),
    [anon_sym_u2287] = ACTIONS(244),
    [anon_sym_u2283] = ACTIONS(244),
    [anon_sym_u2285] = ACTIONS(244),
    [anon_sym_u2208] = ACTIONS(244),
    [anon_sym_u2209] = ACTIONS(244),
    [anon_sym_u2286] = ACTIONS(244),
    [anon_sym_u2282] = ACTIONS(244),
    [anon_sym_u2284] = ACTIONS(244),
    [anon_sym_AT_AT] = ACTIONS(244),
  },
  [STATE(62)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(208),
    [sym_keyword_on] = ACTIONS(208),
    [sym_keyword_return] = ACTIONS(208),
    [sym_keyword_from] = ACTIONS(208),
    [sym_keyword_as] = ACTIONS(208),
    [sym_keyword_omit] = ACTIONS(208),
    [sym_keyword_explain] = ACTIONS(208),
    [sym_keyword_parallel] = ACTIONS(208),
    [sym_keyword_timeout] = ACTIONS(208),
    [sym_keyword_fetch] = ACTIONS(208),
    [sym_keyword_limit] = ACTIONS(208),
    [sym_keyword_where] = ACTIONS(208),
    [sym_keyword_group] = ACTIONS(208),
    [sym_keyword_and] = ACTIONS(208),
    [sym_keyword_or] = ACTIONS(208),
    [sym_keyword_is] = ACTIONS(208),
    [sym_keyword_not] = ACTIONS(210),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(208),
    [sym_keyword_contains_all] = ACTIONS(208),
    [sym_keyword_contains_any] = ACTIONS(208),
    [sym_keyword_contains_none] = ACTIONS(208),
    [sym_keyword_inside] = ACTIONS(208),
    [sym_keyword_in] = ACTIONS(210),
    [sym_keyword_not_inside] = ACTIONS(208),
    [sym_keyword_all_inside] = ACTIONS(208),
    [sym_keyword_any_inside] = ACTIONS(208),
    [sym_keyword_none_inside] = ACTIONS(208),
    [sym_keyword_outside] = ACTIONS(208),
    [sym_keyword_intersects] = ACTIONS(208),
    [sym_keyword_drop] = ACTIONS(208),
    [sym_keyword_schemafull] = ACTIONS(208),
    [sym_keyword_schemaless] = ACTIONS(208),
    [sym_keyword_changefeed] = ACTIONS(208),
    [sym_keyword_content] = ACTIONS(208),
    [sym_keyword_merge] = ACTIONS(208),
    [sym_keyword_patch] = ACTIONS(208),
    [sym_keyword_replace] = ACTIONS(208),
    [sym_keyword_then] = ACTIONS(208),
    [sym_keyword_permissions] = ACTIONS(208),
    [sym_keyword_for] = ACTIONS(208),
    [sym_keyword_comment] = ACTIONS(208),
    [sym_keyword_unset] = ACTIONS(208),
    [sym_keyword_set] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(208),
    [anon_sym_LPAREN] = ACTIONS(208),
    [anon_sym_RPAREN] = ACTIONS(208),
    [anon_sym_DASH_GT] = ACTIONS(208),
    [anon_sym_LBRACK] = ACTIONS(208),
    [anon_sym_RBRACK] = ACTIONS(208),
    [anon_sym_QMARK] = ACTIONS(210),
    [anon_sym_LBRACE] = ACTIONS(208),
    [anon_sym_RBRACE] = ACTIONS(208),
    [anon_sym_LT] = ACTIONS(210),
    [anon_sym_GT] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(210),
    [anon_sym_LT_DASH_GT] = ACTIONS(208),
    [anon_sym_STAR] = ACTIONS(210),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_DOT_DOT] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(210),
    [anon_sym_PERCENT] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(210),
    [anon_sym_LT_PIPE] = ACTIONS(208),
    [anon_sym_AMP_AMP] = ACTIONS(208),
    [anon_sym_PIPE_PIPE] = ACTIONS(208),
    [anon_sym_QMARK_QMARK] = ACTIONS(208),
    [anon_sym_QMARK_COLON] = ACTIONS(208),
    [anon_sym_BANG_EQ] = ACTIONS(208),
    [anon_sym_EQ_EQ] = ACTIONS(208),
    [anon_sym_QMARK_EQ] = ACTIONS(208),
    [anon_sym_STAR_EQ] = ACTIONS(208),
    [anon_sym_TILDE] = ACTIONS(208),
    [anon_sym_BANG_TILDE] = ACTIONS(208),
    [anon_sym_STAR_TILDE] = ACTIONS(208),
    [anon_sym_LT_EQ] = ACTIONS(208),
    [anon_sym_GT_EQ] = ACTIONS(208),
    [anon_sym_PLUS] = ACTIONS(210),
    [anon_sym_PLUS_EQ] = ACTIONS(208),
    [anon_sym_DASH_EQ] = ACTIONS(208),
    [anon_sym_u00d7] = ACTIONS(208),
    [anon_sym_SLASH] = ACTIONS(210),
    [anon_sym_u00f7] = ACTIONS(208),
    [anon_sym_STAR_STAR] = ACTIONS(208),
    [anon_sym_u220b] = ACTIONS(208),
    [anon_sym_u220c] = ACTIONS(208),
    [anon_sym_u2287] = ACTIONS(208),
    [anon_sym_u2283] = ACTIONS(208),
    [anon_sym_u2285] = ACTIONS(208),
    [anon_sym_u2208] = ACTIONS(208),
    [anon_sym_u2209] = ACTIONS(208),
    [anon_sym_u2286] = ACTIONS(208),
    [anon_sym_u2282] = ACTIONS(208),
    [anon_sym_u2284] = ACTIONS(208),
    [anon_sym_AT_AT] = ACTIONS(208),
  },
  [STATE(63)] = {
    [ts_builtin_sym_end] = ACTIONS(351),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(351),
    [sym_keyword_return] = ACTIONS(351),
    [sym_keyword_value] = ACTIONS(351),
    [sym_keyword_explain] = ACTIONS(351),
    [sym_keyword_parallel] = ACTIONS(351),
    [sym_keyword_timeout] = ACTIONS(351),
    [sym_keyword_fetch] = ACTIONS(351),
    [sym_keyword_limit] = ACTIONS(351),
    [sym_keyword_rand] = ACTIONS(351),
    [sym_keyword_collate] = ACTIONS(351),
    [sym_keyword_numeric] = ACTIONS(351),
    [sym_keyword_asc] = ACTIONS(351),
    [sym_keyword_desc] = ACTIONS(351),
    [sym_keyword_where] = ACTIONS(351),
    [sym_keyword_group] = ACTIONS(351),
    [sym_keyword_and] = ACTIONS(351),
    [sym_keyword_or] = ACTIONS(351),
    [sym_keyword_is] = ACTIONS(351),
    [sym_keyword_not] = ACTIONS(353),
    [sym_keyword_contains] = ACTIONS(353),
    [sym_keyword_contains_not] = ACTIONS(351),
    [sym_keyword_contains_all] = ACTIONS(351),
    [sym_keyword_contains_any] = ACTIONS(351),
    [sym_keyword_contains_none] = ACTIONS(351),
    [sym_keyword_inside] = ACTIONS(351),
    [sym_keyword_in] = ACTIONS(353),
    [sym_keyword_not_inside] = ACTIONS(351),
    [sym_keyword_all_inside] = ACTIONS(351),
    [sym_keyword_any_inside] = ACTIONS(351),
    [sym_keyword_none_inside] = ACTIONS(351),
    [sym_keyword_outside] = ACTIONS(351),
    [sym_keyword_intersects] = ACTIONS(351),
    [sym_keyword_drop] = ACTIONS(351),
    [sym_keyword_schemafull] = ACTIONS(351),
    [sym_keyword_schemaless] = ACTIONS(351),
    [sym_keyword_flexible] = ACTIONS(351),
    [sym_keyword_readonly] = ACTIONS(351),
    [sym_keyword_changefeed] = ACTIONS(351),
    [sym_keyword_content] = ACTIONS(351),
    [sym_keyword_merge] = ACTIONS(351),
    [sym_keyword_patch] = ACTIONS(351),
    [sym_keyword_replace] = ACTIONS(351),
    [sym_keyword_type] = ACTIONS(351),
    [sym_keyword_default] = ACTIONS(351),
    [sym_keyword_assert] = ACTIONS(351),
    [sym_keyword_permissions] = ACTIONS(351),
    [sym_keyword_for] = ACTIONS(351),
    [sym_keyword_comment] = ACTIONS(351),
    [sym_keyword_unset] = ACTIONS(351),
    [sym_keyword_set] = ACTIONS(351),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_COMMA] = ACTIONS(351),
    [anon_sym_DASH_GT] = ACTIONS(351),
    [anon_sym_LBRACK] = ACTIONS(351),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH_GT] = ACTIONS(351),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [anon_sym_LT_PIPE] = ACTIONS(351),
    [anon_sym_AMP_AMP] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(351),
    [anon_sym_QMARK_QMARK] = ACTIONS(351),
    [anon_sym_QMARK_COLON] = ACTIONS(351),
    [anon_sym_BANG_EQ] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(351),
    [anon_sym_QMARK_EQ] = ACTIONS(351),
    [anon_sym_STAR_EQ] = ACTIONS(351),
    [anon_sym_TILDE] = ACTIONS(351),
    [anon_sym_BANG_TILDE] = ACTIONS(351),
    [anon_sym_STAR_TILDE] = ACTIONS(351),
    [anon_sym_LT_EQ] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(353),
    [anon_sym_PLUS_EQ] = ACTIONS(351),
    [anon_sym_DASH_EQ] = ACTIONS(351),
    [anon_sym_u00d7] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(353),
    [anon_sym_u00f7] = ACTIONS(351),
    [anon_sym_STAR_STAR] = ACTIONS(351),
    [anon_sym_u220b] = ACTIONS(351),
    [anon_sym_u220c] = ACTIONS(351),
    [anon_sym_u2287] = ACTIONS(351),
    [anon_sym_u2283] = ACTIONS(351),
    [anon_sym_u2285] = ACTIONS(351),
    [anon_sym_u2208] = ACTIONS(351),
    [anon_sym_u2209] = ACTIONS(351),
    [anon_sym_u2286] = ACTIONS(351),
    [anon_sym_u2282] = ACTIONS(351),
    [anon_sym_u2284] = ACTIONS(351),
    [anon_sym_AT_AT] = ACTIONS(351),
  },
  [STATE(64)] = {
    [ts_builtin_sym_end] = ACTIONS(355),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_return] = ACTIONS(355),
    [sym_keyword_value] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_rand] = ACTIONS(355),
    [sym_keyword_collate] = ACTIONS(355),
    [sym_keyword_numeric] = ACTIONS(355),
    [sym_keyword_asc] = ACTIONS(355),
    [sym_keyword_desc] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(355),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [sym_keyword_drop] = ACTIONS(355),
    [sym_keyword_schemafull] = ACTIONS(355),
    [sym_keyword_schemaless] = ACTIONS(355),
    [sym_keyword_flexible] = ACTIONS(355),
    [sym_keyword_readonly] = ACTIONS(355),
    [sym_keyword_changefeed] = ACTIONS(355),
    [sym_keyword_content] = ACTIONS(355),
    [sym_keyword_merge] = ACTIONS(355),
    [sym_keyword_patch] = ACTIONS(355),
    [sym_keyword_replace] = ACTIONS(355),
    [sym_keyword_type] = ACTIONS(355),
    [sym_keyword_default] = ACTIONS(355),
    [sym_keyword_assert] = ACTIONS(355),
    [sym_keyword_permissions] = ACTIONS(355),
    [sym_keyword_for] = ACTIONS(355),
    [sym_keyword_comment] = ACTIONS(355),
    [sym_keyword_unset] = ACTIONS(355),
    [sym_keyword_set] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(65)] = {
    [ts_builtin_sym_end] = ACTIONS(355),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_return] = ACTIONS(355),
    [sym_keyword_value] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_rand] = ACTIONS(355),
    [sym_keyword_collate] = ACTIONS(355),
    [sym_keyword_numeric] = ACTIONS(355),
    [sym_keyword_asc] = ACTIONS(355),
    [sym_keyword_desc] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(355),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [sym_keyword_drop] = ACTIONS(355),
    [sym_keyword_schemafull] = ACTIONS(355),
    [sym_keyword_schemaless] = ACTIONS(355),
    [sym_keyword_flexible] = ACTIONS(355),
    [sym_keyword_readonly] = ACTIONS(355),
    [sym_keyword_changefeed] = ACTIONS(355),
    [sym_keyword_content] = ACTIONS(355),
    [sym_keyword_merge] = ACTIONS(355),
    [sym_keyword_patch] = ACTIONS(355),
    [sym_keyword_replace] = ACTIONS(355),
    [sym_keyword_type] = ACTIONS(355),
    [sym_keyword_default] = ACTIONS(355),
    [sym_keyword_assert] = ACTIONS(355),
    [sym_keyword_permissions] = ACTIONS(355),
    [sym_keyword_for] = ACTIONS(355),
    [sym_keyword_comment] = ACTIONS(355),
    [sym_keyword_unset] = ACTIONS(355),
    [sym_keyword_set] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(66)] = {
    [ts_builtin_sym_end] = ACTIONS(304),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_return] = ACTIONS(304),
    [sym_keyword_value] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_rand] = ACTIONS(304),
    [sym_keyword_collate] = ACTIONS(304),
    [sym_keyword_numeric] = ACTIONS(304),
    [sym_keyword_asc] = ACTIONS(304),
    [sym_keyword_desc] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(304),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [sym_keyword_drop] = ACTIONS(304),
    [sym_keyword_schemafull] = ACTIONS(304),
    [sym_keyword_schemaless] = ACTIONS(304),
    [sym_keyword_flexible] = ACTIONS(304),
    [sym_keyword_readonly] = ACTIONS(304),
    [sym_keyword_changefeed] = ACTIONS(304),
    [sym_keyword_content] = ACTIONS(304),
    [sym_keyword_merge] = ACTIONS(304),
    [sym_keyword_patch] = ACTIONS(304),
    [sym_keyword_replace] = ACTIONS(304),
    [sym_keyword_type] = ACTIONS(304),
    [sym_keyword_default] = ACTIONS(304),
    [sym_keyword_assert] = ACTIONS(304),
    [sym_keyword_permissions] = ACTIONS(304),
    [sym_keyword_for] = ACTIONS(304),
    [sym_keyword_comment] = ACTIONS(304),
    [sym_keyword_unset] = ACTIONS(304),
    [sym_keyword_set] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(67)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(232),
    [sym_keyword_on] = ACTIONS(232),
    [sym_keyword_return] = ACTIONS(232),
    [sym_keyword_from] = ACTIONS(232),
    [sym_keyword_as] = ACTIONS(232),
    [sym_keyword_omit] = ACTIONS(232),
    [sym_keyword_explain] = ACTIONS(232),
    [sym_keyword_parallel] = ACTIONS(232),
    [sym_keyword_timeout] = ACTIONS(232),
    [sym_keyword_fetch] = ACTIONS(232),
    [sym_keyword_limit] = ACTIONS(232),
    [sym_keyword_where] = ACTIONS(232),
    [sym_keyword_group] = ACTIONS(232),
    [sym_keyword_and] = ACTIONS(232),
    [sym_keyword_or] = ACTIONS(232),
    [sym_keyword_is] = ACTIONS(232),
    [sym_keyword_not] = ACTIONS(234),
    [sym_keyword_contains] = ACTIONS(234),
    [sym_keyword_contains_not] = ACTIONS(232),
    [sym_keyword_contains_all] = ACTIONS(232),
    [sym_keyword_contains_any] = ACTIONS(232),
    [sym_keyword_contains_none] = ACTIONS(232),
    [sym_keyword_inside] = ACTIONS(232),
    [sym_keyword_in] = ACTIONS(234),
    [sym_keyword_not_inside] = ACTIONS(232),
    [sym_keyword_all_inside] = ACTIONS(232),
    [sym_keyword_any_inside] = ACTIONS(232),
    [sym_keyword_none_inside] = ACTIONS(232),
    [sym_keyword_outside] = ACTIONS(232),
    [sym_keyword_intersects] = ACTIONS(232),
    [sym_keyword_drop] = ACTIONS(232),
    [sym_keyword_schemafull] = ACTIONS(232),
    [sym_keyword_schemaless] = ACTIONS(232),
    [sym_keyword_changefeed] = ACTIONS(232),
    [sym_keyword_content] = ACTIONS(232),
    [sym_keyword_merge] = ACTIONS(232),
    [sym_keyword_patch] = ACTIONS(232),
    [sym_keyword_replace] = ACTIONS(232),
    [sym_keyword_then] = ACTIONS(232),
    [sym_keyword_permissions] = ACTIONS(232),
    [sym_keyword_for] = ACTIONS(232),
    [sym_keyword_comment] = ACTIONS(232),
    [sym_keyword_unset] = ACTIONS(232),
    [sym_keyword_set] = ACTIONS(232),
    [anon_sym_EQ] = ACTIONS(234),
    [anon_sym_COMMA] = ACTIONS(232),
    [anon_sym_LPAREN] = ACTIONS(232),
    [anon_sym_RPAREN] = ACTIONS(232),
    [anon_sym_DASH_GT] = ACTIONS(232),
    [anon_sym_LBRACK] = ACTIONS(232),
    [anon_sym_RBRACK] = ACTIONS(232),
    [anon_sym_QMARK] = ACTIONS(234),
    [anon_sym_LBRACE] = ACTIONS(232),
    [anon_sym_RBRACE] = ACTIONS(232),
    [anon_sym_LT] = ACTIONS(234),
    [anon_sym_GT] = ACTIONS(234),
    [anon_sym_LT_DASH] = ACTIONS(234),
    [anon_sym_LT_DASH_GT] = ACTIONS(232),
    [anon_sym_STAR] = ACTIONS(234),
    [anon_sym_DOT] = ACTIONS(234),
    [anon_sym_DOT_DOT] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(234),
    [anon_sym_PERCENT] = ACTIONS(232),
    [anon_sym_AT] = ACTIONS(234),
    [anon_sym_LT_PIPE] = ACTIONS(232),
    [anon_sym_AMP_AMP] = ACTIONS(232),
    [anon_sym_PIPE_PIPE] = ACTIONS(232),
    [anon_sym_QMARK_QMARK] = ACTIONS(232),
    [anon_sym_QMARK_COLON] = ACTIONS(232),
    [anon_sym_BANG_EQ] = ACTIONS(232),
    [anon_sym_EQ_EQ] = ACTIONS(232),
    [anon_sym_QMARK_EQ] = ACTIONS(232),
    [anon_sym_STAR_EQ] = ACTIONS(232),
    [anon_sym_TILDE] = ACTIONS(232),
    [anon_sym_BANG_TILDE] = ACTIONS(232),
    [anon_sym_STAR_TILDE] = ACTIONS(232),
    [anon_sym_LT_EQ] = ACTIONS(232),
    [anon_sym_GT_EQ] = ACTIONS(232),
    [anon_sym_PLUS] = ACTIONS(234),
    [anon_sym_PLUS_EQ] = ACTIONS(232),
    [anon_sym_DASH_EQ] = ACTIONS(232),
    [anon_sym_u00d7] = ACTIONS(232),
    [anon_sym_SLASH] = ACTIONS(234),
    [anon_sym_u00f7] = ACTIONS(232),
    [anon_sym_STAR_STAR] = ACTIONS(232),
    [anon_sym_u220b] = ACTIONS(232),
    [anon_sym_u220c] = ACTIONS(232),
    [anon_sym_u2287] = ACTIONS(232),
    [anon_sym_u2283] = ACTIONS(232),
    [anon_sym_u2285] = ACTIONS(232),
    [anon_sym_u2208] = ACTIONS(232),
    [anon_sym_u2209] = ACTIONS(232),
    [anon_sym_u2286] = ACTIONS(232),
    [anon_sym_u2282] = ACTIONS(232),
    [anon_sym_u2284] = ACTIONS(232),
    [anon_sym_AT_AT] = ACTIONS(232),
  },
  [STATE(68)] = {
    [ts_builtin_sym_end] = ACTIONS(359),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(359),
    [sym_keyword_return] = ACTIONS(359),
    [sym_keyword_value] = ACTIONS(359),
    [sym_keyword_explain] = ACTIONS(359),
    [sym_keyword_parallel] = ACTIONS(359),
    [sym_keyword_timeout] = ACTIONS(359),
    [sym_keyword_fetch] = ACTIONS(359),
    [sym_keyword_limit] = ACTIONS(359),
    [sym_keyword_rand] = ACTIONS(359),
    [sym_keyword_collate] = ACTIONS(359),
    [sym_keyword_numeric] = ACTIONS(359),
    [sym_keyword_asc] = ACTIONS(359),
    [sym_keyword_desc] = ACTIONS(359),
    [sym_keyword_where] = ACTIONS(359),
    [sym_keyword_group] = ACTIONS(359),
    [sym_keyword_and] = ACTIONS(359),
    [sym_keyword_or] = ACTIONS(359),
    [sym_keyword_is] = ACTIONS(359),
    [sym_keyword_not] = ACTIONS(361),
    [sym_keyword_contains] = ACTIONS(361),
    [sym_keyword_contains_not] = ACTIONS(359),
    [sym_keyword_contains_all] = ACTIONS(359),
    [sym_keyword_contains_any] = ACTIONS(359),
    [sym_keyword_contains_none] = ACTIONS(359),
    [sym_keyword_inside] = ACTIONS(359),
    [sym_keyword_in] = ACTIONS(361),
    [sym_keyword_not_inside] = ACTIONS(359),
    [sym_keyword_all_inside] = ACTIONS(359),
    [sym_keyword_any_inside] = ACTIONS(359),
    [sym_keyword_none_inside] = ACTIONS(359),
    [sym_keyword_outside] = ACTIONS(359),
    [sym_keyword_intersects] = ACTIONS(359),
    [sym_keyword_drop] = ACTIONS(359),
    [sym_keyword_schemafull] = ACTIONS(359),
    [sym_keyword_schemaless] = ACTIONS(359),
    [sym_keyword_flexible] = ACTIONS(359),
    [sym_keyword_readonly] = ACTIONS(359),
    [sym_keyword_changefeed] = ACTIONS(359),
    [sym_keyword_content] = ACTIONS(359),
    [sym_keyword_merge] = ACTIONS(359),
    [sym_keyword_patch] = ACTIONS(359),
    [sym_keyword_replace] = ACTIONS(359),
    [sym_keyword_type] = ACTIONS(359),
    [sym_keyword_default] = ACTIONS(359),
    [sym_keyword_assert] = ACTIONS(359),
    [sym_keyword_permissions] = ACTIONS(359),
    [sym_keyword_for] = ACTIONS(359),
    [sym_keyword_comment] = ACTIONS(359),
    [sym_keyword_unset] = ACTIONS(359),
    [sym_keyword_set] = ACTIONS(359),
    [anon_sym_EQ] = ACTIONS(361),
    [anon_sym_COMMA] = ACTIONS(359),
    [anon_sym_DASH_GT] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_LT] = ACTIONS(361),
    [anon_sym_GT] = ACTIONS(361),
    [anon_sym_LT_DASH] = ACTIONS(361),
    [anon_sym_LT_DASH_GT] = ACTIONS(359),
    [anon_sym_STAR] = ACTIONS(361),
    [anon_sym_DOT] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [anon_sym_PERCENT] = ACTIONS(359),
    [anon_sym_AT] = ACTIONS(361),
    [anon_sym_LT_PIPE] = ACTIONS(359),
    [anon_sym_AMP_AMP] = ACTIONS(359),
    [anon_sym_PIPE_PIPE] = ACTIONS(359),
    [anon_sym_QMARK_QMARK] = ACTIONS(359),
    [anon_sym_QMARK_COLON] = ACTIONS(359),
    [anon_sym_BANG_EQ] = ACTIONS(359),
    [anon_sym_EQ_EQ] = ACTIONS(359),
    [anon_sym_QMARK_EQ] = ACTIONS(359),
    [anon_sym_STAR_EQ] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(359),
    [anon_sym_BANG_TILDE] = ACTIONS(359),
    [anon_sym_STAR_TILDE] = ACTIONS(359),
    [anon_sym_LT_EQ] = ACTIONS(359),
    [anon_sym_GT_EQ] = ACTIONS(359),
    [anon_sym_PLUS] = ACTIONS(361),
    [anon_sym_PLUS_EQ] = ACTIONS(359),
    [anon_sym_DASH_EQ] = ACTIONS(359),
    [anon_sym_u00d7] = ACTIONS(359),
    [anon_sym_SLASH] = ACTIONS(361),
    [anon_sym_u00f7] = ACTIONS(359),
    [anon_sym_STAR_STAR] = ACTIONS(359),
    [anon_sym_u220b] = ACTIONS(359),
    [anon_sym_u220c] = ACTIONS(359),
    [anon_sym_u2287] = ACTIONS(359),
    [anon_sym_u2283] = ACTIONS(359),
    [anon_sym_u2285] = ACTIONS(359),
    [anon_sym_u2208] = ACTIONS(359),
    [anon_sym_u2209] = ACTIONS(359),
    [anon_sym_u2286] = ACTIONS(359),
    [anon_sym_u2282] = ACTIONS(359),
    [anon_sym_u2284] = ACTIONS(359),
    [anon_sym_AT_AT] = ACTIONS(359),
  },
  [STATE(69)] = {
    [sym_argument_list] = STATE(92),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_on] = ACTIONS(278),
    [sym_keyword_return] = ACTIONS(278),
    [sym_keyword_from] = ACTIONS(278),
    [sym_keyword_as] = ACTIONS(278),
    [sym_keyword_omit] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(278),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [sym_keyword_drop] = ACTIONS(278),
    [sym_keyword_schemafull] = ACTIONS(278),
    [sym_keyword_schemaless] = ACTIONS(278),
    [sym_keyword_changefeed] = ACTIONS(278),
    [sym_keyword_content] = ACTIONS(278),
    [sym_keyword_merge] = ACTIONS(278),
    [sym_keyword_patch] = ACTIONS(278),
    [sym_keyword_replace] = ACTIONS(278),
    [sym_keyword_then] = ACTIONS(278),
    [sym_keyword_permissions] = ACTIONS(278),
    [sym_keyword_for] = ACTIONS(278),
    [sym_keyword_comment] = ACTIONS(278),
    [sym_keyword_unset] = ACTIONS(278),
    [sym_keyword_set] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_LPAREN] = ACTIONS(363),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_RBRACK] = ACTIONS(278),
    [anon_sym_QMARK] = ACTIONS(280),
    [anon_sym_LBRACE] = ACTIONS(278),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(70)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(240),
    [sym_keyword_on] = ACTIONS(240),
    [sym_keyword_return] = ACTIONS(240),
    [sym_keyword_from] = ACTIONS(240),
    [sym_keyword_as] = ACTIONS(240),
    [sym_keyword_omit] = ACTIONS(240),
    [sym_keyword_explain] = ACTIONS(240),
    [sym_keyword_parallel] = ACTIONS(240),
    [sym_keyword_timeout] = ACTIONS(240),
    [sym_keyword_fetch] = ACTIONS(240),
    [sym_keyword_limit] = ACTIONS(240),
    [sym_keyword_where] = ACTIONS(240),
    [sym_keyword_group] = ACTIONS(240),
    [sym_keyword_and] = ACTIONS(240),
    [sym_keyword_or] = ACTIONS(240),
    [sym_keyword_is] = ACTIONS(240),
    [sym_keyword_not] = ACTIONS(242),
    [sym_keyword_contains] = ACTIONS(242),
    [sym_keyword_contains_not] = ACTIONS(240),
    [sym_keyword_contains_all] = ACTIONS(240),
    [sym_keyword_contains_any] = ACTIONS(240),
    [sym_keyword_contains_none] = ACTIONS(240),
    [sym_keyword_inside] = ACTIONS(240),
    [sym_keyword_in] = ACTIONS(242),
    [sym_keyword_not_inside] = ACTIONS(240),
    [sym_keyword_all_inside] = ACTIONS(240),
    [sym_keyword_any_inside] = ACTIONS(240),
    [sym_keyword_none_inside] = ACTIONS(240),
    [sym_keyword_outside] = ACTIONS(240),
    [sym_keyword_intersects] = ACTIONS(240),
    [sym_keyword_drop] = ACTIONS(240),
    [sym_keyword_schemafull] = ACTIONS(240),
    [sym_keyword_schemaless] = ACTIONS(240),
    [sym_keyword_changefeed] = ACTIONS(240),
    [sym_keyword_content] = ACTIONS(240),
    [sym_keyword_merge] = ACTIONS(240),
    [sym_keyword_patch] = ACTIONS(240),
    [sym_keyword_replace] = ACTIONS(240),
    [sym_keyword_then] = ACTIONS(240),
    [sym_keyword_permissions] = ACTIONS(240),
    [sym_keyword_for] = ACTIONS(240),
    [sym_keyword_comment] = ACTIONS(240),
    [sym_keyword_unset] = ACTIONS(240),
    [sym_keyword_set] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_LPAREN] = ACTIONS(240),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_DASH_GT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(240),
    [anon_sym_RBRACK] = ACTIONS(240),
    [anon_sym_QMARK] = ACTIONS(242),
    [anon_sym_LBRACE] = ACTIONS(240),
    [anon_sym_RBRACE] = ACTIONS(240),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_DASH] = ACTIONS(242),
    [anon_sym_LT_DASH_GT] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_DOT_DOT] = ACTIONS(240),
    [anon_sym_DASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LT_PIPE] = ACTIONS(240),
    [anon_sym_AMP_AMP] = ACTIONS(240),
    [anon_sym_PIPE_PIPE] = ACTIONS(240),
    [anon_sym_QMARK_QMARK] = ACTIONS(240),
    [anon_sym_QMARK_COLON] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_QMARK_EQ] = ACTIONS(240),
    [anon_sym_STAR_EQ] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(240),
    [anon_sym_BANG_TILDE] = ACTIONS(240),
    [anon_sym_STAR_TILDE] = ACTIONS(240),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_PLUS] = ACTIONS(242),
    [anon_sym_PLUS_EQ] = ACTIONS(240),
    [anon_sym_DASH_EQ] = ACTIONS(240),
    [anon_sym_u00d7] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_u00f7] = ACTIONS(240),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_u220b] = ACTIONS(240),
    [anon_sym_u220c] = ACTIONS(240),
    [anon_sym_u2287] = ACTIONS(240),
    [anon_sym_u2283] = ACTIONS(240),
    [anon_sym_u2285] = ACTIONS(240),
    [anon_sym_u2208] = ACTIONS(240),
    [anon_sym_u2209] = ACTIONS(240),
    [anon_sym_u2286] = ACTIONS(240),
    [anon_sym_u2282] = ACTIONS(240),
    [anon_sym_u2284] = ACTIONS(240),
    [anon_sym_AT_AT] = ACTIONS(240),
  },
  [STATE(71)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(248),
    [sym_keyword_on] = ACTIONS(248),
    [sym_keyword_return] = ACTIONS(248),
    [sym_keyword_from] = ACTIONS(248),
    [sym_keyword_as] = ACTIONS(248),
    [sym_keyword_omit] = ACTIONS(248),
    [sym_keyword_explain] = ACTIONS(248),
    [sym_keyword_parallel] = ACTIONS(248),
    [sym_keyword_timeout] = ACTIONS(248),
    [sym_keyword_fetch] = ACTIONS(248),
    [sym_keyword_limit] = ACTIONS(248),
    [sym_keyword_where] = ACTIONS(248),
    [sym_keyword_group] = ACTIONS(248),
    [sym_keyword_and] = ACTIONS(248),
    [sym_keyword_or] = ACTIONS(248),
    [sym_keyword_is] = ACTIONS(248),
    [sym_keyword_not] = ACTIONS(250),
    [sym_keyword_contains] = ACTIONS(250),
    [sym_keyword_contains_not] = ACTIONS(248),
    [sym_keyword_contains_all] = ACTIONS(248),
    [sym_keyword_contains_any] = ACTIONS(248),
    [sym_keyword_contains_none] = ACTIONS(248),
    [sym_keyword_inside] = ACTIONS(248),
    [sym_keyword_in] = ACTIONS(250),
    [sym_keyword_not_inside] = ACTIONS(248),
    [sym_keyword_all_inside] = ACTIONS(248),
    [sym_keyword_any_inside] = ACTIONS(248),
    [sym_keyword_none_inside] = ACTIONS(248),
    [sym_keyword_outside] = ACTIONS(248),
    [sym_keyword_intersects] = ACTIONS(248),
    [sym_keyword_drop] = ACTIONS(248),
    [sym_keyword_schemafull] = ACTIONS(248),
    [sym_keyword_schemaless] = ACTIONS(248),
    [sym_keyword_changefeed] = ACTIONS(248),
    [sym_keyword_content] = ACTIONS(248),
    [sym_keyword_merge] = ACTIONS(248),
    [sym_keyword_patch] = ACTIONS(248),
    [sym_keyword_replace] = ACTIONS(248),
    [sym_keyword_then] = ACTIONS(248),
    [sym_keyword_permissions] = ACTIONS(248),
    [sym_keyword_for] = ACTIONS(248),
    [sym_keyword_comment] = ACTIONS(248),
    [sym_keyword_unset] = ACTIONS(248),
    [sym_keyword_set] = ACTIONS(248),
    [anon_sym_EQ] = ACTIONS(250),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_LPAREN] = ACTIONS(248),
    [anon_sym_RPAREN] = ACTIONS(248),
    [anon_sym_DASH_GT] = ACTIONS(248),
    [anon_sym_LBRACK] = ACTIONS(248),
    [anon_sym_RBRACK] = ACTIONS(248),
    [anon_sym_QMARK] = ACTIONS(250),
    [anon_sym_LBRACE] = ACTIONS(248),
    [anon_sym_RBRACE] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_LT_DASH] = ACTIONS(250),
    [anon_sym_LT_DASH_GT] = ACTIONS(248),
    [anon_sym_STAR] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(250),
    [anon_sym_DOT_DOT] = ACTIONS(248),
    [anon_sym_DASH] = ACTIONS(250),
    [anon_sym_PERCENT] = ACTIONS(248),
    [anon_sym_AT] = ACTIONS(250),
    [anon_sym_LT_PIPE] = ACTIONS(248),
    [anon_sym_AMP_AMP] = ACTIONS(248),
    [anon_sym_PIPE_PIPE] = ACTIONS(248),
    [anon_sym_QMARK_QMARK] = ACTIONS(248),
    [anon_sym_QMARK_COLON] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_QMARK_EQ] = ACTIONS(248),
    [anon_sym_STAR_EQ] = ACTIONS(248),
    [anon_sym_TILDE] = ACTIONS(248),
    [anon_sym_BANG_TILDE] = ACTIONS(248),
    [anon_sym_STAR_TILDE] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(250),
    [anon_sym_PLUS_EQ] = ACTIONS(248),
    [anon_sym_DASH_EQ] = ACTIONS(248),
    [anon_sym_u00d7] = ACTIONS(248),
    [anon_sym_SLASH] = ACTIONS(250),
    [anon_sym_u00f7] = ACTIONS(248),
    [anon_sym_STAR_STAR] = ACTIONS(248),
    [anon_sym_u220b] = ACTIONS(248),
    [anon_sym_u220c] = ACTIONS(248),
    [anon_sym_u2287] = ACTIONS(248),
    [anon_sym_u2283] = ACTIONS(248),
    [anon_sym_u2285] = ACTIONS(248),
    [anon_sym_u2208] = ACTIONS(248),
    [anon_sym_u2209] = ACTIONS(248),
    [anon_sym_u2286] = ACTIONS(248),
    [anon_sym_u2282] = ACTIONS(248),
    [anon_sym_u2284] = ACTIONS(248),
    [anon_sym_AT_AT] = ACTIONS(248),
  },
  [STATE(72)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(256),
    [sym_keyword_on] = ACTIONS(256),
    [sym_keyword_return] = ACTIONS(256),
    [sym_keyword_from] = ACTIONS(256),
    [sym_keyword_as] = ACTIONS(256),
    [sym_keyword_omit] = ACTIONS(256),
    [sym_keyword_explain] = ACTIONS(256),
    [sym_keyword_parallel] = ACTIONS(256),
    [sym_keyword_timeout] = ACTIONS(256),
    [sym_keyword_fetch] = ACTIONS(256),
    [sym_keyword_limit] = ACTIONS(256),
    [sym_keyword_where] = ACTIONS(256),
    [sym_keyword_group] = ACTIONS(256),
    [sym_keyword_and] = ACTIONS(256),
    [sym_keyword_or] = ACTIONS(256),
    [sym_keyword_is] = ACTIONS(256),
    [sym_keyword_not] = ACTIONS(258),
    [sym_keyword_contains] = ACTIONS(258),
    [sym_keyword_contains_not] = ACTIONS(256),
    [sym_keyword_contains_all] = ACTIONS(256),
    [sym_keyword_contains_any] = ACTIONS(256),
    [sym_keyword_contains_none] = ACTIONS(256),
    [sym_keyword_inside] = ACTIONS(256),
    [sym_keyword_in] = ACTIONS(258),
    [sym_keyword_not_inside] = ACTIONS(256),
    [sym_keyword_all_inside] = ACTIONS(256),
    [sym_keyword_any_inside] = ACTIONS(256),
    [sym_keyword_none_inside] = ACTIONS(256),
    [sym_keyword_outside] = ACTIONS(256),
    [sym_keyword_intersects] = ACTIONS(256),
    [sym_keyword_drop] = ACTIONS(256),
    [sym_keyword_schemafull] = ACTIONS(256),
    [sym_keyword_schemaless] = ACTIONS(256),
    [sym_keyword_changefeed] = ACTIONS(256),
    [sym_keyword_content] = ACTIONS(256),
    [sym_keyword_merge] = ACTIONS(256),
    [sym_keyword_patch] = ACTIONS(256),
    [sym_keyword_replace] = ACTIONS(256),
    [sym_keyword_then] = ACTIONS(256),
    [sym_keyword_permissions] = ACTIONS(256),
    [sym_keyword_for] = ACTIONS(256),
    [sym_keyword_comment] = ACTIONS(256),
    [sym_keyword_unset] = ACTIONS(256),
    [sym_keyword_set] = ACTIONS(256),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_COMMA] = ACTIONS(256),
    [anon_sym_LPAREN] = ACTIONS(256),
    [anon_sym_RPAREN] = ACTIONS(256),
    [anon_sym_DASH_GT] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(256),
    [anon_sym_RBRACK] = ACTIONS(256),
    [anon_sym_QMARK] = ACTIONS(258),
    [anon_sym_LBRACE] = ACTIONS(256),
    [anon_sym_RBRACE] = ACTIONS(256),
    [anon_sym_LT] = ACTIONS(258),
    [anon_sym_GT] = ACTIONS(258),
    [anon_sym_LT_DASH] = ACTIONS(258),
    [anon_sym_LT_DASH_GT] = ACTIONS(256),
    [anon_sym_STAR] = ACTIONS(258),
    [anon_sym_DOT] = ACTIONS(258),
    [anon_sym_DOT_DOT] = ACTIONS(256),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_PERCENT] = ACTIONS(256),
    [anon_sym_AT] = ACTIONS(258),
    [anon_sym_LT_PIPE] = ACTIONS(256),
    [anon_sym_AMP_AMP] = ACTIONS(256),
    [anon_sym_PIPE_PIPE] = ACTIONS(256),
    [anon_sym_QMARK_QMARK] = ACTIONS(256),
    [anon_sym_QMARK_COLON] = ACTIONS(256),
    [anon_sym_BANG_EQ] = ACTIONS(256),
    [anon_sym_EQ_EQ] = ACTIONS(256),
    [anon_sym_QMARK_EQ] = ACTIONS(256),
    [anon_sym_STAR_EQ] = ACTIONS(256),
    [anon_sym_TILDE] = ACTIONS(256),
    [anon_sym_BANG_TILDE] = ACTIONS(256),
    [anon_sym_STAR_TILDE] = ACTIONS(256),
    [anon_sym_LT_EQ] = ACTIONS(256),
    [anon_sym_GT_EQ] = ACTIONS(256),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_PLUS_EQ] = ACTIONS(256),
    [anon_sym_DASH_EQ] = ACTIONS(256),
    [anon_sym_u00d7] = ACTIONS(256),
    [anon_sym_SLASH] = ACTIONS(258),
    [anon_sym_u00f7] = ACTIONS(256),
    [anon_sym_STAR_STAR] = ACTIONS(256),
    [anon_sym_u220b] = ACTIONS(256),
    [anon_sym_u220c] = ACTIONS(256),
    [anon_sym_u2287] = ACTIONS(256),
    [anon_sym_u2283] = ACTIONS(256),
    [anon_sym_u2285] = ACTIONS(256),
    [anon_sym_u2208] = ACTIONS(256),
    [anon_sym_u2209] = ACTIONS(256),
    [anon_sym_u2286] = ACTIONS(256),
    [anon_sym_u2282] = ACTIONS(256),
    [anon_sym_u2284] = ACTIONS(256),
    [anon_sym_AT_AT] = ACTIONS(256),
  },
  [STATE(73)] = {
    [ts_builtin_sym_end] = ACTIONS(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_return] = ACTIONS(278),
    [sym_keyword_value] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_rand] = ACTIONS(278),
    [sym_keyword_collate] = ACTIONS(278),
    [sym_keyword_numeric] = ACTIONS(278),
    [sym_keyword_asc] = ACTIONS(278),
    [sym_keyword_desc] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(278),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [sym_keyword_drop] = ACTIONS(278),
    [sym_keyword_schemafull] = ACTIONS(278),
    [sym_keyword_schemaless] = ACTIONS(278),
    [sym_keyword_flexible] = ACTIONS(278),
    [sym_keyword_readonly] = ACTIONS(278),
    [sym_keyword_changefeed] = ACTIONS(278),
    [sym_keyword_content] = ACTIONS(278),
    [sym_keyword_merge] = ACTIONS(278),
    [sym_keyword_patch] = ACTIONS(278),
    [sym_keyword_replace] = ACTIONS(278),
    [sym_keyword_type] = ACTIONS(278),
    [sym_keyword_default] = ACTIONS(278),
    [sym_keyword_assert] = ACTIONS(278),
    [sym_keyword_permissions] = ACTIONS(278),
    [sym_keyword_for] = ACTIONS(278),
    [sym_keyword_comment] = ACTIONS(278),
    [sym_keyword_unset] = ACTIONS(278),
    [sym_keyword_set] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(74)] = {
    [ts_builtin_sym_end] = ACTIONS(365),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(365),
    [sym_keyword_return] = ACTIONS(365),
    [sym_keyword_value] = ACTIONS(365),
    [sym_keyword_explain] = ACTIONS(365),
    [sym_keyword_parallel] = ACTIONS(365),
    [sym_keyword_timeout] = ACTIONS(365),
    [sym_keyword_fetch] = ACTIONS(365),
    [sym_keyword_limit] = ACTIONS(365),
    [sym_keyword_rand] = ACTIONS(365),
    [sym_keyword_collate] = ACTIONS(365),
    [sym_keyword_numeric] = ACTIONS(365),
    [sym_keyword_asc] = ACTIONS(365),
    [sym_keyword_desc] = ACTIONS(365),
    [sym_keyword_where] = ACTIONS(365),
    [sym_keyword_group] = ACTIONS(365),
    [sym_keyword_and] = ACTIONS(365),
    [sym_keyword_or] = ACTIONS(365),
    [sym_keyword_is] = ACTIONS(365),
    [sym_keyword_not] = ACTIONS(367),
    [sym_keyword_contains] = ACTIONS(367),
    [sym_keyword_contains_not] = ACTIONS(365),
    [sym_keyword_contains_all] = ACTIONS(365),
    [sym_keyword_contains_any] = ACTIONS(365),
    [sym_keyword_contains_none] = ACTIONS(365),
    [sym_keyword_inside] = ACTIONS(365),
    [sym_keyword_in] = ACTIONS(367),
    [sym_keyword_not_inside] = ACTIONS(365),
    [sym_keyword_all_inside] = ACTIONS(365),
    [sym_keyword_any_inside] = ACTIONS(365),
    [sym_keyword_none_inside] = ACTIONS(365),
    [sym_keyword_outside] = ACTIONS(365),
    [sym_keyword_intersects] = ACTIONS(365),
    [sym_keyword_drop] = ACTIONS(365),
    [sym_keyword_schemafull] = ACTIONS(365),
    [sym_keyword_schemaless] = ACTIONS(365),
    [sym_keyword_flexible] = ACTIONS(365),
    [sym_keyword_readonly] = ACTIONS(365),
    [sym_keyword_changefeed] = ACTIONS(365),
    [sym_keyword_content] = ACTIONS(365),
    [sym_keyword_merge] = ACTIONS(365),
    [sym_keyword_patch] = ACTIONS(365),
    [sym_keyword_replace] = ACTIONS(365),
    [sym_keyword_type] = ACTIONS(365),
    [sym_keyword_default] = ACTIONS(365),
    [sym_keyword_assert] = ACTIONS(365),
    [sym_keyword_permissions] = ACTIONS(365),
    [sym_keyword_for] = ACTIONS(365),
    [sym_keyword_comment] = ACTIONS(365),
    [sym_keyword_unset] = ACTIONS(365),
    [sym_keyword_set] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(367),
    [anon_sym_COMMA] = ACTIONS(365),
    [anon_sym_DASH_GT] = ACTIONS(365),
    [anon_sym_LBRACK] = ACTIONS(365),
    [anon_sym_LT] = ACTIONS(367),
    [anon_sym_GT] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(367),
    [anon_sym_LT_DASH_GT] = ACTIONS(365),
    [anon_sym_STAR] = ACTIONS(367),
    [anon_sym_DOT] = ACTIONS(365),
    [anon_sym_DASH] = ACTIONS(367),
    [anon_sym_PERCENT] = ACTIONS(365),
    [anon_sym_AT] = ACTIONS(367),
    [anon_sym_LT_PIPE] = ACTIONS(365),
    [anon_sym_AMP_AMP] = ACTIONS(365),
    [anon_sym_PIPE_PIPE] = ACTIONS(365),
    [anon_sym_QMARK_QMARK] = ACTIONS(365),
    [anon_sym_QMARK_COLON] = ACTIONS(365),
    [anon_sym_BANG_EQ] = ACTIONS(365),
    [anon_sym_EQ_EQ] = ACTIONS(365),
    [anon_sym_QMARK_EQ] = ACTIONS(365),
    [anon_sym_STAR_EQ] = ACTIONS(365),
    [anon_sym_TILDE] = ACTIONS(365),
    [anon_sym_BANG_TILDE] = ACTIONS(365),
    [anon_sym_STAR_TILDE] = ACTIONS(365),
    [anon_sym_LT_EQ] = ACTIONS(365),
    [anon_sym_GT_EQ] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(367),
    [anon_sym_PLUS_EQ] = ACTIONS(365),
    [anon_sym_DASH_EQ] = ACTIONS(365),
    [anon_sym_u00d7] = ACTIONS(365),
    [anon_sym_SLASH] = ACTIONS(367),
    [anon_sym_u00f7] = ACTIONS(365),
    [anon_sym_STAR_STAR] = ACTIONS(365),
    [anon_sym_u220b] = ACTIONS(365),
    [anon_sym_u220c] = ACTIONS(365),
    [anon_sym_u2287] = ACTIONS(365),
    [anon_sym_u2283] = ACTIONS(365),
    [anon_sym_u2285] = ACTIONS(365),
    [anon_sym_u2208] = ACTIONS(365),
    [anon_sym_u2209] = ACTIONS(365),
    [anon_sym_u2286] = ACTIONS(365),
    [anon_sym_u2282] = ACTIONS(365),
    [anon_sym_u2284] = ACTIONS(365),
    [anon_sym_AT_AT] = ACTIONS(365),
  },
  [STATE(75)] = {
    [ts_builtin_sym_end] = ACTIONS(369),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(369),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_value] = ACTIONS(369),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_rand] = ACTIONS(369),
    [sym_keyword_collate] = ACTIONS(369),
    [sym_keyword_numeric] = ACTIONS(369),
    [sym_keyword_asc] = ACTIONS(369),
    [sym_keyword_desc] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(371),
    [sym_keyword_contains] = ACTIONS(371),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(371),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_flexible] = ACTIONS(369),
    [sym_keyword_readonly] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_content] = ACTIONS(369),
    [sym_keyword_merge] = ACTIONS(369),
    [sym_keyword_patch] = ACTIONS(369),
    [sym_keyword_replace] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_default] = ACTIONS(369),
    [sym_keyword_assert] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [sym_keyword_unset] = ACTIONS(369),
    [sym_keyword_set] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(371),
    [anon_sym_LT_DASH_GT] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(371),
    [anon_sym_DOT] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(371),
    [anon_sym_LT_PIPE] = ACTIONS(369),
    [anon_sym_AMP_AMP] = ACTIONS(369),
    [anon_sym_PIPE_PIPE] = ACTIONS(369),
    [anon_sym_QMARK_QMARK] = ACTIONS(369),
    [anon_sym_QMARK_COLON] = ACTIONS(369),
    [anon_sym_BANG_EQ] = ACTIONS(369),
    [anon_sym_EQ_EQ] = ACTIONS(369),
    [anon_sym_QMARK_EQ] = ACTIONS(369),
    [anon_sym_STAR_EQ] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_BANG_TILDE] = ACTIONS(369),
    [anon_sym_STAR_TILDE] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(371),
    [anon_sym_PLUS_EQ] = ACTIONS(369),
    [anon_sym_DASH_EQ] = ACTIONS(369),
    [anon_sym_u00d7] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_u00f7] = ACTIONS(369),
    [anon_sym_STAR_STAR] = ACTIONS(369),
    [anon_sym_u220b] = ACTIONS(369),
    [anon_sym_u220c] = ACTIONS(369),
    [anon_sym_u2287] = ACTIONS(369),
    [anon_sym_u2283] = ACTIONS(369),
    [anon_sym_u2285] = ACTIONS(369),
    [anon_sym_u2208] = ACTIONS(369),
    [anon_sym_u2209] = ACTIONS(369),
    [anon_sym_u2286] = ACTIONS(369),
    [anon_sym_u2282] = ACTIONS(369),
    [anon_sym_u2284] = ACTIONS(369),
    [anon_sym_AT_AT] = ACTIONS(369),
  },
  [STATE(76)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_on] = ACTIONS(304),
    [sym_keyword_return] = ACTIONS(304),
    [sym_keyword_from] = ACTIONS(304),
    [sym_keyword_as] = ACTIONS(304),
    [sym_keyword_omit] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(304),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [sym_keyword_drop] = ACTIONS(304),
    [sym_keyword_schemafull] = ACTIONS(304),
    [sym_keyword_schemaless] = ACTIONS(304),
    [sym_keyword_changefeed] = ACTIONS(304),
    [sym_keyword_content] = ACTIONS(304),
    [sym_keyword_merge] = ACTIONS(304),
    [sym_keyword_patch] = ACTIONS(304),
    [sym_keyword_replace] = ACTIONS(304),
    [sym_keyword_then] = ACTIONS(304),
    [sym_keyword_permissions] = ACTIONS(304),
    [sym_keyword_for] = ACTIONS(304),
    [sym_keyword_comment] = ACTIONS(304),
    [sym_keyword_unset] = ACTIONS(304),
    [sym_keyword_set] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_LPAREN] = ACTIONS(304),
    [anon_sym_RPAREN] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACK] = ACTIONS(304),
    [anon_sym_QMARK] = ACTIONS(306),
    [anon_sym_LBRACE] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(77)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_on] = ACTIONS(204),
    [sym_keyword_return] = ACTIONS(204),
    [sym_keyword_from] = ACTIONS(204),
    [sym_keyword_as] = ACTIONS(204),
    [sym_keyword_omit] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_drop] = ACTIONS(204),
    [sym_keyword_schemafull] = ACTIONS(204),
    [sym_keyword_schemaless] = ACTIONS(204),
    [sym_keyword_changefeed] = ACTIONS(204),
    [sym_keyword_content] = ACTIONS(204),
    [sym_keyword_merge] = ACTIONS(204),
    [sym_keyword_patch] = ACTIONS(204),
    [sym_keyword_replace] = ACTIONS(204),
    [sym_keyword_then] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [sym_keyword_unset] = ACTIONS(204),
    [sym_keyword_set] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_LPAREN] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACK] = ACTIONS(204),
    [anon_sym_QMARK] = ACTIONS(206),
    [anon_sym_LBRACE] = ACTIONS(204),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(78)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(326),
    [sym_keyword_on] = ACTIONS(326),
    [sym_keyword_return] = ACTIONS(326),
    [sym_keyword_from] = ACTIONS(326),
    [sym_keyword_as] = ACTIONS(326),
    [sym_keyword_omit] = ACTIONS(326),
    [sym_keyword_explain] = ACTIONS(326),
    [sym_keyword_parallel] = ACTIONS(326),
    [sym_keyword_timeout] = ACTIONS(326),
    [sym_keyword_fetch] = ACTIONS(326),
    [sym_keyword_limit] = ACTIONS(326),
    [sym_keyword_where] = ACTIONS(326),
    [sym_keyword_group] = ACTIONS(326),
    [sym_keyword_and] = ACTIONS(326),
    [sym_keyword_or] = ACTIONS(326),
    [sym_keyword_is] = ACTIONS(326),
    [sym_keyword_not] = ACTIONS(328),
    [sym_keyword_contains] = ACTIONS(328),
    [sym_keyword_contains_not] = ACTIONS(326),
    [sym_keyword_contains_all] = ACTIONS(326),
    [sym_keyword_contains_any] = ACTIONS(326),
    [sym_keyword_contains_none] = ACTIONS(326),
    [sym_keyword_inside] = ACTIONS(326),
    [sym_keyword_in] = ACTIONS(328),
    [sym_keyword_not_inside] = ACTIONS(326),
    [sym_keyword_all_inside] = ACTIONS(326),
    [sym_keyword_any_inside] = ACTIONS(326),
    [sym_keyword_none_inside] = ACTIONS(326),
    [sym_keyword_outside] = ACTIONS(326),
    [sym_keyword_intersects] = ACTIONS(326),
    [sym_keyword_drop] = ACTIONS(326),
    [sym_keyword_schemafull] = ACTIONS(326),
    [sym_keyword_schemaless] = ACTIONS(326),
    [sym_keyword_changefeed] = ACTIONS(326),
    [sym_keyword_content] = ACTIONS(326),
    [sym_keyword_merge] = ACTIONS(326),
    [sym_keyword_patch] = ACTIONS(326),
    [sym_keyword_replace] = ACTIONS(326),
    [sym_keyword_then] = ACTIONS(326),
    [sym_keyword_permissions] = ACTIONS(326),
    [sym_keyword_for] = ACTIONS(326),
    [sym_keyword_comment] = ACTIONS(326),
    [sym_keyword_unset] = ACTIONS(326),
    [sym_keyword_set] = ACTIONS(326),
    [anon_sym_EQ] = ACTIONS(328),
    [anon_sym_COMMA] = ACTIONS(326),
    [anon_sym_LPAREN] = ACTIONS(326),
    [anon_sym_RPAREN] = ACTIONS(326),
    [anon_sym_DASH_GT] = ACTIONS(326),
    [anon_sym_LBRACK] = ACTIONS(326),
    [anon_sym_RBRACK] = ACTIONS(326),
    [anon_sym_QMARK] = ACTIONS(328),
    [anon_sym_LBRACE] = ACTIONS(326),
    [anon_sym_RBRACE] = ACTIONS(326),
    [anon_sym_LT] = ACTIONS(328),
    [anon_sym_GT] = ACTIONS(328),
    [anon_sym_LT_DASH] = ACTIONS(328),
    [anon_sym_LT_DASH_GT] = ACTIONS(326),
    [anon_sym_STAR] = ACTIONS(328),
    [anon_sym_DOT] = ACTIONS(326),
    [anon_sym_DASH] = ACTIONS(328),
    [anon_sym_PERCENT] = ACTIONS(326),
    [anon_sym_AT] = ACTIONS(328),
    [anon_sym_LT_PIPE] = ACTIONS(326),
    [anon_sym_AMP_AMP] = ACTIONS(326),
    [anon_sym_PIPE_PIPE] = ACTIONS(326),
    [anon_sym_QMARK_QMARK] = ACTIONS(326),
    [anon_sym_QMARK_COLON] = ACTIONS(326),
    [anon_sym_BANG_EQ] = ACTIONS(326),
    [anon_sym_EQ_EQ] = ACTIONS(326),
    [anon_sym_QMARK_EQ] = ACTIONS(326),
    [anon_sym_STAR_EQ] = ACTIONS(326),
    [anon_sym_TILDE] = ACTIONS(326),
    [anon_sym_BANG_TILDE] = ACTIONS(326),
    [anon_sym_STAR_TILDE] = ACTIONS(326),
    [anon_sym_LT_EQ] = ACTIONS(326),
    [anon_sym_GT_EQ] = ACTIONS(326),
    [anon_sym_PLUS] = ACTIONS(328),
    [anon_sym_PLUS_EQ] = ACTIONS(326),
    [anon_sym_DASH_EQ] = ACTIONS(326),
    [anon_sym_u00d7] = ACTIONS(326),
    [anon_sym_SLASH] = ACTIONS(328),
    [anon_sym_u00f7] = ACTIONS(326),
    [anon_sym_STAR_STAR] = ACTIONS(326),
    [anon_sym_u220b] = ACTIONS(326),
    [anon_sym_u220c] = ACTIONS(326),
    [anon_sym_u2287] = ACTIONS(326),
    [anon_sym_u2283] = ACTIONS(326),
    [anon_sym_u2285] = ACTIONS(326),
    [anon_sym_u2208] = ACTIONS(326),
    [anon_sym_u2209] = ACTIONS(326),
    [anon_sym_u2286] = ACTIONS(326),
    [anon_sym_u2282] = ACTIONS(326),
    [anon_sym_u2284] = ACTIONS(326),
    [anon_sym_AT_AT] = ACTIONS(326),
  },
  [STATE(79)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(284),
    [sym_keyword_on] = ACTIONS(284),
    [sym_keyword_return] = ACTIONS(284),
    [sym_keyword_from] = ACTIONS(284),
    [sym_keyword_as] = ACTIONS(284),
    [sym_keyword_omit] = ACTIONS(284),
    [sym_keyword_explain] = ACTIONS(284),
    [sym_keyword_parallel] = ACTIONS(284),
    [sym_keyword_timeout] = ACTIONS(284),
    [sym_keyword_fetch] = ACTIONS(284),
    [sym_keyword_limit] = ACTIONS(284),
    [sym_keyword_where] = ACTIONS(284),
    [sym_keyword_group] = ACTIONS(284),
    [sym_keyword_and] = ACTIONS(284),
    [sym_keyword_or] = ACTIONS(284),
    [sym_keyword_is] = ACTIONS(284),
    [sym_keyword_not] = ACTIONS(286),
    [sym_keyword_contains] = ACTIONS(286),
    [sym_keyword_contains_not] = ACTIONS(284),
    [sym_keyword_contains_all] = ACTIONS(284),
    [sym_keyword_contains_any] = ACTIONS(284),
    [sym_keyword_contains_none] = ACTIONS(284),
    [sym_keyword_inside] = ACTIONS(284),
    [sym_keyword_in] = ACTIONS(286),
    [sym_keyword_not_inside] = ACTIONS(284),
    [sym_keyword_all_inside] = ACTIONS(284),
    [sym_keyword_any_inside] = ACTIONS(284),
    [sym_keyword_none_inside] = ACTIONS(284),
    [sym_keyword_outside] = ACTIONS(284),
    [sym_keyword_intersects] = ACTIONS(284),
    [sym_keyword_drop] = ACTIONS(284),
    [sym_keyword_schemafull] = ACTIONS(284),
    [sym_keyword_schemaless] = ACTIONS(284),
    [sym_keyword_changefeed] = ACTIONS(284),
    [sym_keyword_content] = ACTIONS(284),
    [sym_keyword_merge] = ACTIONS(284),
    [sym_keyword_patch] = ACTIONS(284),
    [sym_keyword_replace] = ACTIONS(284),
    [sym_keyword_then] = ACTIONS(284),
    [sym_keyword_permissions] = ACTIONS(284),
    [sym_keyword_for] = ACTIONS(284),
    [sym_keyword_comment] = ACTIONS(284),
    [sym_keyword_unset] = ACTIONS(284),
    [sym_keyword_set] = ACTIONS(284),
    [anon_sym_EQ] = ACTIONS(286),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_LPAREN] = ACTIONS(284),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_DASH_GT] = ACTIONS(284),
    [anon_sym_LBRACK] = ACTIONS(284),
    [anon_sym_RBRACK] = ACTIONS(284),
    [anon_sym_QMARK] = ACTIONS(286),
    [anon_sym_LBRACE] = ACTIONS(284),
    [anon_sym_RBRACE] = ACTIONS(284),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_LT_DASH] = ACTIONS(286),
    [anon_sym_LT_DASH_GT] = ACTIONS(284),
    [anon_sym_STAR] = ACTIONS(286),
    [anon_sym_DOT] = ACTIONS(284),
    [anon_sym_DASH] = ACTIONS(286),
    [anon_sym_PERCENT] = ACTIONS(284),
    [anon_sym_AT] = ACTIONS(286),
    [anon_sym_LT_PIPE] = ACTIONS(284),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_PIPE_PIPE] = ACTIONS(284),
    [anon_sym_QMARK_QMARK] = ACTIONS(284),
    [anon_sym_QMARK_COLON] = ACTIONS(284),
    [anon_sym_BANG_EQ] = ACTIONS(284),
    [anon_sym_EQ_EQ] = ACTIONS(284),
    [anon_sym_QMARK_EQ] = ACTIONS(284),
    [anon_sym_STAR_EQ] = ACTIONS(284),
    [anon_sym_TILDE] = ACTIONS(284),
    [anon_sym_BANG_TILDE] = ACTIONS(284),
    [anon_sym_STAR_TILDE] = ACTIONS(284),
    [anon_sym_LT_EQ] = ACTIONS(284),
    [anon_sym_GT_EQ] = ACTIONS(284),
    [anon_sym_PLUS] = ACTIONS(286),
    [anon_sym_PLUS_EQ] = ACTIONS(284),
    [anon_sym_DASH_EQ] = ACTIONS(284),
    [anon_sym_u00d7] = ACTIONS(284),
    [anon_sym_SLASH] = ACTIONS(286),
    [anon_sym_u00f7] = ACTIONS(284),
    [anon_sym_STAR_STAR] = ACTIONS(284),
    [anon_sym_u220b] = ACTIONS(284),
    [anon_sym_u220c] = ACTIONS(284),
    [anon_sym_u2287] = ACTIONS(284),
    [anon_sym_u2283] = ACTIONS(284),
    [anon_sym_u2285] = ACTIONS(284),
    [anon_sym_u2208] = ACTIONS(284),
    [anon_sym_u2209] = ACTIONS(284),
    [anon_sym_u2286] = ACTIONS(284),
    [anon_sym_u2282] = ACTIONS(284),
    [anon_sym_u2284] = ACTIONS(284),
    [anon_sym_AT_AT] = ACTIONS(284),
  },
  [STATE(80)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(292),
    [sym_keyword_on] = ACTIONS(292),
    [sym_keyword_return] = ACTIONS(292),
    [sym_keyword_from] = ACTIONS(292),
    [sym_keyword_as] = ACTIONS(292),
    [sym_keyword_omit] = ACTIONS(292),
    [sym_keyword_explain] = ACTIONS(292),
    [sym_keyword_parallel] = ACTIONS(292),
    [sym_keyword_timeout] = ACTIONS(292),
    [sym_keyword_fetch] = ACTIONS(292),
    [sym_keyword_limit] = ACTIONS(292),
    [sym_keyword_where] = ACTIONS(292),
    [sym_keyword_group] = ACTIONS(292),
    [sym_keyword_and] = ACTIONS(292),
    [sym_keyword_or] = ACTIONS(292),
    [sym_keyword_is] = ACTIONS(292),
    [sym_keyword_not] = ACTIONS(294),
    [sym_keyword_contains] = ACTIONS(294),
    [sym_keyword_contains_not] = ACTIONS(292),
    [sym_keyword_contains_all] = ACTIONS(292),
    [sym_keyword_contains_any] = ACTIONS(292),
    [sym_keyword_contains_none] = ACTIONS(292),
    [sym_keyword_inside] = ACTIONS(292),
    [sym_keyword_in] = ACTIONS(294),
    [sym_keyword_not_inside] = ACTIONS(292),
    [sym_keyword_all_inside] = ACTIONS(292),
    [sym_keyword_any_inside] = ACTIONS(292),
    [sym_keyword_none_inside] = ACTIONS(292),
    [sym_keyword_outside] = ACTIONS(292),
    [sym_keyword_intersects] = ACTIONS(292),
    [sym_keyword_drop] = ACTIONS(292),
    [sym_keyword_schemafull] = ACTIONS(292),
    [sym_keyword_schemaless] = ACTIONS(292),
    [sym_keyword_changefeed] = ACTIONS(292),
    [sym_keyword_content] = ACTIONS(292),
    [sym_keyword_merge] = ACTIONS(292),
    [sym_keyword_patch] = ACTIONS(292),
    [sym_keyword_replace] = ACTIONS(292),
    [sym_keyword_then] = ACTIONS(292),
    [sym_keyword_permissions] = ACTIONS(292),
    [sym_keyword_for] = ACTIONS(292),
    [sym_keyword_comment] = ACTIONS(292),
    [sym_keyword_unset] = ACTIONS(292),
    [sym_keyword_set] = ACTIONS(292),
    [anon_sym_EQ] = ACTIONS(294),
    [anon_sym_COMMA] = ACTIONS(292),
    [anon_sym_LPAREN] = ACTIONS(292),
    [anon_sym_RPAREN] = ACTIONS(292),
    [anon_sym_DASH_GT] = ACTIONS(292),
    [anon_sym_LBRACK] = ACTIONS(292),
    [anon_sym_RBRACK] = ACTIONS(292),
    [anon_sym_QMARK] = ACTIONS(294),
    [anon_sym_LBRACE] = ACTIONS(292),
    [anon_sym_RBRACE] = ACTIONS(292),
    [anon_sym_LT] = ACTIONS(294),
    [anon_sym_GT] = ACTIONS(294),
    [anon_sym_LT_DASH] = ACTIONS(294),
    [anon_sym_LT_DASH_GT] = ACTIONS(292),
    [anon_sym_STAR] = ACTIONS(294),
    [anon_sym_DOT] = ACTIONS(292),
    [anon_sym_DASH] = ACTIONS(294),
    [anon_sym_PERCENT] = ACTIONS(292),
    [anon_sym_AT] = ACTIONS(294),
    [anon_sym_LT_PIPE] = ACTIONS(292),
    [anon_sym_AMP_AMP] = ACTIONS(292),
    [anon_sym_PIPE_PIPE] = ACTIONS(292),
    [anon_sym_QMARK_QMARK] = ACTIONS(292),
    [anon_sym_QMARK_COLON] = ACTIONS(292),
    [anon_sym_BANG_EQ] = ACTIONS(292),
    [anon_sym_EQ_EQ] = ACTIONS(292),
    [anon_sym_QMARK_EQ] = ACTIONS(292),
    [anon_sym_STAR_EQ] = ACTIONS(292),
    [anon_sym_TILDE] = ACTIONS(292),
    [anon_sym_BANG_TILDE] = ACTIONS(292),
    [anon_sym_STAR_TILDE] = ACTIONS(292),
    [anon_sym_LT_EQ] = ACTIONS(292),
    [anon_sym_GT_EQ] = ACTIONS(292),
    [anon_sym_PLUS] = ACTIONS(294),
    [anon_sym_PLUS_EQ] = ACTIONS(292),
    [anon_sym_DASH_EQ] = ACTIONS(292),
    [anon_sym_u00d7] = ACTIONS(292),
    [anon_sym_SLASH] = ACTIONS(294),
    [anon_sym_u00f7] = ACTIONS(292),
    [anon_sym_STAR_STAR] = ACTIONS(292),
    [anon_sym_u220b] = ACTIONS(292),
    [anon_sym_u220c] = ACTIONS(292),
    [anon_sym_u2287] = ACTIONS(292),
    [anon_sym_u2283] = ACTIONS(292),
    [anon_sym_u2285] = ACTIONS(292),
    [anon_sym_u2208] = ACTIONS(292),
    [anon_sym_u2209] = ACTIONS(292),
    [anon_sym_u2286] = ACTIONS(292),
    [anon_sym_u2282] = ACTIONS(292),
    [anon_sym_u2284] = ACTIONS(292),
    [anon_sym_AT_AT] = ACTIONS(292),
  },
  [STATE(81)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_on] = ACTIONS(190),
    [sym_keyword_return] = ACTIONS(190),
    [sym_keyword_from] = ACTIONS(190),
    [sym_keyword_as] = ACTIONS(190),
    [sym_keyword_omit] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(192),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_drop] = ACTIONS(190),
    [sym_keyword_schemafull] = ACTIONS(190),
    [sym_keyword_schemaless] = ACTIONS(190),
    [sym_keyword_changefeed] = ACTIONS(190),
    [sym_keyword_content] = ACTIONS(190),
    [sym_keyword_merge] = ACTIONS(190),
    [sym_keyword_patch] = ACTIONS(190),
    [sym_keyword_replace] = ACTIONS(190),
    [sym_keyword_then] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [sym_keyword_unset] = ACTIONS(190),
    [sym_keyword_set] = ACTIONS(190),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_LPAREN] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RBRACK] = ACTIONS(190),
    [anon_sym_QMARK] = ACTIONS(192),
    [anon_sym_LBRACE] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_PERCENT] = ACTIONS(190),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [STATE(82)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(310),
    [sym_keyword_on] = ACTIONS(310),
    [sym_keyword_return] = ACTIONS(310),
    [sym_keyword_from] = ACTIONS(310),
    [sym_keyword_as] = ACTIONS(310),
    [sym_keyword_omit] = ACTIONS(310),
    [sym_keyword_explain] = ACTIONS(310),
    [sym_keyword_parallel] = ACTIONS(310),
    [sym_keyword_timeout] = ACTIONS(310),
    [sym_keyword_fetch] = ACTIONS(310),
    [sym_keyword_limit] = ACTIONS(310),
    [sym_keyword_where] = ACTIONS(310),
    [sym_keyword_group] = ACTIONS(310),
    [sym_keyword_and] = ACTIONS(310),
    [sym_keyword_or] = ACTIONS(310),
    [sym_keyword_is] = ACTIONS(310),
    [sym_keyword_not] = ACTIONS(312),
    [sym_keyword_contains] = ACTIONS(312),
    [sym_keyword_contains_not] = ACTIONS(310),
    [sym_keyword_contains_all] = ACTIONS(310),
    [sym_keyword_contains_any] = ACTIONS(310),
    [sym_keyword_contains_none] = ACTIONS(310),
    [sym_keyword_inside] = ACTIONS(310),
    [sym_keyword_in] = ACTIONS(312),
    [sym_keyword_not_inside] = ACTIONS(310),
    [sym_keyword_all_inside] = ACTIONS(310),
    [sym_keyword_any_inside] = ACTIONS(310),
    [sym_keyword_none_inside] = ACTIONS(310),
    [sym_keyword_outside] = ACTIONS(310),
    [sym_keyword_intersects] = ACTIONS(310),
    [sym_keyword_drop] = ACTIONS(310),
    [sym_keyword_schemafull] = ACTIONS(310),
    [sym_keyword_schemaless] = ACTIONS(310),
    [sym_keyword_changefeed] = ACTIONS(310),
    [sym_keyword_content] = ACTIONS(310),
    [sym_keyword_merge] = ACTIONS(310),
    [sym_keyword_patch] = ACTIONS(310),
    [sym_keyword_replace] = ACTIONS(310),
    [sym_keyword_then] = ACTIONS(310),
    [sym_keyword_permissions] = ACTIONS(310),
    [sym_keyword_for] = ACTIONS(310),
    [sym_keyword_comment] = ACTIONS(310),
    [sym_keyword_unset] = ACTIONS(310),
    [sym_keyword_set] = ACTIONS(310),
    [anon_sym_EQ] = ACTIONS(312),
    [anon_sym_COMMA] = ACTIONS(310),
    [anon_sym_LPAREN] = ACTIONS(310),
    [anon_sym_RPAREN] = ACTIONS(310),
    [anon_sym_DASH_GT] = ACTIONS(310),
    [anon_sym_LBRACK] = ACTIONS(310),
    [anon_sym_RBRACK] = ACTIONS(310),
    [anon_sym_QMARK] = ACTIONS(312),
    [anon_sym_LBRACE] = ACTIONS(310),
    [anon_sym_RBRACE] = ACTIONS(310),
    [anon_sym_LT] = ACTIONS(312),
    [anon_sym_GT] = ACTIONS(312),
    [anon_sym_LT_DASH] = ACTIONS(312),
    [anon_sym_LT_DASH_GT] = ACTIONS(310),
    [anon_sym_STAR] = ACTIONS(312),
    [anon_sym_DOT] = ACTIONS(310),
    [anon_sym_DASH] = ACTIONS(312),
    [anon_sym_PERCENT] = ACTIONS(310),
    [anon_sym_AT] = ACTIONS(312),
    [anon_sym_LT_PIPE] = ACTIONS(310),
    [anon_sym_AMP_AMP] = ACTIONS(310),
    [anon_sym_PIPE_PIPE] = ACTIONS(310),
    [anon_sym_QMARK_QMARK] = ACTIONS(310),
    [anon_sym_QMARK_COLON] = ACTIONS(310),
    [anon_sym_BANG_EQ] = ACTIONS(310),
    [anon_sym_EQ_EQ] = ACTIONS(310),
    [anon_sym_QMARK_EQ] = ACTIONS(310),
    [anon_sym_STAR_EQ] = ACTIONS(310),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG_TILDE] = ACTIONS(310),
    [anon_sym_STAR_TILDE] = ACTIONS(310),
    [anon_sym_LT_EQ] = ACTIONS(310),
    [anon_sym_GT_EQ] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(312),
    [anon_sym_PLUS_EQ] = ACTIONS(310),
    [anon_sym_DASH_EQ] = ACTIONS(310),
    [anon_sym_u00d7] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(312),
    [anon_sym_u00f7] = ACTIONS(310),
    [anon_sym_STAR_STAR] = ACTIONS(310),
    [anon_sym_u220b] = ACTIONS(310),
    [anon_sym_u220c] = ACTIONS(310),
    [anon_sym_u2287] = ACTIONS(310),
    [anon_sym_u2283] = ACTIONS(310),
    [anon_sym_u2285] = ACTIONS(310),
    [anon_sym_u2208] = ACTIONS(310),
    [anon_sym_u2209] = ACTIONS(310),
    [anon_sym_u2286] = ACTIONS(310),
    [anon_sym_u2282] = ACTIONS(310),
    [anon_sym_u2284] = ACTIONS(310),
    [anon_sym_AT_AT] = ACTIONS(310),
  },
  [STATE(83)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_on] = ACTIONS(278),
    [sym_keyword_return] = ACTIONS(278),
    [sym_keyword_from] = ACTIONS(278),
    [sym_keyword_as] = ACTIONS(278),
    [sym_keyword_omit] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(278),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [sym_keyword_drop] = ACTIONS(278),
    [sym_keyword_schemafull] = ACTIONS(278),
    [sym_keyword_schemaless] = ACTIONS(278),
    [sym_keyword_changefeed] = ACTIONS(278),
    [sym_keyword_content] = ACTIONS(278),
    [sym_keyword_merge] = ACTIONS(278),
    [sym_keyword_patch] = ACTIONS(278),
    [sym_keyword_replace] = ACTIONS(278),
    [sym_keyword_then] = ACTIONS(278),
    [sym_keyword_permissions] = ACTIONS(278),
    [sym_keyword_for] = ACTIONS(278),
    [sym_keyword_comment] = ACTIONS(278),
    [sym_keyword_unset] = ACTIONS(278),
    [sym_keyword_set] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_LPAREN] = ACTIONS(278),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_RBRACK] = ACTIONS(278),
    [anon_sym_QMARK] = ACTIONS(280),
    [anon_sym_LBRACE] = ACTIONS(278),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(84)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(347),
    [sym_keyword_on] = ACTIONS(347),
    [sym_keyword_return] = ACTIONS(347),
    [sym_keyword_from] = ACTIONS(347),
    [sym_keyword_as] = ACTIONS(347),
    [sym_keyword_omit] = ACTIONS(347),
    [sym_keyword_explain] = ACTIONS(347),
    [sym_keyword_parallel] = ACTIONS(347),
    [sym_keyword_timeout] = ACTIONS(347),
    [sym_keyword_fetch] = ACTIONS(347),
    [sym_keyword_limit] = ACTIONS(347),
    [sym_keyword_where] = ACTIONS(347),
    [sym_keyword_group] = ACTIONS(347),
    [sym_keyword_and] = ACTIONS(347),
    [sym_keyword_or] = ACTIONS(347),
    [sym_keyword_is] = ACTIONS(347),
    [sym_keyword_not] = ACTIONS(349),
    [sym_keyword_contains] = ACTIONS(349),
    [sym_keyword_contains_not] = ACTIONS(347),
    [sym_keyword_contains_all] = ACTIONS(347),
    [sym_keyword_contains_any] = ACTIONS(347),
    [sym_keyword_contains_none] = ACTIONS(347),
    [sym_keyword_inside] = ACTIONS(347),
    [sym_keyword_in] = ACTIONS(349),
    [sym_keyword_not_inside] = ACTIONS(347),
    [sym_keyword_all_inside] = ACTIONS(347),
    [sym_keyword_any_inside] = ACTIONS(347),
    [sym_keyword_none_inside] = ACTIONS(347),
    [sym_keyword_outside] = ACTIONS(347),
    [sym_keyword_intersects] = ACTIONS(347),
    [sym_keyword_drop] = ACTIONS(347),
    [sym_keyword_schemafull] = ACTIONS(347),
    [sym_keyword_schemaless] = ACTIONS(347),
    [sym_keyword_changefeed] = ACTIONS(347),
    [sym_keyword_content] = ACTIONS(347),
    [sym_keyword_merge] = ACTIONS(347),
    [sym_keyword_patch] = ACTIONS(347),
    [sym_keyword_replace] = ACTIONS(347),
    [sym_keyword_then] = ACTIONS(347),
    [sym_keyword_permissions] = ACTIONS(347),
    [sym_keyword_for] = ACTIONS(347),
    [sym_keyword_comment] = ACTIONS(347),
    [sym_keyword_unset] = ACTIONS(347),
    [sym_keyword_set] = ACTIONS(347),
    [anon_sym_EQ] = ACTIONS(349),
    [anon_sym_COMMA] = ACTIONS(347),
    [anon_sym_LPAREN] = ACTIONS(347),
    [anon_sym_RPAREN] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(347),
    [anon_sym_LBRACK] = ACTIONS(347),
    [anon_sym_RBRACK] = ACTIONS(347),
    [anon_sym_QMARK] = ACTIONS(349),
    [anon_sym_LBRACE] = ACTIONS(347),
    [anon_sym_RBRACE] = ACTIONS(347),
    [anon_sym_LT] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(349),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_DASH_GT] = ACTIONS(347),
    [anon_sym_STAR] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_AT] = ACTIONS(349),
    [anon_sym_LT_PIPE] = ACTIONS(347),
    [anon_sym_AMP_AMP] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(347),
    [anon_sym_QMARK_QMARK] = ACTIONS(347),
    [anon_sym_QMARK_COLON] = ACTIONS(347),
    [anon_sym_BANG_EQ] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(347),
    [anon_sym_QMARK_EQ] = ACTIONS(347),
    [anon_sym_STAR_EQ] = ACTIONS(347),
    [anon_sym_TILDE] = ACTIONS(347),
    [anon_sym_BANG_TILDE] = ACTIONS(347),
    [anon_sym_STAR_TILDE] = ACTIONS(347),
    [anon_sym_LT_EQ] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_PLUS_EQ] = ACTIONS(347),
    [anon_sym_DASH_EQ] = ACTIONS(347),
    [anon_sym_u00d7] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_u00f7] = ACTIONS(347),
    [anon_sym_STAR_STAR] = ACTIONS(347),
    [anon_sym_u220b] = ACTIONS(347),
    [anon_sym_u220c] = ACTIONS(347),
    [anon_sym_u2287] = ACTIONS(347),
    [anon_sym_u2283] = ACTIONS(347),
    [anon_sym_u2285] = ACTIONS(347),
    [anon_sym_u2208] = ACTIONS(347),
    [anon_sym_u2209] = ACTIONS(347),
    [anon_sym_u2286] = ACTIONS(347),
    [anon_sym_u2282] = ACTIONS(347),
    [anon_sym_u2284] = ACTIONS(347),
    [anon_sym_AT_AT] = ACTIONS(347),
  },
  [STATE(85)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_on] = ACTIONS(93),
    [sym_keyword_return] = ACTIONS(93),
    [sym_keyword_from] = ACTIONS(93),
    [sym_keyword_as] = ACTIONS(93),
    [sym_keyword_omit] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_drop] = ACTIONS(93),
    [sym_keyword_schemafull] = ACTIONS(93),
    [sym_keyword_schemaless] = ACTIONS(93),
    [sym_keyword_changefeed] = ACTIONS(93),
    [sym_keyword_content] = ACTIONS(93),
    [sym_keyword_merge] = ACTIONS(93),
    [sym_keyword_patch] = ACTIONS(93),
    [sym_keyword_replace] = ACTIONS(93),
    [sym_keyword_then] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [sym_keyword_unset] = ACTIONS(93),
    [sym_keyword_set] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_RBRACK] = ACTIONS(93),
    [anon_sym_QMARK] = ACTIONS(95),
    [anon_sym_LBRACE] = ACTIONS(93),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(86)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_on] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_from] = ACTIONS(288),
    [sym_keyword_as] = ACTIONS(288),
    [sym_keyword_omit] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_drop] = ACTIONS(288),
    [sym_keyword_schemafull] = ACTIONS(288),
    [sym_keyword_schemaless] = ACTIONS(288),
    [sym_keyword_changefeed] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_merge] = ACTIONS(288),
    [sym_keyword_patch] = ACTIONS(288),
    [sym_keyword_replace] = ACTIONS(288),
    [sym_keyword_then] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [sym_keyword_unset] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_LPAREN] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACK] = ACTIONS(288),
    [anon_sym_QMARK] = ACTIONS(290),
    [anon_sym_LBRACE] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(290),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(288),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(87)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(260),
    [sym_keyword_on] = ACTIONS(260),
    [sym_keyword_return] = ACTIONS(260),
    [sym_keyword_from] = ACTIONS(260),
    [sym_keyword_as] = ACTIONS(260),
    [sym_keyword_omit] = ACTIONS(260),
    [sym_keyword_explain] = ACTIONS(260),
    [sym_keyword_parallel] = ACTIONS(260),
    [sym_keyword_timeout] = ACTIONS(260),
    [sym_keyword_fetch] = ACTIONS(260),
    [sym_keyword_limit] = ACTIONS(260),
    [sym_keyword_where] = ACTIONS(260),
    [sym_keyword_group] = ACTIONS(260),
    [sym_keyword_and] = ACTIONS(260),
    [sym_keyword_or] = ACTIONS(260),
    [sym_keyword_is] = ACTIONS(260),
    [sym_keyword_not] = ACTIONS(262),
    [sym_keyword_contains] = ACTIONS(262),
    [sym_keyword_contains_not] = ACTIONS(260),
    [sym_keyword_contains_all] = ACTIONS(260),
    [sym_keyword_contains_any] = ACTIONS(260),
    [sym_keyword_contains_none] = ACTIONS(260),
    [sym_keyword_inside] = ACTIONS(260),
    [sym_keyword_in] = ACTIONS(262),
    [sym_keyword_not_inside] = ACTIONS(260),
    [sym_keyword_all_inside] = ACTIONS(260),
    [sym_keyword_any_inside] = ACTIONS(260),
    [sym_keyword_none_inside] = ACTIONS(260),
    [sym_keyword_outside] = ACTIONS(260),
    [sym_keyword_intersects] = ACTIONS(260),
    [sym_keyword_drop] = ACTIONS(260),
    [sym_keyword_schemafull] = ACTIONS(260),
    [sym_keyword_schemaless] = ACTIONS(260),
    [sym_keyword_changefeed] = ACTIONS(260),
    [sym_keyword_content] = ACTIONS(260),
    [sym_keyword_merge] = ACTIONS(260),
    [sym_keyword_patch] = ACTIONS(260),
    [sym_keyword_replace] = ACTIONS(260),
    [sym_keyword_then] = ACTIONS(260),
    [sym_keyword_permissions] = ACTIONS(260),
    [sym_keyword_for] = ACTIONS(260),
    [sym_keyword_comment] = ACTIONS(260),
    [sym_keyword_unset] = ACTIONS(260),
    [sym_keyword_set] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(262),
    [anon_sym_COMMA] = ACTIONS(260),
    [anon_sym_LPAREN] = ACTIONS(260),
    [anon_sym_RPAREN] = ACTIONS(260),
    [anon_sym_DASH_GT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(260),
    [anon_sym_RBRACK] = ACTIONS(260),
    [anon_sym_QMARK] = ACTIONS(262),
    [anon_sym_LBRACE] = ACTIONS(260),
    [anon_sym_RBRACE] = ACTIONS(260),
    [anon_sym_LT] = ACTIONS(262),
    [anon_sym_GT] = ACTIONS(262),
    [anon_sym_LT_DASH] = ACTIONS(262),
    [anon_sym_LT_DASH_GT] = ACTIONS(260),
    [anon_sym_STAR] = ACTIONS(262),
    [anon_sym_DOT] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(262),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_AT] = ACTIONS(262),
    [anon_sym_LT_PIPE] = ACTIONS(260),
    [anon_sym_AMP_AMP] = ACTIONS(260),
    [anon_sym_PIPE_PIPE] = ACTIONS(260),
    [anon_sym_QMARK_QMARK] = ACTIONS(260),
    [anon_sym_QMARK_COLON] = ACTIONS(260),
    [anon_sym_BANG_EQ] = ACTIONS(260),
    [anon_sym_EQ_EQ] = ACTIONS(260),
    [anon_sym_QMARK_EQ] = ACTIONS(260),
    [anon_sym_STAR_EQ] = ACTIONS(260),
    [anon_sym_TILDE] = ACTIONS(260),
    [anon_sym_BANG_TILDE] = ACTIONS(260),
    [anon_sym_STAR_TILDE] = ACTIONS(260),
    [anon_sym_LT_EQ] = ACTIONS(260),
    [anon_sym_GT_EQ] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(262),
    [anon_sym_PLUS_EQ] = ACTIONS(260),
    [anon_sym_DASH_EQ] = ACTIONS(260),
    [anon_sym_u00d7] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(262),
    [anon_sym_u00f7] = ACTIONS(260),
    [anon_sym_STAR_STAR] = ACTIONS(260),
    [anon_sym_u220b] = ACTIONS(260),
    [anon_sym_u220c] = ACTIONS(260),
    [anon_sym_u2287] = ACTIONS(260),
    [anon_sym_u2283] = ACTIONS(260),
    [anon_sym_u2285] = ACTIONS(260),
    [anon_sym_u2208] = ACTIONS(260),
    [anon_sym_u2209] = ACTIONS(260),
    [anon_sym_u2286] = ACTIONS(260),
    [anon_sym_u2282] = ACTIONS(260),
    [anon_sym_u2284] = ACTIONS(260),
    [anon_sym_AT_AT] = ACTIONS(260),
  },
  [STATE(88)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(296),
    [sym_keyword_on] = ACTIONS(296),
    [sym_keyword_return] = ACTIONS(296),
    [sym_keyword_from] = ACTIONS(296),
    [sym_keyword_as] = ACTIONS(296),
    [sym_keyword_omit] = ACTIONS(296),
    [sym_keyword_explain] = ACTIONS(296),
    [sym_keyword_parallel] = ACTIONS(296),
    [sym_keyword_timeout] = ACTIONS(296),
    [sym_keyword_fetch] = ACTIONS(296),
    [sym_keyword_limit] = ACTIONS(296),
    [sym_keyword_where] = ACTIONS(296),
    [sym_keyword_group] = ACTIONS(296),
    [sym_keyword_and] = ACTIONS(296),
    [sym_keyword_or] = ACTIONS(296),
    [sym_keyword_is] = ACTIONS(296),
    [sym_keyword_not] = ACTIONS(298),
    [sym_keyword_contains] = ACTIONS(298),
    [sym_keyword_contains_not] = ACTIONS(296),
    [sym_keyword_contains_all] = ACTIONS(296),
    [sym_keyword_contains_any] = ACTIONS(296),
    [sym_keyword_contains_none] = ACTIONS(296),
    [sym_keyword_inside] = ACTIONS(296),
    [sym_keyword_in] = ACTIONS(298),
    [sym_keyword_not_inside] = ACTIONS(296),
    [sym_keyword_all_inside] = ACTIONS(296),
    [sym_keyword_any_inside] = ACTIONS(296),
    [sym_keyword_none_inside] = ACTIONS(296),
    [sym_keyword_outside] = ACTIONS(296),
    [sym_keyword_intersects] = ACTIONS(296),
    [sym_keyword_drop] = ACTIONS(296),
    [sym_keyword_schemafull] = ACTIONS(296),
    [sym_keyword_schemaless] = ACTIONS(296),
    [sym_keyword_changefeed] = ACTIONS(296),
    [sym_keyword_content] = ACTIONS(296),
    [sym_keyword_merge] = ACTIONS(296),
    [sym_keyword_patch] = ACTIONS(296),
    [sym_keyword_replace] = ACTIONS(296),
    [sym_keyword_then] = ACTIONS(296),
    [sym_keyword_permissions] = ACTIONS(296),
    [sym_keyword_for] = ACTIONS(296),
    [sym_keyword_comment] = ACTIONS(296),
    [sym_keyword_unset] = ACTIONS(296),
    [sym_keyword_set] = ACTIONS(296),
    [anon_sym_EQ] = ACTIONS(298),
    [anon_sym_COMMA] = ACTIONS(296),
    [anon_sym_LPAREN] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(296),
    [anon_sym_DASH_GT] = ACTIONS(296),
    [anon_sym_LBRACK] = ACTIONS(296),
    [anon_sym_RBRACK] = ACTIONS(296),
    [anon_sym_QMARK] = ACTIONS(298),
    [anon_sym_LBRACE] = ACTIONS(296),
    [anon_sym_RBRACE] = ACTIONS(296),
    [anon_sym_LT] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(298),
    [anon_sym_LT_DASH] = ACTIONS(298),
    [anon_sym_LT_DASH_GT] = ACTIONS(296),
    [anon_sym_STAR] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(296),
    [anon_sym_DASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(296),
    [anon_sym_AT] = ACTIONS(298),
    [anon_sym_LT_PIPE] = ACTIONS(296),
    [anon_sym_AMP_AMP] = ACTIONS(296),
    [anon_sym_PIPE_PIPE] = ACTIONS(296),
    [anon_sym_QMARK_QMARK] = ACTIONS(296),
    [anon_sym_QMARK_COLON] = ACTIONS(296),
    [anon_sym_BANG_EQ] = ACTIONS(296),
    [anon_sym_EQ_EQ] = ACTIONS(296),
    [anon_sym_QMARK_EQ] = ACTIONS(296),
    [anon_sym_STAR_EQ] = ACTIONS(296),
    [anon_sym_TILDE] = ACTIONS(296),
    [anon_sym_BANG_TILDE] = ACTIONS(296),
    [anon_sym_STAR_TILDE] = ACTIONS(296),
    [anon_sym_LT_EQ] = ACTIONS(296),
    [anon_sym_GT_EQ] = ACTIONS(296),
    [anon_sym_PLUS] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(296),
    [anon_sym_DASH_EQ] = ACTIONS(296),
    [anon_sym_u00d7] = ACTIONS(296),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_u00f7] = ACTIONS(296),
    [anon_sym_STAR_STAR] = ACTIONS(296),
    [anon_sym_u220b] = ACTIONS(296),
    [anon_sym_u220c] = ACTIONS(296),
    [anon_sym_u2287] = ACTIONS(296),
    [anon_sym_u2283] = ACTIONS(296),
    [anon_sym_u2285] = ACTIONS(296),
    [anon_sym_u2208] = ACTIONS(296),
    [anon_sym_u2209] = ACTIONS(296),
    [anon_sym_u2286] = ACTIONS(296),
    [anon_sym_u2282] = ACTIONS(296),
    [anon_sym_u2284] = ACTIONS(296),
    [anon_sym_AT_AT] = ACTIONS(296),
  },
  [STATE(89)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(343),
    [sym_keyword_on] = ACTIONS(343),
    [sym_keyword_return] = ACTIONS(343),
    [sym_keyword_from] = ACTIONS(343),
    [sym_keyword_as] = ACTIONS(343),
    [sym_keyword_omit] = ACTIONS(343),
    [sym_keyword_explain] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(343),
    [sym_keyword_timeout] = ACTIONS(343),
    [sym_keyword_fetch] = ACTIONS(343),
    [sym_keyword_limit] = ACTIONS(343),
    [sym_keyword_where] = ACTIONS(343),
    [sym_keyword_group] = ACTIONS(343),
    [sym_keyword_and] = ACTIONS(343),
    [sym_keyword_or] = ACTIONS(343),
    [sym_keyword_is] = ACTIONS(343),
    [sym_keyword_not] = ACTIONS(345),
    [sym_keyword_contains] = ACTIONS(345),
    [sym_keyword_contains_not] = ACTIONS(343),
    [sym_keyword_contains_all] = ACTIONS(343),
    [sym_keyword_contains_any] = ACTIONS(343),
    [sym_keyword_contains_none] = ACTIONS(343),
    [sym_keyword_inside] = ACTIONS(343),
    [sym_keyword_in] = ACTIONS(345),
    [sym_keyword_not_inside] = ACTIONS(343),
    [sym_keyword_all_inside] = ACTIONS(343),
    [sym_keyword_any_inside] = ACTIONS(343),
    [sym_keyword_none_inside] = ACTIONS(343),
    [sym_keyword_outside] = ACTIONS(343),
    [sym_keyword_intersects] = ACTIONS(343),
    [sym_keyword_drop] = ACTIONS(343),
    [sym_keyword_schemafull] = ACTIONS(343),
    [sym_keyword_schemaless] = ACTIONS(343),
    [sym_keyword_changefeed] = ACTIONS(343),
    [sym_keyword_content] = ACTIONS(343),
    [sym_keyword_merge] = ACTIONS(343),
    [sym_keyword_patch] = ACTIONS(343),
    [sym_keyword_replace] = ACTIONS(343),
    [sym_keyword_then] = ACTIONS(343),
    [sym_keyword_permissions] = ACTIONS(343),
    [sym_keyword_for] = ACTIONS(343),
    [sym_keyword_comment] = ACTIONS(343),
    [sym_keyword_unset] = ACTIONS(343),
    [sym_keyword_set] = ACTIONS(343),
    [anon_sym_EQ] = ACTIONS(345),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_LPAREN] = ACTIONS(343),
    [anon_sym_RPAREN] = ACTIONS(343),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(343),
    [anon_sym_RBRACK] = ACTIONS(343),
    [anon_sym_QMARK] = ACTIONS(345),
    [anon_sym_LBRACE] = ACTIONS(343),
    [anon_sym_RBRACE] = ACTIONS(343),
    [anon_sym_LT] = ACTIONS(345),
    [anon_sym_GT] = ACTIONS(345),
    [anon_sym_LT_DASH] = ACTIONS(345),
    [anon_sym_LT_DASH_GT] = ACTIONS(343),
    [anon_sym_STAR] = ACTIONS(345),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_PERCENT] = ACTIONS(343),
    [anon_sym_AT] = ACTIONS(345),
    [anon_sym_LT_PIPE] = ACTIONS(343),
    [anon_sym_AMP_AMP] = ACTIONS(343),
    [anon_sym_PIPE_PIPE] = ACTIONS(343),
    [anon_sym_QMARK_QMARK] = ACTIONS(343),
    [anon_sym_QMARK_COLON] = ACTIONS(343),
    [anon_sym_BANG_EQ] = ACTIONS(343),
    [anon_sym_EQ_EQ] = ACTIONS(343),
    [anon_sym_QMARK_EQ] = ACTIONS(343),
    [anon_sym_STAR_EQ] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(343),
    [anon_sym_BANG_TILDE] = ACTIONS(343),
    [anon_sym_STAR_TILDE] = ACTIONS(343),
    [anon_sym_LT_EQ] = ACTIONS(343),
    [anon_sym_GT_EQ] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_PLUS_EQ] = ACTIONS(343),
    [anon_sym_DASH_EQ] = ACTIONS(343),
    [anon_sym_u00d7] = ACTIONS(343),
    [anon_sym_SLASH] = ACTIONS(345),
    [anon_sym_u00f7] = ACTIONS(343),
    [anon_sym_STAR_STAR] = ACTIONS(343),
    [anon_sym_u220b] = ACTIONS(343),
    [anon_sym_u220c] = ACTIONS(343),
    [anon_sym_u2287] = ACTIONS(343),
    [anon_sym_u2283] = ACTIONS(343),
    [anon_sym_u2285] = ACTIONS(343),
    [anon_sym_u2208] = ACTIONS(343),
    [anon_sym_u2209] = ACTIONS(343),
    [anon_sym_u2286] = ACTIONS(343),
    [anon_sym_u2282] = ACTIONS(343),
    [anon_sym_u2284] = ACTIONS(343),
    [anon_sym_AT_AT] = ACTIONS(343),
  },
  [STATE(90)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(359),
    [sym_keyword_on] = ACTIONS(359),
    [sym_keyword_return] = ACTIONS(359),
    [sym_keyword_from] = ACTIONS(359),
    [sym_keyword_as] = ACTIONS(359),
    [sym_keyword_omit] = ACTIONS(359),
    [sym_keyword_explain] = ACTIONS(359),
    [sym_keyword_parallel] = ACTIONS(359),
    [sym_keyword_timeout] = ACTIONS(359),
    [sym_keyword_fetch] = ACTIONS(359),
    [sym_keyword_limit] = ACTIONS(359),
    [sym_keyword_where] = ACTIONS(359),
    [sym_keyword_group] = ACTIONS(359),
    [sym_keyword_and] = ACTIONS(359),
    [sym_keyword_or] = ACTIONS(359),
    [sym_keyword_is] = ACTIONS(359),
    [sym_keyword_not] = ACTIONS(361),
    [sym_keyword_contains] = ACTIONS(361),
    [sym_keyword_contains_not] = ACTIONS(359),
    [sym_keyword_contains_all] = ACTIONS(359),
    [sym_keyword_contains_any] = ACTIONS(359),
    [sym_keyword_contains_none] = ACTIONS(359),
    [sym_keyword_inside] = ACTIONS(359),
    [sym_keyword_in] = ACTIONS(361),
    [sym_keyword_not_inside] = ACTIONS(359),
    [sym_keyword_all_inside] = ACTIONS(359),
    [sym_keyword_any_inside] = ACTIONS(359),
    [sym_keyword_none_inside] = ACTIONS(359),
    [sym_keyword_outside] = ACTIONS(359),
    [sym_keyword_intersects] = ACTIONS(359),
    [sym_keyword_drop] = ACTIONS(359),
    [sym_keyword_schemafull] = ACTIONS(359),
    [sym_keyword_schemaless] = ACTIONS(359),
    [sym_keyword_changefeed] = ACTIONS(359),
    [sym_keyword_content] = ACTIONS(359),
    [sym_keyword_merge] = ACTIONS(359),
    [sym_keyword_patch] = ACTIONS(359),
    [sym_keyword_replace] = ACTIONS(359),
    [sym_keyword_then] = ACTIONS(359),
    [sym_keyword_permissions] = ACTIONS(359),
    [sym_keyword_for] = ACTIONS(359),
    [sym_keyword_comment] = ACTIONS(359),
    [sym_keyword_unset] = ACTIONS(359),
    [sym_keyword_set] = ACTIONS(359),
    [anon_sym_EQ] = ACTIONS(361),
    [anon_sym_COMMA] = ACTIONS(359),
    [anon_sym_LPAREN] = ACTIONS(359),
    [anon_sym_RPAREN] = ACTIONS(359),
    [anon_sym_DASH_GT] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_RBRACK] = ACTIONS(359),
    [anon_sym_QMARK] = ACTIONS(361),
    [anon_sym_LBRACE] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(359),
    [anon_sym_LT] = ACTIONS(361),
    [anon_sym_GT] = ACTIONS(361),
    [anon_sym_LT_DASH] = ACTIONS(361),
    [anon_sym_LT_DASH_GT] = ACTIONS(359),
    [anon_sym_STAR] = ACTIONS(361),
    [anon_sym_DOT] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [anon_sym_PERCENT] = ACTIONS(359),
    [anon_sym_AT] = ACTIONS(361),
    [anon_sym_LT_PIPE] = ACTIONS(359),
    [anon_sym_AMP_AMP] = ACTIONS(359),
    [anon_sym_PIPE_PIPE] = ACTIONS(359),
    [anon_sym_QMARK_QMARK] = ACTIONS(359),
    [anon_sym_QMARK_COLON] = ACTIONS(359),
    [anon_sym_BANG_EQ] = ACTIONS(359),
    [anon_sym_EQ_EQ] = ACTIONS(359),
    [anon_sym_QMARK_EQ] = ACTIONS(359),
    [anon_sym_STAR_EQ] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(359),
    [anon_sym_BANG_TILDE] = ACTIONS(359),
    [anon_sym_STAR_TILDE] = ACTIONS(359),
    [anon_sym_LT_EQ] = ACTIONS(359),
    [anon_sym_GT_EQ] = ACTIONS(359),
    [anon_sym_PLUS] = ACTIONS(361),
    [anon_sym_PLUS_EQ] = ACTIONS(359),
    [anon_sym_DASH_EQ] = ACTIONS(359),
    [anon_sym_u00d7] = ACTIONS(359),
    [anon_sym_SLASH] = ACTIONS(361),
    [anon_sym_u00f7] = ACTIONS(359),
    [anon_sym_STAR_STAR] = ACTIONS(359),
    [anon_sym_u220b] = ACTIONS(359),
    [anon_sym_u220c] = ACTIONS(359),
    [anon_sym_u2287] = ACTIONS(359),
    [anon_sym_u2283] = ACTIONS(359),
    [anon_sym_u2285] = ACTIONS(359),
    [anon_sym_u2208] = ACTIONS(359),
    [anon_sym_u2209] = ACTIONS(359),
    [anon_sym_u2286] = ACTIONS(359),
    [anon_sym_u2282] = ACTIONS(359),
    [anon_sym_u2284] = ACTIONS(359),
    [anon_sym_AT_AT] = ACTIONS(359),
  },
  [STATE(91)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_on] = ACTIONS(355),
    [sym_keyword_return] = ACTIONS(355),
    [sym_keyword_from] = ACTIONS(355),
    [sym_keyword_as] = ACTIONS(355),
    [sym_keyword_omit] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(355),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [sym_keyword_drop] = ACTIONS(355),
    [sym_keyword_schemafull] = ACTIONS(355),
    [sym_keyword_schemaless] = ACTIONS(355),
    [sym_keyword_changefeed] = ACTIONS(355),
    [sym_keyword_content] = ACTIONS(355),
    [sym_keyword_merge] = ACTIONS(355),
    [sym_keyword_patch] = ACTIONS(355),
    [sym_keyword_replace] = ACTIONS(355),
    [sym_keyword_then] = ACTIONS(355),
    [sym_keyword_permissions] = ACTIONS(355),
    [sym_keyword_for] = ACTIONS(355),
    [sym_keyword_comment] = ACTIONS(355),
    [sym_keyword_unset] = ACTIONS(355),
    [sym_keyword_set] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_LPAREN] = ACTIONS(355),
    [anon_sym_RPAREN] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_RBRACK] = ACTIONS(355),
    [anon_sym_QMARK] = ACTIONS(357),
    [anon_sym_LBRACE] = ACTIONS(355),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(92)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_on] = ACTIONS(355),
    [sym_keyword_return] = ACTIONS(355),
    [sym_keyword_from] = ACTIONS(355),
    [sym_keyword_as] = ACTIONS(355),
    [sym_keyword_omit] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(355),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [sym_keyword_drop] = ACTIONS(355),
    [sym_keyword_schemafull] = ACTIONS(355),
    [sym_keyword_schemaless] = ACTIONS(355),
    [sym_keyword_changefeed] = ACTIONS(355),
    [sym_keyword_content] = ACTIONS(355),
    [sym_keyword_merge] = ACTIONS(355),
    [sym_keyword_patch] = ACTIONS(355),
    [sym_keyword_replace] = ACTIONS(355),
    [sym_keyword_then] = ACTIONS(355),
    [sym_keyword_permissions] = ACTIONS(355),
    [sym_keyword_for] = ACTIONS(355),
    [sym_keyword_comment] = ACTIONS(355),
    [sym_keyword_unset] = ACTIONS(355),
    [sym_keyword_set] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_LPAREN] = ACTIONS(355),
    [anon_sym_RPAREN] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_RBRACK] = ACTIONS(355),
    [anon_sym_QMARK] = ACTIONS(357),
    [anon_sym_LBRACE] = ACTIONS(355),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(93)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(300),
    [sym_keyword_on] = ACTIONS(300),
    [sym_keyword_return] = ACTIONS(300),
    [sym_keyword_from] = ACTIONS(300),
    [sym_keyword_as] = ACTIONS(300),
    [sym_keyword_omit] = ACTIONS(300),
    [sym_keyword_explain] = ACTIONS(300),
    [sym_keyword_parallel] = ACTIONS(300),
    [sym_keyword_timeout] = ACTIONS(300),
    [sym_keyword_fetch] = ACTIONS(300),
    [sym_keyword_limit] = ACTIONS(300),
    [sym_keyword_where] = ACTIONS(300),
    [sym_keyword_group] = ACTIONS(300),
    [sym_keyword_and] = ACTIONS(300),
    [sym_keyword_or] = ACTIONS(300),
    [sym_keyword_is] = ACTIONS(300),
    [sym_keyword_not] = ACTIONS(302),
    [sym_keyword_contains] = ACTIONS(302),
    [sym_keyword_contains_not] = ACTIONS(300),
    [sym_keyword_contains_all] = ACTIONS(300),
    [sym_keyword_contains_any] = ACTIONS(300),
    [sym_keyword_contains_none] = ACTIONS(300),
    [sym_keyword_inside] = ACTIONS(300),
    [sym_keyword_in] = ACTIONS(302),
    [sym_keyword_not_inside] = ACTIONS(300),
    [sym_keyword_all_inside] = ACTIONS(300),
    [sym_keyword_any_inside] = ACTIONS(300),
    [sym_keyword_none_inside] = ACTIONS(300),
    [sym_keyword_outside] = ACTIONS(300),
    [sym_keyword_intersects] = ACTIONS(300),
    [sym_keyword_drop] = ACTIONS(300),
    [sym_keyword_schemafull] = ACTIONS(300),
    [sym_keyword_schemaless] = ACTIONS(300),
    [sym_keyword_changefeed] = ACTIONS(300),
    [sym_keyword_content] = ACTIONS(300),
    [sym_keyword_merge] = ACTIONS(300),
    [sym_keyword_patch] = ACTIONS(300),
    [sym_keyword_replace] = ACTIONS(300),
    [sym_keyword_then] = ACTIONS(300),
    [sym_keyword_permissions] = ACTIONS(300),
    [sym_keyword_for] = ACTIONS(300),
    [sym_keyword_comment] = ACTIONS(300),
    [sym_keyword_unset] = ACTIONS(300),
    [sym_keyword_set] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(300),
    [anon_sym_LPAREN] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(300),
    [anon_sym_DASH_GT] = ACTIONS(300),
    [anon_sym_LBRACK] = ACTIONS(300),
    [anon_sym_RBRACK] = ACTIONS(300),
    [anon_sym_QMARK] = ACTIONS(302),
    [anon_sym_LBRACE] = ACTIONS(300),
    [anon_sym_RBRACE] = ACTIONS(300),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_LT_DASH] = ACTIONS(302),
    [anon_sym_LT_DASH_GT] = ACTIONS(300),
    [anon_sym_STAR] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(300),
    [anon_sym_DASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(300),
    [anon_sym_AT] = ACTIONS(302),
    [anon_sym_LT_PIPE] = ACTIONS(300),
    [anon_sym_AMP_AMP] = ACTIONS(300),
    [anon_sym_PIPE_PIPE] = ACTIONS(300),
    [anon_sym_QMARK_QMARK] = ACTIONS(300),
    [anon_sym_QMARK_COLON] = ACTIONS(300),
    [anon_sym_BANG_EQ] = ACTIONS(300),
    [anon_sym_EQ_EQ] = ACTIONS(300),
    [anon_sym_QMARK_EQ] = ACTIONS(300),
    [anon_sym_STAR_EQ] = ACTIONS(300),
    [anon_sym_TILDE] = ACTIONS(300),
    [anon_sym_BANG_TILDE] = ACTIONS(300),
    [anon_sym_STAR_TILDE] = ACTIONS(300),
    [anon_sym_LT_EQ] = ACTIONS(300),
    [anon_sym_GT_EQ] = ACTIONS(300),
    [anon_sym_PLUS] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(300),
    [anon_sym_DASH_EQ] = ACTIONS(300),
    [anon_sym_u00d7] = ACTIONS(300),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_u00f7] = ACTIONS(300),
    [anon_sym_STAR_STAR] = ACTIONS(300),
    [anon_sym_u220b] = ACTIONS(300),
    [anon_sym_u220c] = ACTIONS(300),
    [anon_sym_u2287] = ACTIONS(300),
    [anon_sym_u2283] = ACTIONS(300),
    [anon_sym_u2285] = ACTIONS(300),
    [anon_sym_u2208] = ACTIONS(300),
    [anon_sym_u2209] = ACTIONS(300),
    [anon_sym_u2286] = ACTIONS(300),
    [anon_sym_u2282] = ACTIONS(300),
    [anon_sym_u2284] = ACTIONS(300),
    [anon_sym_AT_AT] = ACTIONS(300),
  },
  [STATE(94)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_on] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(314),
    [sym_keyword_from] = ACTIONS(314),
    [sym_keyword_as] = ACTIONS(314),
    [sym_keyword_omit] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(314),
    [sym_keyword_where] = ACTIONS(314),
    [sym_keyword_group] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(314),
    [sym_keyword_or] = ACTIONS(314),
    [sym_keyword_is] = ACTIONS(314),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(314),
    [sym_keyword_contains_all] = ACTIONS(314),
    [sym_keyword_contains_any] = ACTIONS(314),
    [sym_keyword_contains_none] = ACTIONS(314),
    [sym_keyword_inside] = ACTIONS(314),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(314),
    [sym_keyword_all_inside] = ACTIONS(314),
    [sym_keyword_any_inside] = ACTIONS(314),
    [sym_keyword_none_inside] = ACTIONS(314),
    [sym_keyword_outside] = ACTIONS(314),
    [sym_keyword_intersects] = ACTIONS(314),
    [sym_keyword_drop] = ACTIONS(314),
    [sym_keyword_schemafull] = ACTIONS(314),
    [sym_keyword_schemaless] = ACTIONS(314),
    [sym_keyword_changefeed] = ACTIONS(314),
    [sym_keyword_content] = ACTIONS(314),
    [sym_keyword_merge] = ACTIONS(314),
    [sym_keyword_patch] = ACTIONS(314),
    [sym_keyword_replace] = ACTIONS(314),
    [sym_keyword_then] = ACTIONS(314),
    [sym_keyword_permissions] = ACTIONS(314),
    [sym_keyword_for] = ACTIONS(314),
    [sym_keyword_comment] = ACTIONS(314),
    [sym_keyword_unset] = ACTIONS(314),
    [sym_keyword_set] = ACTIONS(314),
    [anon_sym_EQ] = ACTIONS(316),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_LPAREN] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(314),
    [anon_sym_RBRACK] = ACTIONS(314),
    [anon_sym_QMARK] = ACTIONS(316),
    [anon_sym_LBRACE] = ACTIONS(314),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(95)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(318),
    [sym_keyword_on] = ACTIONS(318),
    [sym_keyword_return] = ACTIONS(318),
    [sym_keyword_from] = ACTIONS(318),
    [sym_keyword_as] = ACTIONS(318),
    [sym_keyword_omit] = ACTIONS(318),
    [sym_keyword_explain] = ACTIONS(318),
    [sym_keyword_parallel] = ACTIONS(318),
    [sym_keyword_timeout] = ACTIONS(318),
    [sym_keyword_fetch] = ACTIONS(318),
    [sym_keyword_limit] = ACTIONS(318),
    [sym_keyword_where] = ACTIONS(318),
    [sym_keyword_group] = ACTIONS(318),
    [sym_keyword_and] = ACTIONS(318),
    [sym_keyword_or] = ACTIONS(318),
    [sym_keyword_is] = ACTIONS(318),
    [sym_keyword_not] = ACTIONS(320),
    [sym_keyword_contains] = ACTIONS(320),
    [sym_keyword_contains_not] = ACTIONS(318),
    [sym_keyword_contains_all] = ACTIONS(318),
    [sym_keyword_contains_any] = ACTIONS(318),
    [sym_keyword_contains_none] = ACTIONS(318),
    [sym_keyword_inside] = ACTIONS(318),
    [sym_keyword_in] = ACTIONS(320),
    [sym_keyword_not_inside] = ACTIONS(318),
    [sym_keyword_all_inside] = ACTIONS(318),
    [sym_keyword_any_inside] = ACTIONS(318),
    [sym_keyword_none_inside] = ACTIONS(318),
    [sym_keyword_outside] = ACTIONS(318),
    [sym_keyword_intersects] = ACTIONS(318),
    [sym_keyword_drop] = ACTIONS(318),
    [sym_keyword_schemafull] = ACTIONS(318),
    [sym_keyword_schemaless] = ACTIONS(318),
    [sym_keyword_changefeed] = ACTIONS(318),
    [sym_keyword_content] = ACTIONS(318),
    [sym_keyword_merge] = ACTIONS(318),
    [sym_keyword_patch] = ACTIONS(318),
    [sym_keyword_replace] = ACTIONS(318),
    [sym_keyword_then] = ACTIONS(318),
    [sym_keyword_permissions] = ACTIONS(318),
    [sym_keyword_for] = ACTIONS(318),
    [sym_keyword_comment] = ACTIONS(318),
    [sym_keyword_unset] = ACTIONS(318),
    [sym_keyword_set] = ACTIONS(318),
    [anon_sym_EQ] = ACTIONS(320),
    [anon_sym_COMMA] = ACTIONS(318),
    [anon_sym_LPAREN] = ACTIONS(318),
    [anon_sym_RPAREN] = ACTIONS(318),
    [anon_sym_DASH_GT] = ACTIONS(318),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_RBRACK] = ACTIONS(318),
    [anon_sym_QMARK] = ACTIONS(320),
    [anon_sym_LBRACE] = ACTIONS(318),
    [anon_sym_RBRACE] = ACTIONS(318),
    [anon_sym_LT] = ACTIONS(320),
    [anon_sym_GT] = ACTIONS(320),
    [anon_sym_LT_DASH] = ACTIONS(320),
    [anon_sym_LT_DASH_GT] = ACTIONS(318),
    [anon_sym_STAR] = ACTIONS(320),
    [anon_sym_DOT] = ACTIONS(318),
    [anon_sym_DASH] = ACTIONS(320),
    [anon_sym_PERCENT] = ACTIONS(318),
    [anon_sym_AT] = ACTIONS(320),
    [anon_sym_LT_PIPE] = ACTIONS(318),
    [anon_sym_AMP_AMP] = ACTIONS(318),
    [anon_sym_PIPE_PIPE] = ACTIONS(318),
    [anon_sym_QMARK_QMARK] = ACTIONS(318),
    [anon_sym_QMARK_COLON] = ACTIONS(318),
    [anon_sym_BANG_EQ] = ACTIONS(318),
    [anon_sym_EQ_EQ] = ACTIONS(318),
    [anon_sym_QMARK_EQ] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(318),
    [anon_sym_TILDE] = ACTIONS(318),
    [anon_sym_BANG_TILDE] = ACTIONS(318),
    [anon_sym_STAR_TILDE] = ACTIONS(318),
    [anon_sym_LT_EQ] = ACTIONS(318),
    [anon_sym_GT_EQ] = ACTIONS(318),
    [anon_sym_PLUS] = ACTIONS(320),
    [anon_sym_PLUS_EQ] = ACTIONS(318),
    [anon_sym_DASH_EQ] = ACTIONS(318),
    [anon_sym_u00d7] = ACTIONS(318),
    [anon_sym_SLASH] = ACTIONS(320),
    [anon_sym_u00f7] = ACTIONS(318),
    [anon_sym_STAR_STAR] = ACTIONS(318),
    [anon_sym_u220b] = ACTIONS(318),
    [anon_sym_u220c] = ACTIONS(318),
    [anon_sym_u2287] = ACTIONS(318),
    [anon_sym_u2283] = ACTIONS(318),
    [anon_sym_u2285] = ACTIONS(318),
    [anon_sym_u2208] = ACTIONS(318),
    [anon_sym_u2209] = ACTIONS(318),
    [anon_sym_u2286] = ACTIONS(318),
    [anon_sym_u2282] = ACTIONS(318),
    [anon_sym_u2284] = ACTIONS(318),
    [anon_sym_AT_AT] = ACTIONS(318),
  },
  [STATE(96)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(322),
    [sym_keyword_on] = ACTIONS(322),
    [sym_keyword_return] = ACTIONS(322),
    [sym_keyword_from] = ACTIONS(322),
    [sym_keyword_as] = ACTIONS(322),
    [sym_keyword_omit] = ACTIONS(322),
    [sym_keyword_explain] = ACTIONS(322),
    [sym_keyword_parallel] = ACTIONS(322),
    [sym_keyword_timeout] = ACTIONS(322),
    [sym_keyword_fetch] = ACTIONS(322),
    [sym_keyword_limit] = ACTIONS(322),
    [sym_keyword_where] = ACTIONS(322),
    [sym_keyword_group] = ACTIONS(322),
    [sym_keyword_and] = ACTIONS(322),
    [sym_keyword_or] = ACTIONS(322),
    [sym_keyword_is] = ACTIONS(322),
    [sym_keyword_not] = ACTIONS(324),
    [sym_keyword_contains] = ACTIONS(324),
    [sym_keyword_contains_not] = ACTIONS(322),
    [sym_keyword_contains_all] = ACTIONS(322),
    [sym_keyword_contains_any] = ACTIONS(322),
    [sym_keyword_contains_none] = ACTIONS(322),
    [sym_keyword_inside] = ACTIONS(322),
    [sym_keyword_in] = ACTIONS(324),
    [sym_keyword_not_inside] = ACTIONS(322),
    [sym_keyword_all_inside] = ACTIONS(322),
    [sym_keyword_any_inside] = ACTIONS(322),
    [sym_keyword_none_inside] = ACTIONS(322),
    [sym_keyword_outside] = ACTIONS(322),
    [sym_keyword_intersects] = ACTIONS(322),
    [sym_keyword_drop] = ACTIONS(322),
    [sym_keyword_schemafull] = ACTIONS(322),
    [sym_keyword_schemaless] = ACTIONS(322),
    [sym_keyword_changefeed] = ACTIONS(322),
    [sym_keyword_content] = ACTIONS(322),
    [sym_keyword_merge] = ACTIONS(322),
    [sym_keyword_patch] = ACTIONS(322),
    [sym_keyword_replace] = ACTIONS(322),
    [sym_keyword_then] = ACTIONS(322),
    [sym_keyword_permissions] = ACTIONS(322),
    [sym_keyword_for] = ACTIONS(322),
    [sym_keyword_comment] = ACTIONS(322),
    [sym_keyword_unset] = ACTIONS(322),
    [sym_keyword_set] = ACTIONS(322),
    [anon_sym_EQ] = ACTIONS(324),
    [anon_sym_COMMA] = ACTIONS(322),
    [anon_sym_LPAREN] = ACTIONS(322),
    [anon_sym_RPAREN] = ACTIONS(322),
    [anon_sym_DASH_GT] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(322),
    [anon_sym_RBRACK] = ACTIONS(322),
    [anon_sym_QMARK] = ACTIONS(324),
    [anon_sym_LBRACE] = ACTIONS(322),
    [anon_sym_RBRACE] = ACTIONS(322),
    [anon_sym_LT] = ACTIONS(324),
    [anon_sym_GT] = ACTIONS(324),
    [anon_sym_LT_DASH] = ACTIONS(324),
    [anon_sym_LT_DASH_GT] = ACTIONS(322),
    [anon_sym_STAR] = ACTIONS(324),
    [anon_sym_DOT] = ACTIONS(322),
    [anon_sym_DASH] = ACTIONS(324),
    [anon_sym_PERCENT] = ACTIONS(322),
    [anon_sym_AT] = ACTIONS(324),
    [anon_sym_LT_PIPE] = ACTIONS(322),
    [anon_sym_AMP_AMP] = ACTIONS(322),
    [anon_sym_PIPE_PIPE] = ACTIONS(322),
    [anon_sym_QMARK_QMARK] = ACTIONS(322),
    [anon_sym_QMARK_COLON] = ACTIONS(322),
    [anon_sym_BANG_EQ] = ACTIONS(322),
    [anon_sym_EQ_EQ] = ACTIONS(322),
    [anon_sym_QMARK_EQ] = ACTIONS(322),
    [anon_sym_STAR_EQ] = ACTIONS(322),
    [anon_sym_TILDE] = ACTIONS(322),
    [anon_sym_BANG_TILDE] = ACTIONS(322),
    [anon_sym_STAR_TILDE] = ACTIONS(322),
    [anon_sym_LT_EQ] = ACTIONS(322),
    [anon_sym_GT_EQ] = ACTIONS(322),
    [anon_sym_PLUS] = ACTIONS(324),
    [anon_sym_PLUS_EQ] = ACTIONS(322),
    [anon_sym_DASH_EQ] = ACTIONS(322),
    [anon_sym_u00d7] = ACTIONS(322),
    [anon_sym_SLASH] = ACTIONS(324),
    [anon_sym_u00f7] = ACTIONS(322),
    [anon_sym_STAR_STAR] = ACTIONS(322),
    [anon_sym_u220b] = ACTIONS(322),
    [anon_sym_u220c] = ACTIONS(322),
    [anon_sym_u2287] = ACTIONS(322),
    [anon_sym_u2283] = ACTIONS(322),
    [anon_sym_u2285] = ACTIONS(322),
    [anon_sym_u2208] = ACTIONS(322),
    [anon_sym_u2209] = ACTIONS(322),
    [anon_sym_u2286] = ACTIONS(322),
    [anon_sym_u2282] = ACTIONS(322),
    [anon_sym_u2284] = ACTIONS(322),
    [anon_sym_AT_AT] = ACTIONS(322),
  },
  [STATE(97)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(365),
    [sym_keyword_on] = ACTIONS(365),
    [sym_keyword_return] = ACTIONS(365),
    [sym_keyword_from] = ACTIONS(365),
    [sym_keyword_as] = ACTIONS(365),
    [sym_keyword_omit] = ACTIONS(365),
    [sym_keyword_explain] = ACTIONS(365),
    [sym_keyword_parallel] = ACTIONS(365),
    [sym_keyword_timeout] = ACTIONS(365),
    [sym_keyword_fetch] = ACTIONS(365),
    [sym_keyword_limit] = ACTIONS(365),
    [sym_keyword_where] = ACTIONS(365),
    [sym_keyword_group] = ACTIONS(365),
    [sym_keyword_and] = ACTIONS(365),
    [sym_keyword_or] = ACTIONS(365),
    [sym_keyword_is] = ACTIONS(365),
    [sym_keyword_not] = ACTIONS(367),
    [sym_keyword_contains] = ACTIONS(367),
    [sym_keyword_contains_not] = ACTIONS(365),
    [sym_keyword_contains_all] = ACTIONS(365),
    [sym_keyword_contains_any] = ACTIONS(365),
    [sym_keyword_contains_none] = ACTIONS(365),
    [sym_keyword_inside] = ACTIONS(365),
    [sym_keyword_in] = ACTIONS(367),
    [sym_keyword_not_inside] = ACTIONS(365),
    [sym_keyword_all_inside] = ACTIONS(365),
    [sym_keyword_any_inside] = ACTIONS(365),
    [sym_keyword_none_inside] = ACTIONS(365),
    [sym_keyword_outside] = ACTIONS(365),
    [sym_keyword_intersects] = ACTIONS(365),
    [sym_keyword_drop] = ACTIONS(365),
    [sym_keyword_schemafull] = ACTIONS(365),
    [sym_keyword_schemaless] = ACTIONS(365),
    [sym_keyword_changefeed] = ACTIONS(365),
    [sym_keyword_content] = ACTIONS(365),
    [sym_keyword_merge] = ACTIONS(365),
    [sym_keyword_patch] = ACTIONS(365),
    [sym_keyword_replace] = ACTIONS(365),
    [sym_keyword_then] = ACTIONS(365),
    [sym_keyword_permissions] = ACTIONS(365),
    [sym_keyword_for] = ACTIONS(365),
    [sym_keyword_comment] = ACTIONS(365),
    [sym_keyword_unset] = ACTIONS(365),
    [sym_keyword_set] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(367),
    [anon_sym_COMMA] = ACTIONS(365),
    [anon_sym_LPAREN] = ACTIONS(365),
    [anon_sym_RPAREN] = ACTIONS(365),
    [anon_sym_DASH_GT] = ACTIONS(365),
    [anon_sym_LBRACK] = ACTIONS(365),
    [anon_sym_RBRACK] = ACTIONS(365),
    [anon_sym_QMARK] = ACTIONS(367),
    [anon_sym_LBRACE] = ACTIONS(365),
    [anon_sym_RBRACE] = ACTIONS(365),
    [anon_sym_LT] = ACTIONS(367),
    [anon_sym_GT] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(367),
    [anon_sym_LT_DASH_GT] = ACTIONS(365),
    [anon_sym_STAR] = ACTIONS(367),
    [anon_sym_DOT] = ACTIONS(365),
    [anon_sym_DASH] = ACTIONS(367),
    [anon_sym_PERCENT] = ACTIONS(365),
    [anon_sym_AT] = ACTIONS(367),
    [anon_sym_LT_PIPE] = ACTIONS(365),
    [anon_sym_AMP_AMP] = ACTIONS(365),
    [anon_sym_PIPE_PIPE] = ACTIONS(365),
    [anon_sym_QMARK_QMARK] = ACTIONS(365),
    [anon_sym_QMARK_COLON] = ACTIONS(365),
    [anon_sym_BANG_EQ] = ACTIONS(365),
    [anon_sym_EQ_EQ] = ACTIONS(365),
    [anon_sym_QMARK_EQ] = ACTIONS(365),
    [anon_sym_STAR_EQ] = ACTIONS(365),
    [anon_sym_TILDE] = ACTIONS(365),
    [anon_sym_BANG_TILDE] = ACTIONS(365),
    [anon_sym_STAR_TILDE] = ACTIONS(365),
    [anon_sym_LT_EQ] = ACTIONS(365),
    [anon_sym_GT_EQ] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(367),
    [anon_sym_PLUS_EQ] = ACTIONS(365),
    [anon_sym_DASH_EQ] = ACTIONS(365),
    [anon_sym_u00d7] = ACTIONS(365),
    [anon_sym_SLASH] = ACTIONS(367),
    [anon_sym_u00f7] = ACTIONS(365),
    [anon_sym_STAR_STAR] = ACTIONS(365),
    [anon_sym_u220b] = ACTIONS(365),
    [anon_sym_u220c] = ACTIONS(365),
    [anon_sym_u2287] = ACTIONS(365),
    [anon_sym_u2283] = ACTIONS(365),
    [anon_sym_u2285] = ACTIONS(365),
    [anon_sym_u2208] = ACTIONS(365),
    [anon_sym_u2209] = ACTIONS(365),
    [anon_sym_u2286] = ACTIONS(365),
    [anon_sym_u2282] = ACTIONS(365),
    [anon_sym_u2284] = ACTIONS(365),
    [anon_sym_AT_AT] = ACTIONS(365),
  },
  [STATE(98)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(369),
    [sym_keyword_on] = ACTIONS(369),
    [sym_keyword_return] = ACTIONS(369),
    [sym_keyword_from] = ACTIONS(369),
    [sym_keyword_as] = ACTIONS(369),
    [sym_keyword_omit] = ACTIONS(369),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(371),
    [sym_keyword_contains] = ACTIONS(371),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(371),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_drop] = ACTIONS(369),
    [sym_keyword_schemafull] = ACTIONS(369),
    [sym_keyword_schemaless] = ACTIONS(369),
    [sym_keyword_changefeed] = ACTIONS(369),
    [sym_keyword_content] = ACTIONS(369),
    [sym_keyword_merge] = ACTIONS(369),
    [sym_keyword_patch] = ACTIONS(369),
    [sym_keyword_replace] = ACTIONS(369),
    [sym_keyword_then] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [sym_keyword_unset] = ACTIONS(369),
    [sym_keyword_set] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_LPAREN] = ACTIONS(369),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(369),
    [anon_sym_RBRACK] = ACTIONS(369),
    [anon_sym_QMARK] = ACTIONS(371),
    [anon_sym_LBRACE] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(371),
    [anon_sym_LT_DASH_GT] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(371),
    [anon_sym_DOT] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(371),
    [anon_sym_LT_PIPE] = ACTIONS(369),
    [anon_sym_AMP_AMP] = ACTIONS(369),
    [anon_sym_PIPE_PIPE] = ACTIONS(369),
    [anon_sym_QMARK_QMARK] = ACTIONS(369),
    [anon_sym_QMARK_COLON] = ACTIONS(369),
    [anon_sym_BANG_EQ] = ACTIONS(369),
    [anon_sym_EQ_EQ] = ACTIONS(369),
    [anon_sym_QMARK_EQ] = ACTIONS(369),
    [anon_sym_STAR_EQ] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_BANG_TILDE] = ACTIONS(369),
    [anon_sym_STAR_TILDE] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(371),
    [anon_sym_PLUS_EQ] = ACTIONS(369),
    [anon_sym_DASH_EQ] = ACTIONS(369),
    [anon_sym_u00d7] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_u00f7] = ACTIONS(369),
    [anon_sym_STAR_STAR] = ACTIONS(369),
    [anon_sym_u220b] = ACTIONS(369),
    [anon_sym_u220c] = ACTIONS(369),
    [anon_sym_u2287] = ACTIONS(369),
    [anon_sym_u2283] = ACTIONS(369),
    [anon_sym_u2285] = ACTIONS(369),
    [anon_sym_u2208] = ACTIONS(369),
    [anon_sym_u2209] = ACTIONS(369),
    [anon_sym_u2286] = ACTIONS(369),
    [anon_sym_u2282] = ACTIONS(369),
    [anon_sym_u2284] = ACTIONS(369),
    [anon_sym_AT_AT] = ACTIONS(369),
  },
  [STATE(99)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_on] = ACTIONS(186),
    [sym_keyword_return] = ACTIONS(186),
    [sym_keyword_from] = ACTIONS(186),
    [sym_keyword_as] = ACTIONS(186),
    [sym_keyword_omit] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_drop] = ACTIONS(186),
    [sym_keyword_schemafull] = ACTIONS(186),
    [sym_keyword_schemaless] = ACTIONS(186),
    [sym_keyword_changefeed] = ACTIONS(186),
    [sym_keyword_content] = ACTIONS(186),
    [sym_keyword_merge] = ACTIONS(186),
    [sym_keyword_patch] = ACTIONS(186),
    [sym_keyword_replace] = ACTIONS(186),
    [sym_keyword_then] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [sym_keyword_unset] = ACTIONS(186),
    [sym_keyword_set] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_LPAREN] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACK] = ACTIONS(186),
    [anon_sym_QMARK] = ACTIONS(188),
    [anon_sym_LBRACE] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(100)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_on] = ACTIONS(264),
    [sym_keyword_return] = ACTIONS(264),
    [sym_keyword_from] = ACTIONS(264),
    [sym_keyword_as] = ACTIONS(264),
    [sym_keyword_omit] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(264),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [sym_keyword_drop] = ACTIONS(264),
    [sym_keyword_schemafull] = ACTIONS(264),
    [sym_keyword_schemaless] = ACTIONS(264),
    [sym_keyword_changefeed] = ACTIONS(264),
    [sym_keyword_content] = ACTIONS(264),
    [sym_keyword_merge] = ACTIONS(264),
    [sym_keyword_patch] = ACTIONS(264),
    [sym_keyword_replace] = ACTIONS(264),
    [sym_keyword_then] = ACTIONS(264),
    [sym_keyword_permissions] = ACTIONS(264),
    [sym_keyword_for] = ACTIONS(264),
    [sym_keyword_comment] = ACTIONS(264),
    [sym_keyword_unset] = ACTIONS(264),
    [sym_keyword_set] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(266),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_LPAREN] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACK] = ACTIONS(264),
    [anon_sym_QMARK] = ACTIONS(266),
    [anon_sym_LBRACE] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(101)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_on] = ACTIONS(264),
    [sym_keyword_return] = ACTIONS(264),
    [sym_keyword_from] = ACTIONS(264),
    [sym_keyword_as] = ACTIONS(264),
    [sym_keyword_omit] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(264),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [sym_keyword_drop] = ACTIONS(264),
    [sym_keyword_schemafull] = ACTIONS(264),
    [sym_keyword_schemaless] = ACTIONS(264),
    [sym_keyword_changefeed] = ACTIONS(264),
    [sym_keyword_content] = ACTIONS(264),
    [sym_keyword_merge] = ACTIONS(264),
    [sym_keyword_patch] = ACTIONS(264),
    [sym_keyword_replace] = ACTIONS(264),
    [sym_keyword_then] = ACTIONS(264),
    [sym_keyword_permissions] = ACTIONS(264),
    [sym_keyword_for] = ACTIONS(264),
    [sym_keyword_comment] = ACTIONS(264),
    [sym_keyword_unset] = ACTIONS(264),
    [sym_keyword_set] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(373),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_LPAREN] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACK] = ACTIONS(264),
    [anon_sym_QMARK] = ACTIONS(266),
    [anon_sym_LBRACE] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(102)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(337),
    [sym_keyword_on] = ACTIONS(337),
    [sym_keyword_return] = ACTIONS(337),
    [sym_keyword_from] = ACTIONS(337),
    [sym_keyword_as] = ACTIONS(337),
    [sym_keyword_omit] = ACTIONS(337),
    [sym_keyword_explain] = ACTIONS(337),
    [sym_keyword_parallel] = ACTIONS(337),
    [sym_keyword_timeout] = ACTIONS(337),
    [sym_keyword_fetch] = ACTIONS(337),
    [sym_keyword_limit] = ACTIONS(337),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_group] = ACTIONS(337),
    [sym_keyword_and] = ACTIONS(337),
    [sym_keyword_or] = ACTIONS(337),
    [sym_keyword_is] = ACTIONS(337),
    [sym_keyword_not] = ACTIONS(339),
    [sym_keyword_contains] = ACTIONS(339),
    [sym_keyword_contains_not] = ACTIONS(337),
    [sym_keyword_contains_all] = ACTIONS(337),
    [sym_keyword_contains_any] = ACTIONS(337),
    [sym_keyword_contains_none] = ACTIONS(337),
    [sym_keyword_inside] = ACTIONS(337),
    [sym_keyword_in] = ACTIONS(339),
    [sym_keyword_not_inside] = ACTIONS(337),
    [sym_keyword_all_inside] = ACTIONS(337),
    [sym_keyword_any_inside] = ACTIONS(337),
    [sym_keyword_none_inside] = ACTIONS(337),
    [sym_keyword_outside] = ACTIONS(337),
    [sym_keyword_intersects] = ACTIONS(337),
    [sym_keyword_drop] = ACTIONS(337),
    [sym_keyword_schemafull] = ACTIONS(337),
    [sym_keyword_schemaless] = ACTIONS(337),
    [sym_keyword_changefeed] = ACTIONS(337),
    [sym_keyword_content] = ACTIONS(337),
    [sym_keyword_merge] = ACTIONS(337),
    [sym_keyword_patch] = ACTIONS(337),
    [sym_keyword_replace] = ACTIONS(337),
    [sym_keyword_then] = ACTIONS(337),
    [sym_keyword_permissions] = ACTIONS(337),
    [sym_keyword_for] = ACTIONS(337),
    [sym_keyword_comment] = ACTIONS(337),
    [sym_keyword_unset] = ACTIONS(337),
    [sym_keyword_set] = ACTIONS(337),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_COMMA] = ACTIONS(337),
    [anon_sym_LPAREN] = ACTIONS(337),
    [anon_sym_RPAREN] = ACTIONS(337),
    [anon_sym_DASH_GT] = ACTIONS(337),
    [anon_sym_LBRACK] = ACTIONS(337),
    [anon_sym_RBRACK] = ACTIONS(337),
    [anon_sym_QMARK] = ACTIONS(339),
    [anon_sym_LBRACE] = ACTIONS(337),
    [anon_sym_RBRACE] = ACTIONS(337),
    [anon_sym_LT] = ACTIONS(339),
    [anon_sym_GT] = ACTIONS(339),
    [anon_sym_LT_DASH] = ACTIONS(339),
    [anon_sym_LT_DASH_GT] = ACTIONS(337),
    [anon_sym_STAR] = ACTIONS(339),
    [anon_sym_DOT] = ACTIONS(337),
    [anon_sym_DASH] = ACTIONS(339),
    [anon_sym_PERCENT] = ACTIONS(337),
    [anon_sym_AT] = ACTIONS(339),
    [anon_sym_LT_PIPE] = ACTIONS(337),
    [anon_sym_AMP_AMP] = ACTIONS(337),
    [anon_sym_PIPE_PIPE] = ACTIONS(337),
    [anon_sym_QMARK_QMARK] = ACTIONS(337),
    [anon_sym_QMARK_COLON] = ACTIONS(337),
    [anon_sym_BANG_EQ] = ACTIONS(337),
    [anon_sym_EQ_EQ] = ACTIONS(337),
    [anon_sym_QMARK_EQ] = ACTIONS(337),
    [anon_sym_STAR_EQ] = ACTIONS(337),
    [anon_sym_TILDE] = ACTIONS(337),
    [anon_sym_BANG_TILDE] = ACTIONS(337),
    [anon_sym_STAR_TILDE] = ACTIONS(337),
    [anon_sym_LT_EQ] = ACTIONS(337),
    [anon_sym_GT_EQ] = ACTIONS(337),
    [anon_sym_PLUS] = ACTIONS(339),
    [anon_sym_PLUS_EQ] = ACTIONS(337),
    [anon_sym_DASH_EQ] = ACTIONS(337),
    [anon_sym_u00d7] = ACTIONS(337),
    [anon_sym_SLASH] = ACTIONS(339),
    [anon_sym_u00f7] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(337),
    [anon_sym_u220b] = ACTIONS(337),
    [anon_sym_u220c] = ACTIONS(337),
    [anon_sym_u2287] = ACTIONS(337),
    [anon_sym_u2283] = ACTIONS(337),
    [anon_sym_u2285] = ACTIONS(337),
    [anon_sym_u2208] = ACTIONS(337),
    [anon_sym_u2209] = ACTIONS(337),
    [anon_sym_u2286] = ACTIONS(337),
    [anon_sym_u2282] = ACTIONS(337),
    [anon_sym_u2284] = ACTIONS(337),
    [anon_sym_AT_AT] = ACTIONS(337),
  },
  [STATE(103)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(270),
    [sym_keyword_on] = ACTIONS(270),
    [sym_keyword_return] = ACTIONS(270),
    [sym_keyword_from] = ACTIONS(270),
    [sym_keyword_as] = ACTIONS(270),
    [sym_keyword_omit] = ACTIONS(270),
    [sym_keyword_explain] = ACTIONS(270),
    [sym_keyword_parallel] = ACTIONS(270),
    [sym_keyword_timeout] = ACTIONS(270),
    [sym_keyword_fetch] = ACTIONS(270),
    [sym_keyword_limit] = ACTIONS(270),
    [sym_keyword_where] = ACTIONS(270),
    [sym_keyword_group] = ACTIONS(270),
    [sym_keyword_and] = ACTIONS(270),
    [sym_keyword_or] = ACTIONS(270),
    [sym_keyword_is] = ACTIONS(270),
    [sym_keyword_not] = ACTIONS(272),
    [sym_keyword_contains] = ACTIONS(272),
    [sym_keyword_contains_not] = ACTIONS(270),
    [sym_keyword_contains_all] = ACTIONS(270),
    [sym_keyword_contains_any] = ACTIONS(270),
    [sym_keyword_contains_none] = ACTIONS(270),
    [sym_keyword_inside] = ACTIONS(270),
    [sym_keyword_in] = ACTIONS(272),
    [sym_keyword_not_inside] = ACTIONS(270),
    [sym_keyword_all_inside] = ACTIONS(270),
    [sym_keyword_any_inside] = ACTIONS(270),
    [sym_keyword_none_inside] = ACTIONS(270),
    [sym_keyword_outside] = ACTIONS(270),
    [sym_keyword_intersects] = ACTIONS(270),
    [sym_keyword_drop] = ACTIONS(270),
    [sym_keyword_schemafull] = ACTIONS(270),
    [sym_keyword_schemaless] = ACTIONS(270),
    [sym_keyword_changefeed] = ACTIONS(270),
    [sym_keyword_content] = ACTIONS(270),
    [sym_keyword_merge] = ACTIONS(270),
    [sym_keyword_patch] = ACTIONS(270),
    [sym_keyword_replace] = ACTIONS(270),
    [sym_keyword_then] = ACTIONS(270),
    [sym_keyword_permissions] = ACTIONS(270),
    [sym_keyword_for] = ACTIONS(270),
    [sym_keyword_comment] = ACTIONS(270),
    [sym_keyword_unset] = ACTIONS(270),
    [sym_keyword_set] = ACTIONS(270),
    [anon_sym_EQ] = ACTIONS(272),
    [anon_sym_COMMA] = ACTIONS(270),
    [anon_sym_LPAREN] = ACTIONS(270),
    [anon_sym_RPAREN] = ACTIONS(270),
    [anon_sym_DASH_GT] = ACTIONS(270),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_RBRACK] = ACTIONS(270),
    [anon_sym_QMARK] = ACTIONS(272),
    [anon_sym_LBRACE] = ACTIONS(270),
    [anon_sym_RBRACE] = ACTIONS(270),
    [anon_sym_LT] = ACTIONS(272),
    [anon_sym_GT] = ACTIONS(272),
    [anon_sym_LT_DASH] = ACTIONS(272),
    [anon_sym_LT_DASH_GT] = ACTIONS(270),
    [anon_sym_STAR] = ACTIONS(272),
    [anon_sym_DOT] = ACTIONS(270),
    [anon_sym_DASH] = ACTIONS(272),
    [anon_sym_PERCENT] = ACTIONS(270),
    [anon_sym_AT] = ACTIONS(272),
    [anon_sym_LT_PIPE] = ACTIONS(270),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_PIPE_PIPE] = ACTIONS(270),
    [anon_sym_QMARK_QMARK] = ACTIONS(270),
    [anon_sym_QMARK_COLON] = ACTIONS(270),
    [anon_sym_BANG_EQ] = ACTIONS(270),
    [anon_sym_EQ_EQ] = ACTIONS(270),
    [anon_sym_QMARK_EQ] = ACTIONS(270),
    [anon_sym_STAR_EQ] = ACTIONS(270),
    [anon_sym_TILDE] = ACTIONS(270),
    [anon_sym_BANG_TILDE] = ACTIONS(270),
    [anon_sym_STAR_TILDE] = ACTIONS(270),
    [anon_sym_LT_EQ] = ACTIONS(270),
    [anon_sym_GT_EQ] = ACTIONS(270),
    [anon_sym_PLUS] = ACTIONS(272),
    [anon_sym_PLUS_EQ] = ACTIONS(270),
    [anon_sym_DASH_EQ] = ACTIONS(270),
    [anon_sym_u00d7] = ACTIONS(270),
    [anon_sym_SLASH] = ACTIONS(272),
    [anon_sym_u00f7] = ACTIONS(270),
    [anon_sym_STAR_STAR] = ACTIONS(270),
    [anon_sym_u220b] = ACTIONS(270),
    [anon_sym_u220c] = ACTIONS(270),
    [anon_sym_u2287] = ACTIONS(270),
    [anon_sym_u2283] = ACTIONS(270),
    [anon_sym_u2285] = ACTIONS(270),
    [anon_sym_u2208] = ACTIONS(270),
    [anon_sym_u2209] = ACTIONS(270),
    [anon_sym_u2286] = ACTIONS(270),
    [anon_sym_u2282] = ACTIONS(270),
    [anon_sym_u2284] = ACTIONS(270),
    [anon_sym_AT_AT] = ACTIONS(270),
  },
  [STATE(104)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(274),
    [sym_keyword_on] = ACTIONS(274),
    [sym_keyword_return] = ACTIONS(274),
    [sym_keyword_from] = ACTIONS(274),
    [sym_keyword_as] = ACTIONS(274),
    [sym_keyword_omit] = ACTIONS(274),
    [sym_keyword_explain] = ACTIONS(274),
    [sym_keyword_parallel] = ACTIONS(274),
    [sym_keyword_timeout] = ACTIONS(274),
    [sym_keyword_fetch] = ACTIONS(274),
    [sym_keyword_limit] = ACTIONS(274),
    [sym_keyword_where] = ACTIONS(274),
    [sym_keyword_group] = ACTIONS(274),
    [sym_keyword_and] = ACTIONS(274),
    [sym_keyword_or] = ACTIONS(274),
    [sym_keyword_is] = ACTIONS(274),
    [sym_keyword_not] = ACTIONS(276),
    [sym_keyword_contains] = ACTIONS(276),
    [sym_keyword_contains_not] = ACTIONS(274),
    [sym_keyword_contains_all] = ACTIONS(274),
    [sym_keyword_contains_any] = ACTIONS(274),
    [sym_keyword_contains_none] = ACTIONS(274),
    [sym_keyword_inside] = ACTIONS(274),
    [sym_keyword_in] = ACTIONS(276),
    [sym_keyword_not_inside] = ACTIONS(274),
    [sym_keyword_all_inside] = ACTIONS(274),
    [sym_keyword_any_inside] = ACTIONS(274),
    [sym_keyword_none_inside] = ACTIONS(274),
    [sym_keyword_outside] = ACTIONS(274),
    [sym_keyword_intersects] = ACTIONS(274),
    [sym_keyword_drop] = ACTIONS(274),
    [sym_keyword_schemafull] = ACTIONS(274),
    [sym_keyword_schemaless] = ACTIONS(274),
    [sym_keyword_changefeed] = ACTIONS(274),
    [sym_keyword_content] = ACTIONS(274),
    [sym_keyword_merge] = ACTIONS(274),
    [sym_keyword_patch] = ACTIONS(274),
    [sym_keyword_replace] = ACTIONS(274),
    [sym_keyword_then] = ACTIONS(274),
    [sym_keyword_permissions] = ACTIONS(274),
    [sym_keyword_for] = ACTIONS(274),
    [sym_keyword_comment] = ACTIONS(274),
    [sym_keyword_unset] = ACTIONS(274),
    [sym_keyword_set] = ACTIONS(274),
    [anon_sym_EQ] = ACTIONS(276),
    [anon_sym_COMMA] = ACTIONS(274),
    [anon_sym_LPAREN] = ACTIONS(274),
    [anon_sym_RPAREN] = ACTIONS(274),
    [anon_sym_DASH_GT] = ACTIONS(274),
    [anon_sym_LBRACK] = ACTIONS(274),
    [anon_sym_RBRACK] = ACTIONS(274),
    [anon_sym_QMARK] = ACTIONS(276),
    [anon_sym_LBRACE] = ACTIONS(274),
    [anon_sym_RBRACE] = ACTIONS(274),
    [anon_sym_LT] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(276),
    [anon_sym_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_DASH_GT] = ACTIONS(274),
    [anon_sym_STAR] = ACTIONS(276),
    [anon_sym_DOT] = ACTIONS(274),
    [anon_sym_DASH] = ACTIONS(276),
    [anon_sym_PERCENT] = ACTIONS(274),
    [anon_sym_AT] = ACTIONS(276),
    [anon_sym_LT_PIPE] = ACTIONS(274),
    [anon_sym_AMP_AMP] = ACTIONS(274),
    [anon_sym_PIPE_PIPE] = ACTIONS(274),
    [anon_sym_QMARK_QMARK] = ACTIONS(274),
    [anon_sym_QMARK_COLON] = ACTIONS(274),
    [anon_sym_BANG_EQ] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(274),
    [anon_sym_QMARK_EQ] = ACTIONS(274),
    [anon_sym_STAR_EQ] = ACTIONS(274),
    [anon_sym_TILDE] = ACTIONS(274),
    [anon_sym_BANG_TILDE] = ACTIONS(274),
    [anon_sym_STAR_TILDE] = ACTIONS(274),
    [anon_sym_LT_EQ] = ACTIONS(274),
    [anon_sym_GT_EQ] = ACTIONS(274),
    [anon_sym_PLUS] = ACTIONS(276),
    [anon_sym_PLUS_EQ] = ACTIONS(274),
    [anon_sym_DASH_EQ] = ACTIONS(274),
    [anon_sym_u00d7] = ACTIONS(274),
    [anon_sym_SLASH] = ACTIONS(276),
    [anon_sym_u00f7] = ACTIONS(274),
    [anon_sym_STAR_STAR] = ACTIONS(274),
    [anon_sym_u220b] = ACTIONS(274),
    [anon_sym_u220c] = ACTIONS(274),
    [anon_sym_u2287] = ACTIONS(274),
    [anon_sym_u2283] = ACTIONS(274),
    [anon_sym_u2285] = ACTIONS(274),
    [anon_sym_u2208] = ACTIONS(274),
    [anon_sym_u2209] = ACTIONS(274),
    [anon_sym_u2286] = ACTIONS(274),
    [anon_sym_u2282] = ACTIONS(274),
    [anon_sym_u2284] = ACTIONS(274),
    [anon_sym_AT_AT] = ACTIONS(274),
  },
  [STATE(105)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(351),
    [sym_keyword_on] = ACTIONS(351),
    [sym_keyword_return] = ACTIONS(351),
    [sym_keyword_from] = ACTIONS(351),
    [sym_keyword_as] = ACTIONS(351),
    [sym_keyword_omit] = ACTIONS(351),
    [sym_keyword_explain] = ACTIONS(351),
    [sym_keyword_parallel] = ACTIONS(351),
    [sym_keyword_timeout] = ACTIONS(351),
    [sym_keyword_fetch] = ACTIONS(351),
    [sym_keyword_limit] = ACTIONS(351),
    [sym_keyword_where] = ACTIONS(351),
    [sym_keyword_group] = ACTIONS(351),
    [sym_keyword_and] = ACTIONS(351),
    [sym_keyword_or] = ACTIONS(351),
    [sym_keyword_is] = ACTIONS(351),
    [sym_keyword_not] = ACTIONS(353),
    [sym_keyword_contains] = ACTIONS(353),
    [sym_keyword_contains_not] = ACTIONS(351),
    [sym_keyword_contains_all] = ACTIONS(351),
    [sym_keyword_contains_any] = ACTIONS(351),
    [sym_keyword_contains_none] = ACTIONS(351),
    [sym_keyword_inside] = ACTIONS(351),
    [sym_keyword_in] = ACTIONS(353),
    [sym_keyword_not_inside] = ACTIONS(351),
    [sym_keyword_all_inside] = ACTIONS(351),
    [sym_keyword_any_inside] = ACTIONS(351),
    [sym_keyword_none_inside] = ACTIONS(351),
    [sym_keyword_outside] = ACTIONS(351),
    [sym_keyword_intersects] = ACTIONS(351),
    [sym_keyword_drop] = ACTIONS(351),
    [sym_keyword_schemafull] = ACTIONS(351),
    [sym_keyword_schemaless] = ACTIONS(351),
    [sym_keyword_changefeed] = ACTIONS(351),
    [sym_keyword_content] = ACTIONS(351),
    [sym_keyword_merge] = ACTIONS(351),
    [sym_keyword_patch] = ACTIONS(351),
    [sym_keyword_replace] = ACTIONS(351),
    [sym_keyword_then] = ACTIONS(351),
    [sym_keyword_permissions] = ACTIONS(351),
    [sym_keyword_for] = ACTIONS(351),
    [sym_keyword_comment] = ACTIONS(351),
    [sym_keyword_unset] = ACTIONS(351),
    [sym_keyword_set] = ACTIONS(351),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_COMMA] = ACTIONS(351),
    [anon_sym_LPAREN] = ACTIONS(351),
    [anon_sym_RPAREN] = ACTIONS(351),
    [anon_sym_DASH_GT] = ACTIONS(351),
    [anon_sym_LBRACK] = ACTIONS(351),
    [anon_sym_RBRACK] = ACTIONS(351),
    [anon_sym_QMARK] = ACTIONS(353),
    [anon_sym_LBRACE] = ACTIONS(351),
    [anon_sym_RBRACE] = ACTIONS(351),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH_GT] = ACTIONS(351),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [anon_sym_LT_PIPE] = ACTIONS(351),
    [anon_sym_AMP_AMP] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(351),
    [anon_sym_QMARK_QMARK] = ACTIONS(351),
    [anon_sym_QMARK_COLON] = ACTIONS(351),
    [anon_sym_BANG_EQ] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(351),
    [anon_sym_QMARK_EQ] = ACTIONS(351),
    [anon_sym_STAR_EQ] = ACTIONS(351),
    [anon_sym_TILDE] = ACTIONS(351),
    [anon_sym_BANG_TILDE] = ACTIONS(351),
    [anon_sym_STAR_TILDE] = ACTIONS(351),
    [anon_sym_LT_EQ] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(353),
    [anon_sym_PLUS_EQ] = ACTIONS(351),
    [anon_sym_DASH_EQ] = ACTIONS(351),
    [anon_sym_u00d7] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(353),
    [anon_sym_u00f7] = ACTIONS(351),
    [anon_sym_STAR_STAR] = ACTIONS(351),
    [anon_sym_u220b] = ACTIONS(351),
    [anon_sym_u220c] = ACTIONS(351),
    [anon_sym_u2287] = ACTIONS(351),
    [anon_sym_u2283] = ACTIONS(351),
    [anon_sym_u2285] = ACTIONS(351),
    [anon_sym_u2208] = ACTIONS(351),
    [anon_sym_u2209] = ACTIONS(351),
    [anon_sym_u2286] = ACTIONS(351),
    [anon_sym_u2282] = ACTIONS(351),
    [anon_sym_u2284] = ACTIONS(351),
    [anon_sym_AT_AT] = ACTIONS(351),
  },
  [STATE(106)] = {
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_return] = ACTIONS(204),
    [sym_keyword_value] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_rand] = ACTIONS(204),
    [sym_keyword_collate] = ACTIONS(204),
    [sym_keyword_numeric] = ACTIONS(204),
    [sym_keyword_asc] = ACTIONS(204),
    [sym_keyword_desc] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_drop] = ACTIONS(204),
    [sym_keyword_schemafull] = ACTIONS(204),
    [sym_keyword_schemaless] = ACTIONS(204),
    [sym_keyword_flexible] = ACTIONS(204),
    [sym_keyword_readonly] = ACTIONS(204),
    [sym_keyword_changefeed] = ACTIONS(204),
    [sym_keyword_content] = ACTIONS(204),
    [sym_keyword_merge] = ACTIONS(204),
    [sym_keyword_patch] = ACTIONS(204),
    [sym_keyword_replace] = ACTIONS(204),
    [sym_keyword_type] = ACTIONS(204),
    [sym_keyword_default] = ACTIONS(204),
    [sym_keyword_assert] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [sym_keyword_unset] = ACTIONS(204),
    [sym_keyword_set] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(107)] = {
    [ts_builtin_sym_end] = ACTIONS(375),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_return] = ACTIONS(375),
    [sym_keyword_value] = ACTIONS(375),
    [sym_keyword_explain] = ACTIONS(375),
    [sym_keyword_parallel] = ACTIONS(375),
    [sym_keyword_timeout] = ACTIONS(375),
    [sym_keyword_fetch] = ACTIONS(375),
    [sym_keyword_limit] = ACTIONS(375),
    [sym_keyword_rand] = ACTIONS(375),
    [sym_keyword_collate] = ACTIONS(375),
    [sym_keyword_numeric] = ACTIONS(375),
    [sym_keyword_asc] = ACTIONS(375),
    [sym_keyword_desc] = ACTIONS(375),
    [sym_keyword_where] = ACTIONS(375),
    [sym_keyword_group] = ACTIONS(375),
    [sym_keyword_and] = ACTIONS(375),
    [sym_keyword_or] = ACTIONS(375),
    [sym_keyword_is] = ACTIONS(375),
    [sym_keyword_not] = ACTIONS(377),
    [sym_keyword_contains] = ACTIONS(377),
    [sym_keyword_contains_not] = ACTIONS(375),
    [sym_keyword_contains_all] = ACTIONS(375),
    [sym_keyword_contains_any] = ACTIONS(375),
    [sym_keyword_contains_none] = ACTIONS(375),
    [sym_keyword_inside] = ACTIONS(375),
    [sym_keyword_in] = ACTIONS(377),
    [sym_keyword_not_inside] = ACTIONS(375),
    [sym_keyword_all_inside] = ACTIONS(375),
    [sym_keyword_any_inside] = ACTIONS(375),
    [sym_keyword_none_inside] = ACTIONS(375),
    [sym_keyword_outside] = ACTIONS(375),
    [sym_keyword_intersects] = ACTIONS(375),
    [sym_keyword_drop] = ACTIONS(375),
    [sym_keyword_schemafull] = ACTIONS(375),
    [sym_keyword_schemaless] = ACTIONS(375),
    [sym_keyword_flexible] = ACTIONS(375),
    [sym_keyword_readonly] = ACTIONS(375),
    [sym_keyword_changefeed] = ACTIONS(375),
    [sym_keyword_content] = ACTIONS(375),
    [sym_keyword_merge] = ACTIONS(375),
    [sym_keyword_patch] = ACTIONS(375),
    [sym_keyword_replace] = ACTIONS(375),
    [sym_keyword_type] = ACTIONS(375),
    [sym_keyword_default] = ACTIONS(375),
    [sym_keyword_assert] = ACTIONS(375),
    [sym_keyword_permissions] = ACTIONS(375),
    [sym_keyword_for] = ACTIONS(375),
    [sym_keyword_comment] = ACTIONS(375),
    [sym_keyword_unset] = ACTIONS(375),
    [sym_keyword_set] = ACTIONS(375),
    [anon_sym_EQ] = ACTIONS(377),
    [anon_sym_COMMA] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PERCENT] = ACTIONS(375),
    [anon_sym_AT] = ACTIONS(377),
    [anon_sym_LT_PIPE] = ACTIONS(375),
    [anon_sym_AMP_AMP] = ACTIONS(375),
    [anon_sym_PIPE_PIPE] = ACTIONS(375),
    [anon_sym_QMARK_QMARK] = ACTIONS(375),
    [anon_sym_QMARK_COLON] = ACTIONS(375),
    [anon_sym_BANG_EQ] = ACTIONS(375),
    [anon_sym_EQ_EQ] = ACTIONS(375),
    [anon_sym_QMARK_EQ] = ACTIONS(375),
    [anon_sym_STAR_EQ] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(375),
    [anon_sym_BANG_TILDE] = ACTIONS(375),
    [anon_sym_STAR_TILDE] = ACTIONS(375),
    [anon_sym_LT_EQ] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(375),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_PLUS_EQ] = ACTIONS(375),
    [anon_sym_DASH_EQ] = ACTIONS(375),
    [anon_sym_u00d7] = ACTIONS(375),
    [anon_sym_SLASH] = ACTIONS(377),
    [anon_sym_u00f7] = ACTIONS(375),
    [anon_sym_STAR_STAR] = ACTIONS(375),
    [anon_sym_u220b] = ACTIONS(375),
    [anon_sym_u220c] = ACTIONS(375),
    [anon_sym_u2287] = ACTIONS(375),
    [anon_sym_u2283] = ACTIONS(375),
    [anon_sym_u2285] = ACTIONS(375),
    [anon_sym_u2208] = ACTIONS(375),
    [anon_sym_u2209] = ACTIONS(375),
    [anon_sym_u2286] = ACTIONS(375),
    [anon_sym_u2282] = ACTIONS(375),
    [anon_sym_u2284] = ACTIONS(375),
    [anon_sym_AT_AT] = ACTIONS(375),
  },
  [STATE(108)] = {
    [ts_builtin_sym_end] = ACTIONS(379),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(379),
    [sym_keyword_return] = ACTIONS(379),
    [sym_keyword_value] = ACTIONS(379),
    [sym_keyword_explain] = ACTIONS(379),
    [sym_keyword_parallel] = ACTIONS(379),
    [sym_keyword_timeout] = ACTIONS(379),
    [sym_keyword_fetch] = ACTIONS(379),
    [sym_keyword_limit] = ACTIONS(379),
    [sym_keyword_rand] = ACTIONS(379),
    [sym_keyword_collate] = ACTIONS(379),
    [sym_keyword_numeric] = ACTIONS(379),
    [sym_keyword_asc] = ACTIONS(379),
    [sym_keyword_desc] = ACTIONS(379),
    [sym_keyword_where] = ACTIONS(379),
    [sym_keyword_group] = ACTIONS(379),
    [sym_keyword_and] = ACTIONS(379),
    [sym_keyword_or] = ACTIONS(379),
    [sym_keyword_is] = ACTIONS(379),
    [sym_keyword_not] = ACTIONS(381),
    [sym_keyword_contains] = ACTIONS(381),
    [sym_keyword_contains_not] = ACTIONS(379),
    [sym_keyword_contains_all] = ACTIONS(379),
    [sym_keyword_contains_any] = ACTIONS(379),
    [sym_keyword_contains_none] = ACTIONS(379),
    [sym_keyword_inside] = ACTIONS(379),
    [sym_keyword_in] = ACTIONS(381),
    [sym_keyword_not_inside] = ACTIONS(379),
    [sym_keyword_all_inside] = ACTIONS(379),
    [sym_keyword_any_inside] = ACTIONS(379),
    [sym_keyword_none_inside] = ACTIONS(379),
    [sym_keyword_outside] = ACTIONS(379),
    [sym_keyword_intersects] = ACTIONS(379),
    [sym_keyword_drop] = ACTIONS(379),
    [sym_keyword_schemafull] = ACTIONS(379),
    [sym_keyword_schemaless] = ACTIONS(379),
    [sym_keyword_flexible] = ACTIONS(379),
    [sym_keyword_readonly] = ACTIONS(379),
    [sym_keyword_changefeed] = ACTIONS(379),
    [sym_keyword_content] = ACTIONS(379),
    [sym_keyword_merge] = ACTIONS(379),
    [sym_keyword_patch] = ACTIONS(379),
    [sym_keyword_replace] = ACTIONS(379),
    [sym_keyword_type] = ACTIONS(379),
    [sym_keyword_default] = ACTIONS(379),
    [sym_keyword_assert] = ACTIONS(379),
    [sym_keyword_permissions] = ACTIONS(379),
    [sym_keyword_for] = ACTIONS(379),
    [sym_keyword_comment] = ACTIONS(379),
    [sym_keyword_unset] = ACTIONS(379),
    [sym_keyword_set] = ACTIONS(379),
    [anon_sym_EQ] = ACTIONS(381),
    [anon_sym_COMMA] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PERCENT] = ACTIONS(379),
    [anon_sym_AT] = ACTIONS(381),
    [anon_sym_LT_PIPE] = ACTIONS(379),
    [anon_sym_AMP_AMP] = ACTIONS(379),
    [anon_sym_PIPE_PIPE] = ACTIONS(379),
    [anon_sym_QMARK_QMARK] = ACTIONS(379),
    [anon_sym_QMARK_COLON] = ACTIONS(379),
    [anon_sym_BANG_EQ] = ACTIONS(379),
    [anon_sym_EQ_EQ] = ACTIONS(379),
    [anon_sym_QMARK_EQ] = ACTIONS(379),
    [anon_sym_STAR_EQ] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(379),
    [anon_sym_BANG_TILDE] = ACTIONS(379),
    [anon_sym_STAR_TILDE] = ACTIONS(379),
    [anon_sym_LT_EQ] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_PLUS_EQ] = ACTIONS(379),
    [anon_sym_DASH_EQ] = ACTIONS(379),
    [anon_sym_u00d7] = ACTIONS(379),
    [anon_sym_SLASH] = ACTIONS(381),
    [anon_sym_u00f7] = ACTIONS(379),
    [anon_sym_STAR_STAR] = ACTIONS(379),
    [anon_sym_u220b] = ACTIONS(379),
    [anon_sym_u220c] = ACTIONS(379),
    [anon_sym_u2287] = ACTIONS(379),
    [anon_sym_u2283] = ACTIONS(379),
    [anon_sym_u2285] = ACTIONS(379),
    [anon_sym_u2208] = ACTIONS(379),
    [anon_sym_u2209] = ACTIONS(379),
    [anon_sym_u2286] = ACTIONS(379),
    [anon_sym_u2282] = ACTIONS(379),
    [anon_sym_u2284] = ACTIONS(379),
    [anon_sym_AT_AT] = ACTIONS(379),
  },
  [STATE(109)] = {
    [ts_builtin_sym_end] = ACTIONS(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_return] = ACTIONS(236),
    [sym_keyword_value] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_rand] = ACTIONS(236),
    [sym_keyword_collate] = ACTIONS(236),
    [sym_keyword_numeric] = ACTIONS(236),
    [sym_keyword_asc] = ACTIONS(236),
    [sym_keyword_desc] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_drop] = ACTIONS(236),
    [sym_keyword_schemafull] = ACTIONS(236),
    [sym_keyword_schemaless] = ACTIONS(236),
    [sym_keyword_flexible] = ACTIONS(236),
    [sym_keyword_readonly] = ACTIONS(236),
    [sym_keyword_changefeed] = ACTIONS(236),
    [sym_keyword_content] = ACTIONS(236),
    [sym_keyword_merge] = ACTIONS(236),
    [sym_keyword_patch] = ACTIONS(236),
    [sym_keyword_replace] = ACTIONS(236),
    [sym_keyword_type] = ACTIONS(236),
    [sym_keyword_default] = ACTIONS(236),
    [sym_keyword_assert] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [sym_keyword_unset] = ACTIONS(236),
    [sym_keyword_set] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(110)] = {
    [sym_subquery_statement] = STATE(2148),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_select_clause] = STATE(2037),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(714),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_show] = ACTIONS(97),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_let] = ACTIONS(101),
    [sym_keyword_return] = ACTIONS(103),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_define] = ACTIONS(109),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(113),
    [sym_keyword_delete] = ACTIONS(115),
    [sym_keyword_update] = ACTIONS(117),
    [sym_keyword_upsert] = ACTIONS(119),
    [sym_keyword_insert] = ACTIONS(121),
    [sym_keyword_relate] = ACTIONS(123),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_alter] = ACTIONS(127),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(111)] = {
    [sym_subquery_statement] = STATE(2148),
    [sym_for_statement] = STATE(2016),
    [sym_return_statement] = STATE(2016),
    [sym_if_statement] = STATE(2016),
    [sym_let_statement] = STATE(2016),
    [sym_alter_statement] = STATE(2016),
    [sym_define_analyzer_statement] = STATE(2016),
    [sym_define_database_statement] = STATE(2016),
    [sym_define_event_statement] = STATE(2016),
    [sym_define_field_statement] = STATE(2016),
    [sym_define_function_statement] = STATE(2016),
    [sym_define_index_statement] = STATE(2016),
    [sym_define_namespace_statement] = STATE(2016),
    [sym_define_param_statement] = STATE(2016),
    [sym_define_scope_statement] = STATE(2016),
    [sym_define_access_statement] = STATE(2016),
    [sym_define_table_statement] = STATE(2016),
    [sym_define_token_statement] = STATE(2016),
    [sym_define_user_statement] = STATE(2016),
    [sym_rebuild_index_statement] = STATE(2016),
    [sym_remove_statement] = STATE(2016),
    [sym_create_statement] = STATE(2016),
    [sym_update_statement] = STATE(2016),
    [sym_upsert_statement] = STATE(2016),
    [sym_relate_statement] = STATE(2016),
    [sym_delete_statement] = STATE(2016),
    [sym_show_statement] = STATE(2016),
    [sym_insert_statement] = STATE(2016),
    [sym_select_statement] = STATE(2016),
    [sym_select_clause] = STATE(2018),
    [sym_return_clause] = STATE(2023),
    [sym_value] = STATE(738),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2809),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_show] = ACTIONS(7),
    [sym_keyword_if] = ACTIONS(9),
    [sym_keyword_let] = ACTIONS(13),
    [sym_keyword_return] = ACTIONS(15),
    [sym_keyword_select] = ACTIONS(17),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_define] = ACTIONS(31),
    [sym_keyword_remove] = ACTIONS(37),
    [sym_keyword_create] = ACTIONS(39),
    [sym_keyword_delete] = ACTIONS(41),
    [sym_keyword_update] = ACTIONS(43),
    [sym_keyword_upsert] = ACTIONS(45),
    [sym_keyword_insert] = ACTIONS(47),
    [sym_keyword_relate] = ACTIONS(49),
    [sym_keyword_for] = ACTIONS(51),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_alter] = ACTIONS(55),
    [sym_keyword_rebuild] = ACTIONS(65),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(75),
    [anon_sym_BANG] = ACTIONS(77),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(112)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(379),
    [sym_keyword_on] = ACTIONS(379),
    [sym_keyword_return] = ACTIONS(379),
    [sym_keyword_from] = ACTIONS(379),
    [sym_keyword_as] = ACTIONS(379),
    [sym_keyword_omit] = ACTIONS(379),
    [sym_keyword_explain] = ACTIONS(379),
    [sym_keyword_parallel] = ACTIONS(379),
    [sym_keyword_timeout] = ACTIONS(379),
    [sym_keyword_fetch] = ACTIONS(379),
    [sym_keyword_limit] = ACTIONS(379),
    [sym_keyword_where] = ACTIONS(379),
    [sym_keyword_group] = ACTIONS(379),
    [sym_keyword_and] = ACTIONS(379),
    [sym_keyword_or] = ACTIONS(379),
    [sym_keyword_is] = ACTIONS(379),
    [sym_keyword_not] = ACTIONS(381),
    [sym_keyword_contains] = ACTIONS(381),
    [sym_keyword_contains_not] = ACTIONS(379),
    [sym_keyword_contains_all] = ACTIONS(379),
    [sym_keyword_contains_any] = ACTIONS(379),
    [sym_keyword_contains_none] = ACTIONS(379),
    [sym_keyword_inside] = ACTIONS(379),
    [sym_keyword_in] = ACTIONS(381),
    [sym_keyword_not_inside] = ACTIONS(379),
    [sym_keyword_all_inside] = ACTIONS(379),
    [sym_keyword_any_inside] = ACTIONS(379),
    [sym_keyword_none_inside] = ACTIONS(379),
    [sym_keyword_outside] = ACTIONS(379),
    [sym_keyword_intersects] = ACTIONS(379),
    [sym_keyword_drop] = ACTIONS(379),
    [sym_keyword_schemafull] = ACTIONS(379),
    [sym_keyword_schemaless] = ACTIONS(379),
    [sym_keyword_changefeed] = ACTIONS(379),
    [sym_keyword_content] = ACTIONS(379),
    [sym_keyword_merge] = ACTIONS(379),
    [sym_keyword_patch] = ACTIONS(379),
    [sym_keyword_replace] = ACTIONS(379),
    [sym_keyword_then] = ACTIONS(379),
    [sym_keyword_permissions] = ACTIONS(379),
    [sym_keyword_for] = ACTIONS(379),
    [sym_keyword_comment] = ACTIONS(379),
    [sym_keyword_unset] = ACTIONS(379),
    [sym_keyword_set] = ACTIONS(379),
    [anon_sym_EQ] = ACTIONS(381),
    [anon_sym_COMMA] = ACTIONS(379),
    [anon_sym_LPAREN] = ACTIONS(379),
    [anon_sym_RPAREN] = ACTIONS(379),
    [anon_sym_RBRACK] = ACTIONS(379),
    [anon_sym_QMARK] = ACTIONS(381),
    [anon_sym_LBRACE] = ACTIONS(379),
    [anon_sym_RBRACE] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PERCENT] = ACTIONS(379),
    [anon_sym_AT] = ACTIONS(381),
    [anon_sym_LT_PIPE] = ACTIONS(379),
    [anon_sym_AMP_AMP] = ACTIONS(379),
    [anon_sym_PIPE_PIPE] = ACTIONS(379),
    [anon_sym_QMARK_QMARK] = ACTIONS(379),
    [anon_sym_QMARK_COLON] = ACTIONS(379),
    [anon_sym_BANG_EQ] = ACTIONS(379),
    [anon_sym_EQ_EQ] = ACTIONS(379),
    [anon_sym_QMARK_EQ] = ACTIONS(379),
    [anon_sym_STAR_EQ] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(379),
    [anon_sym_BANG_TILDE] = ACTIONS(379),
    [anon_sym_STAR_TILDE] = ACTIONS(379),
    [anon_sym_LT_EQ] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_PLUS_EQ] = ACTIONS(379),
    [anon_sym_DASH_EQ] = ACTIONS(379),
    [anon_sym_u00d7] = ACTIONS(379),
    [anon_sym_SLASH] = ACTIONS(381),
    [anon_sym_u00f7] = ACTIONS(379),
    [anon_sym_STAR_STAR] = ACTIONS(379),
    [anon_sym_u220b] = ACTIONS(379),
    [anon_sym_u220c] = ACTIONS(379),
    [anon_sym_u2287] = ACTIONS(379),
    [anon_sym_u2283] = ACTIONS(379),
    [anon_sym_u2285] = ACTIONS(379),
    [anon_sym_u2208] = ACTIONS(379),
    [anon_sym_u2209] = ACTIONS(379),
    [anon_sym_u2286] = ACTIONS(379),
    [anon_sym_u2282] = ACTIONS(379),
    [anon_sym_u2284] = ACTIONS(379),
    [anon_sym_AT_AT] = ACTIONS(379),
  },
  [STATE(113)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(120),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(120),
    [ts_builtin_sym_end] = ACTIONS(212),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(212),
    [sym_keyword_return] = ACTIONS(212),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(214),
    [sym_keyword_contains] = ACTIONS(214),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(214),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_drop] = ACTIONS(212),
    [sym_keyword_schemafull] = ACTIONS(212),
    [sym_keyword_schemaless] = ACTIONS(212),
    [sym_keyword_changefeed] = ACTIONS(212),
    [sym_keyword_content] = ACTIONS(212),
    [sym_keyword_merge] = ACTIONS(212),
    [sym_keyword_patch] = ACTIONS(212),
    [sym_keyword_replace] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [sym_keyword_unset] = ACTIONS(212),
    [sym_keyword_set] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(214),
    [anon_sym_COMMA] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(214),
    [anon_sym_GT] = ACTIONS(214),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(214),
    [anon_sym_DOT] = ACTIONS(385),
    [anon_sym_DASH] = ACTIONS(214),
    [anon_sym_PERCENT] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(214),
    [anon_sym_LT_PIPE] = ACTIONS(212),
    [anon_sym_AMP_AMP] = ACTIONS(212),
    [anon_sym_PIPE_PIPE] = ACTIONS(212),
    [anon_sym_QMARK_QMARK] = ACTIONS(212),
    [anon_sym_QMARK_COLON] = ACTIONS(212),
    [anon_sym_BANG_EQ] = ACTIONS(212),
    [anon_sym_EQ_EQ] = ACTIONS(212),
    [anon_sym_QMARK_EQ] = ACTIONS(212),
    [anon_sym_STAR_EQ] = ACTIONS(212),
    [anon_sym_TILDE] = ACTIONS(212),
    [anon_sym_BANG_TILDE] = ACTIONS(212),
    [anon_sym_STAR_TILDE] = ACTIONS(212),
    [anon_sym_LT_EQ] = ACTIONS(212),
    [anon_sym_GT_EQ] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(214),
    [anon_sym_PLUS_EQ] = ACTIONS(212),
    [anon_sym_DASH_EQ] = ACTIONS(212),
    [anon_sym_u00d7] = ACTIONS(212),
    [anon_sym_SLASH] = ACTIONS(214),
    [anon_sym_u00f7] = ACTIONS(212),
    [anon_sym_STAR_STAR] = ACTIONS(212),
    [anon_sym_u220b] = ACTIONS(212),
    [anon_sym_u220c] = ACTIONS(212),
    [anon_sym_u2287] = ACTIONS(212),
    [anon_sym_u2283] = ACTIONS(212),
    [anon_sym_u2285] = ACTIONS(212),
    [anon_sym_u2208] = ACTIONS(212),
    [anon_sym_u2209] = ACTIONS(212),
    [anon_sym_u2286] = ACTIONS(212),
    [anon_sym_u2282] = ACTIONS(212),
    [anon_sym_u2284] = ACTIONS(212),
    [anon_sym_AT_AT] = ACTIONS(212),
  },
  [STATE(114)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(113),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(113),
    [ts_builtin_sym_end] = ACTIONS(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_return] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_drop] = ACTIONS(236),
    [sym_keyword_schemafull] = ACTIONS(236),
    [sym_keyword_schemaless] = ACTIONS(236),
    [sym_keyword_changefeed] = ACTIONS(236),
    [sym_keyword_content] = ACTIONS(236),
    [sym_keyword_merge] = ACTIONS(236),
    [sym_keyword_patch] = ACTIONS(236),
    [sym_keyword_replace] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [sym_keyword_unset] = ACTIONS(236),
    [sym_keyword_set] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DOT] = ACTIONS(385),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(115)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_on] = ACTIONS(236),
    [sym_keyword_return] = ACTIONS(236),
    [sym_keyword_from] = ACTIONS(236),
    [sym_keyword_as] = ACTIONS(236),
    [sym_keyword_omit] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_drop] = ACTIONS(236),
    [sym_keyword_schemafull] = ACTIONS(236),
    [sym_keyword_schemaless] = ACTIONS(236),
    [sym_keyword_changefeed] = ACTIONS(236),
    [sym_keyword_content] = ACTIONS(236),
    [sym_keyword_merge] = ACTIONS(236),
    [sym_keyword_patch] = ACTIONS(236),
    [sym_keyword_replace] = ACTIONS(236),
    [sym_keyword_then] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [sym_keyword_unset] = ACTIONS(236),
    [sym_keyword_set] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_LPAREN] = ACTIONS(236),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_RBRACK] = ACTIONS(236),
    [anon_sym_QMARK] = ACTIONS(238),
    [anon_sym_LBRACE] = ACTIONS(236),
    [anon_sym_RBRACE] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(116)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(113),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(113),
    [ts_builtin_sym_end] = ACTIONS(196),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(196),
    [sym_keyword_return] = ACTIONS(196),
    [sym_keyword_explain] = ACTIONS(196),
    [sym_keyword_parallel] = ACTIONS(196),
    [sym_keyword_timeout] = ACTIONS(196),
    [sym_keyword_fetch] = ACTIONS(196),
    [sym_keyword_limit] = ACTIONS(196),
    [sym_keyword_where] = ACTIONS(196),
    [sym_keyword_group] = ACTIONS(196),
    [sym_keyword_and] = ACTIONS(196),
    [sym_keyword_or] = ACTIONS(196),
    [sym_keyword_is] = ACTIONS(196),
    [sym_keyword_not] = ACTIONS(198),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(196),
    [sym_keyword_contains_all] = ACTIONS(196),
    [sym_keyword_contains_any] = ACTIONS(196),
    [sym_keyword_contains_none] = ACTIONS(196),
    [sym_keyword_inside] = ACTIONS(196),
    [sym_keyword_in] = ACTIONS(198),
    [sym_keyword_not_inside] = ACTIONS(196),
    [sym_keyword_all_inside] = ACTIONS(196),
    [sym_keyword_any_inside] = ACTIONS(196),
    [sym_keyword_none_inside] = ACTIONS(196),
    [sym_keyword_outside] = ACTIONS(196),
    [sym_keyword_intersects] = ACTIONS(196),
    [sym_keyword_drop] = ACTIONS(196),
    [sym_keyword_schemafull] = ACTIONS(196),
    [sym_keyword_schemaless] = ACTIONS(196),
    [sym_keyword_changefeed] = ACTIONS(196),
    [sym_keyword_content] = ACTIONS(196),
    [sym_keyword_merge] = ACTIONS(196),
    [sym_keyword_patch] = ACTIONS(196),
    [sym_keyword_replace] = ACTIONS(196),
    [sym_keyword_permissions] = ACTIONS(196),
    [sym_keyword_for] = ACTIONS(196),
    [sym_keyword_comment] = ACTIONS(196),
    [sym_keyword_unset] = ACTIONS(196),
    [sym_keyword_set] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(196),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(385),
    [anon_sym_DASH] = ACTIONS(198),
    [anon_sym_PERCENT] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(198),
    [anon_sym_LT_PIPE] = ACTIONS(196),
    [anon_sym_AMP_AMP] = ACTIONS(196),
    [anon_sym_PIPE_PIPE] = ACTIONS(196),
    [anon_sym_QMARK_QMARK] = ACTIONS(196),
    [anon_sym_QMARK_COLON] = ACTIONS(196),
    [anon_sym_BANG_EQ] = ACTIONS(196),
    [anon_sym_EQ_EQ] = ACTIONS(196),
    [anon_sym_QMARK_EQ] = ACTIONS(196),
    [anon_sym_STAR_EQ] = ACTIONS(196),
    [anon_sym_TILDE] = ACTIONS(196),
    [anon_sym_BANG_TILDE] = ACTIONS(196),
    [anon_sym_STAR_TILDE] = ACTIONS(196),
    [anon_sym_LT_EQ] = ACTIONS(196),
    [anon_sym_GT_EQ] = ACTIONS(196),
    [anon_sym_PLUS] = ACTIONS(198),
    [anon_sym_PLUS_EQ] = ACTIONS(196),
    [anon_sym_DASH_EQ] = ACTIONS(196),
    [anon_sym_u00d7] = ACTIONS(196),
    [anon_sym_SLASH] = ACTIONS(198),
    [anon_sym_u00f7] = ACTIONS(196),
    [anon_sym_STAR_STAR] = ACTIONS(196),
    [anon_sym_u220b] = ACTIONS(196),
    [anon_sym_u220c] = ACTIONS(196),
    [anon_sym_u2287] = ACTIONS(196),
    [anon_sym_u2283] = ACTIONS(196),
    [anon_sym_u2285] = ACTIONS(196),
    [anon_sym_u2208] = ACTIONS(196),
    [anon_sym_u2209] = ACTIONS(196),
    [anon_sym_u2286] = ACTIONS(196),
    [anon_sym_u2282] = ACTIONS(196),
    [anon_sym_u2284] = ACTIONS(196),
    [anon_sym_AT_AT] = ACTIONS(196),
  },
  [STATE(117)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_on] = ACTIONS(204),
    [sym_keyword_return] = ACTIONS(204),
    [sym_keyword_from] = ACTIONS(204),
    [sym_keyword_as] = ACTIONS(204),
    [sym_keyword_omit] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_drop] = ACTIONS(204),
    [sym_keyword_schemafull] = ACTIONS(204),
    [sym_keyword_schemaless] = ACTIONS(204),
    [sym_keyword_changefeed] = ACTIONS(204),
    [sym_keyword_content] = ACTIONS(204),
    [sym_keyword_merge] = ACTIONS(204),
    [sym_keyword_patch] = ACTIONS(204),
    [sym_keyword_replace] = ACTIONS(204),
    [sym_keyword_then] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [sym_keyword_unset] = ACTIONS(204),
    [sym_keyword_set] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_LPAREN] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_RBRACK] = ACTIONS(204),
    [anon_sym_QMARK] = ACTIONS(206),
    [anon_sym_LBRACE] = ACTIONS(204),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(118)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(113),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(113),
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_return] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_drop] = ACTIONS(204),
    [sym_keyword_schemafull] = ACTIONS(204),
    [sym_keyword_schemaless] = ACTIONS(204),
    [sym_keyword_changefeed] = ACTIONS(204),
    [sym_keyword_content] = ACTIONS(204),
    [sym_keyword_merge] = ACTIONS(204),
    [sym_keyword_patch] = ACTIONS(204),
    [sym_keyword_replace] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [sym_keyword_unset] = ACTIONS(204),
    [sym_keyword_set] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(385),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(119)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_on] = ACTIONS(375),
    [sym_keyword_return] = ACTIONS(375),
    [sym_keyword_from] = ACTIONS(375),
    [sym_keyword_as] = ACTIONS(375),
    [sym_keyword_omit] = ACTIONS(375),
    [sym_keyword_explain] = ACTIONS(375),
    [sym_keyword_parallel] = ACTIONS(375),
    [sym_keyword_timeout] = ACTIONS(375),
    [sym_keyword_fetch] = ACTIONS(375),
    [sym_keyword_limit] = ACTIONS(375),
    [sym_keyword_where] = ACTIONS(375),
    [sym_keyword_group] = ACTIONS(375),
    [sym_keyword_and] = ACTIONS(375),
    [sym_keyword_or] = ACTIONS(375),
    [sym_keyword_is] = ACTIONS(375),
    [sym_keyword_not] = ACTIONS(377),
    [sym_keyword_contains] = ACTIONS(377),
    [sym_keyword_contains_not] = ACTIONS(375),
    [sym_keyword_contains_all] = ACTIONS(375),
    [sym_keyword_contains_any] = ACTIONS(375),
    [sym_keyword_contains_none] = ACTIONS(375),
    [sym_keyword_inside] = ACTIONS(375),
    [sym_keyword_in] = ACTIONS(377),
    [sym_keyword_not_inside] = ACTIONS(375),
    [sym_keyword_all_inside] = ACTIONS(375),
    [sym_keyword_any_inside] = ACTIONS(375),
    [sym_keyword_none_inside] = ACTIONS(375),
    [sym_keyword_outside] = ACTIONS(375),
    [sym_keyword_intersects] = ACTIONS(375),
    [sym_keyword_drop] = ACTIONS(375),
    [sym_keyword_schemafull] = ACTIONS(375),
    [sym_keyword_schemaless] = ACTIONS(375),
    [sym_keyword_changefeed] = ACTIONS(375),
    [sym_keyword_content] = ACTIONS(375),
    [sym_keyword_merge] = ACTIONS(375),
    [sym_keyword_patch] = ACTIONS(375),
    [sym_keyword_replace] = ACTIONS(375),
    [sym_keyword_then] = ACTIONS(375),
    [sym_keyword_permissions] = ACTIONS(375),
    [sym_keyword_for] = ACTIONS(375),
    [sym_keyword_comment] = ACTIONS(375),
    [sym_keyword_unset] = ACTIONS(375),
    [sym_keyword_set] = ACTIONS(375),
    [anon_sym_EQ] = ACTIONS(377),
    [anon_sym_COMMA] = ACTIONS(375),
    [anon_sym_LPAREN] = ACTIONS(375),
    [anon_sym_RPAREN] = ACTIONS(375),
    [anon_sym_RBRACK] = ACTIONS(375),
    [anon_sym_QMARK] = ACTIONS(377),
    [anon_sym_LBRACE] = ACTIONS(375),
    [anon_sym_RBRACE] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PERCENT] = ACTIONS(375),
    [anon_sym_AT] = ACTIONS(377),
    [anon_sym_LT_PIPE] = ACTIONS(375),
    [anon_sym_AMP_AMP] = ACTIONS(375),
    [anon_sym_PIPE_PIPE] = ACTIONS(375),
    [anon_sym_QMARK_QMARK] = ACTIONS(375),
    [anon_sym_QMARK_COLON] = ACTIONS(375),
    [anon_sym_BANG_EQ] = ACTIONS(375),
    [anon_sym_EQ_EQ] = ACTIONS(375),
    [anon_sym_QMARK_EQ] = ACTIONS(375),
    [anon_sym_STAR_EQ] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(375),
    [anon_sym_BANG_TILDE] = ACTIONS(375),
    [anon_sym_STAR_TILDE] = ACTIONS(375),
    [anon_sym_LT_EQ] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(375),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_PLUS_EQ] = ACTIONS(375),
    [anon_sym_DASH_EQ] = ACTIONS(375),
    [anon_sym_u00d7] = ACTIONS(375),
    [anon_sym_SLASH] = ACTIONS(377),
    [anon_sym_u00f7] = ACTIONS(375),
    [anon_sym_STAR_STAR] = ACTIONS(375),
    [anon_sym_u220b] = ACTIONS(375),
    [anon_sym_u220c] = ACTIONS(375),
    [anon_sym_u2287] = ACTIONS(375),
    [anon_sym_u2283] = ACTIONS(375),
    [anon_sym_u2285] = ACTIONS(375),
    [anon_sym_u2208] = ACTIONS(375),
    [anon_sym_u2209] = ACTIONS(375),
    [anon_sym_u2286] = ACTIONS(375),
    [anon_sym_u2282] = ACTIONS(375),
    [anon_sym_u2284] = ACTIONS(375),
    [anon_sym_AT_AT] = ACTIONS(375),
  },
  [STATE(120)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(120),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(120),
    [ts_builtin_sym_end] = ACTIONS(216),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(216),
    [sym_keyword_return] = ACTIONS(216),
    [sym_keyword_explain] = ACTIONS(216),
    [sym_keyword_parallel] = ACTIONS(216),
    [sym_keyword_timeout] = ACTIONS(216),
    [sym_keyword_fetch] = ACTIONS(216),
    [sym_keyword_limit] = ACTIONS(216),
    [sym_keyword_where] = ACTIONS(216),
    [sym_keyword_group] = ACTIONS(216),
    [sym_keyword_and] = ACTIONS(216),
    [sym_keyword_or] = ACTIONS(216),
    [sym_keyword_is] = ACTIONS(216),
    [sym_keyword_not] = ACTIONS(218),
    [sym_keyword_contains] = ACTIONS(218),
    [sym_keyword_contains_not] = ACTIONS(216),
    [sym_keyword_contains_all] = ACTIONS(216),
    [sym_keyword_contains_any] = ACTIONS(216),
    [sym_keyword_contains_none] = ACTIONS(216),
    [sym_keyword_inside] = ACTIONS(216),
    [sym_keyword_in] = ACTIONS(218),
    [sym_keyword_not_inside] = ACTIONS(216),
    [sym_keyword_all_inside] = ACTIONS(216),
    [sym_keyword_any_inside] = ACTIONS(216),
    [sym_keyword_none_inside] = ACTIONS(216),
    [sym_keyword_outside] = ACTIONS(216),
    [sym_keyword_intersects] = ACTIONS(216),
    [sym_keyword_drop] = ACTIONS(216),
    [sym_keyword_schemafull] = ACTIONS(216),
    [sym_keyword_schemaless] = ACTIONS(216),
    [sym_keyword_changefeed] = ACTIONS(216),
    [sym_keyword_content] = ACTIONS(216),
    [sym_keyword_merge] = ACTIONS(216),
    [sym_keyword_patch] = ACTIONS(216),
    [sym_keyword_replace] = ACTIONS(216),
    [sym_keyword_permissions] = ACTIONS(216),
    [sym_keyword_for] = ACTIONS(216),
    [sym_keyword_comment] = ACTIONS(216),
    [sym_keyword_unset] = ACTIONS(216),
    [sym_keyword_set] = ACTIONS(216),
    [anon_sym_EQ] = ACTIONS(218),
    [anon_sym_COMMA] = ACTIONS(216),
    [anon_sym_DASH_GT] = ACTIONS(387),
    [anon_sym_LBRACK] = ACTIONS(390),
    [anon_sym_LT] = ACTIONS(218),
    [anon_sym_GT] = ACTIONS(218),
    [anon_sym_LT_DASH] = ACTIONS(393),
    [anon_sym_LT_DASH_GT] = ACTIONS(387),
    [anon_sym_STAR] = ACTIONS(218),
    [anon_sym_DOT] = ACTIONS(396),
    [anon_sym_DASH] = ACTIONS(218),
    [anon_sym_PERCENT] = ACTIONS(216),
    [anon_sym_AT] = ACTIONS(218),
    [anon_sym_LT_PIPE] = ACTIONS(216),
    [anon_sym_AMP_AMP] = ACTIONS(216),
    [anon_sym_PIPE_PIPE] = ACTIONS(216),
    [anon_sym_QMARK_QMARK] = ACTIONS(216),
    [anon_sym_QMARK_COLON] = ACTIONS(216),
    [anon_sym_BANG_EQ] = ACTIONS(216),
    [anon_sym_EQ_EQ] = ACTIONS(216),
    [anon_sym_QMARK_EQ] = ACTIONS(216),
    [anon_sym_STAR_EQ] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(216),
    [anon_sym_BANG_TILDE] = ACTIONS(216),
    [anon_sym_STAR_TILDE] = ACTIONS(216),
    [anon_sym_LT_EQ] = ACTIONS(216),
    [anon_sym_GT_EQ] = ACTIONS(216),
    [anon_sym_PLUS] = ACTIONS(218),
    [anon_sym_PLUS_EQ] = ACTIONS(216),
    [anon_sym_DASH_EQ] = ACTIONS(216),
    [anon_sym_u00d7] = ACTIONS(216),
    [anon_sym_SLASH] = ACTIONS(218),
    [anon_sym_u00f7] = ACTIONS(216),
    [anon_sym_STAR_STAR] = ACTIONS(216),
    [anon_sym_u220b] = ACTIONS(216),
    [anon_sym_u220c] = ACTIONS(216),
    [anon_sym_u2287] = ACTIONS(216),
    [anon_sym_u2283] = ACTIONS(216),
    [anon_sym_u2285] = ACTIONS(216),
    [anon_sym_u2208] = ACTIONS(216),
    [anon_sym_u2209] = ACTIONS(216),
    [anon_sym_u2286] = ACTIONS(216),
    [anon_sym_u2282] = ACTIONS(216),
    [anon_sym_u2284] = ACTIONS(216),
    [anon_sym_AT_AT] = ACTIONS(216),
  },
  [STATE(121)] = {
    [sym_filter] = STATE(153),
    [sym_path_element] = STATE(122),
    [sym_graph_path] = STATE(153),
    [sym_subscript] = STATE(153),
    [aux_sym_path_repeat1] = STATE(122),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_value] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_rand] = ACTIONS(236),
    [sym_keyword_collate] = ACTIONS(236),
    [sym_keyword_numeric] = ACTIONS(236),
    [sym_keyword_asc] = ACTIONS(236),
    [sym_keyword_desc] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_flexible] = ACTIONS(236),
    [sym_keyword_readonly] = ACTIONS(236),
    [sym_keyword_type] = ACTIONS(236),
    [sym_keyword_default] = ACTIONS(236),
    [sym_keyword_assert] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_DASH_GT] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(401),
    [anon_sym_RBRACE] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_LT_DASH] = ACTIONS(403),
    [anon_sym_LT_DASH_GT] = ACTIONS(399),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DOT] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(122)] = {
    [sym_filter] = STATE(153),
    [sym_path_element] = STATE(123),
    [sym_graph_path] = STATE(153),
    [sym_subscript] = STATE(153),
    [aux_sym_path_repeat1] = STATE(123),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(212),
    [sym_keyword_value] = ACTIONS(212),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_rand] = ACTIONS(212),
    [sym_keyword_collate] = ACTIONS(212),
    [sym_keyword_numeric] = ACTIONS(212),
    [sym_keyword_asc] = ACTIONS(212),
    [sym_keyword_desc] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(214),
    [sym_keyword_contains] = ACTIONS(214),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(214),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_flexible] = ACTIONS(212),
    [sym_keyword_readonly] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_default] = ACTIONS(212),
    [sym_keyword_assert] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(214),
    [anon_sym_COMMA] = ACTIONS(212),
    [anon_sym_RPAREN] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(401),
    [anon_sym_RBRACE] = ACTIONS(212),
    [anon_sym_LT] = ACTIONS(214),
    [anon_sym_GT] = ACTIONS(214),
    [anon_sym_LT_DASH] = ACTIONS(403),
    [anon_sym_LT_DASH_GT] = ACTIONS(399),
    [anon_sym_STAR] = ACTIONS(214),
    [anon_sym_DOT] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(214),
    [anon_sym_PERCENT] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(214),
    [anon_sym_LT_PIPE] = ACTIONS(212),
    [anon_sym_AMP_AMP] = ACTIONS(212),
    [anon_sym_PIPE_PIPE] = ACTIONS(212),
    [anon_sym_QMARK_QMARK] = ACTIONS(212),
    [anon_sym_QMARK_COLON] = ACTIONS(212),
    [anon_sym_BANG_EQ] = ACTIONS(212),
    [anon_sym_EQ_EQ] = ACTIONS(212),
    [anon_sym_QMARK_EQ] = ACTIONS(212),
    [anon_sym_STAR_EQ] = ACTIONS(212),
    [anon_sym_TILDE] = ACTIONS(212),
    [anon_sym_BANG_TILDE] = ACTIONS(212),
    [anon_sym_STAR_TILDE] = ACTIONS(212),
    [anon_sym_LT_EQ] = ACTIONS(212),
    [anon_sym_GT_EQ] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(214),
    [anon_sym_PLUS_EQ] = ACTIONS(212),
    [anon_sym_DASH_EQ] = ACTIONS(212),
    [anon_sym_u00d7] = ACTIONS(212),
    [anon_sym_SLASH] = ACTIONS(214),
    [anon_sym_u00f7] = ACTIONS(212),
    [anon_sym_STAR_STAR] = ACTIONS(212),
    [anon_sym_u220b] = ACTIONS(212),
    [anon_sym_u220c] = ACTIONS(212),
    [anon_sym_u2287] = ACTIONS(212),
    [anon_sym_u2283] = ACTIONS(212),
    [anon_sym_u2285] = ACTIONS(212),
    [anon_sym_u2208] = ACTIONS(212),
    [anon_sym_u2209] = ACTIONS(212),
    [anon_sym_u2286] = ACTIONS(212),
    [anon_sym_u2282] = ACTIONS(212),
    [anon_sym_u2284] = ACTIONS(212),
    [anon_sym_AT_AT] = ACTIONS(212),
  },
  [STATE(123)] = {
    [sym_filter] = STATE(153),
    [sym_path_element] = STATE(123),
    [sym_graph_path] = STATE(153),
    [sym_subscript] = STATE(153),
    [aux_sym_path_repeat1] = STATE(123),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(216),
    [sym_keyword_value] = ACTIONS(216),
    [sym_keyword_explain] = ACTIONS(216),
    [sym_keyword_parallel] = ACTIONS(216),
    [sym_keyword_timeout] = ACTIONS(216),
    [sym_keyword_fetch] = ACTIONS(216),
    [sym_keyword_limit] = ACTIONS(216),
    [sym_keyword_rand] = ACTIONS(216),
    [sym_keyword_collate] = ACTIONS(216),
    [sym_keyword_numeric] = ACTIONS(216),
    [sym_keyword_asc] = ACTIONS(216),
    [sym_keyword_desc] = ACTIONS(216),
    [sym_keyword_and] = ACTIONS(216),
    [sym_keyword_or] = ACTIONS(216),
    [sym_keyword_is] = ACTIONS(216),
    [sym_keyword_not] = ACTIONS(218),
    [sym_keyword_contains] = ACTIONS(218),
    [sym_keyword_contains_not] = ACTIONS(216),
    [sym_keyword_contains_all] = ACTIONS(216),
    [sym_keyword_contains_any] = ACTIONS(216),
    [sym_keyword_contains_none] = ACTIONS(216),
    [sym_keyword_inside] = ACTIONS(216),
    [sym_keyword_in] = ACTIONS(218),
    [sym_keyword_not_inside] = ACTIONS(216),
    [sym_keyword_all_inside] = ACTIONS(216),
    [sym_keyword_any_inside] = ACTIONS(216),
    [sym_keyword_none_inside] = ACTIONS(216),
    [sym_keyword_outside] = ACTIONS(216),
    [sym_keyword_intersects] = ACTIONS(216),
    [sym_keyword_flexible] = ACTIONS(216),
    [sym_keyword_readonly] = ACTIONS(216),
    [sym_keyword_type] = ACTIONS(216),
    [sym_keyword_default] = ACTIONS(216),
    [sym_keyword_assert] = ACTIONS(216),
    [sym_keyword_permissions] = ACTIONS(216),
    [sym_keyword_for] = ACTIONS(216),
    [sym_keyword_comment] = ACTIONS(216),
    [anon_sym_EQ] = ACTIONS(218),
    [anon_sym_COMMA] = ACTIONS(216),
    [anon_sym_RPAREN] = ACTIONS(216),
    [anon_sym_DASH_GT] = ACTIONS(407),
    [anon_sym_LBRACK] = ACTIONS(410),
    [anon_sym_RBRACE] = ACTIONS(216),
    [anon_sym_LT] = ACTIONS(218),
    [anon_sym_GT] = ACTIONS(218),
    [anon_sym_LT_DASH] = ACTIONS(413),
    [anon_sym_LT_DASH_GT] = ACTIONS(407),
    [anon_sym_STAR] = ACTIONS(218),
    [anon_sym_DOT] = ACTIONS(416),
    [anon_sym_DASH] = ACTIONS(218),
    [anon_sym_PERCENT] = ACTIONS(216),
    [anon_sym_AT] = ACTIONS(218),
    [anon_sym_LT_PIPE] = ACTIONS(216),
    [anon_sym_AMP_AMP] = ACTIONS(216),
    [anon_sym_PIPE_PIPE] = ACTIONS(216),
    [anon_sym_QMARK_QMARK] = ACTIONS(216),
    [anon_sym_QMARK_COLON] = ACTIONS(216),
    [anon_sym_BANG_EQ] = ACTIONS(216),
    [anon_sym_EQ_EQ] = ACTIONS(216),
    [anon_sym_QMARK_EQ] = ACTIONS(216),
    [anon_sym_STAR_EQ] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(216),
    [anon_sym_BANG_TILDE] = ACTIONS(216),
    [anon_sym_STAR_TILDE] = ACTIONS(216),
    [anon_sym_LT_EQ] = ACTIONS(216),
    [anon_sym_GT_EQ] = ACTIONS(216),
    [anon_sym_PLUS] = ACTIONS(218),
    [anon_sym_PLUS_EQ] = ACTIONS(216),
    [anon_sym_DASH_EQ] = ACTIONS(216),
    [anon_sym_u00d7] = ACTIONS(216),
    [anon_sym_SLASH] = ACTIONS(218),
    [anon_sym_u00f7] = ACTIONS(216),
    [anon_sym_STAR_STAR] = ACTIONS(216),
    [anon_sym_u220b] = ACTIONS(216),
    [anon_sym_u220c] = ACTIONS(216),
    [anon_sym_u2287] = ACTIONS(216),
    [anon_sym_u2283] = ACTIONS(216),
    [anon_sym_u2285] = ACTIONS(216),
    [anon_sym_u2208] = ACTIONS(216),
    [anon_sym_u2209] = ACTIONS(216),
    [anon_sym_u2286] = ACTIONS(216),
    [anon_sym_u2282] = ACTIONS(216),
    [anon_sym_u2284] = ACTIONS(216),
    [anon_sym_AT_AT] = ACTIONS(216),
  },
  [STATE(124)] = {
    [sym_filter] = STATE(153),
    [sym_path_element] = STATE(122),
    [sym_graph_path] = STATE(153),
    [sym_subscript] = STATE(153),
    [aux_sym_path_repeat1] = STATE(122),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_value] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_rand] = ACTIONS(204),
    [sym_keyword_collate] = ACTIONS(204),
    [sym_keyword_numeric] = ACTIONS(204),
    [sym_keyword_asc] = ACTIONS(204),
    [sym_keyword_desc] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_flexible] = ACTIONS(204),
    [sym_keyword_readonly] = ACTIONS(204),
    [sym_keyword_type] = ACTIONS(204),
    [sym_keyword_default] = ACTIONS(204),
    [sym_keyword_assert] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(401),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(403),
    [anon_sym_LT_DASH_GT] = ACTIONS(399),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(125)] = {
    [sym_filter] = STATE(153),
    [sym_path_element] = STATE(122),
    [sym_graph_path] = STATE(153),
    [sym_subscript] = STATE(153),
    [aux_sym_path_repeat1] = STATE(122),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(196),
    [sym_keyword_value] = ACTIONS(196),
    [sym_keyword_explain] = ACTIONS(196),
    [sym_keyword_parallel] = ACTIONS(196),
    [sym_keyword_timeout] = ACTIONS(196),
    [sym_keyword_fetch] = ACTIONS(196),
    [sym_keyword_limit] = ACTIONS(196),
    [sym_keyword_rand] = ACTIONS(196),
    [sym_keyword_collate] = ACTIONS(196),
    [sym_keyword_numeric] = ACTIONS(196),
    [sym_keyword_asc] = ACTIONS(196),
    [sym_keyword_desc] = ACTIONS(196),
    [sym_keyword_and] = ACTIONS(196),
    [sym_keyword_or] = ACTIONS(196),
    [sym_keyword_is] = ACTIONS(196),
    [sym_keyword_not] = ACTIONS(198),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(196),
    [sym_keyword_contains_all] = ACTIONS(196),
    [sym_keyword_contains_any] = ACTIONS(196),
    [sym_keyword_contains_none] = ACTIONS(196),
    [sym_keyword_inside] = ACTIONS(196),
    [sym_keyword_in] = ACTIONS(198),
    [sym_keyword_not_inside] = ACTIONS(196),
    [sym_keyword_all_inside] = ACTIONS(196),
    [sym_keyword_any_inside] = ACTIONS(196),
    [sym_keyword_none_inside] = ACTIONS(196),
    [sym_keyword_outside] = ACTIONS(196),
    [sym_keyword_intersects] = ACTIONS(196),
    [sym_keyword_flexible] = ACTIONS(196),
    [sym_keyword_readonly] = ACTIONS(196),
    [sym_keyword_type] = ACTIONS(196),
    [sym_keyword_default] = ACTIONS(196),
    [sym_keyword_assert] = ACTIONS(196),
    [sym_keyword_permissions] = ACTIONS(196),
    [sym_keyword_for] = ACTIONS(196),
    [sym_keyword_comment] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(196),
    [anon_sym_RPAREN] = ACTIONS(196),
    [anon_sym_DASH_GT] = ACTIONS(399),
    [anon_sym_LBRACK] = ACTIONS(401),
    [anon_sym_RBRACE] = ACTIONS(196),
    [anon_sym_LT] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(403),
    [anon_sym_LT_DASH_GT] = ACTIONS(399),
    [anon_sym_STAR] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(405),
    [anon_sym_DASH] = ACTIONS(198),
    [anon_sym_PERCENT] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(198),
    [anon_sym_LT_PIPE] = ACTIONS(196),
    [anon_sym_AMP_AMP] = ACTIONS(196),
    [anon_sym_PIPE_PIPE] = ACTIONS(196),
    [anon_sym_QMARK_QMARK] = ACTIONS(196),
    [anon_sym_QMARK_COLON] = ACTIONS(196),
    [anon_sym_BANG_EQ] = ACTIONS(196),
    [anon_sym_EQ_EQ] = ACTIONS(196),
    [anon_sym_QMARK_EQ] = ACTIONS(196),
    [anon_sym_STAR_EQ] = ACTIONS(196),
    [anon_sym_TILDE] = ACTIONS(196),
    [anon_sym_BANG_TILDE] = ACTIONS(196),
    [anon_sym_STAR_TILDE] = ACTIONS(196),
    [anon_sym_LT_EQ] = ACTIONS(196),
    [anon_sym_GT_EQ] = ACTIONS(196),
    [anon_sym_PLUS] = ACTIONS(198),
    [anon_sym_PLUS_EQ] = ACTIONS(196),
    [anon_sym_DASH_EQ] = ACTIONS(196),
    [anon_sym_u00d7] = ACTIONS(196),
    [anon_sym_SLASH] = ACTIONS(198),
    [anon_sym_u00f7] = ACTIONS(196),
    [anon_sym_STAR_STAR] = ACTIONS(196),
    [anon_sym_u220b] = ACTIONS(196),
    [anon_sym_u220c] = ACTIONS(196),
    [anon_sym_u2287] = ACTIONS(196),
    [anon_sym_u2283] = ACTIONS(196),
    [anon_sym_u2285] = ACTIONS(196),
    [anon_sym_u2208] = ACTIONS(196),
    [anon_sym_u2209] = ACTIONS(196),
    [anon_sym_u2286] = ACTIONS(196),
    [anon_sym_u2282] = ACTIONS(196),
    [anon_sym_u2284] = ACTIONS(196),
    [anon_sym_AT_AT] = ACTIONS(196),
  },
  [STATE(126)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(130),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(130),
    [ts_builtin_sym_end] = ACTIONS(196),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(196),
    [sym_keyword_value] = ACTIONS(196),
    [sym_keyword_explain] = ACTIONS(196),
    [sym_keyword_parallel] = ACTIONS(196),
    [sym_keyword_timeout] = ACTIONS(196),
    [sym_keyword_fetch] = ACTIONS(196),
    [sym_keyword_limit] = ACTIONS(196),
    [sym_keyword_rand] = ACTIONS(196),
    [sym_keyword_collate] = ACTIONS(196),
    [sym_keyword_numeric] = ACTIONS(196),
    [sym_keyword_asc] = ACTIONS(196),
    [sym_keyword_desc] = ACTIONS(196),
    [sym_keyword_and] = ACTIONS(196),
    [sym_keyword_or] = ACTIONS(196),
    [sym_keyword_is] = ACTIONS(196),
    [sym_keyword_not] = ACTIONS(198),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(196),
    [sym_keyword_contains_all] = ACTIONS(196),
    [sym_keyword_contains_any] = ACTIONS(196),
    [sym_keyword_contains_none] = ACTIONS(196),
    [sym_keyword_inside] = ACTIONS(196),
    [sym_keyword_in] = ACTIONS(198),
    [sym_keyword_not_inside] = ACTIONS(196),
    [sym_keyword_all_inside] = ACTIONS(196),
    [sym_keyword_any_inside] = ACTIONS(196),
    [sym_keyword_none_inside] = ACTIONS(196),
    [sym_keyword_outside] = ACTIONS(196),
    [sym_keyword_intersects] = ACTIONS(196),
    [sym_keyword_flexible] = ACTIONS(196),
    [sym_keyword_readonly] = ACTIONS(196),
    [sym_keyword_type] = ACTIONS(196),
    [sym_keyword_default] = ACTIONS(196),
    [sym_keyword_assert] = ACTIONS(196),
    [sym_keyword_permissions] = ACTIONS(196),
    [sym_keyword_for] = ACTIONS(196),
    [sym_keyword_comment] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(196),
    [anon_sym_DASH_GT] = ACTIONS(419),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(421),
    [anon_sym_LT_DASH_GT] = ACTIONS(419),
    [anon_sym_STAR] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(198),
    [anon_sym_PERCENT] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(198),
    [anon_sym_LT_PIPE] = ACTIONS(196),
    [anon_sym_AMP_AMP] = ACTIONS(196),
    [anon_sym_PIPE_PIPE] = ACTIONS(196),
    [anon_sym_QMARK_QMARK] = ACTIONS(196),
    [anon_sym_QMARK_COLON] = ACTIONS(196),
    [anon_sym_BANG_EQ] = ACTIONS(196),
    [anon_sym_EQ_EQ] = ACTIONS(196),
    [anon_sym_QMARK_EQ] = ACTIONS(196),
    [anon_sym_STAR_EQ] = ACTIONS(196),
    [anon_sym_TILDE] = ACTIONS(196),
    [anon_sym_BANG_TILDE] = ACTIONS(196),
    [anon_sym_STAR_TILDE] = ACTIONS(196),
    [anon_sym_LT_EQ] = ACTIONS(196),
    [anon_sym_GT_EQ] = ACTIONS(196),
    [anon_sym_PLUS] = ACTIONS(198),
    [anon_sym_PLUS_EQ] = ACTIONS(196),
    [anon_sym_DASH_EQ] = ACTIONS(196),
    [anon_sym_u00d7] = ACTIONS(196),
    [anon_sym_SLASH] = ACTIONS(198),
    [anon_sym_u00f7] = ACTIONS(196),
    [anon_sym_STAR_STAR] = ACTIONS(196),
    [anon_sym_u220b] = ACTIONS(196),
    [anon_sym_u220c] = ACTIONS(196),
    [anon_sym_u2287] = ACTIONS(196),
    [anon_sym_u2283] = ACTIONS(196),
    [anon_sym_u2285] = ACTIONS(196),
    [anon_sym_u2208] = ACTIONS(196),
    [anon_sym_u2209] = ACTIONS(196),
    [anon_sym_u2286] = ACTIONS(196),
    [anon_sym_u2282] = ACTIONS(196),
    [anon_sym_u2284] = ACTIONS(196),
    [anon_sym_AT_AT] = ACTIONS(196),
  },
  [STATE(127)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(127),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(127),
    [ts_builtin_sym_end] = ACTIONS(216),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(216),
    [sym_keyword_value] = ACTIONS(216),
    [sym_keyword_explain] = ACTIONS(216),
    [sym_keyword_parallel] = ACTIONS(216),
    [sym_keyword_timeout] = ACTIONS(216),
    [sym_keyword_fetch] = ACTIONS(216),
    [sym_keyword_limit] = ACTIONS(216),
    [sym_keyword_rand] = ACTIONS(216),
    [sym_keyword_collate] = ACTIONS(216),
    [sym_keyword_numeric] = ACTIONS(216),
    [sym_keyword_asc] = ACTIONS(216),
    [sym_keyword_desc] = ACTIONS(216),
    [sym_keyword_and] = ACTIONS(216),
    [sym_keyword_or] = ACTIONS(216),
    [sym_keyword_is] = ACTIONS(216),
    [sym_keyword_not] = ACTIONS(218),
    [sym_keyword_contains] = ACTIONS(218),
    [sym_keyword_contains_not] = ACTIONS(216),
    [sym_keyword_contains_all] = ACTIONS(216),
    [sym_keyword_contains_any] = ACTIONS(216),
    [sym_keyword_contains_none] = ACTIONS(216),
    [sym_keyword_inside] = ACTIONS(216),
    [sym_keyword_in] = ACTIONS(218),
    [sym_keyword_not_inside] = ACTIONS(216),
    [sym_keyword_all_inside] = ACTIONS(216),
    [sym_keyword_any_inside] = ACTIONS(216),
    [sym_keyword_none_inside] = ACTIONS(216),
    [sym_keyword_outside] = ACTIONS(216),
    [sym_keyword_intersects] = ACTIONS(216),
    [sym_keyword_flexible] = ACTIONS(216),
    [sym_keyword_readonly] = ACTIONS(216),
    [sym_keyword_type] = ACTIONS(216),
    [sym_keyword_default] = ACTIONS(216),
    [sym_keyword_assert] = ACTIONS(216),
    [sym_keyword_permissions] = ACTIONS(216),
    [sym_keyword_for] = ACTIONS(216),
    [sym_keyword_comment] = ACTIONS(216),
    [anon_sym_EQ] = ACTIONS(218),
    [anon_sym_COMMA] = ACTIONS(216),
    [anon_sym_DASH_GT] = ACTIONS(425),
    [anon_sym_LBRACK] = ACTIONS(390),
    [anon_sym_LT] = ACTIONS(218),
    [anon_sym_GT] = ACTIONS(218),
    [anon_sym_LT_DASH] = ACTIONS(428),
    [anon_sym_LT_DASH_GT] = ACTIONS(425),
    [anon_sym_STAR] = ACTIONS(218),
    [anon_sym_DOT] = ACTIONS(431),
    [anon_sym_DASH] = ACTIONS(218),
    [anon_sym_PERCENT] = ACTIONS(216),
    [anon_sym_AT] = ACTIONS(218),
    [anon_sym_LT_PIPE] = ACTIONS(216),
    [anon_sym_AMP_AMP] = ACTIONS(216),
    [anon_sym_PIPE_PIPE] = ACTIONS(216),
    [anon_sym_QMARK_QMARK] = ACTIONS(216),
    [anon_sym_QMARK_COLON] = ACTIONS(216),
    [anon_sym_BANG_EQ] = ACTIONS(216),
    [anon_sym_EQ_EQ] = ACTIONS(216),
    [anon_sym_QMARK_EQ] = ACTIONS(216),
    [anon_sym_STAR_EQ] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(216),
    [anon_sym_BANG_TILDE] = ACTIONS(216),
    [anon_sym_STAR_TILDE] = ACTIONS(216),
    [anon_sym_LT_EQ] = ACTIONS(216),
    [anon_sym_GT_EQ] = ACTIONS(216),
    [anon_sym_PLUS] = ACTIONS(218),
    [anon_sym_PLUS_EQ] = ACTIONS(216),
    [anon_sym_DASH_EQ] = ACTIONS(216),
    [anon_sym_u00d7] = ACTIONS(216),
    [anon_sym_SLASH] = ACTIONS(218),
    [anon_sym_u00f7] = ACTIONS(216),
    [anon_sym_STAR_STAR] = ACTIONS(216),
    [anon_sym_u220b] = ACTIONS(216),
    [anon_sym_u220c] = ACTIONS(216),
    [anon_sym_u2287] = ACTIONS(216),
    [anon_sym_u2283] = ACTIONS(216),
    [anon_sym_u2285] = ACTIONS(216),
    [anon_sym_u2208] = ACTIONS(216),
    [anon_sym_u2209] = ACTIONS(216),
    [anon_sym_u2286] = ACTIONS(216),
    [anon_sym_u2282] = ACTIONS(216),
    [anon_sym_u2284] = ACTIONS(216),
    [anon_sym_AT_AT] = ACTIONS(216),
  },
  [STATE(128)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(130),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(130),
    [ts_builtin_sym_end] = ACTIONS(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_value] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_rand] = ACTIONS(236),
    [sym_keyword_collate] = ACTIONS(236),
    [sym_keyword_numeric] = ACTIONS(236),
    [sym_keyword_asc] = ACTIONS(236),
    [sym_keyword_desc] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_flexible] = ACTIONS(236),
    [sym_keyword_readonly] = ACTIONS(236),
    [sym_keyword_type] = ACTIONS(236),
    [sym_keyword_default] = ACTIONS(236),
    [sym_keyword_assert] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_DASH_GT] = ACTIONS(419),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_LT_DASH] = ACTIONS(421),
    [anon_sym_LT_DASH_GT] = ACTIONS(419),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DOT] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(129)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(130),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(130),
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_value] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_rand] = ACTIONS(204),
    [sym_keyword_collate] = ACTIONS(204),
    [sym_keyword_numeric] = ACTIONS(204),
    [sym_keyword_asc] = ACTIONS(204),
    [sym_keyword_desc] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_flexible] = ACTIONS(204),
    [sym_keyword_readonly] = ACTIONS(204),
    [sym_keyword_type] = ACTIONS(204),
    [sym_keyword_default] = ACTIONS(204),
    [sym_keyword_assert] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(419),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(421),
    [anon_sym_LT_DASH_GT] = ACTIONS(419),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(130)] = {
    [sym_filter] = STATE(68),
    [sym_path_element] = STATE(127),
    [sym_graph_path] = STATE(68),
    [sym_subscript] = STATE(68),
    [aux_sym_path_repeat1] = STATE(127),
    [ts_builtin_sym_end] = ACTIONS(212),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(212),
    [sym_keyword_value] = ACTIONS(212),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_rand] = ACTIONS(212),
    [sym_keyword_collate] = ACTIONS(212),
    [sym_keyword_numeric] = ACTIONS(212),
    [sym_keyword_asc] = ACTIONS(212),
    [sym_keyword_desc] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(212),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(214),
    [sym_keyword_contains] = ACTIONS(214),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(214),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [sym_keyword_flexible] = ACTIONS(212),
    [sym_keyword_readonly] = ACTIONS(212),
    [sym_keyword_type] = ACTIONS(212),
    [sym_keyword_default] = ACTIONS(212),
    [sym_keyword_assert] = ACTIONS(212),
    [sym_keyword_permissions] = ACTIONS(212),
    [sym_keyword_for] = ACTIONS(212),
    [sym_keyword_comment] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(214),
    [anon_sym_COMMA] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(419),
    [anon_sym_LBRACK] = ACTIONS(383),
    [anon_sym_LT] = ACTIONS(214),
    [anon_sym_GT] = ACTIONS(214),
    [anon_sym_LT_DASH] = ACTIONS(421),
    [anon_sym_LT_DASH_GT] = ACTIONS(419),
    [anon_sym_STAR] = ACTIONS(214),
    [anon_sym_DOT] = ACTIONS(423),
    [anon_sym_DASH] = ACTIONS(214),
    [anon_sym_PERCENT] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(214),
    [anon_sym_LT_PIPE] = ACTIONS(212),
    [anon_sym_AMP_AMP] = ACTIONS(212),
    [anon_sym_PIPE_PIPE] = ACTIONS(212),
    [anon_sym_QMARK_QMARK] = ACTIONS(212),
    [anon_sym_QMARK_COLON] = ACTIONS(212),
    [anon_sym_BANG_EQ] = ACTIONS(212),
    [anon_sym_EQ_EQ] = ACTIONS(212),
    [anon_sym_QMARK_EQ] = ACTIONS(212),
    [anon_sym_STAR_EQ] = ACTIONS(212),
    [anon_sym_TILDE] = ACTIONS(212),
    [anon_sym_BANG_TILDE] = ACTIONS(212),
    [anon_sym_STAR_TILDE] = ACTIONS(212),
    [anon_sym_LT_EQ] = ACTIONS(212),
    [anon_sym_GT_EQ] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(214),
    [anon_sym_PLUS_EQ] = ACTIONS(212),
    [anon_sym_DASH_EQ] = ACTIONS(212),
    [anon_sym_u00d7] = ACTIONS(212),
    [anon_sym_SLASH] = ACTIONS(214),
    [anon_sym_u00f7] = ACTIONS(212),
    [anon_sym_STAR_STAR] = ACTIONS(212),
    [anon_sym_u220b] = ACTIONS(212),
    [anon_sym_u220c] = ACTIONS(212),
    [anon_sym_u2287] = ACTIONS(212),
    [anon_sym_u2283] = ACTIONS(212),
    [anon_sym_u2285] = ACTIONS(212),
    [anon_sym_u2208] = ACTIONS(212),
    [anon_sym_u2209] = ACTIONS(212),
    [anon_sym_u2286] = ACTIONS(212),
    [anon_sym_u2282] = ACTIONS(212),
    [anon_sym_u2284] = ACTIONS(212),
    [anon_sym_AT_AT] = ACTIONS(212),
  },
  [STATE(131)] = {
    [sym_argument_list] = STATE(164),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_value] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_rand] = ACTIONS(278),
    [sym_keyword_collate] = ACTIONS(278),
    [sym_keyword_numeric] = ACTIONS(278),
    [sym_keyword_asc] = ACTIONS(278),
    [sym_keyword_desc] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(278),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [sym_keyword_flexible] = ACTIONS(278),
    [sym_keyword_readonly] = ACTIONS(278),
    [sym_keyword_type] = ACTIONS(278),
    [sym_keyword_default] = ACTIONS(278),
    [sym_keyword_assert] = ACTIONS(278),
    [sym_keyword_permissions] = ACTIONS(278),
    [sym_keyword_for] = ACTIONS(278),
    [sym_keyword_comment] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_LPAREN] = ACTIONS(434),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(132)] = {
    [aux_sym_duration_repeat1] = STATE(132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(179),
    [sym_keyword_value] = ACTIONS(179),
    [sym_keyword_explain] = ACTIONS(179),
    [sym_keyword_parallel] = ACTIONS(179),
    [sym_keyword_timeout] = ACTIONS(179),
    [sym_keyword_fetch] = ACTIONS(179),
    [sym_keyword_limit] = ACTIONS(179),
    [sym_keyword_rand] = ACTIONS(179),
    [sym_keyword_collate] = ACTIONS(179),
    [sym_keyword_numeric] = ACTIONS(179),
    [sym_keyword_asc] = ACTIONS(179),
    [sym_keyword_desc] = ACTIONS(179),
    [sym_keyword_and] = ACTIONS(179),
    [sym_keyword_or] = ACTIONS(179),
    [sym_keyword_is] = ACTIONS(179),
    [sym_keyword_not] = ACTIONS(181),
    [sym_keyword_contains] = ACTIONS(181),
    [sym_keyword_contains_not] = ACTIONS(179),
    [sym_keyword_contains_all] = ACTIONS(179),
    [sym_keyword_contains_any] = ACTIONS(179),
    [sym_keyword_contains_none] = ACTIONS(179),
    [sym_keyword_inside] = ACTIONS(179),
    [sym_keyword_in] = ACTIONS(181),
    [sym_keyword_not_inside] = ACTIONS(179),
    [sym_keyword_all_inside] = ACTIONS(179),
    [sym_keyword_any_inside] = ACTIONS(179),
    [sym_keyword_none_inside] = ACTIONS(179),
    [sym_keyword_outside] = ACTIONS(179),
    [sym_keyword_intersects] = ACTIONS(179),
    [sym_keyword_flexible] = ACTIONS(179),
    [sym_keyword_readonly] = ACTIONS(179),
    [sym_keyword_type] = ACTIONS(179),
    [sym_keyword_default] = ACTIONS(179),
    [sym_keyword_assert] = ACTIONS(179),
    [sym_keyword_permissions] = ACTIONS(179),
    [sym_keyword_for] = ACTIONS(179),
    [sym_keyword_comment] = ACTIONS(179),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_COMMA] = ACTIONS(179),
    [anon_sym_RPAREN] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(179),
    [anon_sym_LBRACK] = ACTIONS(179),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH_GT] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_DOT] = ACTIONS(179),
    [sym_duration_part] = ACTIONS(436),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_PERCENT] = ACTIONS(179),
    [anon_sym_AT] = ACTIONS(181),
    [anon_sym_LT_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_QMARK_QMARK] = ACTIONS(179),
    [anon_sym_QMARK_COLON] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_QMARK_EQ] = ACTIONS(179),
    [anon_sym_STAR_EQ] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG_TILDE] = ACTIONS(179),
    [anon_sym_STAR_TILDE] = ACTIONS(179),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_PLUS] = ACTIONS(181),
    [anon_sym_PLUS_EQ] = ACTIONS(179),
    [anon_sym_DASH_EQ] = ACTIONS(179),
    [anon_sym_u00d7] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(181),
    [anon_sym_u00f7] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(179),
    [anon_sym_u220b] = ACTIONS(179),
    [anon_sym_u220c] = ACTIONS(179),
    [anon_sym_u2287] = ACTIONS(179),
    [anon_sym_u2283] = ACTIONS(179),
    [anon_sym_u2285] = ACTIONS(179),
    [anon_sym_u2208] = ACTIONS(179),
    [anon_sym_u2209] = ACTIONS(179),
    [anon_sym_u2286] = ACTIONS(179),
    [anon_sym_u2282] = ACTIONS(179),
    [anon_sym_u2284] = ACTIONS(179),
    [anon_sym_AT_AT] = ACTIONS(179),
  },
  [STATE(133)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_value] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_rand] = ACTIONS(93),
    [sym_keyword_collate] = ACTIONS(93),
    [sym_keyword_numeric] = ACTIONS(93),
    [sym_keyword_asc] = ACTIONS(93),
    [sym_keyword_desc] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_flexible] = ACTIONS(93),
    [sym_keyword_readonly] = ACTIONS(93),
    [sym_keyword_type] = ACTIONS(93),
    [sym_keyword_default] = ACTIONS(93),
    [sym_keyword_assert] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(194),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_COLON_COLON] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(134)] = {
    [aux_sym_duration_repeat1] = STATE(132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(173),
    [sym_keyword_value] = ACTIONS(173),
    [sym_keyword_explain] = ACTIONS(173),
    [sym_keyword_parallel] = ACTIONS(173),
    [sym_keyword_timeout] = ACTIONS(173),
    [sym_keyword_fetch] = ACTIONS(173),
    [sym_keyword_limit] = ACTIONS(173),
    [sym_keyword_rand] = ACTIONS(173),
    [sym_keyword_collate] = ACTIONS(173),
    [sym_keyword_numeric] = ACTIONS(173),
    [sym_keyword_asc] = ACTIONS(173),
    [sym_keyword_desc] = ACTIONS(173),
    [sym_keyword_and] = ACTIONS(173),
    [sym_keyword_or] = ACTIONS(173),
    [sym_keyword_is] = ACTIONS(173),
    [sym_keyword_not] = ACTIONS(175),
    [sym_keyword_contains] = ACTIONS(175),
    [sym_keyword_contains_not] = ACTIONS(173),
    [sym_keyword_contains_all] = ACTIONS(173),
    [sym_keyword_contains_any] = ACTIONS(173),
    [sym_keyword_contains_none] = ACTIONS(173),
    [sym_keyword_inside] = ACTIONS(173),
    [sym_keyword_in] = ACTIONS(175),
    [sym_keyword_not_inside] = ACTIONS(173),
    [sym_keyword_all_inside] = ACTIONS(173),
    [sym_keyword_any_inside] = ACTIONS(173),
    [sym_keyword_none_inside] = ACTIONS(173),
    [sym_keyword_outside] = ACTIONS(173),
    [sym_keyword_intersects] = ACTIONS(173),
    [sym_keyword_flexible] = ACTIONS(173),
    [sym_keyword_readonly] = ACTIONS(173),
    [sym_keyword_type] = ACTIONS(173),
    [sym_keyword_default] = ACTIONS(173),
    [sym_keyword_assert] = ACTIONS(173),
    [sym_keyword_permissions] = ACTIONS(173),
    [sym_keyword_for] = ACTIONS(173),
    [sym_keyword_comment] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(175),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_RPAREN] = ACTIONS(173),
    [anon_sym_DASH_GT] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(173),
    [anon_sym_RBRACE] = ACTIONS(173),
    [anon_sym_LT] = ACTIONS(175),
    [anon_sym_GT] = ACTIONS(175),
    [anon_sym_LT_DASH] = ACTIONS(175),
    [anon_sym_LT_DASH_GT] = ACTIONS(173),
    [anon_sym_STAR] = ACTIONS(175),
    [anon_sym_DOT] = ACTIONS(173),
    [sym_duration_part] = ACTIONS(439),
    [anon_sym_DASH] = ACTIONS(175),
    [anon_sym_PERCENT] = ACTIONS(173),
    [anon_sym_AT] = ACTIONS(175),
    [anon_sym_LT_PIPE] = ACTIONS(173),
    [anon_sym_AMP_AMP] = ACTIONS(173),
    [anon_sym_PIPE_PIPE] = ACTIONS(173),
    [anon_sym_QMARK_QMARK] = ACTIONS(173),
    [anon_sym_QMARK_COLON] = ACTIONS(173),
    [anon_sym_BANG_EQ] = ACTIONS(173),
    [anon_sym_EQ_EQ] = ACTIONS(173),
    [anon_sym_QMARK_EQ] = ACTIONS(173),
    [anon_sym_STAR_EQ] = ACTIONS(173),
    [anon_sym_TILDE] = ACTIONS(173),
    [anon_sym_BANG_TILDE] = ACTIONS(173),
    [anon_sym_STAR_TILDE] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(173),
    [anon_sym_GT_EQ] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(175),
    [anon_sym_PLUS_EQ] = ACTIONS(173),
    [anon_sym_DASH_EQ] = ACTIONS(173),
    [anon_sym_u00d7] = ACTIONS(173),
    [anon_sym_SLASH] = ACTIONS(175),
    [anon_sym_u00f7] = ACTIONS(173),
    [anon_sym_STAR_STAR] = ACTIONS(173),
    [anon_sym_u220b] = ACTIONS(173),
    [anon_sym_u220c] = ACTIONS(173),
    [anon_sym_u2287] = ACTIONS(173),
    [anon_sym_u2283] = ACTIONS(173),
    [anon_sym_u2285] = ACTIONS(173),
    [anon_sym_u2208] = ACTIONS(173),
    [anon_sym_u2209] = ACTIONS(173),
    [anon_sym_u2286] = ACTIONS(173),
    [anon_sym_u2282] = ACTIONS(173),
    [anon_sym_u2284] = ACTIONS(173),
    [anon_sym_AT_AT] = ACTIONS(173),
  },
  [STATE(135)] = {
    [aux_sym_function_call_repeat1] = STATE(1897),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_value] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_rand] = ACTIONS(304),
    [sym_keyword_collate] = ACTIONS(304),
    [sym_keyword_numeric] = ACTIONS(304),
    [sym_keyword_asc] = ACTIONS(304),
    [sym_keyword_desc] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(304),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [sym_keyword_flexible] = ACTIONS(304),
    [sym_keyword_readonly] = ACTIONS(304),
    [sym_keyword_type] = ACTIONS(304),
    [sym_keyword_default] = ACTIONS(304),
    [sym_keyword_assert] = ACTIONS(304),
    [sym_keyword_permissions] = ACTIONS(304),
    [sym_keyword_for] = ACTIONS(304),
    [sym_keyword_comment] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_RPAREN] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(304),
    [anon_sym_COLON_COLON] = ACTIONS(308),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(136)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(252),
    [sym_keyword_value] = ACTIONS(252),
    [sym_keyword_explain] = ACTIONS(252),
    [sym_keyword_parallel] = ACTIONS(252),
    [sym_keyword_timeout] = ACTIONS(252),
    [sym_keyword_fetch] = ACTIONS(252),
    [sym_keyword_limit] = ACTIONS(252),
    [sym_keyword_rand] = ACTIONS(252),
    [sym_keyword_collate] = ACTIONS(252),
    [sym_keyword_numeric] = ACTIONS(252),
    [sym_keyword_asc] = ACTIONS(252),
    [sym_keyword_desc] = ACTIONS(252),
    [sym_keyword_and] = ACTIONS(252),
    [sym_keyword_or] = ACTIONS(252),
    [sym_keyword_is] = ACTIONS(252),
    [sym_keyword_not] = ACTIONS(254),
    [sym_keyword_contains] = ACTIONS(254),
    [sym_keyword_contains_not] = ACTIONS(252),
    [sym_keyword_contains_all] = ACTIONS(252),
    [sym_keyword_contains_any] = ACTIONS(252),
    [sym_keyword_contains_none] = ACTIONS(252),
    [sym_keyword_inside] = ACTIONS(252),
    [sym_keyword_in] = ACTIONS(254),
    [sym_keyword_not_inside] = ACTIONS(252),
    [sym_keyword_all_inside] = ACTIONS(252),
    [sym_keyword_any_inside] = ACTIONS(252),
    [sym_keyword_none_inside] = ACTIONS(252),
    [sym_keyword_outside] = ACTIONS(252),
    [sym_keyword_intersects] = ACTIONS(252),
    [sym_keyword_flexible] = ACTIONS(252),
    [sym_keyword_readonly] = ACTIONS(252),
    [sym_keyword_type] = ACTIONS(252),
    [sym_keyword_default] = ACTIONS(252),
    [sym_keyword_assert] = ACTIONS(252),
    [sym_keyword_permissions] = ACTIONS(252),
    [sym_keyword_for] = ACTIONS(252),
    [sym_keyword_comment] = ACTIONS(252),
    [anon_sym_EQ] = ACTIONS(254),
    [anon_sym_COMMA] = ACTIONS(252),
    [anon_sym_RPAREN] = ACTIONS(252),
    [anon_sym_DASH_GT] = ACTIONS(252),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_RBRACE] = ACTIONS(252),
    [anon_sym_LT] = ACTIONS(254),
    [anon_sym_GT] = ACTIONS(254),
    [anon_sym_LT_DASH] = ACTIONS(254),
    [anon_sym_LT_DASH_GT] = ACTIONS(252),
    [anon_sym_STAR] = ACTIONS(254),
    [anon_sym_DOT] = ACTIONS(254),
    [anon_sym_DOT_DOT] = ACTIONS(252),
    [anon_sym_DASH] = ACTIONS(254),
    [anon_sym_PERCENT] = ACTIONS(252),
    [anon_sym_AT] = ACTIONS(254),
    [anon_sym_LT_PIPE] = ACTIONS(252),
    [anon_sym_AMP_AMP] = ACTIONS(252),
    [anon_sym_PIPE_PIPE] = ACTIONS(252),
    [anon_sym_QMARK_QMARK] = ACTIONS(252),
    [anon_sym_QMARK_COLON] = ACTIONS(252),
    [anon_sym_BANG_EQ] = ACTIONS(252),
    [anon_sym_EQ_EQ] = ACTIONS(252),
    [anon_sym_QMARK_EQ] = ACTIONS(252),
    [anon_sym_STAR_EQ] = ACTIONS(252),
    [anon_sym_TILDE] = ACTIONS(252),
    [anon_sym_BANG_TILDE] = ACTIONS(252),
    [anon_sym_STAR_TILDE] = ACTIONS(252),
    [anon_sym_LT_EQ] = ACTIONS(252),
    [anon_sym_GT_EQ] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(254),
    [anon_sym_PLUS_EQ] = ACTIONS(252),
    [anon_sym_DASH_EQ] = ACTIONS(252),
    [anon_sym_u00d7] = ACTIONS(252),
    [anon_sym_SLASH] = ACTIONS(254),
    [anon_sym_u00f7] = ACTIONS(252),
    [anon_sym_STAR_STAR] = ACTIONS(252),
    [anon_sym_u220b] = ACTIONS(252),
    [anon_sym_u220c] = ACTIONS(252),
    [anon_sym_u2287] = ACTIONS(252),
    [anon_sym_u2283] = ACTIONS(252),
    [anon_sym_u2285] = ACTIONS(252),
    [anon_sym_u2208] = ACTIONS(252),
    [anon_sym_u2209] = ACTIONS(252),
    [anon_sym_u2286] = ACTIONS(252),
    [anon_sym_u2282] = ACTIONS(252),
    [anon_sym_u2284] = ACTIONS(252),
    [anon_sym_AT_AT] = ACTIONS(252),
  },
  [STATE(137)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(232),
    [sym_keyword_value] = ACTIONS(232),
    [sym_keyword_explain] = ACTIONS(232),
    [sym_keyword_parallel] = ACTIONS(232),
    [sym_keyword_timeout] = ACTIONS(232),
    [sym_keyword_fetch] = ACTIONS(232),
    [sym_keyword_limit] = ACTIONS(232),
    [sym_keyword_rand] = ACTIONS(232),
    [sym_keyword_collate] = ACTIONS(232),
    [sym_keyword_numeric] = ACTIONS(232),
    [sym_keyword_asc] = ACTIONS(232),
    [sym_keyword_desc] = ACTIONS(232),
    [sym_keyword_and] = ACTIONS(232),
    [sym_keyword_or] = ACTIONS(232),
    [sym_keyword_is] = ACTIONS(232),
    [sym_keyword_not] = ACTIONS(234),
    [sym_keyword_contains] = ACTIONS(234),
    [sym_keyword_contains_not] = ACTIONS(232),
    [sym_keyword_contains_all] = ACTIONS(232),
    [sym_keyword_contains_any] = ACTIONS(232),
    [sym_keyword_contains_none] = ACTIONS(232),
    [sym_keyword_inside] = ACTIONS(232),
    [sym_keyword_in] = ACTIONS(234),
    [sym_keyword_not_inside] = ACTIONS(232),
    [sym_keyword_all_inside] = ACTIONS(232),
    [sym_keyword_any_inside] = ACTIONS(232),
    [sym_keyword_none_inside] = ACTIONS(232),
    [sym_keyword_outside] = ACTIONS(232),
    [sym_keyword_intersects] = ACTIONS(232),
    [sym_keyword_flexible] = ACTIONS(232),
    [sym_keyword_readonly] = ACTIONS(232),
    [sym_keyword_type] = ACTIONS(232),
    [sym_keyword_default] = ACTIONS(232),
    [sym_keyword_assert] = ACTIONS(232),
    [sym_keyword_permissions] = ACTIONS(232),
    [sym_keyword_for] = ACTIONS(232),
    [sym_keyword_comment] = ACTIONS(232),
    [anon_sym_EQ] = ACTIONS(234),
    [anon_sym_COMMA] = ACTIONS(232),
    [anon_sym_RPAREN] = ACTIONS(232),
    [anon_sym_DASH_GT] = ACTIONS(232),
    [anon_sym_LBRACK] = ACTIONS(232),
    [anon_sym_RBRACE] = ACTIONS(232),
    [anon_sym_LT] = ACTIONS(234),
    [anon_sym_GT] = ACTIONS(234),
    [anon_sym_LT_DASH] = ACTIONS(234),
    [anon_sym_LT_DASH_GT] = ACTIONS(232),
    [anon_sym_STAR] = ACTIONS(234),
    [anon_sym_DOT] = ACTIONS(234),
    [anon_sym_DOT_DOT] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(234),
    [anon_sym_PERCENT] = ACTIONS(232),
    [anon_sym_AT] = ACTIONS(234),
    [anon_sym_LT_PIPE] = ACTIONS(232),
    [anon_sym_AMP_AMP] = ACTIONS(232),
    [anon_sym_PIPE_PIPE] = ACTIONS(232),
    [anon_sym_QMARK_QMARK] = ACTIONS(232),
    [anon_sym_QMARK_COLON] = ACTIONS(232),
    [anon_sym_BANG_EQ] = ACTIONS(232),
    [anon_sym_EQ_EQ] = ACTIONS(232),
    [anon_sym_QMARK_EQ] = ACTIONS(232),
    [anon_sym_STAR_EQ] = ACTIONS(232),
    [anon_sym_TILDE] = ACTIONS(232),
    [anon_sym_BANG_TILDE] = ACTIONS(232),
    [anon_sym_STAR_TILDE] = ACTIONS(232),
    [anon_sym_LT_EQ] = ACTIONS(232),
    [anon_sym_GT_EQ] = ACTIONS(232),
    [anon_sym_PLUS] = ACTIONS(234),
    [anon_sym_PLUS_EQ] = ACTIONS(232),
    [anon_sym_DASH_EQ] = ACTIONS(232),
    [anon_sym_u00d7] = ACTIONS(232),
    [anon_sym_SLASH] = ACTIONS(234),
    [anon_sym_u00f7] = ACTIONS(232),
    [anon_sym_STAR_STAR] = ACTIONS(232),
    [anon_sym_u220b] = ACTIONS(232),
    [anon_sym_u220c] = ACTIONS(232),
    [anon_sym_u2287] = ACTIONS(232),
    [anon_sym_u2283] = ACTIONS(232),
    [anon_sym_u2285] = ACTIONS(232),
    [anon_sym_u2208] = ACTIONS(232),
    [anon_sym_u2209] = ACTIONS(232),
    [anon_sym_u2286] = ACTIONS(232),
    [anon_sym_u2282] = ACTIONS(232),
    [anon_sym_u2284] = ACTIONS(232),
    [anon_sym_AT_AT] = ACTIONS(232),
  },
  [STATE(138)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(240),
    [sym_keyword_value] = ACTIONS(240),
    [sym_keyword_explain] = ACTIONS(240),
    [sym_keyword_parallel] = ACTIONS(240),
    [sym_keyword_timeout] = ACTIONS(240),
    [sym_keyword_fetch] = ACTIONS(240),
    [sym_keyword_limit] = ACTIONS(240),
    [sym_keyword_rand] = ACTIONS(240),
    [sym_keyword_collate] = ACTIONS(240),
    [sym_keyword_numeric] = ACTIONS(240),
    [sym_keyword_asc] = ACTIONS(240),
    [sym_keyword_desc] = ACTIONS(240),
    [sym_keyword_and] = ACTIONS(240),
    [sym_keyword_or] = ACTIONS(240),
    [sym_keyword_is] = ACTIONS(240),
    [sym_keyword_not] = ACTIONS(242),
    [sym_keyword_contains] = ACTIONS(242),
    [sym_keyword_contains_not] = ACTIONS(240),
    [sym_keyword_contains_all] = ACTIONS(240),
    [sym_keyword_contains_any] = ACTIONS(240),
    [sym_keyword_contains_none] = ACTIONS(240),
    [sym_keyword_inside] = ACTIONS(240),
    [sym_keyword_in] = ACTIONS(242),
    [sym_keyword_not_inside] = ACTIONS(240),
    [sym_keyword_all_inside] = ACTIONS(240),
    [sym_keyword_any_inside] = ACTIONS(240),
    [sym_keyword_none_inside] = ACTIONS(240),
    [sym_keyword_outside] = ACTIONS(240),
    [sym_keyword_intersects] = ACTIONS(240),
    [sym_keyword_flexible] = ACTIONS(240),
    [sym_keyword_readonly] = ACTIONS(240),
    [sym_keyword_type] = ACTIONS(240),
    [sym_keyword_default] = ACTIONS(240),
    [sym_keyword_assert] = ACTIONS(240),
    [sym_keyword_permissions] = ACTIONS(240),
    [sym_keyword_for] = ACTIONS(240),
    [sym_keyword_comment] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_DASH_GT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(240),
    [anon_sym_RBRACE] = ACTIONS(240),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_DASH] = ACTIONS(242),
    [anon_sym_LT_DASH_GT] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_DOT_DOT] = ACTIONS(240),
    [anon_sym_DASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LT_PIPE] = ACTIONS(240),
    [anon_sym_AMP_AMP] = ACTIONS(240),
    [anon_sym_PIPE_PIPE] = ACTIONS(240),
    [anon_sym_QMARK_QMARK] = ACTIONS(240),
    [anon_sym_QMARK_COLON] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_QMARK_EQ] = ACTIONS(240),
    [anon_sym_STAR_EQ] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(240),
    [anon_sym_BANG_TILDE] = ACTIONS(240),
    [anon_sym_STAR_TILDE] = ACTIONS(240),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_PLUS] = ACTIONS(242),
    [anon_sym_PLUS_EQ] = ACTIONS(240),
    [anon_sym_DASH_EQ] = ACTIONS(240),
    [anon_sym_u00d7] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_u00f7] = ACTIONS(240),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_u220b] = ACTIONS(240),
    [anon_sym_u220c] = ACTIONS(240),
    [anon_sym_u2287] = ACTIONS(240),
    [anon_sym_u2283] = ACTIONS(240),
    [anon_sym_u2285] = ACTIONS(240),
    [anon_sym_u2208] = ACTIONS(240),
    [anon_sym_u2209] = ACTIONS(240),
    [anon_sym_u2286] = ACTIONS(240),
    [anon_sym_u2282] = ACTIONS(240),
    [anon_sym_u2284] = ACTIONS(240),
    [anon_sym_AT_AT] = ACTIONS(240),
  },
  [STATE(139)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(248),
    [sym_keyword_value] = ACTIONS(248),
    [sym_keyword_explain] = ACTIONS(248),
    [sym_keyword_parallel] = ACTIONS(248),
    [sym_keyword_timeout] = ACTIONS(248),
    [sym_keyword_fetch] = ACTIONS(248),
    [sym_keyword_limit] = ACTIONS(248),
    [sym_keyword_rand] = ACTIONS(248),
    [sym_keyword_collate] = ACTIONS(248),
    [sym_keyword_numeric] = ACTIONS(248),
    [sym_keyword_asc] = ACTIONS(248),
    [sym_keyword_desc] = ACTIONS(248),
    [sym_keyword_and] = ACTIONS(248),
    [sym_keyword_or] = ACTIONS(248),
    [sym_keyword_is] = ACTIONS(248),
    [sym_keyword_not] = ACTIONS(250),
    [sym_keyword_contains] = ACTIONS(250),
    [sym_keyword_contains_not] = ACTIONS(248),
    [sym_keyword_contains_all] = ACTIONS(248),
    [sym_keyword_contains_any] = ACTIONS(248),
    [sym_keyword_contains_none] = ACTIONS(248),
    [sym_keyword_inside] = ACTIONS(248),
    [sym_keyword_in] = ACTIONS(250),
    [sym_keyword_not_inside] = ACTIONS(248),
    [sym_keyword_all_inside] = ACTIONS(248),
    [sym_keyword_any_inside] = ACTIONS(248),
    [sym_keyword_none_inside] = ACTIONS(248),
    [sym_keyword_outside] = ACTIONS(248),
    [sym_keyword_intersects] = ACTIONS(248),
    [sym_keyword_flexible] = ACTIONS(248),
    [sym_keyword_readonly] = ACTIONS(248),
    [sym_keyword_type] = ACTIONS(248),
    [sym_keyword_default] = ACTIONS(248),
    [sym_keyword_assert] = ACTIONS(248),
    [sym_keyword_permissions] = ACTIONS(248),
    [sym_keyword_for] = ACTIONS(248),
    [sym_keyword_comment] = ACTIONS(248),
    [anon_sym_EQ] = ACTIONS(250),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_RPAREN] = ACTIONS(248),
    [anon_sym_DASH_GT] = ACTIONS(248),
    [anon_sym_LBRACK] = ACTIONS(248),
    [anon_sym_RBRACE] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_LT_DASH] = ACTIONS(250),
    [anon_sym_LT_DASH_GT] = ACTIONS(248),
    [anon_sym_STAR] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(250),
    [anon_sym_DOT_DOT] = ACTIONS(248),
    [anon_sym_DASH] = ACTIONS(250),
    [anon_sym_PERCENT] = ACTIONS(248),
    [anon_sym_AT] = ACTIONS(250),
    [anon_sym_LT_PIPE] = ACTIONS(248),
    [anon_sym_AMP_AMP] = ACTIONS(248),
    [anon_sym_PIPE_PIPE] = ACTIONS(248),
    [anon_sym_QMARK_QMARK] = ACTIONS(248),
    [anon_sym_QMARK_COLON] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_QMARK_EQ] = ACTIONS(248),
    [anon_sym_STAR_EQ] = ACTIONS(248),
    [anon_sym_TILDE] = ACTIONS(248),
    [anon_sym_BANG_TILDE] = ACTIONS(248),
    [anon_sym_STAR_TILDE] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(250),
    [anon_sym_PLUS_EQ] = ACTIONS(248),
    [anon_sym_DASH_EQ] = ACTIONS(248),
    [anon_sym_u00d7] = ACTIONS(248),
    [anon_sym_SLASH] = ACTIONS(250),
    [anon_sym_u00f7] = ACTIONS(248),
    [anon_sym_STAR_STAR] = ACTIONS(248),
    [anon_sym_u220b] = ACTIONS(248),
    [anon_sym_u220c] = ACTIONS(248),
    [anon_sym_u2287] = ACTIONS(248),
    [anon_sym_u2283] = ACTIONS(248),
    [anon_sym_u2285] = ACTIONS(248),
    [anon_sym_u2208] = ACTIONS(248),
    [anon_sym_u2209] = ACTIONS(248),
    [anon_sym_u2286] = ACTIONS(248),
    [anon_sym_u2282] = ACTIONS(248),
    [anon_sym_u2284] = ACTIONS(248),
    [anon_sym_AT_AT] = ACTIONS(248),
  },
  [STATE(140)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(256),
    [sym_keyword_value] = ACTIONS(256),
    [sym_keyword_explain] = ACTIONS(256),
    [sym_keyword_parallel] = ACTIONS(256),
    [sym_keyword_timeout] = ACTIONS(256),
    [sym_keyword_fetch] = ACTIONS(256),
    [sym_keyword_limit] = ACTIONS(256),
    [sym_keyword_rand] = ACTIONS(256),
    [sym_keyword_collate] = ACTIONS(256),
    [sym_keyword_numeric] = ACTIONS(256),
    [sym_keyword_asc] = ACTIONS(256),
    [sym_keyword_desc] = ACTIONS(256),
    [sym_keyword_and] = ACTIONS(256),
    [sym_keyword_or] = ACTIONS(256),
    [sym_keyword_is] = ACTIONS(256),
    [sym_keyword_not] = ACTIONS(258),
    [sym_keyword_contains] = ACTIONS(258),
    [sym_keyword_contains_not] = ACTIONS(256),
    [sym_keyword_contains_all] = ACTIONS(256),
    [sym_keyword_contains_any] = ACTIONS(256),
    [sym_keyword_contains_none] = ACTIONS(256),
    [sym_keyword_inside] = ACTIONS(256),
    [sym_keyword_in] = ACTIONS(258),
    [sym_keyword_not_inside] = ACTIONS(256),
    [sym_keyword_all_inside] = ACTIONS(256),
    [sym_keyword_any_inside] = ACTIONS(256),
    [sym_keyword_none_inside] = ACTIONS(256),
    [sym_keyword_outside] = ACTIONS(256),
    [sym_keyword_intersects] = ACTIONS(256),
    [sym_keyword_flexible] = ACTIONS(256),
    [sym_keyword_readonly] = ACTIONS(256),
    [sym_keyword_type] = ACTIONS(256),
    [sym_keyword_default] = ACTIONS(256),
    [sym_keyword_assert] = ACTIONS(256),
    [sym_keyword_permissions] = ACTIONS(256),
    [sym_keyword_for] = ACTIONS(256),
    [sym_keyword_comment] = ACTIONS(256),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_COMMA] = ACTIONS(256),
    [anon_sym_RPAREN] = ACTIONS(256),
    [anon_sym_DASH_GT] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(256),
    [anon_sym_RBRACE] = ACTIONS(256),
    [anon_sym_LT] = ACTIONS(258),
    [anon_sym_GT] = ACTIONS(258),
    [anon_sym_LT_DASH] = ACTIONS(258),
    [anon_sym_LT_DASH_GT] = ACTIONS(256),
    [anon_sym_STAR] = ACTIONS(258),
    [anon_sym_DOT] = ACTIONS(258),
    [anon_sym_DOT_DOT] = ACTIONS(256),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_PERCENT] = ACTIONS(256),
    [anon_sym_AT] = ACTIONS(258),
    [anon_sym_LT_PIPE] = ACTIONS(256),
    [anon_sym_AMP_AMP] = ACTIONS(256),
    [anon_sym_PIPE_PIPE] = ACTIONS(256),
    [anon_sym_QMARK_QMARK] = ACTIONS(256),
    [anon_sym_QMARK_COLON] = ACTIONS(256),
    [anon_sym_BANG_EQ] = ACTIONS(256),
    [anon_sym_EQ_EQ] = ACTIONS(256),
    [anon_sym_QMARK_EQ] = ACTIONS(256),
    [anon_sym_STAR_EQ] = ACTIONS(256),
    [anon_sym_TILDE] = ACTIONS(256),
    [anon_sym_BANG_TILDE] = ACTIONS(256),
    [anon_sym_STAR_TILDE] = ACTIONS(256),
    [anon_sym_LT_EQ] = ACTIONS(256),
    [anon_sym_GT_EQ] = ACTIONS(256),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_PLUS_EQ] = ACTIONS(256),
    [anon_sym_DASH_EQ] = ACTIONS(256),
    [anon_sym_u00d7] = ACTIONS(256),
    [anon_sym_SLASH] = ACTIONS(258),
    [anon_sym_u00f7] = ACTIONS(256),
    [anon_sym_STAR_STAR] = ACTIONS(256),
    [anon_sym_u220b] = ACTIONS(256),
    [anon_sym_u220c] = ACTIONS(256),
    [anon_sym_u2287] = ACTIONS(256),
    [anon_sym_u2283] = ACTIONS(256),
    [anon_sym_u2285] = ACTIONS(256),
    [anon_sym_u2208] = ACTIONS(256),
    [anon_sym_u2209] = ACTIONS(256),
    [anon_sym_u2286] = ACTIONS(256),
    [anon_sym_u2282] = ACTIONS(256),
    [anon_sym_u2284] = ACTIONS(256),
    [anon_sym_AT_AT] = ACTIONS(256),
  },
  [STATE(141)] = {
    [ts_builtin_sym_end] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_value] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_order] = ACTIONS(93),
    [sym_keyword_with] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_split] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_flexible] = ACTIONS(93),
    [sym_keyword_readonly] = ACTIONS(93),
    [sym_keyword_type] = ACTIONS(93),
    [sym_keyword_default] = ACTIONS(93),
    [sym_keyword_assert] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(142)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_value] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_rand] = ACTIONS(93),
    [sym_keyword_collate] = ACTIONS(93),
    [sym_keyword_numeric] = ACTIONS(93),
    [sym_keyword_asc] = ACTIONS(93),
    [sym_keyword_desc] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_flexible] = ACTIONS(93),
    [sym_keyword_readonly] = ACTIONS(93),
    [sym_keyword_type] = ACTIONS(93),
    [sym_keyword_default] = ACTIONS(93),
    [sym_keyword_assert] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(143)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(244),
    [sym_keyword_value] = ACTIONS(244),
    [sym_keyword_explain] = ACTIONS(244),
    [sym_keyword_parallel] = ACTIONS(244),
    [sym_keyword_timeout] = ACTIONS(244),
    [sym_keyword_fetch] = ACTIONS(244),
    [sym_keyword_limit] = ACTIONS(244),
    [sym_keyword_rand] = ACTIONS(244),
    [sym_keyword_collate] = ACTIONS(244),
    [sym_keyword_numeric] = ACTIONS(244),
    [sym_keyword_asc] = ACTIONS(244),
    [sym_keyword_desc] = ACTIONS(244),
    [sym_keyword_and] = ACTIONS(244),
    [sym_keyword_or] = ACTIONS(244),
    [sym_keyword_is] = ACTIONS(244),
    [sym_keyword_not] = ACTIONS(246),
    [sym_keyword_contains] = ACTIONS(246),
    [sym_keyword_contains_not] = ACTIONS(244),
    [sym_keyword_contains_all] = ACTIONS(244),
    [sym_keyword_contains_any] = ACTIONS(244),
    [sym_keyword_contains_none] = ACTIONS(244),
    [sym_keyword_inside] = ACTIONS(244),
    [sym_keyword_in] = ACTIONS(246),
    [sym_keyword_not_inside] = ACTIONS(244),
    [sym_keyword_all_inside] = ACTIONS(244),
    [sym_keyword_any_inside] = ACTIONS(244),
    [sym_keyword_none_inside] = ACTIONS(244),
    [sym_keyword_outside] = ACTIONS(244),
    [sym_keyword_intersects] = ACTIONS(244),
    [sym_keyword_flexible] = ACTIONS(244),
    [sym_keyword_readonly] = ACTIONS(244),
    [sym_keyword_type] = ACTIONS(244),
    [sym_keyword_default] = ACTIONS(244),
    [sym_keyword_assert] = ACTIONS(244),
    [sym_keyword_permissions] = ACTIONS(244),
    [sym_keyword_for] = ACTIONS(244),
    [sym_keyword_comment] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(246),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_DASH_GT] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(244),
    [anon_sym_RBRACE] = ACTIONS(244),
    [anon_sym_LT] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(246),
    [anon_sym_LT_DASH] = ACTIONS(246),
    [anon_sym_LT_DASH_GT] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(246),
    [anon_sym_DOT_DOT] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(246),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_AT] = ACTIONS(246),
    [anon_sym_LT_PIPE] = ACTIONS(244),
    [anon_sym_AMP_AMP] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(244),
    [anon_sym_QMARK_QMARK] = ACTIONS(244),
    [anon_sym_QMARK_COLON] = ACTIONS(244),
    [anon_sym_BANG_EQ] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(244),
    [anon_sym_QMARK_EQ] = ACTIONS(244),
    [anon_sym_STAR_EQ] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_BANG_TILDE] = ACTIONS(244),
    [anon_sym_STAR_TILDE] = ACTIONS(244),
    [anon_sym_LT_EQ] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(246),
    [anon_sym_PLUS_EQ] = ACTIONS(244),
    [anon_sym_DASH_EQ] = ACTIONS(244),
    [anon_sym_u00d7] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(246),
    [anon_sym_u00f7] = ACTIONS(244),
    [anon_sym_STAR_STAR] = ACTIONS(244),
    [anon_sym_u220b] = ACTIONS(244),
    [anon_sym_u220c] = ACTIONS(244),
    [anon_sym_u2287] = ACTIONS(244),
    [anon_sym_u2283] = ACTIONS(244),
    [anon_sym_u2285] = ACTIONS(244),
    [anon_sym_u2208] = ACTIONS(244),
    [anon_sym_u2209] = ACTIONS(244),
    [anon_sym_u2286] = ACTIONS(244),
    [anon_sym_u2282] = ACTIONS(244),
    [anon_sym_u2284] = ACTIONS(244),
    [anon_sym_AT_AT] = ACTIONS(244),
  },
  [STATE(144)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(208),
    [sym_keyword_value] = ACTIONS(208),
    [sym_keyword_explain] = ACTIONS(208),
    [sym_keyword_parallel] = ACTIONS(208),
    [sym_keyword_timeout] = ACTIONS(208),
    [sym_keyword_fetch] = ACTIONS(208),
    [sym_keyword_limit] = ACTIONS(208),
    [sym_keyword_rand] = ACTIONS(208),
    [sym_keyword_collate] = ACTIONS(208),
    [sym_keyword_numeric] = ACTIONS(208),
    [sym_keyword_asc] = ACTIONS(208),
    [sym_keyword_desc] = ACTIONS(208),
    [sym_keyword_and] = ACTIONS(208),
    [sym_keyword_or] = ACTIONS(208),
    [sym_keyword_is] = ACTIONS(208),
    [sym_keyword_not] = ACTIONS(210),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(208),
    [sym_keyword_contains_all] = ACTIONS(208),
    [sym_keyword_contains_any] = ACTIONS(208),
    [sym_keyword_contains_none] = ACTIONS(208),
    [sym_keyword_inside] = ACTIONS(208),
    [sym_keyword_in] = ACTIONS(210),
    [sym_keyword_not_inside] = ACTIONS(208),
    [sym_keyword_all_inside] = ACTIONS(208),
    [sym_keyword_any_inside] = ACTIONS(208),
    [sym_keyword_none_inside] = ACTIONS(208),
    [sym_keyword_outside] = ACTIONS(208),
    [sym_keyword_intersects] = ACTIONS(208),
    [sym_keyword_flexible] = ACTIONS(208),
    [sym_keyword_readonly] = ACTIONS(208),
    [sym_keyword_type] = ACTIONS(208),
    [sym_keyword_default] = ACTIONS(208),
    [sym_keyword_assert] = ACTIONS(208),
    [sym_keyword_permissions] = ACTIONS(208),
    [sym_keyword_for] = ACTIONS(208),
    [sym_keyword_comment] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(208),
    [anon_sym_RPAREN] = ACTIONS(208),
    [anon_sym_DASH_GT] = ACTIONS(208),
    [anon_sym_LBRACK] = ACTIONS(208),
    [anon_sym_RBRACE] = ACTIONS(208),
    [anon_sym_LT] = ACTIONS(210),
    [anon_sym_GT] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(210),
    [anon_sym_LT_DASH_GT] = ACTIONS(208),
    [anon_sym_STAR] = ACTIONS(210),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_DOT_DOT] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(210),
    [anon_sym_PERCENT] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(210),
    [anon_sym_LT_PIPE] = ACTIONS(208),
    [anon_sym_AMP_AMP] = ACTIONS(208),
    [anon_sym_PIPE_PIPE] = ACTIONS(208),
    [anon_sym_QMARK_QMARK] = ACTIONS(208),
    [anon_sym_QMARK_COLON] = ACTIONS(208),
    [anon_sym_BANG_EQ] = ACTIONS(208),
    [anon_sym_EQ_EQ] = ACTIONS(208),
    [anon_sym_QMARK_EQ] = ACTIONS(208),
    [anon_sym_STAR_EQ] = ACTIONS(208),
    [anon_sym_TILDE] = ACTIONS(208),
    [anon_sym_BANG_TILDE] = ACTIONS(208),
    [anon_sym_STAR_TILDE] = ACTIONS(208),
    [anon_sym_LT_EQ] = ACTIONS(208),
    [anon_sym_GT_EQ] = ACTIONS(208),
    [anon_sym_PLUS] = ACTIONS(210),
    [anon_sym_PLUS_EQ] = ACTIONS(208),
    [anon_sym_DASH_EQ] = ACTIONS(208),
    [anon_sym_u00d7] = ACTIONS(208),
    [anon_sym_SLASH] = ACTIONS(210),
    [anon_sym_u00f7] = ACTIONS(208),
    [anon_sym_STAR_STAR] = ACTIONS(208),
    [anon_sym_u220b] = ACTIONS(208),
    [anon_sym_u220c] = ACTIONS(208),
    [anon_sym_u2287] = ACTIONS(208),
    [anon_sym_u2283] = ACTIONS(208),
    [anon_sym_u2285] = ACTIONS(208),
    [anon_sym_u2208] = ACTIONS(208),
    [anon_sym_u2209] = ACTIONS(208),
    [anon_sym_u2286] = ACTIONS(208),
    [anon_sym_u2282] = ACTIONS(208),
    [anon_sym_u2284] = ACTIONS(208),
    [anon_sym_AT_AT] = ACTIONS(208),
  },
  [STATE(145)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_value] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_rand] = ACTIONS(186),
    [sym_keyword_collate] = ACTIONS(186),
    [sym_keyword_numeric] = ACTIONS(186),
    [sym_keyword_asc] = ACTIONS(186),
    [sym_keyword_desc] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_flexible] = ACTIONS(186),
    [sym_keyword_readonly] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_default] = ACTIONS(186),
    [sym_keyword_assert] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(188),
    [anon_sym_DOT_DOT] = ACTIONS(441),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(146)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(326),
    [sym_keyword_value] = ACTIONS(326),
    [sym_keyword_explain] = ACTIONS(326),
    [sym_keyword_parallel] = ACTIONS(326),
    [sym_keyword_timeout] = ACTIONS(326),
    [sym_keyword_fetch] = ACTIONS(326),
    [sym_keyword_limit] = ACTIONS(326),
    [sym_keyword_rand] = ACTIONS(326),
    [sym_keyword_collate] = ACTIONS(326),
    [sym_keyword_numeric] = ACTIONS(326),
    [sym_keyword_asc] = ACTIONS(326),
    [sym_keyword_desc] = ACTIONS(326),
    [sym_keyword_and] = ACTIONS(326),
    [sym_keyword_or] = ACTIONS(326),
    [sym_keyword_is] = ACTIONS(326),
    [sym_keyword_not] = ACTIONS(328),
    [sym_keyword_contains] = ACTIONS(328),
    [sym_keyword_contains_not] = ACTIONS(326),
    [sym_keyword_contains_all] = ACTIONS(326),
    [sym_keyword_contains_any] = ACTIONS(326),
    [sym_keyword_contains_none] = ACTIONS(326),
    [sym_keyword_inside] = ACTIONS(326),
    [sym_keyword_in] = ACTIONS(328),
    [sym_keyword_not_inside] = ACTIONS(326),
    [sym_keyword_all_inside] = ACTIONS(326),
    [sym_keyword_any_inside] = ACTIONS(326),
    [sym_keyword_none_inside] = ACTIONS(326),
    [sym_keyword_outside] = ACTIONS(326),
    [sym_keyword_intersects] = ACTIONS(326),
    [sym_keyword_flexible] = ACTIONS(326),
    [sym_keyword_readonly] = ACTIONS(326),
    [sym_keyword_type] = ACTIONS(326),
    [sym_keyword_default] = ACTIONS(326),
    [sym_keyword_assert] = ACTIONS(326),
    [sym_keyword_permissions] = ACTIONS(326),
    [sym_keyword_for] = ACTIONS(326),
    [sym_keyword_comment] = ACTIONS(326),
    [anon_sym_EQ] = ACTIONS(328),
    [anon_sym_COMMA] = ACTIONS(326),
    [anon_sym_RPAREN] = ACTIONS(326),
    [anon_sym_DASH_GT] = ACTIONS(326),
    [anon_sym_LBRACK] = ACTIONS(326),
    [anon_sym_RBRACE] = ACTIONS(326),
    [anon_sym_LT] = ACTIONS(328),
    [anon_sym_GT] = ACTIONS(328),
    [anon_sym_LT_DASH] = ACTIONS(328),
    [anon_sym_LT_DASH_GT] = ACTIONS(326),
    [anon_sym_STAR] = ACTIONS(328),
    [anon_sym_DOT] = ACTIONS(326),
    [anon_sym_DASH] = ACTIONS(328),
    [anon_sym_PERCENT] = ACTIONS(326),
    [anon_sym_AT] = ACTIONS(328),
    [anon_sym_LT_PIPE] = ACTIONS(326),
    [anon_sym_AMP_AMP] = ACTIONS(326),
    [anon_sym_PIPE_PIPE] = ACTIONS(326),
    [anon_sym_QMARK_QMARK] = ACTIONS(326),
    [anon_sym_QMARK_COLON] = ACTIONS(326),
    [anon_sym_BANG_EQ] = ACTIONS(326),
    [anon_sym_EQ_EQ] = ACTIONS(326),
    [anon_sym_QMARK_EQ] = ACTIONS(326),
    [anon_sym_STAR_EQ] = ACTIONS(326),
    [anon_sym_TILDE] = ACTIONS(326),
    [anon_sym_BANG_TILDE] = ACTIONS(326),
    [anon_sym_STAR_TILDE] = ACTIONS(326),
    [anon_sym_LT_EQ] = ACTIONS(326),
    [anon_sym_GT_EQ] = ACTIONS(326),
    [anon_sym_PLUS] = ACTIONS(328),
    [anon_sym_PLUS_EQ] = ACTIONS(326),
    [anon_sym_DASH_EQ] = ACTIONS(326),
    [anon_sym_u00d7] = ACTIONS(326),
    [anon_sym_SLASH] = ACTIONS(328),
    [anon_sym_u00f7] = ACTIONS(326),
    [anon_sym_STAR_STAR] = ACTIONS(326),
    [anon_sym_u220b] = ACTIONS(326),
    [anon_sym_u220c] = ACTIONS(326),
    [anon_sym_u2287] = ACTIONS(326),
    [anon_sym_u2283] = ACTIONS(326),
    [anon_sym_u2285] = ACTIONS(326),
    [anon_sym_u2208] = ACTIONS(326),
    [anon_sym_u2209] = ACTIONS(326),
    [anon_sym_u2286] = ACTIONS(326),
    [anon_sym_u2282] = ACTIONS(326),
    [anon_sym_u2284] = ACTIONS(326),
    [anon_sym_AT_AT] = ACTIONS(326),
  },
  [STATE(147)] = {
    [ts_builtin_sym_end] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_value] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_rand] = ACTIONS(93),
    [sym_keyword_collate] = ACTIONS(93),
    [sym_keyword_numeric] = ACTIONS(93),
    [sym_keyword_asc] = ACTIONS(93),
    [sym_keyword_desc] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(93),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [sym_keyword_flexible] = ACTIONS(93),
    [sym_keyword_readonly] = ACTIONS(93),
    [sym_keyword_type] = ACTIONS(93),
    [sym_keyword_default] = ACTIONS(93),
    [sym_keyword_assert] = ACTIONS(93),
    [sym_keyword_permissions] = ACTIONS(93),
    [sym_keyword_for] = ACTIONS(93),
    [sym_keyword_comment] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(148)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_value] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_rand] = ACTIONS(304),
    [sym_keyword_collate] = ACTIONS(304),
    [sym_keyword_numeric] = ACTIONS(304),
    [sym_keyword_asc] = ACTIONS(304),
    [sym_keyword_desc] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(304),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [sym_keyword_flexible] = ACTIONS(304),
    [sym_keyword_readonly] = ACTIONS(304),
    [sym_keyword_type] = ACTIONS(304),
    [sym_keyword_default] = ACTIONS(304),
    [sym_keyword_assert] = ACTIONS(304),
    [sym_keyword_permissions] = ACTIONS(304),
    [sym_keyword_for] = ACTIONS(304),
    [sym_keyword_comment] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_RPAREN] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(149)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_value] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_rand] = ACTIONS(186),
    [sym_keyword_collate] = ACTIONS(186),
    [sym_keyword_numeric] = ACTIONS(186),
    [sym_keyword_asc] = ACTIONS(186),
    [sym_keyword_desc] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(186),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [sym_keyword_flexible] = ACTIONS(186),
    [sym_keyword_readonly] = ACTIONS(186),
    [sym_keyword_type] = ACTIONS(186),
    [sym_keyword_default] = ACTIONS(186),
    [sym_keyword_assert] = ACTIONS(186),
    [sym_keyword_permissions] = ACTIONS(186),
    [sym_keyword_for] = ACTIONS(186),
    [sym_keyword_comment] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(150)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(310),
    [sym_keyword_value] = ACTIONS(310),
    [sym_keyword_explain] = ACTIONS(310),
    [sym_keyword_parallel] = ACTIONS(310),
    [sym_keyword_timeout] = ACTIONS(310),
    [sym_keyword_fetch] = ACTIONS(310),
    [sym_keyword_limit] = ACTIONS(310),
    [sym_keyword_rand] = ACTIONS(310),
    [sym_keyword_collate] = ACTIONS(310),
    [sym_keyword_numeric] = ACTIONS(310),
    [sym_keyword_asc] = ACTIONS(310),
    [sym_keyword_desc] = ACTIONS(310),
    [sym_keyword_and] = ACTIONS(310),
    [sym_keyword_or] = ACTIONS(310),
    [sym_keyword_is] = ACTIONS(310),
    [sym_keyword_not] = ACTIONS(312),
    [sym_keyword_contains] = ACTIONS(312),
    [sym_keyword_contains_not] = ACTIONS(310),
    [sym_keyword_contains_all] = ACTIONS(310),
    [sym_keyword_contains_any] = ACTIONS(310),
    [sym_keyword_contains_none] = ACTIONS(310),
    [sym_keyword_inside] = ACTIONS(310),
    [sym_keyword_in] = ACTIONS(312),
    [sym_keyword_not_inside] = ACTIONS(310),
    [sym_keyword_all_inside] = ACTIONS(310),
    [sym_keyword_any_inside] = ACTIONS(310),
    [sym_keyword_none_inside] = ACTIONS(310),
    [sym_keyword_outside] = ACTIONS(310),
    [sym_keyword_intersects] = ACTIONS(310),
    [sym_keyword_flexible] = ACTIONS(310),
    [sym_keyword_readonly] = ACTIONS(310),
    [sym_keyword_type] = ACTIONS(310),
    [sym_keyword_default] = ACTIONS(310),
    [sym_keyword_assert] = ACTIONS(310),
    [sym_keyword_permissions] = ACTIONS(310),
    [sym_keyword_for] = ACTIONS(310),
    [sym_keyword_comment] = ACTIONS(310),
    [anon_sym_EQ] = ACTIONS(312),
    [anon_sym_COMMA] = ACTIONS(310),
    [anon_sym_RPAREN] = ACTIONS(310),
    [anon_sym_DASH_GT] = ACTIONS(310),
    [anon_sym_LBRACK] = ACTIONS(310),
    [anon_sym_RBRACE] = ACTIONS(310),
    [anon_sym_LT] = ACTIONS(312),
    [anon_sym_GT] = ACTIONS(312),
    [anon_sym_LT_DASH] = ACTIONS(312),
    [anon_sym_LT_DASH_GT] = ACTIONS(310),
    [anon_sym_STAR] = ACTIONS(312),
    [anon_sym_DOT] = ACTIONS(310),
    [anon_sym_DASH] = ACTIONS(312),
    [anon_sym_PERCENT] = ACTIONS(310),
    [anon_sym_AT] = ACTIONS(312),
    [anon_sym_LT_PIPE] = ACTIONS(310),
    [anon_sym_AMP_AMP] = ACTIONS(310),
    [anon_sym_PIPE_PIPE] = ACTIONS(310),
    [anon_sym_QMARK_QMARK] = ACTIONS(310),
    [anon_sym_QMARK_COLON] = ACTIONS(310),
    [anon_sym_BANG_EQ] = ACTIONS(310),
    [anon_sym_EQ_EQ] = ACTIONS(310),
    [anon_sym_QMARK_EQ] = ACTIONS(310),
    [anon_sym_STAR_EQ] = ACTIONS(310),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG_TILDE] = ACTIONS(310),
    [anon_sym_STAR_TILDE] = ACTIONS(310),
    [anon_sym_LT_EQ] = ACTIONS(310),
    [anon_sym_GT_EQ] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(312),
    [anon_sym_PLUS_EQ] = ACTIONS(310),
    [anon_sym_DASH_EQ] = ACTIONS(310),
    [anon_sym_u00d7] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(312),
    [anon_sym_u00f7] = ACTIONS(310),
    [anon_sym_STAR_STAR] = ACTIONS(310),
    [anon_sym_u220b] = ACTIONS(310),
    [anon_sym_u220c] = ACTIONS(310),
    [anon_sym_u2287] = ACTIONS(310),
    [anon_sym_u2283] = ACTIONS(310),
    [anon_sym_u2285] = ACTIONS(310),
    [anon_sym_u2208] = ACTIONS(310),
    [anon_sym_u2209] = ACTIONS(310),
    [anon_sym_u2286] = ACTIONS(310),
    [anon_sym_u2282] = ACTIONS(310),
    [anon_sym_u2284] = ACTIONS(310),
    [anon_sym_AT_AT] = ACTIONS(310),
  },
  [STATE(151)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(347),
    [sym_keyword_value] = ACTIONS(347),
    [sym_keyword_explain] = ACTIONS(347),
    [sym_keyword_parallel] = ACTIONS(347),
    [sym_keyword_timeout] = ACTIONS(347),
    [sym_keyword_fetch] = ACTIONS(347),
    [sym_keyword_limit] = ACTIONS(347),
    [sym_keyword_rand] = ACTIONS(347),
    [sym_keyword_collate] = ACTIONS(347),
    [sym_keyword_numeric] = ACTIONS(347),
    [sym_keyword_asc] = ACTIONS(347),
    [sym_keyword_desc] = ACTIONS(347),
    [sym_keyword_and] = ACTIONS(347),
    [sym_keyword_or] = ACTIONS(347),
    [sym_keyword_is] = ACTIONS(347),
    [sym_keyword_not] = ACTIONS(349),
    [sym_keyword_contains] = ACTIONS(349),
    [sym_keyword_contains_not] = ACTIONS(347),
    [sym_keyword_contains_all] = ACTIONS(347),
    [sym_keyword_contains_any] = ACTIONS(347),
    [sym_keyword_contains_none] = ACTIONS(347),
    [sym_keyword_inside] = ACTIONS(347),
    [sym_keyword_in] = ACTIONS(349),
    [sym_keyword_not_inside] = ACTIONS(347),
    [sym_keyword_all_inside] = ACTIONS(347),
    [sym_keyword_any_inside] = ACTIONS(347),
    [sym_keyword_none_inside] = ACTIONS(347),
    [sym_keyword_outside] = ACTIONS(347),
    [sym_keyword_intersects] = ACTIONS(347),
    [sym_keyword_flexible] = ACTIONS(347),
    [sym_keyword_readonly] = ACTIONS(347),
    [sym_keyword_type] = ACTIONS(347),
    [sym_keyword_default] = ACTIONS(347),
    [sym_keyword_assert] = ACTIONS(347),
    [sym_keyword_permissions] = ACTIONS(347),
    [sym_keyword_for] = ACTIONS(347),
    [sym_keyword_comment] = ACTIONS(347),
    [anon_sym_EQ] = ACTIONS(349),
    [anon_sym_COMMA] = ACTIONS(347),
    [anon_sym_RPAREN] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(347),
    [anon_sym_LBRACK] = ACTIONS(347),
    [anon_sym_RBRACE] = ACTIONS(347),
    [anon_sym_LT] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(349),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_DASH_GT] = ACTIONS(347),
    [anon_sym_STAR] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_AT] = ACTIONS(349),
    [anon_sym_LT_PIPE] = ACTIONS(347),
    [anon_sym_AMP_AMP] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(347),
    [anon_sym_QMARK_QMARK] = ACTIONS(347),
    [anon_sym_QMARK_COLON] = ACTIONS(347),
    [anon_sym_BANG_EQ] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(347),
    [anon_sym_QMARK_EQ] = ACTIONS(347),
    [anon_sym_STAR_EQ] = ACTIONS(347),
    [anon_sym_TILDE] = ACTIONS(347),
    [anon_sym_BANG_TILDE] = ACTIONS(347),
    [anon_sym_STAR_TILDE] = ACTIONS(347),
    [anon_sym_LT_EQ] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_PLUS_EQ] = ACTIONS(347),
    [anon_sym_DASH_EQ] = ACTIONS(347),
    [anon_sym_u00d7] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_u00f7] = ACTIONS(347),
    [anon_sym_STAR_STAR] = ACTIONS(347),
    [anon_sym_u220b] = ACTIONS(347),
    [anon_sym_u220c] = ACTIONS(347),
    [anon_sym_u2287] = ACTIONS(347),
    [anon_sym_u2283] = ACTIONS(347),
    [anon_sym_u2285] = ACTIONS(347),
    [anon_sym_u2208] = ACTIONS(347),
    [anon_sym_u2209] = ACTIONS(347),
    [anon_sym_u2286] = ACTIONS(347),
    [anon_sym_u2282] = ACTIONS(347),
    [anon_sym_u2284] = ACTIONS(347),
    [anon_sym_AT_AT] = ACTIONS(347),
  },
  [STATE(152)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_value] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_rand] = ACTIONS(204),
    [sym_keyword_collate] = ACTIONS(204),
    [sym_keyword_numeric] = ACTIONS(204),
    [sym_keyword_asc] = ACTIONS(204),
    [sym_keyword_desc] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_flexible] = ACTIONS(204),
    [sym_keyword_readonly] = ACTIONS(204),
    [sym_keyword_type] = ACTIONS(204),
    [sym_keyword_default] = ACTIONS(204),
    [sym_keyword_assert] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(153)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(359),
    [sym_keyword_value] = ACTIONS(359),
    [sym_keyword_explain] = ACTIONS(359),
    [sym_keyword_parallel] = ACTIONS(359),
    [sym_keyword_timeout] = ACTIONS(359),
    [sym_keyword_fetch] = ACTIONS(359),
    [sym_keyword_limit] = ACTIONS(359),
    [sym_keyword_rand] = ACTIONS(359),
    [sym_keyword_collate] = ACTIONS(359),
    [sym_keyword_numeric] = ACTIONS(359),
    [sym_keyword_asc] = ACTIONS(359),
    [sym_keyword_desc] = ACTIONS(359),
    [sym_keyword_and] = ACTIONS(359),
    [sym_keyword_or] = ACTIONS(359),
    [sym_keyword_is] = ACTIONS(359),
    [sym_keyword_not] = ACTIONS(361),
    [sym_keyword_contains] = ACTIONS(361),
    [sym_keyword_contains_not] = ACTIONS(359),
    [sym_keyword_contains_all] = ACTIONS(359),
    [sym_keyword_contains_any] = ACTIONS(359),
    [sym_keyword_contains_none] = ACTIONS(359),
    [sym_keyword_inside] = ACTIONS(359),
    [sym_keyword_in] = ACTIONS(361),
    [sym_keyword_not_inside] = ACTIONS(359),
    [sym_keyword_all_inside] = ACTIONS(359),
    [sym_keyword_any_inside] = ACTIONS(359),
    [sym_keyword_none_inside] = ACTIONS(359),
    [sym_keyword_outside] = ACTIONS(359),
    [sym_keyword_intersects] = ACTIONS(359),
    [sym_keyword_flexible] = ACTIONS(359),
    [sym_keyword_readonly] = ACTIONS(359),
    [sym_keyword_type] = ACTIONS(359),
    [sym_keyword_default] = ACTIONS(359),
    [sym_keyword_assert] = ACTIONS(359),
    [sym_keyword_permissions] = ACTIONS(359),
    [sym_keyword_for] = ACTIONS(359),
    [sym_keyword_comment] = ACTIONS(359),
    [anon_sym_EQ] = ACTIONS(361),
    [anon_sym_COMMA] = ACTIONS(359),
    [anon_sym_RPAREN] = ACTIONS(359),
    [anon_sym_DASH_GT] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(359),
    [anon_sym_LT] = ACTIONS(361),
    [anon_sym_GT] = ACTIONS(361),
    [anon_sym_LT_DASH] = ACTIONS(361),
    [anon_sym_LT_DASH_GT] = ACTIONS(359),
    [anon_sym_STAR] = ACTIONS(361),
    [anon_sym_DOT] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [anon_sym_PERCENT] = ACTIONS(359),
    [anon_sym_AT] = ACTIONS(361),
    [anon_sym_LT_PIPE] = ACTIONS(359),
    [anon_sym_AMP_AMP] = ACTIONS(359),
    [anon_sym_PIPE_PIPE] = ACTIONS(359),
    [anon_sym_QMARK_QMARK] = ACTIONS(359),
    [anon_sym_QMARK_COLON] = ACTIONS(359),
    [anon_sym_BANG_EQ] = ACTIONS(359),
    [anon_sym_EQ_EQ] = ACTIONS(359),
    [anon_sym_QMARK_EQ] = ACTIONS(359),
    [anon_sym_STAR_EQ] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(359),
    [anon_sym_BANG_TILDE] = ACTIONS(359),
    [anon_sym_STAR_TILDE] = ACTIONS(359),
    [anon_sym_LT_EQ] = ACTIONS(359),
    [anon_sym_GT_EQ] = ACTIONS(359),
    [anon_sym_PLUS] = ACTIONS(361),
    [anon_sym_PLUS_EQ] = ACTIONS(359),
    [anon_sym_DASH_EQ] = ACTIONS(359),
    [anon_sym_u00d7] = ACTIONS(359),
    [anon_sym_SLASH] = ACTIONS(361),
    [anon_sym_u00f7] = ACTIONS(359),
    [anon_sym_STAR_STAR] = ACTIONS(359),
    [anon_sym_u220b] = ACTIONS(359),
    [anon_sym_u220c] = ACTIONS(359),
    [anon_sym_u2287] = ACTIONS(359),
    [anon_sym_u2283] = ACTIONS(359),
    [anon_sym_u2285] = ACTIONS(359),
    [anon_sym_u2208] = ACTIONS(359),
    [anon_sym_u2209] = ACTIONS(359),
    [anon_sym_u2286] = ACTIONS(359),
    [anon_sym_u2282] = ACTIONS(359),
    [anon_sym_u2284] = ACTIONS(359),
    [anon_sym_AT_AT] = ACTIONS(359),
  },
  [STATE(154)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(284),
    [sym_keyword_value] = ACTIONS(284),
    [sym_keyword_explain] = ACTIONS(284),
    [sym_keyword_parallel] = ACTIONS(284),
    [sym_keyword_timeout] = ACTIONS(284),
    [sym_keyword_fetch] = ACTIONS(284),
    [sym_keyword_limit] = ACTIONS(284),
    [sym_keyword_rand] = ACTIONS(284),
    [sym_keyword_collate] = ACTIONS(284),
    [sym_keyword_numeric] = ACTIONS(284),
    [sym_keyword_asc] = ACTIONS(284),
    [sym_keyword_desc] = ACTIONS(284),
    [sym_keyword_and] = ACTIONS(284),
    [sym_keyword_or] = ACTIONS(284),
    [sym_keyword_is] = ACTIONS(284),
    [sym_keyword_not] = ACTIONS(286),
    [sym_keyword_contains] = ACTIONS(286),
    [sym_keyword_contains_not] = ACTIONS(284),
    [sym_keyword_contains_all] = ACTIONS(284),
    [sym_keyword_contains_any] = ACTIONS(284),
    [sym_keyword_contains_none] = ACTIONS(284),
    [sym_keyword_inside] = ACTIONS(284),
    [sym_keyword_in] = ACTIONS(286),
    [sym_keyword_not_inside] = ACTIONS(284),
    [sym_keyword_all_inside] = ACTIONS(284),
    [sym_keyword_any_inside] = ACTIONS(284),
    [sym_keyword_none_inside] = ACTIONS(284),
    [sym_keyword_outside] = ACTIONS(284),
    [sym_keyword_intersects] = ACTIONS(284),
    [sym_keyword_flexible] = ACTIONS(284),
    [sym_keyword_readonly] = ACTIONS(284),
    [sym_keyword_type] = ACTIONS(284),
    [sym_keyword_default] = ACTIONS(284),
    [sym_keyword_assert] = ACTIONS(284),
    [sym_keyword_permissions] = ACTIONS(284),
    [sym_keyword_for] = ACTIONS(284),
    [sym_keyword_comment] = ACTIONS(284),
    [anon_sym_EQ] = ACTIONS(286),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_DASH_GT] = ACTIONS(284),
    [anon_sym_LBRACK] = ACTIONS(284),
    [anon_sym_RBRACE] = ACTIONS(284),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_LT_DASH] = ACTIONS(286),
    [anon_sym_LT_DASH_GT] = ACTIONS(284),
    [anon_sym_STAR] = ACTIONS(286),
    [anon_sym_DOT] = ACTIONS(284),
    [anon_sym_DASH] = ACTIONS(286),
    [anon_sym_PERCENT] = ACTIONS(284),
    [anon_sym_AT] = ACTIONS(286),
    [anon_sym_LT_PIPE] = ACTIONS(284),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_PIPE_PIPE] = ACTIONS(284),
    [anon_sym_QMARK_QMARK] = ACTIONS(284),
    [anon_sym_QMARK_COLON] = ACTIONS(284),
    [anon_sym_BANG_EQ] = ACTIONS(284),
    [anon_sym_EQ_EQ] = ACTIONS(284),
    [anon_sym_QMARK_EQ] = ACTIONS(284),
    [anon_sym_STAR_EQ] = ACTIONS(284),
    [anon_sym_TILDE] = ACTIONS(284),
    [anon_sym_BANG_TILDE] = ACTIONS(284),
    [anon_sym_STAR_TILDE] = ACTIONS(284),
    [anon_sym_LT_EQ] = ACTIONS(284),
    [anon_sym_GT_EQ] = ACTIONS(284),
    [anon_sym_PLUS] = ACTIONS(286),
    [anon_sym_PLUS_EQ] = ACTIONS(284),
    [anon_sym_DASH_EQ] = ACTIONS(284),
    [anon_sym_u00d7] = ACTIONS(284),
    [anon_sym_SLASH] = ACTIONS(286),
    [anon_sym_u00f7] = ACTIONS(284),
    [anon_sym_STAR_STAR] = ACTIONS(284),
    [anon_sym_u220b] = ACTIONS(284),
    [anon_sym_u220c] = ACTIONS(284),
    [anon_sym_u2287] = ACTIONS(284),
    [anon_sym_u2283] = ACTIONS(284),
    [anon_sym_u2285] = ACTIONS(284),
    [anon_sym_u2208] = ACTIONS(284),
    [anon_sym_u2209] = ACTIONS(284),
    [anon_sym_u2286] = ACTIONS(284),
    [anon_sym_u2282] = ACTIONS(284),
    [anon_sym_u2284] = ACTIONS(284),
    [anon_sym_AT_AT] = ACTIONS(284),
  },
  [STATE(155)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(292),
    [sym_keyword_value] = ACTIONS(292),
    [sym_keyword_explain] = ACTIONS(292),
    [sym_keyword_parallel] = ACTIONS(292),
    [sym_keyword_timeout] = ACTIONS(292),
    [sym_keyword_fetch] = ACTIONS(292),
    [sym_keyword_limit] = ACTIONS(292),
    [sym_keyword_rand] = ACTIONS(292),
    [sym_keyword_collate] = ACTIONS(292),
    [sym_keyword_numeric] = ACTIONS(292),
    [sym_keyword_asc] = ACTIONS(292),
    [sym_keyword_desc] = ACTIONS(292),
    [sym_keyword_and] = ACTIONS(292),
    [sym_keyword_or] = ACTIONS(292),
    [sym_keyword_is] = ACTIONS(292),
    [sym_keyword_not] = ACTIONS(294),
    [sym_keyword_contains] = ACTIONS(294),
    [sym_keyword_contains_not] = ACTIONS(292),
    [sym_keyword_contains_all] = ACTIONS(292),
    [sym_keyword_contains_any] = ACTIONS(292),
    [sym_keyword_contains_none] = ACTIONS(292),
    [sym_keyword_inside] = ACTIONS(292),
    [sym_keyword_in] = ACTIONS(294),
    [sym_keyword_not_inside] = ACTIONS(292),
    [sym_keyword_all_inside] = ACTIONS(292),
    [sym_keyword_any_inside] = ACTIONS(292),
    [sym_keyword_none_inside] = ACTIONS(292),
    [sym_keyword_outside] = ACTIONS(292),
    [sym_keyword_intersects] = ACTIONS(292),
    [sym_keyword_flexible] = ACTIONS(292),
    [sym_keyword_readonly] = ACTIONS(292),
    [sym_keyword_type] = ACTIONS(292),
    [sym_keyword_default] = ACTIONS(292),
    [sym_keyword_assert] = ACTIONS(292),
    [sym_keyword_permissions] = ACTIONS(292),
    [sym_keyword_for] = ACTIONS(292),
    [sym_keyword_comment] = ACTIONS(292),
    [anon_sym_EQ] = ACTIONS(294),
    [anon_sym_COMMA] = ACTIONS(292),
    [anon_sym_RPAREN] = ACTIONS(292),
    [anon_sym_DASH_GT] = ACTIONS(292),
    [anon_sym_LBRACK] = ACTIONS(292),
    [anon_sym_RBRACE] = ACTIONS(292),
    [anon_sym_LT] = ACTIONS(294),
    [anon_sym_GT] = ACTIONS(294),
    [anon_sym_LT_DASH] = ACTIONS(294),
    [anon_sym_LT_DASH_GT] = ACTIONS(292),
    [anon_sym_STAR] = ACTIONS(294),
    [anon_sym_DOT] = ACTIONS(292),
    [anon_sym_DASH] = ACTIONS(294),
    [anon_sym_PERCENT] = ACTIONS(292),
    [anon_sym_AT] = ACTIONS(294),
    [anon_sym_LT_PIPE] = ACTIONS(292),
    [anon_sym_AMP_AMP] = ACTIONS(292),
    [anon_sym_PIPE_PIPE] = ACTIONS(292),
    [anon_sym_QMARK_QMARK] = ACTIONS(292),
    [anon_sym_QMARK_COLON] = ACTIONS(292),
    [anon_sym_BANG_EQ] = ACTIONS(292),
    [anon_sym_EQ_EQ] = ACTIONS(292),
    [anon_sym_QMARK_EQ] = ACTIONS(292),
    [anon_sym_STAR_EQ] = ACTIONS(292),
    [anon_sym_TILDE] = ACTIONS(292),
    [anon_sym_BANG_TILDE] = ACTIONS(292),
    [anon_sym_STAR_TILDE] = ACTIONS(292),
    [anon_sym_LT_EQ] = ACTIONS(292),
    [anon_sym_GT_EQ] = ACTIONS(292),
    [anon_sym_PLUS] = ACTIONS(294),
    [anon_sym_PLUS_EQ] = ACTIONS(292),
    [anon_sym_DASH_EQ] = ACTIONS(292),
    [anon_sym_u00d7] = ACTIONS(292),
    [anon_sym_SLASH] = ACTIONS(294),
    [anon_sym_u00f7] = ACTIONS(292),
    [anon_sym_STAR_STAR] = ACTIONS(292),
    [anon_sym_u220b] = ACTIONS(292),
    [anon_sym_u220c] = ACTIONS(292),
    [anon_sym_u2287] = ACTIONS(292),
    [anon_sym_u2283] = ACTIONS(292),
    [anon_sym_u2285] = ACTIONS(292),
    [anon_sym_u2208] = ACTIONS(292),
    [anon_sym_u2209] = ACTIONS(292),
    [anon_sym_u2286] = ACTIONS(292),
    [anon_sym_u2282] = ACTIONS(292),
    [anon_sym_u2284] = ACTIONS(292),
    [anon_sym_AT_AT] = ACTIONS(292),
  },
  [STATE(156)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_value] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_rand] = ACTIONS(190),
    [sym_keyword_collate] = ACTIONS(190),
    [sym_keyword_numeric] = ACTIONS(190),
    [sym_keyword_asc] = ACTIONS(190),
    [sym_keyword_desc] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(190),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(192),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [sym_keyword_flexible] = ACTIONS(190),
    [sym_keyword_readonly] = ACTIONS(190),
    [sym_keyword_type] = ACTIONS(190),
    [sym_keyword_default] = ACTIONS(190),
    [sym_keyword_assert] = ACTIONS(190),
    [sym_keyword_permissions] = ACTIONS(190),
    [sym_keyword_for] = ACTIONS(190),
    [sym_keyword_comment] = ACTIONS(190),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_PERCENT] = ACTIONS(190),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [STATE(157)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_value] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_rand] = ACTIONS(278),
    [sym_keyword_collate] = ACTIONS(278),
    [sym_keyword_numeric] = ACTIONS(278),
    [sym_keyword_asc] = ACTIONS(278),
    [sym_keyword_desc] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(278),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [sym_keyword_flexible] = ACTIONS(278),
    [sym_keyword_readonly] = ACTIONS(278),
    [sym_keyword_type] = ACTIONS(278),
    [sym_keyword_default] = ACTIONS(278),
    [sym_keyword_assert] = ACTIONS(278),
    [sym_keyword_permissions] = ACTIONS(278),
    [sym_keyword_for] = ACTIONS(278),
    [sym_keyword_comment] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(158)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_value] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_rand] = ACTIONS(288),
    [sym_keyword_collate] = ACTIONS(288),
    [sym_keyword_numeric] = ACTIONS(288),
    [sym_keyword_asc] = ACTIONS(288),
    [sym_keyword_desc] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_flexible] = ACTIONS(288),
    [sym_keyword_readonly] = ACTIONS(288),
    [sym_keyword_type] = ACTIONS(288),
    [sym_keyword_default] = ACTIONS(288),
    [sym_keyword_assert] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(290),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(288),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(159)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(260),
    [sym_keyword_value] = ACTIONS(260),
    [sym_keyword_explain] = ACTIONS(260),
    [sym_keyword_parallel] = ACTIONS(260),
    [sym_keyword_timeout] = ACTIONS(260),
    [sym_keyword_fetch] = ACTIONS(260),
    [sym_keyword_limit] = ACTIONS(260),
    [sym_keyword_rand] = ACTIONS(260),
    [sym_keyword_collate] = ACTIONS(260),
    [sym_keyword_numeric] = ACTIONS(260),
    [sym_keyword_asc] = ACTIONS(260),
    [sym_keyword_desc] = ACTIONS(260),
    [sym_keyword_and] = ACTIONS(260),
    [sym_keyword_or] = ACTIONS(260),
    [sym_keyword_is] = ACTIONS(260),
    [sym_keyword_not] = ACTIONS(262),
    [sym_keyword_contains] = ACTIONS(262),
    [sym_keyword_contains_not] = ACTIONS(260),
    [sym_keyword_contains_all] = ACTIONS(260),
    [sym_keyword_contains_any] = ACTIONS(260),
    [sym_keyword_contains_none] = ACTIONS(260),
    [sym_keyword_inside] = ACTIONS(260),
    [sym_keyword_in] = ACTIONS(262),
    [sym_keyword_not_inside] = ACTIONS(260),
    [sym_keyword_all_inside] = ACTIONS(260),
    [sym_keyword_any_inside] = ACTIONS(260),
    [sym_keyword_none_inside] = ACTIONS(260),
    [sym_keyword_outside] = ACTIONS(260),
    [sym_keyword_intersects] = ACTIONS(260),
    [sym_keyword_flexible] = ACTIONS(260),
    [sym_keyword_readonly] = ACTIONS(260),
    [sym_keyword_type] = ACTIONS(260),
    [sym_keyword_default] = ACTIONS(260),
    [sym_keyword_assert] = ACTIONS(260),
    [sym_keyword_permissions] = ACTIONS(260),
    [sym_keyword_for] = ACTIONS(260),
    [sym_keyword_comment] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(262),
    [anon_sym_COMMA] = ACTIONS(260),
    [anon_sym_RPAREN] = ACTIONS(260),
    [anon_sym_DASH_GT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(260),
    [anon_sym_RBRACE] = ACTIONS(260),
    [anon_sym_LT] = ACTIONS(262),
    [anon_sym_GT] = ACTIONS(262),
    [anon_sym_LT_DASH] = ACTIONS(262),
    [anon_sym_LT_DASH_GT] = ACTIONS(260),
    [anon_sym_STAR] = ACTIONS(262),
    [anon_sym_DOT] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(262),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_AT] = ACTIONS(262),
    [anon_sym_LT_PIPE] = ACTIONS(260),
    [anon_sym_AMP_AMP] = ACTIONS(260),
    [anon_sym_PIPE_PIPE] = ACTIONS(260),
    [anon_sym_QMARK_QMARK] = ACTIONS(260),
    [anon_sym_QMARK_COLON] = ACTIONS(260),
    [anon_sym_BANG_EQ] = ACTIONS(260),
    [anon_sym_EQ_EQ] = ACTIONS(260),
    [anon_sym_QMARK_EQ] = ACTIONS(260),
    [anon_sym_STAR_EQ] = ACTIONS(260),
    [anon_sym_TILDE] = ACTIONS(260),
    [anon_sym_BANG_TILDE] = ACTIONS(260),
    [anon_sym_STAR_TILDE] = ACTIONS(260),
    [anon_sym_LT_EQ] = ACTIONS(260),
    [anon_sym_GT_EQ] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(262),
    [anon_sym_PLUS_EQ] = ACTIONS(260),
    [anon_sym_DASH_EQ] = ACTIONS(260),
    [anon_sym_u00d7] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(262),
    [anon_sym_u00f7] = ACTIONS(260),
    [anon_sym_STAR_STAR] = ACTIONS(260),
    [anon_sym_u220b] = ACTIONS(260),
    [anon_sym_u220c] = ACTIONS(260),
    [anon_sym_u2287] = ACTIONS(260),
    [anon_sym_u2283] = ACTIONS(260),
    [anon_sym_u2285] = ACTIONS(260),
    [anon_sym_u2208] = ACTIONS(260),
    [anon_sym_u2209] = ACTIONS(260),
    [anon_sym_u2286] = ACTIONS(260),
    [anon_sym_u2282] = ACTIONS(260),
    [anon_sym_u2284] = ACTIONS(260),
    [anon_sym_AT_AT] = ACTIONS(260),
  },
  [STATE(160)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(296),
    [sym_keyword_value] = ACTIONS(296),
    [sym_keyword_explain] = ACTIONS(296),
    [sym_keyword_parallel] = ACTIONS(296),
    [sym_keyword_timeout] = ACTIONS(296),
    [sym_keyword_fetch] = ACTIONS(296),
    [sym_keyword_limit] = ACTIONS(296),
    [sym_keyword_rand] = ACTIONS(296),
    [sym_keyword_collate] = ACTIONS(296),
    [sym_keyword_numeric] = ACTIONS(296),
    [sym_keyword_asc] = ACTIONS(296),
    [sym_keyword_desc] = ACTIONS(296),
    [sym_keyword_and] = ACTIONS(296),
    [sym_keyword_or] = ACTIONS(296),
    [sym_keyword_is] = ACTIONS(296),
    [sym_keyword_not] = ACTIONS(298),
    [sym_keyword_contains] = ACTIONS(298),
    [sym_keyword_contains_not] = ACTIONS(296),
    [sym_keyword_contains_all] = ACTIONS(296),
    [sym_keyword_contains_any] = ACTIONS(296),
    [sym_keyword_contains_none] = ACTIONS(296),
    [sym_keyword_inside] = ACTIONS(296),
    [sym_keyword_in] = ACTIONS(298),
    [sym_keyword_not_inside] = ACTIONS(296),
    [sym_keyword_all_inside] = ACTIONS(296),
    [sym_keyword_any_inside] = ACTIONS(296),
    [sym_keyword_none_inside] = ACTIONS(296),
    [sym_keyword_outside] = ACTIONS(296),
    [sym_keyword_intersects] = ACTIONS(296),
    [sym_keyword_flexible] = ACTIONS(296),
    [sym_keyword_readonly] = ACTIONS(296),
    [sym_keyword_type] = ACTIONS(296),
    [sym_keyword_default] = ACTIONS(296),
    [sym_keyword_assert] = ACTIONS(296),
    [sym_keyword_permissions] = ACTIONS(296),
    [sym_keyword_for] = ACTIONS(296),
    [sym_keyword_comment] = ACTIONS(296),
    [anon_sym_EQ] = ACTIONS(298),
    [anon_sym_COMMA] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(296),
    [anon_sym_DASH_GT] = ACTIONS(296),
    [anon_sym_LBRACK] = ACTIONS(296),
    [anon_sym_RBRACE] = ACTIONS(296),
    [anon_sym_LT] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(298),
    [anon_sym_LT_DASH] = ACTIONS(298),
    [anon_sym_LT_DASH_GT] = ACTIONS(296),
    [anon_sym_STAR] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(296),
    [anon_sym_DASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(296),
    [anon_sym_AT] = ACTIONS(298),
    [anon_sym_LT_PIPE] = ACTIONS(296),
    [anon_sym_AMP_AMP] = ACTIONS(296),
    [anon_sym_PIPE_PIPE] = ACTIONS(296),
    [anon_sym_QMARK_QMARK] = ACTIONS(296),
    [anon_sym_QMARK_COLON] = ACTIONS(296),
    [anon_sym_BANG_EQ] = ACTIONS(296),
    [anon_sym_EQ_EQ] = ACTIONS(296),
    [anon_sym_QMARK_EQ] = ACTIONS(296),
    [anon_sym_STAR_EQ] = ACTIONS(296),
    [anon_sym_TILDE] = ACTIONS(296),
    [anon_sym_BANG_TILDE] = ACTIONS(296),
    [anon_sym_STAR_TILDE] = ACTIONS(296),
    [anon_sym_LT_EQ] = ACTIONS(296),
    [anon_sym_GT_EQ] = ACTIONS(296),
    [anon_sym_PLUS] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(296),
    [anon_sym_DASH_EQ] = ACTIONS(296),
    [anon_sym_u00d7] = ACTIONS(296),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_u00f7] = ACTIONS(296),
    [anon_sym_STAR_STAR] = ACTIONS(296),
    [anon_sym_u220b] = ACTIONS(296),
    [anon_sym_u220c] = ACTIONS(296),
    [anon_sym_u2287] = ACTIONS(296),
    [anon_sym_u2283] = ACTIONS(296),
    [anon_sym_u2285] = ACTIONS(296),
    [anon_sym_u2208] = ACTIONS(296),
    [anon_sym_u2209] = ACTIONS(296),
    [anon_sym_u2286] = ACTIONS(296),
    [anon_sym_u2282] = ACTIONS(296),
    [anon_sym_u2284] = ACTIONS(296),
    [anon_sym_AT_AT] = ACTIONS(296),
  },
  [STATE(161)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(343),
    [sym_keyword_value] = ACTIONS(343),
    [sym_keyword_explain] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(343),
    [sym_keyword_timeout] = ACTIONS(343),
    [sym_keyword_fetch] = ACTIONS(343),
    [sym_keyword_limit] = ACTIONS(343),
    [sym_keyword_rand] = ACTIONS(343),
    [sym_keyword_collate] = ACTIONS(343),
    [sym_keyword_numeric] = ACTIONS(343),
    [sym_keyword_asc] = ACTIONS(343),
    [sym_keyword_desc] = ACTIONS(343),
    [sym_keyword_and] = ACTIONS(343),
    [sym_keyword_or] = ACTIONS(343),
    [sym_keyword_is] = ACTIONS(343),
    [sym_keyword_not] = ACTIONS(345),
    [sym_keyword_contains] = ACTIONS(345),
    [sym_keyword_contains_not] = ACTIONS(343),
    [sym_keyword_contains_all] = ACTIONS(343),
    [sym_keyword_contains_any] = ACTIONS(343),
    [sym_keyword_contains_none] = ACTIONS(343),
    [sym_keyword_inside] = ACTIONS(343),
    [sym_keyword_in] = ACTIONS(345),
    [sym_keyword_not_inside] = ACTIONS(343),
    [sym_keyword_all_inside] = ACTIONS(343),
    [sym_keyword_any_inside] = ACTIONS(343),
    [sym_keyword_none_inside] = ACTIONS(343),
    [sym_keyword_outside] = ACTIONS(343),
    [sym_keyword_intersects] = ACTIONS(343),
    [sym_keyword_flexible] = ACTIONS(343),
    [sym_keyword_readonly] = ACTIONS(343),
    [sym_keyword_type] = ACTIONS(343),
    [sym_keyword_default] = ACTIONS(343),
    [sym_keyword_assert] = ACTIONS(343),
    [sym_keyword_permissions] = ACTIONS(343),
    [sym_keyword_for] = ACTIONS(343),
    [sym_keyword_comment] = ACTIONS(343),
    [anon_sym_EQ] = ACTIONS(345),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_RPAREN] = ACTIONS(343),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(343),
    [anon_sym_RBRACE] = ACTIONS(343),
    [anon_sym_LT] = ACTIONS(345),
    [anon_sym_GT] = ACTIONS(345),
    [anon_sym_LT_DASH] = ACTIONS(345),
    [anon_sym_LT_DASH_GT] = ACTIONS(343),
    [anon_sym_STAR] = ACTIONS(345),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_PERCENT] = ACTIONS(343),
    [anon_sym_AT] = ACTIONS(345),
    [anon_sym_LT_PIPE] = ACTIONS(343),
    [anon_sym_AMP_AMP] = ACTIONS(343),
    [anon_sym_PIPE_PIPE] = ACTIONS(343),
    [anon_sym_QMARK_QMARK] = ACTIONS(343),
    [anon_sym_QMARK_COLON] = ACTIONS(343),
    [anon_sym_BANG_EQ] = ACTIONS(343),
    [anon_sym_EQ_EQ] = ACTIONS(343),
    [anon_sym_QMARK_EQ] = ACTIONS(343),
    [anon_sym_STAR_EQ] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(343),
    [anon_sym_BANG_TILDE] = ACTIONS(343),
    [anon_sym_STAR_TILDE] = ACTIONS(343),
    [anon_sym_LT_EQ] = ACTIONS(343),
    [anon_sym_GT_EQ] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_PLUS_EQ] = ACTIONS(343),
    [anon_sym_DASH_EQ] = ACTIONS(343),
    [anon_sym_u00d7] = ACTIONS(343),
    [anon_sym_SLASH] = ACTIONS(345),
    [anon_sym_u00f7] = ACTIONS(343),
    [anon_sym_STAR_STAR] = ACTIONS(343),
    [anon_sym_u220b] = ACTIONS(343),
    [anon_sym_u220c] = ACTIONS(343),
    [anon_sym_u2287] = ACTIONS(343),
    [anon_sym_u2283] = ACTIONS(343),
    [anon_sym_u2285] = ACTIONS(343),
    [anon_sym_u2208] = ACTIONS(343),
    [anon_sym_u2209] = ACTIONS(343),
    [anon_sym_u2286] = ACTIONS(343),
    [anon_sym_u2282] = ACTIONS(343),
    [anon_sym_u2284] = ACTIONS(343),
    [anon_sym_AT_AT] = ACTIONS(343),
  },
  [STATE(162)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(351),
    [sym_keyword_value] = ACTIONS(351),
    [sym_keyword_explain] = ACTIONS(351),
    [sym_keyword_parallel] = ACTIONS(351),
    [sym_keyword_timeout] = ACTIONS(351),
    [sym_keyword_fetch] = ACTIONS(351),
    [sym_keyword_limit] = ACTIONS(351),
    [sym_keyword_rand] = ACTIONS(351),
    [sym_keyword_collate] = ACTIONS(351),
    [sym_keyword_numeric] = ACTIONS(351),
    [sym_keyword_asc] = ACTIONS(351),
    [sym_keyword_desc] = ACTIONS(351),
    [sym_keyword_and] = ACTIONS(351),
    [sym_keyword_or] = ACTIONS(351),
    [sym_keyword_is] = ACTIONS(351),
    [sym_keyword_not] = ACTIONS(353),
    [sym_keyword_contains] = ACTIONS(353),
    [sym_keyword_contains_not] = ACTIONS(351),
    [sym_keyword_contains_all] = ACTIONS(351),
    [sym_keyword_contains_any] = ACTIONS(351),
    [sym_keyword_contains_none] = ACTIONS(351),
    [sym_keyword_inside] = ACTIONS(351),
    [sym_keyword_in] = ACTIONS(353),
    [sym_keyword_not_inside] = ACTIONS(351),
    [sym_keyword_all_inside] = ACTIONS(351),
    [sym_keyword_any_inside] = ACTIONS(351),
    [sym_keyword_none_inside] = ACTIONS(351),
    [sym_keyword_outside] = ACTIONS(351),
    [sym_keyword_intersects] = ACTIONS(351),
    [sym_keyword_flexible] = ACTIONS(351),
    [sym_keyword_readonly] = ACTIONS(351),
    [sym_keyword_type] = ACTIONS(351),
    [sym_keyword_default] = ACTIONS(351),
    [sym_keyword_assert] = ACTIONS(351),
    [sym_keyword_permissions] = ACTIONS(351),
    [sym_keyword_for] = ACTIONS(351),
    [sym_keyword_comment] = ACTIONS(351),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_COMMA] = ACTIONS(351),
    [anon_sym_RPAREN] = ACTIONS(351),
    [anon_sym_DASH_GT] = ACTIONS(351),
    [anon_sym_LBRACK] = ACTIONS(351),
    [anon_sym_RBRACE] = ACTIONS(351),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH_GT] = ACTIONS(351),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [anon_sym_LT_PIPE] = ACTIONS(351),
    [anon_sym_AMP_AMP] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(351),
    [anon_sym_QMARK_QMARK] = ACTIONS(351),
    [anon_sym_QMARK_COLON] = ACTIONS(351),
    [anon_sym_BANG_EQ] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(351),
    [anon_sym_QMARK_EQ] = ACTIONS(351),
    [anon_sym_STAR_EQ] = ACTIONS(351),
    [anon_sym_TILDE] = ACTIONS(351),
    [anon_sym_BANG_TILDE] = ACTIONS(351),
    [anon_sym_STAR_TILDE] = ACTIONS(351),
    [anon_sym_LT_EQ] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(353),
    [anon_sym_PLUS_EQ] = ACTIONS(351),
    [anon_sym_DASH_EQ] = ACTIONS(351),
    [anon_sym_u00d7] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(353),
    [anon_sym_u00f7] = ACTIONS(351),
    [anon_sym_STAR_STAR] = ACTIONS(351),
    [anon_sym_u220b] = ACTIONS(351),
    [anon_sym_u220c] = ACTIONS(351),
    [anon_sym_u2287] = ACTIONS(351),
    [anon_sym_u2283] = ACTIONS(351),
    [anon_sym_u2285] = ACTIONS(351),
    [anon_sym_u2208] = ACTIONS(351),
    [anon_sym_u2209] = ACTIONS(351),
    [anon_sym_u2286] = ACTIONS(351),
    [anon_sym_u2282] = ACTIONS(351),
    [anon_sym_u2284] = ACTIONS(351),
    [anon_sym_AT_AT] = ACTIONS(351),
  },
  [STATE(163)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_value] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_rand] = ACTIONS(355),
    [sym_keyword_collate] = ACTIONS(355),
    [sym_keyword_numeric] = ACTIONS(355),
    [sym_keyword_asc] = ACTIONS(355),
    [sym_keyword_desc] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(355),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [sym_keyword_flexible] = ACTIONS(355),
    [sym_keyword_readonly] = ACTIONS(355),
    [sym_keyword_type] = ACTIONS(355),
    [sym_keyword_default] = ACTIONS(355),
    [sym_keyword_assert] = ACTIONS(355),
    [sym_keyword_permissions] = ACTIONS(355),
    [sym_keyword_for] = ACTIONS(355),
    [sym_keyword_comment] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_RPAREN] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(164)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_value] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_rand] = ACTIONS(355),
    [sym_keyword_collate] = ACTIONS(355),
    [sym_keyword_numeric] = ACTIONS(355),
    [sym_keyword_asc] = ACTIONS(355),
    [sym_keyword_desc] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(355),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [sym_keyword_flexible] = ACTIONS(355),
    [sym_keyword_readonly] = ACTIONS(355),
    [sym_keyword_type] = ACTIONS(355),
    [sym_keyword_default] = ACTIONS(355),
    [sym_keyword_assert] = ACTIONS(355),
    [sym_keyword_permissions] = ACTIONS(355),
    [sym_keyword_for] = ACTIONS(355),
    [sym_keyword_comment] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_RPAREN] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(165)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(300),
    [sym_keyword_value] = ACTIONS(300),
    [sym_keyword_explain] = ACTIONS(300),
    [sym_keyword_parallel] = ACTIONS(300),
    [sym_keyword_timeout] = ACTIONS(300),
    [sym_keyword_fetch] = ACTIONS(300),
    [sym_keyword_limit] = ACTIONS(300),
    [sym_keyword_rand] = ACTIONS(300),
    [sym_keyword_collate] = ACTIONS(300),
    [sym_keyword_numeric] = ACTIONS(300),
    [sym_keyword_asc] = ACTIONS(300),
    [sym_keyword_desc] = ACTIONS(300),
    [sym_keyword_and] = ACTIONS(300),
    [sym_keyword_or] = ACTIONS(300),
    [sym_keyword_is] = ACTIONS(300),
    [sym_keyword_not] = ACTIONS(302),
    [sym_keyword_contains] = ACTIONS(302),
    [sym_keyword_contains_not] = ACTIONS(300),
    [sym_keyword_contains_all] = ACTIONS(300),
    [sym_keyword_contains_any] = ACTIONS(300),
    [sym_keyword_contains_none] = ACTIONS(300),
    [sym_keyword_inside] = ACTIONS(300),
    [sym_keyword_in] = ACTIONS(302),
    [sym_keyword_not_inside] = ACTIONS(300),
    [sym_keyword_all_inside] = ACTIONS(300),
    [sym_keyword_any_inside] = ACTIONS(300),
    [sym_keyword_none_inside] = ACTIONS(300),
    [sym_keyword_outside] = ACTIONS(300),
    [sym_keyword_intersects] = ACTIONS(300),
    [sym_keyword_flexible] = ACTIONS(300),
    [sym_keyword_readonly] = ACTIONS(300),
    [sym_keyword_type] = ACTIONS(300),
    [sym_keyword_default] = ACTIONS(300),
    [sym_keyword_assert] = ACTIONS(300),
    [sym_keyword_permissions] = ACTIONS(300),
    [sym_keyword_for] = ACTIONS(300),
    [sym_keyword_comment] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(300),
    [anon_sym_DASH_GT] = ACTIONS(300),
    [anon_sym_LBRACK] = ACTIONS(300),
    [anon_sym_RBRACE] = ACTIONS(300),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_LT_DASH] = ACTIONS(302),
    [anon_sym_LT_DASH_GT] = ACTIONS(300),
    [anon_sym_STAR] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(300),
    [anon_sym_DASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(300),
    [anon_sym_AT] = ACTIONS(302),
    [anon_sym_LT_PIPE] = ACTIONS(300),
    [anon_sym_AMP_AMP] = ACTIONS(300),
    [anon_sym_PIPE_PIPE] = ACTIONS(300),
    [anon_sym_QMARK_QMARK] = ACTIONS(300),
    [anon_sym_QMARK_COLON] = ACTIONS(300),
    [anon_sym_BANG_EQ] = ACTIONS(300),
    [anon_sym_EQ_EQ] = ACTIONS(300),
    [anon_sym_QMARK_EQ] = ACTIONS(300),
    [anon_sym_STAR_EQ] = ACTIONS(300),
    [anon_sym_TILDE] = ACTIONS(300),
    [anon_sym_BANG_TILDE] = ACTIONS(300),
    [anon_sym_STAR_TILDE] = ACTIONS(300),
    [anon_sym_LT_EQ] = ACTIONS(300),
    [anon_sym_GT_EQ] = ACTIONS(300),
    [anon_sym_PLUS] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(300),
    [anon_sym_DASH_EQ] = ACTIONS(300),
    [anon_sym_u00d7] = ACTIONS(300),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_u00f7] = ACTIONS(300),
    [anon_sym_STAR_STAR] = ACTIONS(300),
    [anon_sym_u220b] = ACTIONS(300),
    [anon_sym_u220c] = ACTIONS(300),
    [anon_sym_u2287] = ACTIONS(300),
    [anon_sym_u2283] = ACTIONS(300),
    [anon_sym_u2285] = ACTIONS(300),
    [anon_sym_u2208] = ACTIONS(300),
    [anon_sym_u2209] = ACTIONS(300),
    [anon_sym_u2286] = ACTIONS(300),
    [anon_sym_u2282] = ACTIONS(300),
    [anon_sym_u2284] = ACTIONS(300),
    [anon_sym_AT_AT] = ACTIONS(300),
  },
  [STATE(166)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_value] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(314),
    [sym_keyword_rand] = ACTIONS(314),
    [sym_keyword_collate] = ACTIONS(314),
    [sym_keyword_numeric] = ACTIONS(314),
    [sym_keyword_asc] = ACTIONS(314),
    [sym_keyword_desc] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(314),
    [sym_keyword_or] = ACTIONS(314),
    [sym_keyword_is] = ACTIONS(314),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(314),
    [sym_keyword_contains_all] = ACTIONS(314),
    [sym_keyword_contains_any] = ACTIONS(314),
    [sym_keyword_contains_none] = ACTIONS(314),
    [sym_keyword_inside] = ACTIONS(314),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(314),
    [sym_keyword_all_inside] = ACTIONS(314),
    [sym_keyword_any_inside] = ACTIONS(314),
    [sym_keyword_none_inside] = ACTIONS(314),
    [sym_keyword_outside] = ACTIONS(314),
    [sym_keyword_intersects] = ACTIONS(314),
    [sym_keyword_flexible] = ACTIONS(314),
    [sym_keyword_readonly] = ACTIONS(314),
    [sym_keyword_type] = ACTIONS(314),
    [sym_keyword_default] = ACTIONS(314),
    [sym_keyword_assert] = ACTIONS(314),
    [sym_keyword_permissions] = ACTIONS(314),
    [sym_keyword_for] = ACTIONS(314),
    [sym_keyword_comment] = ACTIONS(314),
    [anon_sym_EQ] = ACTIONS(316),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(314),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(167)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(318),
    [sym_keyword_value] = ACTIONS(318),
    [sym_keyword_explain] = ACTIONS(318),
    [sym_keyword_parallel] = ACTIONS(318),
    [sym_keyword_timeout] = ACTIONS(318),
    [sym_keyword_fetch] = ACTIONS(318),
    [sym_keyword_limit] = ACTIONS(318),
    [sym_keyword_rand] = ACTIONS(318),
    [sym_keyword_collate] = ACTIONS(318),
    [sym_keyword_numeric] = ACTIONS(318),
    [sym_keyword_asc] = ACTIONS(318),
    [sym_keyword_desc] = ACTIONS(318),
    [sym_keyword_and] = ACTIONS(318),
    [sym_keyword_or] = ACTIONS(318),
    [sym_keyword_is] = ACTIONS(318),
    [sym_keyword_not] = ACTIONS(320),
    [sym_keyword_contains] = ACTIONS(320),
    [sym_keyword_contains_not] = ACTIONS(318),
    [sym_keyword_contains_all] = ACTIONS(318),
    [sym_keyword_contains_any] = ACTIONS(318),
    [sym_keyword_contains_none] = ACTIONS(318),
    [sym_keyword_inside] = ACTIONS(318),
    [sym_keyword_in] = ACTIONS(320),
    [sym_keyword_not_inside] = ACTIONS(318),
    [sym_keyword_all_inside] = ACTIONS(318),
    [sym_keyword_any_inside] = ACTIONS(318),
    [sym_keyword_none_inside] = ACTIONS(318),
    [sym_keyword_outside] = ACTIONS(318),
    [sym_keyword_intersects] = ACTIONS(318),
    [sym_keyword_flexible] = ACTIONS(318),
    [sym_keyword_readonly] = ACTIONS(318),
    [sym_keyword_type] = ACTIONS(318),
    [sym_keyword_default] = ACTIONS(318),
    [sym_keyword_assert] = ACTIONS(318),
    [sym_keyword_permissions] = ACTIONS(318),
    [sym_keyword_for] = ACTIONS(318),
    [sym_keyword_comment] = ACTIONS(318),
    [anon_sym_EQ] = ACTIONS(320),
    [anon_sym_COMMA] = ACTIONS(318),
    [anon_sym_RPAREN] = ACTIONS(318),
    [anon_sym_DASH_GT] = ACTIONS(318),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_RBRACE] = ACTIONS(318),
    [anon_sym_LT] = ACTIONS(320),
    [anon_sym_GT] = ACTIONS(320),
    [anon_sym_LT_DASH] = ACTIONS(320),
    [anon_sym_LT_DASH_GT] = ACTIONS(318),
    [anon_sym_STAR] = ACTIONS(320),
    [anon_sym_DOT] = ACTIONS(318),
    [anon_sym_DASH] = ACTIONS(320),
    [anon_sym_PERCENT] = ACTIONS(318),
    [anon_sym_AT] = ACTIONS(320),
    [anon_sym_LT_PIPE] = ACTIONS(318),
    [anon_sym_AMP_AMP] = ACTIONS(318),
    [anon_sym_PIPE_PIPE] = ACTIONS(318),
    [anon_sym_QMARK_QMARK] = ACTIONS(318),
    [anon_sym_QMARK_COLON] = ACTIONS(318),
    [anon_sym_BANG_EQ] = ACTIONS(318),
    [anon_sym_EQ_EQ] = ACTIONS(318),
    [anon_sym_QMARK_EQ] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(318),
    [anon_sym_TILDE] = ACTIONS(318),
    [anon_sym_BANG_TILDE] = ACTIONS(318),
    [anon_sym_STAR_TILDE] = ACTIONS(318),
    [anon_sym_LT_EQ] = ACTIONS(318),
    [anon_sym_GT_EQ] = ACTIONS(318),
    [anon_sym_PLUS] = ACTIONS(320),
    [anon_sym_PLUS_EQ] = ACTIONS(318),
    [anon_sym_DASH_EQ] = ACTIONS(318),
    [anon_sym_u00d7] = ACTIONS(318),
    [anon_sym_SLASH] = ACTIONS(320),
    [anon_sym_u00f7] = ACTIONS(318),
    [anon_sym_STAR_STAR] = ACTIONS(318),
    [anon_sym_u220b] = ACTIONS(318),
    [anon_sym_u220c] = ACTIONS(318),
    [anon_sym_u2287] = ACTIONS(318),
    [anon_sym_u2283] = ACTIONS(318),
    [anon_sym_u2285] = ACTIONS(318),
    [anon_sym_u2208] = ACTIONS(318),
    [anon_sym_u2209] = ACTIONS(318),
    [anon_sym_u2286] = ACTIONS(318),
    [anon_sym_u2282] = ACTIONS(318),
    [anon_sym_u2284] = ACTIONS(318),
    [anon_sym_AT_AT] = ACTIONS(318),
  },
  [STATE(168)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(322),
    [sym_keyword_value] = ACTIONS(322),
    [sym_keyword_explain] = ACTIONS(322),
    [sym_keyword_parallel] = ACTIONS(322),
    [sym_keyword_timeout] = ACTIONS(322),
    [sym_keyword_fetch] = ACTIONS(322),
    [sym_keyword_limit] = ACTIONS(322),
    [sym_keyword_rand] = ACTIONS(322),
    [sym_keyword_collate] = ACTIONS(322),
    [sym_keyword_numeric] = ACTIONS(322),
    [sym_keyword_asc] = ACTIONS(322),
    [sym_keyword_desc] = ACTIONS(322),
    [sym_keyword_and] = ACTIONS(322),
    [sym_keyword_or] = ACTIONS(322),
    [sym_keyword_is] = ACTIONS(322),
    [sym_keyword_not] = ACTIONS(324),
    [sym_keyword_contains] = ACTIONS(324),
    [sym_keyword_contains_not] = ACTIONS(322),
    [sym_keyword_contains_all] = ACTIONS(322),
    [sym_keyword_contains_any] = ACTIONS(322),
    [sym_keyword_contains_none] = ACTIONS(322),
    [sym_keyword_inside] = ACTIONS(322),
    [sym_keyword_in] = ACTIONS(324),
    [sym_keyword_not_inside] = ACTIONS(322),
    [sym_keyword_all_inside] = ACTIONS(322),
    [sym_keyword_any_inside] = ACTIONS(322),
    [sym_keyword_none_inside] = ACTIONS(322),
    [sym_keyword_outside] = ACTIONS(322),
    [sym_keyword_intersects] = ACTIONS(322),
    [sym_keyword_flexible] = ACTIONS(322),
    [sym_keyword_readonly] = ACTIONS(322),
    [sym_keyword_type] = ACTIONS(322),
    [sym_keyword_default] = ACTIONS(322),
    [sym_keyword_assert] = ACTIONS(322),
    [sym_keyword_permissions] = ACTIONS(322),
    [sym_keyword_for] = ACTIONS(322),
    [sym_keyword_comment] = ACTIONS(322),
    [anon_sym_EQ] = ACTIONS(324),
    [anon_sym_COMMA] = ACTIONS(322),
    [anon_sym_RPAREN] = ACTIONS(322),
    [anon_sym_DASH_GT] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(322),
    [anon_sym_RBRACE] = ACTIONS(322),
    [anon_sym_LT] = ACTIONS(324),
    [anon_sym_GT] = ACTIONS(324),
    [anon_sym_LT_DASH] = ACTIONS(324),
    [anon_sym_LT_DASH_GT] = ACTIONS(322),
    [anon_sym_STAR] = ACTIONS(324),
    [anon_sym_DOT] = ACTIONS(322),
    [anon_sym_DASH] = ACTIONS(324),
    [anon_sym_PERCENT] = ACTIONS(322),
    [anon_sym_AT] = ACTIONS(324),
    [anon_sym_LT_PIPE] = ACTIONS(322),
    [anon_sym_AMP_AMP] = ACTIONS(322),
    [anon_sym_PIPE_PIPE] = ACTIONS(322),
    [anon_sym_QMARK_QMARK] = ACTIONS(322),
    [anon_sym_QMARK_COLON] = ACTIONS(322),
    [anon_sym_BANG_EQ] = ACTIONS(322),
    [anon_sym_EQ_EQ] = ACTIONS(322),
    [anon_sym_QMARK_EQ] = ACTIONS(322),
    [anon_sym_STAR_EQ] = ACTIONS(322),
    [anon_sym_TILDE] = ACTIONS(322),
    [anon_sym_BANG_TILDE] = ACTIONS(322),
    [anon_sym_STAR_TILDE] = ACTIONS(322),
    [anon_sym_LT_EQ] = ACTIONS(322),
    [anon_sym_GT_EQ] = ACTIONS(322),
    [anon_sym_PLUS] = ACTIONS(324),
    [anon_sym_PLUS_EQ] = ACTIONS(322),
    [anon_sym_DASH_EQ] = ACTIONS(322),
    [anon_sym_u00d7] = ACTIONS(322),
    [anon_sym_SLASH] = ACTIONS(324),
    [anon_sym_u00f7] = ACTIONS(322),
    [anon_sym_STAR_STAR] = ACTIONS(322),
    [anon_sym_u220b] = ACTIONS(322),
    [anon_sym_u220c] = ACTIONS(322),
    [anon_sym_u2287] = ACTIONS(322),
    [anon_sym_u2283] = ACTIONS(322),
    [anon_sym_u2285] = ACTIONS(322),
    [anon_sym_u2208] = ACTIONS(322),
    [anon_sym_u2209] = ACTIONS(322),
    [anon_sym_u2286] = ACTIONS(322),
    [anon_sym_u2282] = ACTIONS(322),
    [anon_sym_u2284] = ACTIONS(322),
    [anon_sym_AT_AT] = ACTIONS(322),
  },
  [STATE(169)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(365),
    [sym_keyword_value] = ACTIONS(365),
    [sym_keyword_explain] = ACTIONS(365),
    [sym_keyword_parallel] = ACTIONS(365),
    [sym_keyword_timeout] = ACTIONS(365),
    [sym_keyword_fetch] = ACTIONS(365),
    [sym_keyword_limit] = ACTIONS(365),
    [sym_keyword_rand] = ACTIONS(365),
    [sym_keyword_collate] = ACTIONS(365),
    [sym_keyword_numeric] = ACTIONS(365),
    [sym_keyword_asc] = ACTIONS(365),
    [sym_keyword_desc] = ACTIONS(365),
    [sym_keyword_and] = ACTIONS(365),
    [sym_keyword_or] = ACTIONS(365),
    [sym_keyword_is] = ACTIONS(365),
    [sym_keyword_not] = ACTIONS(367),
    [sym_keyword_contains] = ACTIONS(367),
    [sym_keyword_contains_not] = ACTIONS(365),
    [sym_keyword_contains_all] = ACTIONS(365),
    [sym_keyword_contains_any] = ACTIONS(365),
    [sym_keyword_contains_none] = ACTIONS(365),
    [sym_keyword_inside] = ACTIONS(365),
    [sym_keyword_in] = ACTIONS(367),
    [sym_keyword_not_inside] = ACTIONS(365),
    [sym_keyword_all_inside] = ACTIONS(365),
    [sym_keyword_any_inside] = ACTIONS(365),
    [sym_keyword_none_inside] = ACTIONS(365),
    [sym_keyword_outside] = ACTIONS(365),
    [sym_keyword_intersects] = ACTIONS(365),
    [sym_keyword_flexible] = ACTIONS(365),
    [sym_keyword_readonly] = ACTIONS(365),
    [sym_keyword_type] = ACTIONS(365),
    [sym_keyword_default] = ACTIONS(365),
    [sym_keyword_assert] = ACTIONS(365),
    [sym_keyword_permissions] = ACTIONS(365),
    [sym_keyword_for] = ACTIONS(365),
    [sym_keyword_comment] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(367),
    [anon_sym_COMMA] = ACTIONS(365),
    [anon_sym_RPAREN] = ACTIONS(365),
    [anon_sym_DASH_GT] = ACTIONS(365),
    [anon_sym_LBRACK] = ACTIONS(365),
    [anon_sym_RBRACE] = ACTIONS(365),
    [anon_sym_LT] = ACTIONS(367),
    [anon_sym_GT] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(367),
    [anon_sym_LT_DASH_GT] = ACTIONS(365),
    [anon_sym_STAR] = ACTIONS(367),
    [anon_sym_DOT] = ACTIONS(365),
    [anon_sym_DASH] = ACTIONS(367),
    [anon_sym_PERCENT] = ACTIONS(365),
    [anon_sym_AT] = ACTIONS(367),
    [anon_sym_LT_PIPE] = ACTIONS(365),
    [anon_sym_AMP_AMP] = ACTIONS(365),
    [anon_sym_PIPE_PIPE] = ACTIONS(365),
    [anon_sym_QMARK_QMARK] = ACTIONS(365),
    [anon_sym_QMARK_COLON] = ACTIONS(365),
    [anon_sym_BANG_EQ] = ACTIONS(365),
    [anon_sym_EQ_EQ] = ACTIONS(365),
    [anon_sym_QMARK_EQ] = ACTIONS(365),
    [anon_sym_STAR_EQ] = ACTIONS(365),
    [anon_sym_TILDE] = ACTIONS(365),
    [anon_sym_BANG_TILDE] = ACTIONS(365),
    [anon_sym_STAR_TILDE] = ACTIONS(365),
    [anon_sym_LT_EQ] = ACTIONS(365),
    [anon_sym_GT_EQ] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(367),
    [anon_sym_PLUS_EQ] = ACTIONS(365),
    [anon_sym_DASH_EQ] = ACTIONS(365),
    [anon_sym_u00d7] = ACTIONS(365),
    [anon_sym_SLASH] = ACTIONS(367),
    [anon_sym_u00f7] = ACTIONS(365),
    [anon_sym_STAR_STAR] = ACTIONS(365),
    [anon_sym_u220b] = ACTIONS(365),
    [anon_sym_u220c] = ACTIONS(365),
    [anon_sym_u2287] = ACTIONS(365),
    [anon_sym_u2283] = ACTIONS(365),
    [anon_sym_u2285] = ACTIONS(365),
    [anon_sym_u2208] = ACTIONS(365),
    [anon_sym_u2209] = ACTIONS(365),
    [anon_sym_u2286] = ACTIONS(365),
    [anon_sym_u2282] = ACTIONS(365),
    [anon_sym_u2284] = ACTIONS(365),
    [anon_sym_AT_AT] = ACTIONS(365),
  },
  [STATE(170)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(369),
    [sym_keyword_value] = ACTIONS(369),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_rand] = ACTIONS(369),
    [sym_keyword_collate] = ACTIONS(369),
    [sym_keyword_numeric] = ACTIONS(369),
    [sym_keyword_asc] = ACTIONS(369),
    [sym_keyword_desc] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(369),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(371),
    [sym_keyword_contains] = ACTIONS(371),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(371),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [sym_keyword_flexible] = ACTIONS(369),
    [sym_keyword_readonly] = ACTIONS(369),
    [sym_keyword_type] = ACTIONS(369),
    [sym_keyword_default] = ACTIONS(369),
    [sym_keyword_assert] = ACTIONS(369),
    [sym_keyword_permissions] = ACTIONS(369),
    [sym_keyword_for] = ACTIONS(369),
    [sym_keyword_comment] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(371),
    [anon_sym_LT_DASH_GT] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(371),
    [anon_sym_DOT] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(371),
    [anon_sym_LT_PIPE] = ACTIONS(369),
    [anon_sym_AMP_AMP] = ACTIONS(369),
    [anon_sym_PIPE_PIPE] = ACTIONS(369),
    [anon_sym_QMARK_QMARK] = ACTIONS(369),
    [anon_sym_QMARK_COLON] = ACTIONS(369),
    [anon_sym_BANG_EQ] = ACTIONS(369),
    [anon_sym_EQ_EQ] = ACTIONS(369),
    [anon_sym_QMARK_EQ] = ACTIONS(369),
    [anon_sym_STAR_EQ] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_BANG_TILDE] = ACTIONS(369),
    [anon_sym_STAR_TILDE] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(371),
    [anon_sym_PLUS_EQ] = ACTIONS(369),
    [anon_sym_DASH_EQ] = ACTIONS(369),
    [anon_sym_u00d7] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_u00f7] = ACTIONS(369),
    [anon_sym_STAR_STAR] = ACTIONS(369),
    [anon_sym_u220b] = ACTIONS(369),
    [anon_sym_u220c] = ACTIONS(369),
    [anon_sym_u2287] = ACTIONS(369),
    [anon_sym_u2283] = ACTIONS(369),
    [anon_sym_u2285] = ACTIONS(369),
    [anon_sym_u2208] = ACTIONS(369),
    [anon_sym_u2209] = ACTIONS(369),
    [anon_sym_u2286] = ACTIONS(369),
    [anon_sym_u2282] = ACTIONS(369),
    [anon_sym_u2284] = ACTIONS(369),
    [anon_sym_AT_AT] = ACTIONS(369),
  },
  [STATE(171)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_value] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_rand] = ACTIONS(264),
    [sym_keyword_collate] = ACTIONS(264),
    [sym_keyword_numeric] = ACTIONS(264),
    [sym_keyword_asc] = ACTIONS(264),
    [sym_keyword_desc] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(264),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [sym_keyword_flexible] = ACTIONS(264),
    [sym_keyword_readonly] = ACTIONS(264),
    [sym_keyword_type] = ACTIONS(264),
    [sym_keyword_default] = ACTIONS(264),
    [sym_keyword_assert] = ACTIONS(264),
    [sym_keyword_permissions] = ACTIONS(264),
    [sym_keyword_for] = ACTIONS(264),
    [sym_keyword_comment] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(266),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(172)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_value] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_rand] = ACTIONS(264),
    [sym_keyword_collate] = ACTIONS(264),
    [sym_keyword_numeric] = ACTIONS(264),
    [sym_keyword_asc] = ACTIONS(264),
    [sym_keyword_desc] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(264),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [sym_keyword_flexible] = ACTIONS(264),
    [sym_keyword_readonly] = ACTIONS(264),
    [sym_keyword_type] = ACTIONS(264),
    [sym_keyword_default] = ACTIONS(264),
    [sym_keyword_assert] = ACTIONS(264),
    [sym_keyword_permissions] = ACTIONS(264),
    [sym_keyword_for] = ACTIONS(264),
    [sym_keyword_comment] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(443),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(173)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(337),
    [sym_keyword_value] = ACTIONS(337),
    [sym_keyword_explain] = ACTIONS(337),
    [sym_keyword_parallel] = ACTIONS(337),
    [sym_keyword_timeout] = ACTIONS(337),
    [sym_keyword_fetch] = ACTIONS(337),
    [sym_keyword_limit] = ACTIONS(337),
    [sym_keyword_rand] = ACTIONS(337),
    [sym_keyword_collate] = ACTIONS(337),
    [sym_keyword_numeric] = ACTIONS(337),
    [sym_keyword_asc] = ACTIONS(337),
    [sym_keyword_desc] = ACTIONS(337),
    [sym_keyword_and] = ACTIONS(337),
    [sym_keyword_or] = ACTIONS(337),
    [sym_keyword_is] = ACTIONS(337),
    [sym_keyword_not] = ACTIONS(339),
    [sym_keyword_contains] = ACTIONS(339),
    [sym_keyword_contains_not] = ACTIONS(337),
    [sym_keyword_contains_all] = ACTIONS(337),
    [sym_keyword_contains_any] = ACTIONS(337),
    [sym_keyword_contains_none] = ACTIONS(337),
    [sym_keyword_inside] = ACTIONS(337),
    [sym_keyword_in] = ACTIONS(339),
    [sym_keyword_not_inside] = ACTIONS(337),
    [sym_keyword_all_inside] = ACTIONS(337),
    [sym_keyword_any_inside] = ACTIONS(337),
    [sym_keyword_none_inside] = ACTIONS(337),
    [sym_keyword_outside] = ACTIONS(337),
    [sym_keyword_intersects] = ACTIONS(337),
    [sym_keyword_flexible] = ACTIONS(337),
    [sym_keyword_readonly] = ACTIONS(337),
    [sym_keyword_type] = ACTIONS(337),
    [sym_keyword_default] = ACTIONS(337),
    [sym_keyword_assert] = ACTIONS(337),
    [sym_keyword_permissions] = ACTIONS(337),
    [sym_keyword_for] = ACTIONS(337),
    [sym_keyword_comment] = ACTIONS(337),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_COMMA] = ACTIONS(337),
    [anon_sym_RPAREN] = ACTIONS(337),
    [anon_sym_DASH_GT] = ACTIONS(337),
    [anon_sym_LBRACK] = ACTIONS(337),
    [anon_sym_RBRACE] = ACTIONS(337),
    [anon_sym_LT] = ACTIONS(339),
    [anon_sym_GT] = ACTIONS(339),
    [anon_sym_LT_DASH] = ACTIONS(339),
    [anon_sym_LT_DASH_GT] = ACTIONS(337),
    [anon_sym_STAR] = ACTIONS(339),
    [anon_sym_DOT] = ACTIONS(337),
    [anon_sym_DASH] = ACTIONS(339),
    [anon_sym_PERCENT] = ACTIONS(337),
    [anon_sym_AT] = ACTIONS(339),
    [anon_sym_LT_PIPE] = ACTIONS(337),
    [anon_sym_AMP_AMP] = ACTIONS(337),
    [anon_sym_PIPE_PIPE] = ACTIONS(337),
    [anon_sym_QMARK_QMARK] = ACTIONS(337),
    [anon_sym_QMARK_COLON] = ACTIONS(337),
    [anon_sym_BANG_EQ] = ACTIONS(337),
    [anon_sym_EQ_EQ] = ACTIONS(337),
    [anon_sym_QMARK_EQ] = ACTIONS(337),
    [anon_sym_STAR_EQ] = ACTIONS(337),
    [anon_sym_TILDE] = ACTIONS(337),
    [anon_sym_BANG_TILDE] = ACTIONS(337),
    [anon_sym_STAR_TILDE] = ACTIONS(337),
    [anon_sym_LT_EQ] = ACTIONS(337),
    [anon_sym_GT_EQ] = ACTIONS(337),
    [anon_sym_PLUS] = ACTIONS(339),
    [anon_sym_PLUS_EQ] = ACTIONS(337),
    [anon_sym_DASH_EQ] = ACTIONS(337),
    [anon_sym_u00d7] = ACTIONS(337),
    [anon_sym_SLASH] = ACTIONS(339),
    [anon_sym_u00f7] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(337),
    [anon_sym_u220b] = ACTIONS(337),
    [anon_sym_u220c] = ACTIONS(337),
    [anon_sym_u2287] = ACTIONS(337),
    [anon_sym_u2283] = ACTIONS(337),
    [anon_sym_u2285] = ACTIONS(337),
    [anon_sym_u2208] = ACTIONS(337),
    [anon_sym_u2209] = ACTIONS(337),
    [anon_sym_u2286] = ACTIONS(337),
    [anon_sym_u2282] = ACTIONS(337),
    [anon_sym_u2284] = ACTIONS(337),
    [anon_sym_AT_AT] = ACTIONS(337),
  },
  [STATE(174)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(270),
    [sym_keyword_value] = ACTIONS(270),
    [sym_keyword_explain] = ACTIONS(270),
    [sym_keyword_parallel] = ACTIONS(270),
    [sym_keyword_timeout] = ACTIONS(270),
    [sym_keyword_fetch] = ACTIONS(270),
    [sym_keyword_limit] = ACTIONS(270),
    [sym_keyword_rand] = ACTIONS(270),
    [sym_keyword_collate] = ACTIONS(270),
    [sym_keyword_numeric] = ACTIONS(270),
    [sym_keyword_asc] = ACTIONS(270),
    [sym_keyword_desc] = ACTIONS(270),
    [sym_keyword_and] = ACTIONS(270),
    [sym_keyword_or] = ACTIONS(270),
    [sym_keyword_is] = ACTIONS(270),
    [sym_keyword_not] = ACTIONS(272),
    [sym_keyword_contains] = ACTIONS(272),
    [sym_keyword_contains_not] = ACTIONS(270),
    [sym_keyword_contains_all] = ACTIONS(270),
    [sym_keyword_contains_any] = ACTIONS(270),
    [sym_keyword_contains_none] = ACTIONS(270),
    [sym_keyword_inside] = ACTIONS(270),
    [sym_keyword_in] = ACTIONS(272),
    [sym_keyword_not_inside] = ACTIONS(270),
    [sym_keyword_all_inside] = ACTIONS(270),
    [sym_keyword_any_inside] = ACTIONS(270),
    [sym_keyword_none_inside] = ACTIONS(270),
    [sym_keyword_outside] = ACTIONS(270),
    [sym_keyword_intersects] = ACTIONS(270),
    [sym_keyword_flexible] = ACTIONS(270),
    [sym_keyword_readonly] = ACTIONS(270),
    [sym_keyword_type] = ACTIONS(270),
    [sym_keyword_default] = ACTIONS(270),
    [sym_keyword_assert] = ACTIONS(270),
    [sym_keyword_permissions] = ACTIONS(270),
    [sym_keyword_for] = ACTIONS(270),
    [sym_keyword_comment] = ACTIONS(270),
    [anon_sym_EQ] = ACTIONS(272),
    [anon_sym_COMMA] = ACTIONS(270),
    [anon_sym_RPAREN] = ACTIONS(270),
    [anon_sym_DASH_GT] = ACTIONS(270),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_RBRACE] = ACTIONS(270),
    [anon_sym_LT] = ACTIONS(272),
    [anon_sym_GT] = ACTIONS(272),
    [anon_sym_LT_DASH] = ACTIONS(272),
    [anon_sym_LT_DASH_GT] = ACTIONS(270),
    [anon_sym_STAR] = ACTIONS(272),
    [anon_sym_DOT] = ACTIONS(270),
    [anon_sym_DASH] = ACTIONS(272),
    [anon_sym_PERCENT] = ACTIONS(270),
    [anon_sym_AT] = ACTIONS(272),
    [anon_sym_LT_PIPE] = ACTIONS(270),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_PIPE_PIPE] = ACTIONS(270),
    [anon_sym_QMARK_QMARK] = ACTIONS(270),
    [anon_sym_QMARK_COLON] = ACTIONS(270),
    [anon_sym_BANG_EQ] = ACTIONS(270),
    [anon_sym_EQ_EQ] = ACTIONS(270),
    [anon_sym_QMARK_EQ] = ACTIONS(270),
    [anon_sym_STAR_EQ] = ACTIONS(270),
    [anon_sym_TILDE] = ACTIONS(270),
    [anon_sym_BANG_TILDE] = ACTIONS(270),
    [anon_sym_STAR_TILDE] = ACTIONS(270),
    [anon_sym_LT_EQ] = ACTIONS(270),
    [anon_sym_GT_EQ] = ACTIONS(270),
    [anon_sym_PLUS] = ACTIONS(272),
    [anon_sym_PLUS_EQ] = ACTIONS(270),
    [anon_sym_DASH_EQ] = ACTIONS(270),
    [anon_sym_u00d7] = ACTIONS(270),
    [anon_sym_SLASH] = ACTIONS(272),
    [anon_sym_u00f7] = ACTIONS(270),
    [anon_sym_STAR_STAR] = ACTIONS(270),
    [anon_sym_u220b] = ACTIONS(270),
    [anon_sym_u220c] = ACTIONS(270),
    [anon_sym_u2287] = ACTIONS(270),
    [anon_sym_u2283] = ACTIONS(270),
    [anon_sym_u2285] = ACTIONS(270),
    [anon_sym_u2208] = ACTIONS(270),
    [anon_sym_u2209] = ACTIONS(270),
    [anon_sym_u2286] = ACTIONS(270),
    [anon_sym_u2282] = ACTIONS(270),
    [anon_sym_u2284] = ACTIONS(270),
    [anon_sym_AT_AT] = ACTIONS(270),
  },
  [STATE(175)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(274),
    [sym_keyword_value] = ACTIONS(274),
    [sym_keyword_explain] = ACTIONS(274),
    [sym_keyword_parallel] = ACTIONS(274),
    [sym_keyword_timeout] = ACTIONS(274),
    [sym_keyword_fetch] = ACTIONS(274),
    [sym_keyword_limit] = ACTIONS(274),
    [sym_keyword_rand] = ACTIONS(274),
    [sym_keyword_collate] = ACTIONS(274),
    [sym_keyword_numeric] = ACTIONS(274),
    [sym_keyword_asc] = ACTIONS(274),
    [sym_keyword_desc] = ACTIONS(274),
    [sym_keyword_and] = ACTIONS(274),
    [sym_keyword_or] = ACTIONS(274),
    [sym_keyword_is] = ACTIONS(274),
    [sym_keyword_not] = ACTIONS(276),
    [sym_keyword_contains] = ACTIONS(276),
    [sym_keyword_contains_not] = ACTIONS(274),
    [sym_keyword_contains_all] = ACTIONS(274),
    [sym_keyword_contains_any] = ACTIONS(274),
    [sym_keyword_contains_none] = ACTIONS(274),
    [sym_keyword_inside] = ACTIONS(274),
    [sym_keyword_in] = ACTIONS(276),
    [sym_keyword_not_inside] = ACTIONS(274),
    [sym_keyword_all_inside] = ACTIONS(274),
    [sym_keyword_any_inside] = ACTIONS(274),
    [sym_keyword_none_inside] = ACTIONS(274),
    [sym_keyword_outside] = ACTIONS(274),
    [sym_keyword_intersects] = ACTIONS(274),
    [sym_keyword_flexible] = ACTIONS(274),
    [sym_keyword_readonly] = ACTIONS(274),
    [sym_keyword_type] = ACTIONS(274),
    [sym_keyword_default] = ACTIONS(274),
    [sym_keyword_assert] = ACTIONS(274),
    [sym_keyword_permissions] = ACTIONS(274),
    [sym_keyword_for] = ACTIONS(274),
    [sym_keyword_comment] = ACTIONS(274),
    [anon_sym_EQ] = ACTIONS(276),
    [anon_sym_COMMA] = ACTIONS(274),
    [anon_sym_RPAREN] = ACTIONS(274),
    [anon_sym_DASH_GT] = ACTIONS(274),
    [anon_sym_LBRACK] = ACTIONS(274),
    [anon_sym_RBRACE] = ACTIONS(274),
    [anon_sym_LT] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(276),
    [anon_sym_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_DASH_GT] = ACTIONS(274),
    [anon_sym_STAR] = ACTIONS(276),
    [anon_sym_DOT] = ACTIONS(274),
    [anon_sym_DASH] = ACTIONS(276),
    [anon_sym_PERCENT] = ACTIONS(274),
    [anon_sym_AT] = ACTIONS(276),
    [anon_sym_LT_PIPE] = ACTIONS(274),
    [anon_sym_AMP_AMP] = ACTIONS(274),
    [anon_sym_PIPE_PIPE] = ACTIONS(274),
    [anon_sym_QMARK_QMARK] = ACTIONS(274),
    [anon_sym_QMARK_COLON] = ACTIONS(274),
    [anon_sym_BANG_EQ] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(274),
    [anon_sym_QMARK_EQ] = ACTIONS(274),
    [anon_sym_STAR_EQ] = ACTIONS(274),
    [anon_sym_TILDE] = ACTIONS(274),
    [anon_sym_BANG_TILDE] = ACTIONS(274),
    [anon_sym_STAR_TILDE] = ACTIONS(274),
    [anon_sym_LT_EQ] = ACTIONS(274),
    [anon_sym_GT_EQ] = ACTIONS(274),
    [anon_sym_PLUS] = ACTIONS(276),
    [anon_sym_PLUS_EQ] = ACTIONS(274),
    [anon_sym_DASH_EQ] = ACTIONS(274),
    [anon_sym_u00d7] = ACTIONS(274),
    [anon_sym_SLASH] = ACTIONS(276),
    [anon_sym_u00f7] = ACTIONS(274),
    [anon_sym_STAR_STAR] = ACTIONS(274),
    [anon_sym_u220b] = ACTIONS(274),
    [anon_sym_u220c] = ACTIONS(274),
    [anon_sym_u2287] = ACTIONS(274),
    [anon_sym_u2283] = ACTIONS(274),
    [anon_sym_u2285] = ACTIONS(274),
    [anon_sym_u2208] = ACTIONS(274),
    [anon_sym_u2209] = ACTIONS(274),
    [anon_sym_u2286] = ACTIONS(274),
    [anon_sym_u2282] = ACTIONS(274),
    [anon_sym_u2284] = ACTIONS(274),
    [anon_sym_AT_AT] = ACTIONS(274),
  },
  [STATE(176)] = {
    [sym_where_clause] = STATE(1386),
    [sym_timeout_clause] = STATE(1685),
    [sym_parallel_clause] = STATE(1855),
    [sym_explain_clause] = STATE(2118),
    [sym_content_clause] = STATE(1288),
    [sym_return_clause] = STATE(1455),
    [sym_merge_clause] = STATE(1288),
    [sym_patch_clause] = STATE(1288),
    [sym_replace_clause] = STATE(1288),
    [sym_operator] = STATE(971),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1118),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(445),
    [sym_keyword_return] = ACTIONS(447),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(455),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_replace] = ACTIONS(471),
    [sym_keyword_unset] = ACTIONS(473),
    [sym_keyword_set] = ACTIONS(475),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(477),
    [anon_sym_RPAREN] = ACTIONS(445),
    [anon_sym_RBRACE] = ACTIONS(445),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(177)] = {
    [sym_with_clause] = STATE(1152),
    [sym_where_clause] = STATE(1167),
    [sym_split_clause] = STATE(1198),
    [sym_group_clause] = STATE(1227),
    [sym_order_clause] = STATE(1256),
    [sym_limit_clause] = STATE(1369),
    [sym_fetch_clause] = STATE(1457),
    [sym_timeout_clause] = STATE(1620),
    [sym_parallel_clause] = STATE(1871),
    [sym_explain_clause] = STATE(2129),
    [sym_operator] = STATE(861),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1120),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(487),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_fetch] = ACTIONS(489),
    [sym_keyword_limit] = ACTIONS(491),
    [sym_keyword_order] = ACTIONS(493),
    [sym_keyword_with] = ACTIONS(495),
    [sym_keyword_where] = ACTIONS(497),
    [sym_keyword_split] = ACTIONS(499),
    [sym_keyword_group] = ACTIONS(501),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(503),
    [anon_sym_RPAREN] = ACTIONS(487),
    [anon_sym_RBRACE] = ACTIONS(487),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(178)] = {
    [sym_with_clause] = STATE(1153),
    [sym_where_clause] = STATE(1165),
    [sym_split_clause] = STATE(1197),
    [sym_group_clause] = STATE(1230),
    [sym_order_clause] = STATE(1249),
    [sym_limit_clause] = STATE(1360),
    [sym_fetch_clause] = STATE(1431),
    [sym_timeout_clause] = STATE(1651),
    [sym_parallel_clause] = STATE(1813),
    [sym_explain_clause] = STATE(1987),
    [sym_operator] = STATE(861),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1119),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(505),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_fetch] = ACTIONS(489),
    [sym_keyword_limit] = ACTIONS(491),
    [sym_keyword_order] = ACTIONS(493),
    [sym_keyword_with] = ACTIONS(495),
    [sym_keyword_where] = ACTIONS(497),
    [sym_keyword_split] = ACTIONS(499),
    [sym_keyword_group] = ACTIONS(501),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(503),
    [anon_sym_RPAREN] = ACTIONS(505),
    [anon_sym_RBRACE] = ACTIONS(505),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(179)] = {
    [sym_where_clause] = STATE(1383),
    [sym_timeout_clause] = STATE(1618),
    [sym_parallel_clause] = STATE(1789),
    [sym_explain_clause] = STATE(1997),
    [sym_content_clause] = STATE(1316),
    [sym_return_clause] = STATE(1443),
    [sym_merge_clause] = STATE(1316),
    [sym_patch_clause] = STATE(1316),
    [sym_replace_clause] = STATE(1316),
    [sym_operator] = STATE(971),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1124),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(507),
    [sym_keyword_return] = ACTIONS(447),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(455),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_replace] = ACTIONS(471),
    [sym_keyword_unset] = ACTIONS(509),
    [sym_keyword_set] = ACTIONS(511),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(477),
    [anon_sym_RPAREN] = ACTIONS(507),
    [anon_sym_RBRACE] = ACTIONS(507),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(180)] = {
    [sym_with_clause] = STATE(1155),
    [sym_where_clause] = STATE(1186),
    [sym_split_clause] = STATE(1200),
    [sym_group_clause] = STATE(1283),
    [sym_order_clause] = STATE(1249),
    [sym_limit_clause] = STATE(1360),
    [sym_fetch_clause] = STATE(1431),
    [sym_timeout_clause] = STATE(1651),
    [sym_parallel_clause] = STATE(1813),
    [sym_explain_clause] = STATE(1987),
    [sym_operator] = STATE(855),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1131),
    [ts_builtin_sym_end] = ACTIONS(505),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(505),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_fetch] = ACTIONS(489),
    [sym_keyword_limit] = ACTIONS(491),
    [sym_keyword_order] = ACTIONS(513),
    [sym_keyword_with] = ACTIONS(515),
    [sym_keyword_where] = ACTIONS(517),
    [sym_keyword_split] = ACTIONS(499),
    [sym_keyword_group] = ACTIONS(501),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(519),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(181)] = {
    [sym_where_clause] = STATE(1438),
    [sym_timeout_clause] = STATE(1685),
    [sym_parallel_clause] = STATE(1855),
    [sym_explain_clause] = STATE(2118),
    [sym_content_clause] = STATE(1351),
    [sym_return_clause] = STATE(1455),
    [sym_merge_clause] = STATE(1351),
    [sym_patch_clause] = STATE(1351),
    [sym_replace_clause] = STATE(1351),
    [sym_operator] = STATE(950),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1136),
    [ts_builtin_sym_end] = ACTIONS(445),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(445),
    [sym_keyword_return] = ACTIONS(521),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(523),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_replace] = ACTIONS(471),
    [sym_keyword_unset] = ACTIONS(525),
    [sym_keyword_set] = ACTIONS(527),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(529),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(182)] = {
    [sym_where_clause] = STATE(1440),
    [sym_timeout_clause] = STATE(1618),
    [sym_parallel_clause] = STATE(1789),
    [sym_explain_clause] = STATE(1997),
    [sym_content_clause] = STATE(1364),
    [sym_return_clause] = STATE(1443),
    [sym_merge_clause] = STATE(1364),
    [sym_patch_clause] = STATE(1364),
    [sym_replace_clause] = STATE(1364),
    [sym_operator] = STATE(950),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1127),
    [ts_builtin_sym_end] = ACTIONS(507),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(507),
    [sym_keyword_return] = ACTIONS(521),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(523),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_replace] = ACTIONS(471),
    [sym_keyword_unset] = ACTIONS(531),
    [sym_keyword_set] = ACTIONS(533),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(529),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(183)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_content] = ACTIONS(537),
    [sym_keyword_merge] = ACTIONS(537),
    [sym_keyword_patch] = ACTIONS(537),
    [sym_keyword_replace] = ACTIONS(537),
    [sym_keyword_unset] = ACTIONS(537),
    [sym_keyword_set] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(184)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_content] = ACTIONS(316),
    [sym_keyword_merge] = ACTIONS(316),
    [sym_keyword_patch] = ACTIONS(316),
    [sym_keyword_replace] = ACTIONS(316),
    [sym_keyword_unset] = ACTIONS(316),
    [sym_keyword_set] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(185)] = {
    [sym_with_clause] = STATE(1154),
    [sym_where_clause] = STATE(1183),
    [sym_split_clause] = STATE(1199),
    [sym_group_clause] = STATE(1255),
    [sym_order_clause] = STATE(1256),
    [sym_limit_clause] = STATE(1369),
    [sym_fetch_clause] = STATE(1457),
    [sym_timeout_clause] = STATE(1620),
    [sym_parallel_clause] = STATE(1871),
    [sym_explain_clause] = STATE(2129),
    [sym_operator] = STATE(855),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1130),
    [ts_builtin_sym_end] = ACTIONS(487),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(487),
    [sym_keyword_explain] = ACTIONS(449),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_fetch] = ACTIONS(489),
    [sym_keyword_limit] = ACTIONS(491),
    [sym_keyword_order] = ACTIONS(513),
    [sym_keyword_with] = ACTIONS(515),
    [sym_keyword_where] = ACTIONS(517),
    [sym_keyword_split] = ACTIONS(499),
    [sym_keyword_group] = ACTIONS(501),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(519),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(186)] = {
    [sym_where_clause] = STATE(1559),
    [sym_timeout_clause] = STATE(1787),
    [sym_parallel_clause] = STATE(2150),
    [sym_content_clause] = STATE(1380),
    [sym_set_clause] = STATE(1380),
    [sym_unset_clause] = STATE(1380),
    [sym_return_clause] = STATE(1616),
    [sym_merge_clause] = STATE(1380),
    [sym_patch_clause] = STATE(2150),
    [sym_operator] = STATE(963),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1146),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(545),
    [sym_keyword_return] = ACTIONS(547),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(549),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_unset] = ACTIONS(551),
    [sym_keyword_set] = ACTIONS(553),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(555),
    [anon_sym_RPAREN] = ACTIONS(545),
    [anon_sym_RBRACE] = ACTIONS(545),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(187)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_content] = ACTIONS(537),
    [sym_keyword_merge] = ACTIONS(537),
    [sym_keyword_patch] = ACTIONS(537),
    [sym_keyword_replace] = ACTIONS(537),
    [sym_keyword_unset] = ACTIONS(537),
    [sym_keyword_set] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(188)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_content] = ACTIONS(316),
    [sym_keyword_merge] = ACTIONS(316),
    [sym_keyword_patch] = ACTIONS(316),
    [sym_keyword_replace] = ACTIONS(316),
    [sym_keyword_unset] = ACTIONS(316),
    [sym_keyword_set] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(189)] = {
    [sym_array] = STATE(138),
    [sym_object] = STATE(138),
    [sym_record_id_value] = STATE(166),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_rand] = ACTIONS(537),
    [sym_keyword_collate] = ACTIONS(537),
    [sym_keyword_numeric] = ACTIONS(537),
    [sym_keyword_asc] = ACTIONS(537),
    [sym_keyword_desc] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(563),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(565),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(569),
    [sym_record_id_ident] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(190)] = {
    [sym_array] = STATE(138),
    [sym_object] = STATE(138),
    [sym_record_id_value] = STATE(171),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_rand] = ACTIONS(316),
    [sym_keyword_collate] = ACTIONS(316),
    [sym_keyword_numeric] = ACTIONS(316),
    [sym_keyword_asc] = ACTIONS(316),
    [sym_keyword_desc] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(571),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(565),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(569),
    [sym_record_id_ident] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(191)] = {
    [sym_array] = STATE(243),
    [sym_object] = STATE(243),
    [sym_record_id_value] = STATE(294),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_order] = ACTIONS(537),
    [sym_keyword_with] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_split] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(573),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(579),
    [sym_record_id_ident] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(192)] = {
    [sym_array] = STATE(243),
    [sym_object] = STATE(243),
    [sym_record_id_value] = STATE(301),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_order] = ACTIONS(316),
    [sym_keyword_with] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_split] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(581),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(579),
    [sym_record_id_ident] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(193)] = {
    [sym_where_clause] = STATE(1549),
    [sym_timeout_clause] = STATE(1850),
    [sym_parallel_clause] = STATE(2109),
    [sym_content_clause] = STATE(1385),
    [sym_set_clause] = STATE(1385),
    [sym_unset_clause] = STATE(1385),
    [sym_return_clause] = STATE(1683),
    [sym_merge_clause] = STATE(1385),
    [sym_patch_clause] = STATE(2109),
    [sym_operator] = STATE(963),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1138),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(583),
    [sym_keyword_return] = ACTIONS(547),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(549),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_unset] = ACTIONS(551),
    [sym_keyword_set] = ACTIONS(553),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(555),
    [anon_sym_RPAREN] = ACTIONS(583),
    [anon_sym_RBRACE] = ACTIONS(583),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(194)] = {
    [sym_filter] = STATE(272),
    [sym_path_element] = STATE(194),
    [sym_graph_path] = STATE(272),
    [sym_subscript] = STATE(272),
    [aux_sym_path_repeat1] = STATE(194),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(216),
    [sym_keyword_explain] = ACTIONS(216),
    [sym_keyword_parallel] = ACTIONS(216),
    [sym_keyword_timeout] = ACTIONS(216),
    [sym_keyword_fetch] = ACTIONS(216),
    [sym_keyword_limit] = ACTIONS(216),
    [sym_keyword_order] = ACTIONS(216),
    [sym_keyword_with] = ACTIONS(216),
    [sym_keyword_where] = ACTIONS(216),
    [sym_keyword_split] = ACTIONS(216),
    [sym_keyword_group] = ACTIONS(216),
    [sym_keyword_and] = ACTIONS(216),
    [sym_keyword_or] = ACTIONS(218),
    [sym_keyword_is] = ACTIONS(216),
    [sym_keyword_not] = ACTIONS(218),
    [sym_keyword_contains] = ACTIONS(218),
    [sym_keyword_contains_not] = ACTIONS(216),
    [sym_keyword_contains_all] = ACTIONS(216),
    [sym_keyword_contains_any] = ACTIONS(216),
    [sym_keyword_contains_none] = ACTIONS(216),
    [sym_keyword_inside] = ACTIONS(216),
    [sym_keyword_in] = ACTIONS(218),
    [sym_keyword_not_inside] = ACTIONS(216),
    [sym_keyword_all_inside] = ACTIONS(216),
    [sym_keyword_any_inside] = ACTIONS(216),
    [sym_keyword_none_inside] = ACTIONS(216),
    [sym_keyword_outside] = ACTIONS(216),
    [sym_keyword_intersects] = ACTIONS(216),
    [anon_sym_EQ] = ACTIONS(218),
    [anon_sym_COMMA] = ACTIONS(216),
    [anon_sym_RPAREN] = ACTIONS(216),
    [anon_sym_DASH_GT] = ACTIONS(585),
    [anon_sym_LBRACK] = ACTIONS(588),
    [anon_sym_RBRACE] = ACTIONS(216),
    [anon_sym_LT] = ACTIONS(218),
    [anon_sym_GT] = ACTIONS(218),
    [anon_sym_LT_DASH] = ACTIONS(591),
    [anon_sym_LT_DASH_GT] = ACTIONS(585),
    [anon_sym_STAR] = ACTIONS(218),
    [anon_sym_DOT] = ACTIONS(594),
    [anon_sym_DASH] = ACTIONS(218),
    [anon_sym_PERCENT] = ACTIONS(216),
    [anon_sym_AT] = ACTIONS(218),
    [anon_sym_LT_PIPE] = ACTIONS(216),
    [anon_sym_AMP_AMP] = ACTIONS(216),
    [anon_sym_PIPE_PIPE] = ACTIONS(216),
    [anon_sym_QMARK_QMARK] = ACTIONS(216),
    [anon_sym_QMARK_COLON] = ACTIONS(216),
    [anon_sym_BANG_EQ] = ACTIONS(216),
    [anon_sym_EQ_EQ] = ACTIONS(216),
    [anon_sym_QMARK_EQ] = ACTIONS(216),
    [anon_sym_STAR_EQ] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(216),
    [anon_sym_BANG_TILDE] = ACTIONS(216),
    [anon_sym_STAR_TILDE] = ACTIONS(216),
    [anon_sym_LT_EQ] = ACTIONS(216),
    [anon_sym_GT_EQ] = ACTIONS(216),
    [anon_sym_PLUS] = ACTIONS(218),
    [anon_sym_PLUS_EQ] = ACTIONS(216),
    [anon_sym_DASH_EQ] = ACTIONS(216),
    [anon_sym_u00d7] = ACTIONS(216),
    [anon_sym_SLASH] = ACTIONS(218),
    [anon_sym_u00f7] = ACTIONS(216),
    [anon_sym_STAR_STAR] = ACTIONS(216),
    [anon_sym_u220b] = ACTIONS(216),
    [anon_sym_u220c] = ACTIONS(216),
    [anon_sym_u2287] = ACTIONS(216),
    [anon_sym_u2283] = ACTIONS(216),
    [anon_sym_u2285] = ACTIONS(216),
    [anon_sym_u2208] = ACTIONS(216),
    [anon_sym_u2209] = ACTIONS(216),
    [anon_sym_u2286] = ACTIONS(216),
    [anon_sym_u2282] = ACTIONS(216),
    [anon_sym_u2284] = ACTIONS(216),
    [anon_sym_AT_AT] = ACTIONS(216),
  },
  [STATE(195)] = {
    [sym_filter] = STATE(272),
    [sym_path_element] = STATE(200),
    [sym_graph_path] = STATE(272),
    [sym_subscript] = STATE(272),
    [aux_sym_path_repeat1] = STATE(200),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_order] = ACTIONS(236),
    [sym_keyword_with] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_split] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(238),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_DASH_GT] = ACTIONS(597),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_RBRACE] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_LT_DASH] = ACTIONS(601),
    [anon_sym_LT_DASH_GT] = ACTIONS(597),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DOT] = ACTIONS(603),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(196)] = {
    [sym_filter] = STATE(272),
    [sym_path_element] = STATE(200),
    [sym_graph_path] = STATE(272),
    [sym_subscript] = STATE(272),
    [aux_sym_path_repeat1] = STATE(200),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(196),
    [sym_keyword_explain] = ACTIONS(196),
    [sym_keyword_parallel] = ACTIONS(196),
    [sym_keyword_timeout] = ACTIONS(196),
    [sym_keyword_fetch] = ACTIONS(196),
    [sym_keyword_limit] = ACTIONS(196),
    [sym_keyword_order] = ACTIONS(196),
    [sym_keyword_with] = ACTIONS(196),
    [sym_keyword_where] = ACTIONS(196),
    [sym_keyword_split] = ACTIONS(196),
    [sym_keyword_group] = ACTIONS(196),
    [sym_keyword_and] = ACTIONS(196),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(196),
    [sym_keyword_not] = ACTIONS(198),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(196),
    [sym_keyword_contains_all] = ACTIONS(196),
    [sym_keyword_contains_any] = ACTIONS(196),
    [sym_keyword_contains_none] = ACTIONS(196),
    [sym_keyword_inside] = ACTIONS(196),
    [sym_keyword_in] = ACTIONS(198),
    [sym_keyword_not_inside] = ACTIONS(196),
    [sym_keyword_all_inside] = ACTIONS(196),
    [sym_keyword_any_inside] = ACTIONS(196),
    [sym_keyword_none_inside] = ACTIONS(196),
    [sym_keyword_outside] = ACTIONS(196),
    [sym_keyword_intersects] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(196),
    [anon_sym_RPAREN] = ACTIONS(196),
    [anon_sym_DASH_GT] = ACTIONS(597),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_RBRACE] = ACTIONS(196),
    [anon_sym_LT] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(601),
    [anon_sym_LT_DASH_GT] = ACTIONS(597),
    [anon_sym_STAR] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(603),
    [anon_sym_DASH] = ACTIONS(198),
    [anon_sym_PERCENT] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(198),
    [anon_sym_LT_PIPE] = ACTIONS(196),
    [anon_sym_AMP_AMP] = ACTIONS(196),
    [anon_sym_PIPE_PIPE] = ACTIONS(196),
    [anon_sym_QMARK_QMARK] = ACTIONS(196),
    [anon_sym_QMARK_COLON] = ACTIONS(196),
    [anon_sym_BANG_EQ] = ACTIONS(196),
    [anon_sym_EQ_EQ] = ACTIONS(196),
    [anon_sym_QMARK_EQ] = ACTIONS(196),
    [anon_sym_STAR_EQ] = ACTIONS(196),
    [anon_sym_TILDE] = ACTIONS(196),
    [anon_sym_BANG_TILDE] = ACTIONS(196),
    [anon_sym_STAR_TILDE] = ACTIONS(196),
    [anon_sym_LT_EQ] = ACTIONS(196),
    [anon_sym_GT_EQ] = ACTIONS(196),
    [anon_sym_PLUS] = ACTIONS(198),
    [anon_sym_PLUS_EQ] = ACTIONS(196),
    [anon_sym_DASH_EQ] = ACTIONS(196),
    [anon_sym_u00d7] = ACTIONS(196),
    [anon_sym_SLASH] = ACTIONS(198),
    [anon_sym_u00f7] = ACTIONS(196),
    [anon_sym_STAR_STAR] = ACTIONS(196),
    [anon_sym_u220b] = ACTIONS(196),
    [anon_sym_u220c] = ACTIONS(196),
    [anon_sym_u2287] = ACTIONS(196),
    [anon_sym_u2283] = ACTIONS(196),
    [anon_sym_u2285] = ACTIONS(196),
    [anon_sym_u2208] = ACTIONS(196),
    [anon_sym_u2209] = ACTIONS(196),
    [anon_sym_u2286] = ACTIONS(196),
    [anon_sym_u2282] = ACTIONS(196),
    [anon_sym_u2284] = ACTIONS(196),
    [anon_sym_AT_AT] = ACTIONS(196),
  },
  [STATE(197)] = {
    [sym_filter] = STATE(272),
    [sym_path_element] = STATE(200),
    [sym_graph_path] = STATE(272),
    [sym_subscript] = STATE(272),
    [aux_sym_path_repeat1] = STATE(200),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_order] = ACTIONS(204),
    [sym_keyword_with] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_split] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(597),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(601),
    [anon_sym_LT_DASH_GT] = ACTIONS(597),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(603),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(198)] = {
    [sym_where_clause] = STATE(1614),
    [sym_timeout_clause] = STATE(1787),
    [sym_parallel_clause] = STATE(2150),
    [sym_content_clause] = STATE(1430),
    [sym_set_clause] = STATE(1430),
    [sym_unset_clause] = STATE(1430),
    [sym_return_clause] = STATE(1616),
    [sym_merge_clause] = STATE(1430),
    [sym_patch_clause] = STATE(2150),
    [sym_operator] = STATE(939),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1147),
    [ts_builtin_sym_end] = ACTIONS(545),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(545),
    [sym_keyword_return] = ACTIONS(605),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(607),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_unset] = ACTIONS(551),
    [sym_keyword_set] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(199)] = {
    [sym_where_clause] = STATE(1682),
    [sym_timeout_clause] = STATE(1850),
    [sym_parallel_clause] = STATE(2109),
    [sym_content_clause] = STATE(1429),
    [sym_set_clause] = STATE(1429),
    [sym_unset_clause] = STATE(1429),
    [sym_return_clause] = STATE(1683),
    [sym_merge_clause] = STATE(1429),
    [sym_patch_clause] = STATE(2109),
    [sym_operator] = STATE(939),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1148),
    [ts_builtin_sym_end] = ACTIONS(583),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(583),
    [sym_keyword_return] = ACTIONS(605),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(607),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(465),
    [sym_keyword_merge] = ACTIONS(467),
    [sym_keyword_patch] = ACTIONS(469),
    [sym_keyword_unset] = ACTIONS(551),
    [sym_keyword_set] = ACTIONS(609),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(611),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(200)] = {
    [sym_filter] = STATE(272),
    [sym_path_element] = STATE(194),
    [sym_graph_path] = STATE(272),
    [sym_subscript] = STATE(272),
    [aux_sym_path_repeat1] = STATE(194),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(212),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_with] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(214),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(214),
    [sym_keyword_contains] = ACTIONS(214),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(214),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(214),
    [anon_sym_COMMA] = ACTIONS(212),
    [anon_sym_RPAREN] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(597),
    [anon_sym_LBRACK] = ACTIONS(599),
    [anon_sym_RBRACE] = ACTIONS(212),
    [anon_sym_LT] = ACTIONS(214),
    [anon_sym_GT] = ACTIONS(214),
    [anon_sym_LT_DASH] = ACTIONS(601),
    [anon_sym_LT_DASH_GT] = ACTIONS(597),
    [anon_sym_STAR] = ACTIONS(214),
    [anon_sym_DOT] = ACTIONS(603),
    [anon_sym_DASH] = ACTIONS(214),
    [anon_sym_PERCENT] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(214),
    [anon_sym_LT_PIPE] = ACTIONS(212),
    [anon_sym_AMP_AMP] = ACTIONS(212),
    [anon_sym_PIPE_PIPE] = ACTIONS(212),
    [anon_sym_QMARK_QMARK] = ACTIONS(212),
    [anon_sym_QMARK_COLON] = ACTIONS(212),
    [anon_sym_BANG_EQ] = ACTIONS(212),
    [anon_sym_EQ_EQ] = ACTIONS(212),
    [anon_sym_QMARK_EQ] = ACTIONS(212),
    [anon_sym_STAR_EQ] = ACTIONS(212),
    [anon_sym_TILDE] = ACTIONS(212),
    [anon_sym_BANG_TILDE] = ACTIONS(212),
    [anon_sym_STAR_TILDE] = ACTIONS(212),
    [anon_sym_LT_EQ] = ACTIONS(212),
    [anon_sym_GT_EQ] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(214),
    [anon_sym_PLUS_EQ] = ACTIONS(212),
    [anon_sym_DASH_EQ] = ACTIONS(212),
    [anon_sym_u00d7] = ACTIONS(212),
    [anon_sym_SLASH] = ACTIONS(214),
    [anon_sym_u00f7] = ACTIONS(212),
    [anon_sym_STAR_STAR] = ACTIONS(212),
    [anon_sym_u220b] = ACTIONS(212),
    [anon_sym_u220c] = ACTIONS(212),
    [anon_sym_u2287] = ACTIONS(212),
    [anon_sym_u2283] = ACTIONS(212),
    [anon_sym_u2285] = ACTIONS(212),
    [anon_sym_u2208] = ACTIONS(212),
    [anon_sym_u2209] = ACTIONS(212),
    [anon_sym_u2286] = ACTIONS(212),
    [anon_sym_u2282] = ACTIONS(212),
    [anon_sym_u2284] = ACTIONS(212),
    [anon_sym_AT_AT] = ACTIONS(212),
  },
  [STATE(201)] = {
    [sym_array] = STATE(284),
    [sym_object] = STATE(284),
    [sym_record_id_value] = STATE(347),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_order] = ACTIONS(537),
    [sym_keyword_with] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_split] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(619),
    [sym_record_id_ident] = ACTIONS(619),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(202)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_content] = ACTIONS(537),
    [sym_keyword_merge] = ACTIONS(537),
    [sym_keyword_patch] = ACTIONS(537),
    [sym_keyword_unset] = ACTIONS(537),
    [sym_keyword_set] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(203)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_rand] = ACTIONS(537),
    [sym_keyword_collate] = ACTIONS(537),
    [sym_keyword_numeric] = ACTIONS(537),
    [sym_keyword_asc] = ACTIONS(537),
    [sym_keyword_desc] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(204)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_rand] = ACTIONS(316),
    [sym_keyword_collate] = ACTIONS(316),
    [sym_keyword_numeric] = ACTIONS(316),
    [sym_keyword_asc] = ACTIONS(316),
    [sym_keyword_desc] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(205)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_content] = ACTIONS(316),
    [sym_keyword_merge] = ACTIONS(316),
    [sym_keyword_patch] = ACTIONS(316),
    [sym_keyword_unset] = ACTIONS(316),
    [sym_keyword_set] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(206)] = {
    [sym_array] = STATE(284),
    [sym_object] = STATE(284),
    [sym_record_id_value] = STATE(321),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_order] = ACTIONS(316),
    [sym_keyword_with] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_split] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(621),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(619),
    [sym_record_id_ident] = ACTIONS(619),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(207)] = {
    [sym_array] = STATE(243),
    [sym_object] = STATE(243),
    [sym_record_id_value] = STATE(294),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_order] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_split] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(573),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(579),
    [sym_record_id_ident] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(208)] = {
    [sym_array] = STATE(243),
    [sym_object] = STATE(243),
    [sym_record_id_value] = STATE(301),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_order] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_split] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(581),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(579),
    [sym_record_id_ident] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(209)] = {
    [sym_filter] = STATE(341),
    [sym_path_element] = STATE(220),
    [sym_graph_path] = STATE(341),
    [sym_subscript] = STATE(341),
    [aux_sym_path_repeat1] = STATE(220),
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_order] = ACTIONS(204),
    [sym_keyword_with] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_split] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(625),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(627),
    [anon_sym_LT_DASH_GT] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(629),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(210)] = {
    [sym_filter] = STATE(341),
    [sym_path_element] = STATE(210),
    [sym_graph_path] = STATE(341),
    [sym_subscript] = STATE(341),
    [aux_sym_path_repeat1] = STATE(210),
    [ts_builtin_sym_end] = ACTIONS(216),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(216),
    [sym_keyword_explain] = ACTIONS(216),
    [sym_keyword_parallel] = ACTIONS(216),
    [sym_keyword_timeout] = ACTIONS(216),
    [sym_keyword_fetch] = ACTIONS(216),
    [sym_keyword_limit] = ACTIONS(216),
    [sym_keyword_order] = ACTIONS(216),
    [sym_keyword_with] = ACTIONS(216),
    [sym_keyword_where] = ACTIONS(216),
    [sym_keyword_split] = ACTIONS(216),
    [sym_keyword_group] = ACTIONS(216),
    [sym_keyword_and] = ACTIONS(216),
    [sym_keyword_or] = ACTIONS(218),
    [sym_keyword_is] = ACTIONS(216),
    [sym_keyword_not] = ACTIONS(218),
    [sym_keyword_contains] = ACTIONS(218),
    [sym_keyword_contains_not] = ACTIONS(216),
    [sym_keyword_contains_all] = ACTIONS(216),
    [sym_keyword_contains_any] = ACTIONS(216),
    [sym_keyword_contains_none] = ACTIONS(216),
    [sym_keyword_inside] = ACTIONS(216),
    [sym_keyword_in] = ACTIONS(218),
    [sym_keyword_not_inside] = ACTIONS(216),
    [sym_keyword_all_inside] = ACTIONS(216),
    [sym_keyword_any_inside] = ACTIONS(216),
    [sym_keyword_none_inside] = ACTIONS(216),
    [sym_keyword_outside] = ACTIONS(216),
    [sym_keyword_intersects] = ACTIONS(216),
    [anon_sym_EQ] = ACTIONS(218),
    [anon_sym_COMMA] = ACTIONS(216),
    [anon_sym_DASH_GT] = ACTIONS(631),
    [anon_sym_LBRACK] = ACTIONS(634),
    [anon_sym_LT] = ACTIONS(218),
    [anon_sym_GT] = ACTIONS(218),
    [anon_sym_LT_DASH] = ACTIONS(637),
    [anon_sym_LT_DASH_GT] = ACTIONS(631),
    [anon_sym_STAR] = ACTIONS(218),
    [anon_sym_DOT] = ACTIONS(640),
    [anon_sym_DASH] = ACTIONS(218),
    [anon_sym_PERCENT] = ACTIONS(216),
    [anon_sym_AT] = ACTIONS(218),
    [anon_sym_LT_PIPE] = ACTIONS(216),
    [anon_sym_AMP_AMP] = ACTIONS(216),
    [anon_sym_PIPE_PIPE] = ACTIONS(216),
    [anon_sym_QMARK_QMARK] = ACTIONS(216),
    [anon_sym_QMARK_COLON] = ACTIONS(216),
    [anon_sym_BANG_EQ] = ACTIONS(216),
    [anon_sym_EQ_EQ] = ACTIONS(216),
    [anon_sym_QMARK_EQ] = ACTIONS(216),
    [anon_sym_STAR_EQ] = ACTIONS(216),
    [anon_sym_TILDE] = ACTIONS(216),
    [anon_sym_BANG_TILDE] = ACTIONS(216),
    [anon_sym_STAR_TILDE] = ACTIONS(216),
    [anon_sym_LT_EQ] = ACTIONS(216),
    [anon_sym_GT_EQ] = ACTIONS(216),
    [anon_sym_PLUS] = ACTIONS(218),
    [anon_sym_PLUS_EQ] = ACTIONS(216),
    [anon_sym_DASH_EQ] = ACTIONS(216),
    [anon_sym_u00d7] = ACTIONS(216),
    [anon_sym_SLASH] = ACTIONS(218),
    [anon_sym_u00f7] = ACTIONS(216),
    [anon_sym_STAR_STAR] = ACTIONS(216),
    [anon_sym_u220b] = ACTIONS(216),
    [anon_sym_u220c] = ACTIONS(216),
    [anon_sym_u2287] = ACTIONS(216),
    [anon_sym_u2283] = ACTIONS(216),
    [anon_sym_u2285] = ACTIONS(216),
    [anon_sym_u2208] = ACTIONS(216),
    [anon_sym_u2209] = ACTIONS(216),
    [anon_sym_u2286] = ACTIONS(216),
    [anon_sym_u2282] = ACTIONS(216),
    [anon_sym_u2284] = ACTIONS(216),
    [anon_sym_AT_AT] = ACTIONS(216),
  },
  [STATE(211)] = {
    [sym_filter] = STATE(341),
    [sym_path_element] = STATE(220),
    [sym_graph_path] = STATE(341),
    [sym_subscript] = STATE(341),
    [aux_sym_path_repeat1] = STATE(220),
    [ts_builtin_sym_end] = ACTIONS(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_order] = ACTIONS(236),
    [sym_keyword_with] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_split] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(238),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_DASH_GT] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(625),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_LT_DASH] = ACTIONS(627),
    [anon_sym_LT_DASH_GT] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DOT] = ACTIONS(629),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(212)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_value] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_rand] = ACTIONS(204),
    [sym_keyword_collate] = ACTIONS(204),
    [sym_keyword_numeric] = ACTIONS(204),
    [sym_keyword_asc] = ACTIONS(204),
    [sym_keyword_desc] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(204),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [sym_keyword_flexible] = ACTIONS(204),
    [sym_keyword_readonly] = ACTIONS(204),
    [sym_keyword_type] = ACTIONS(204),
    [sym_keyword_default] = ACTIONS(204),
    [sym_keyword_assert] = ACTIONS(204),
    [sym_keyword_permissions] = ACTIONS(204),
    [sym_keyword_for] = ACTIONS(204),
    [sym_keyword_comment] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(213)] = {
    [sym_filter] = STATE(341),
    [sym_path_element] = STATE(220),
    [sym_graph_path] = STATE(341),
    [sym_subscript] = STATE(341),
    [aux_sym_path_repeat1] = STATE(220),
    [ts_builtin_sym_end] = ACTIONS(196),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(196),
    [sym_keyword_explain] = ACTIONS(196),
    [sym_keyword_parallel] = ACTIONS(196),
    [sym_keyword_timeout] = ACTIONS(196),
    [sym_keyword_fetch] = ACTIONS(196),
    [sym_keyword_limit] = ACTIONS(196),
    [sym_keyword_order] = ACTIONS(196),
    [sym_keyword_with] = ACTIONS(196),
    [sym_keyword_where] = ACTIONS(196),
    [sym_keyword_split] = ACTIONS(196),
    [sym_keyword_group] = ACTIONS(196),
    [sym_keyword_and] = ACTIONS(196),
    [sym_keyword_or] = ACTIONS(198),
    [sym_keyword_is] = ACTIONS(196),
    [sym_keyword_not] = ACTIONS(198),
    [sym_keyword_contains] = ACTIONS(198),
    [sym_keyword_contains_not] = ACTIONS(196),
    [sym_keyword_contains_all] = ACTIONS(196),
    [sym_keyword_contains_any] = ACTIONS(196),
    [sym_keyword_contains_none] = ACTIONS(196),
    [sym_keyword_inside] = ACTIONS(196),
    [sym_keyword_in] = ACTIONS(198),
    [sym_keyword_not_inside] = ACTIONS(196),
    [sym_keyword_all_inside] = ACTIONS(196),
    [sym_keyword_any_inside] = ACTIONS(196),
    [sym_keyword_none_inside] = ACTIONS(196),
    [sym_keyword_outside] = ACTIONS(196),
    [sym_keyword_intersects] = ACTIONS(196),
    [anon_sym_EQ] = ACTIONS(198),
    [anon_sym_COMMA] = ACTIONS(196),
    [anon_sym_DASH_GT] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(625),
    [anon_sym_LT] = ACTIONS(198),
    [anon_sym_GT] = ACTIONS(198),
    [anon_sym_LT_DASH] = ACTIONS(627),
    [anon_sym_LT_DASH_GT] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(198),
    [anon_sym_DOT] = ACTIONS(629),
    [anon_sym_DASH] = ACTIONS(198),
    [anon_sym_PERCENT] = ACTIONS(196),
    [anon_sym_AT] = ACTIONS(198),
    [anon_sym_LT_PIPE] = ACTIONS(196),
    [anon_sym_AMP_AMP] = ACTIONS(196),
    [anon_sym_PIPE_PIPE] = ACTIONS(196),
    [anon_sym_QMARK_QMARK] = ACTIONS(196),
    [anon_sym_QMARK_COLON] = ACTIONS(196),
    [anon_sym_BANG_EQ] = ACTIONS(196),
    [anon_sym_EQ_EQ] = ACTIONS(196),
    [anon_sym_QMARK_EQ] = ACTIONS(196),
    [anon_sym_STAR_EQ] = ACTIONS(196),
    [anon_sym_TILDE] = ACTIONS(196),
    [anon_sym_BANG_TILDE] = ACTIONS(196),
    [anon_sym_STAR_TILDE] = ACTIONS(196),
    [anon_sym_LT_EQ] = ACTIONS(196),
    [anon_sym_GT_EQ] = ACTIONS(196),
    [anon_sym_PLUS] = ACTIONS(198),
    [anon_sym_PLUS_EQ] = ACTIONS(196),
    [anon_sym_DASH_EQ] = ACTIONS(196),
    [anon_sym_u00d7] = ACTIONS(196),
    [anon_sym_SLASH] = ACTIONS(198),
    [anon_sym_u00f7] = ACTIONS(196),
    [anon_sym_STAR_STAR] = ACTIONS(196),
    [anon_sym_u220b] = ACTIONS(196),
    [anon_sym_u220c] = ACTIONS(196),
    [anon_sym_u2287] = ACTIONS(196),
    [anon_sym_u2283] = ACTIONS(196),
    [anon_sym_u2285] = ACTIONS(196),
    [anon_sym_u2208] = ACTIONS(196),
    [anon_sym_u2209] = ACTIONS(196),
    [anon_sym_u2286] = ACTIONS(196),
    [anon_sym_u2282] = ACTIONS(196),
    [anon_sym_u2284] = ACTIONS(196),
    [anon_sym_AT_AT] = ACTIONS(196),
  },
  [STATE(214)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_content] = ACTIONS(537),
    [sym_keyword_merge] = ACTIONS(537),
    [sym_keyword_patch] = ACTIONS(537),
    [sym_keyword_unset] = ACTIONS(537),
    [sym_keyword_set] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(215)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_content] = ACTIONS(316),
    [sym_keyword_merge] = ACTIONS(316),
    [sym_keyword_patch] = ACTIONS(316),
    [sym_keyword_unset] = ACTIONS(316),
    [sym_keyword_set] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(216)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_value] = ACTIONS(375),
    [sym_keyword_explain] = ACTIONS(375),
    [sym_keyword_parallel] = ACTIONS(375),
    [sym_keyword_timeout] = ACTIONS(375),
    [sym_keyword_fetch] = ACTIONS(375),
    [sym_keyword_limit] = ACTIONS(375),
    [sym_keyword_rand] = ACTIONS(375),
    [sym_keyword_collate] = ACTIONS(375),
    [sym_keyword_numeric] = ACTIONS(375),
    [sym_keyword_asc] = ACTIONS(375),
    [sym_keyword_desc] = ACTIONS(375),
    [sym_keyword_and] = ACTIONS(375),
    [sym_keyword_or] = ACTIONS(375),
    [sym_keyword_is] = ACTIONS(375),
    [sym_keyword_not] = ACTIONS(377),
    [sym_keyword_contains] = ACTIONS(377),
    [sym_keyword_contains_not] = ACTIONS(375),
    [sym_keyword_contains_all] = ACTIONS(375),
    [sym_keyword_contains_any] = ACTIONS(375),
    [sym_keyword_contains_none] = ACTIONS(375),
    [sym_keyword_inside] = ACTIONS(375),
    [sym_keyword_in] = ACTIONS(377),
    [sym_keyword_not_inside] = ACTIONS(375),
    [sym_keyword_all_inside] = ACTIONS(375),
    [sym_keyword_any_inside] = ACTIONS(375),
    [sym_keyword_none_inside] = ACTIONS(375),
    [sym_keyword_outside] = ACTIONS(375),
    [sym_keyword_intersects] = ACTIONS(375),
    [sym_keyword_flexible] = ACTIONS(375),
    [sym_keyword_readonly] = ACTIONS(375),
    [sym_keyword_type] = ACTIONS(375),
    [sym_keyword_default] = ACTIONS(375),
    [sym_keyword_assert] = ACTIONS(375),
    [sym_keyword_permissions] = ACTIONS(375),
    [sym_keyword_for] = ACTIONS(375),
    [sym_keyword_comment] = ACTIONS(375),
    [anon_sym_EQ] = ACTIONS(377),
    [anon_sym_COMMA] = ACTIONS(375),
    [anon_sym_RPAREN] = ACTIONS(375),
    [anon_sym_RBRACE] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PERCENT] = ACTIONS(375),
    [anon_sym_AT] = ACTIONS(377),
    [anon_sym_LT_PIPE] = ACTIONS(375),
    [anon_sym_AMP_AMP] = ACTIONS(375),
    [anon_sym_PIPE_PIPE] = ACTIONS(375),
    [anon_sym_QMARK_QMARK] = ACTIONS(375),
    [anon_sym_QMARK_COLON] = ACTIONS(375),
    [anon_sym_BANG_EQ] = ACTIONS(375),
    [anon_sym_EQ_EQ] = ACTIONS(375),
    [anon_sym_QMARK_EQ] = ACTIONS(375),
    [anon_sym_STAR_EQ] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(375),
    [anon_sym_BANG_TILDE] = ACTIONS(375),
    [anon_sym_STAR_TILDE] = ACTIONS(375),
    [anon_sym_LT_EQ] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(375),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_PLUS_EQ] = ACTIONS(375),
    [anon_sym_DASH_EQ] = ACTIONS(375),
    [anon_sym_u00d7] = ACTIONS(375),
    [anon_sym_SLASH] = ACTIONS(377),
    [anon_sym_u00f7] = ACTIONS(375),
    [anon_sym_STAR_STAR] = ACTIONS(375),
    [anon_sym_u220b] = ACTIONS(375),
    [anon_sym_u220c] = ACTIONS(375),
    [anon_sym_u2287] = ACTIONS(375),
    [anon_sym_u2283] = ACTIONS(375),
    [anon_sym_u2285] = ACTIONS(375),
    [anon_sym_u2208] = ACTIONS(375),
    [anon_sym_u2209] = ACTIONS(375),
    [anon_sym_u2286] = ACTIONS(375),
    [anon_sym_u2282] = ACTIONS(375),
    [anon_sym_u2284] = ACTIONS(375),
    [anon_sym_AT_AT] = ACTIONS(375),
  },
  [STATE(217)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(379),
    [sym_keyword_value] = ACTIONS(379),
    [sym_keyword_explain] = ACTIONS(379),
    [sym_keyword_parallel] = ACTIONS(379),
    [sym_keyword_timeout] = ACTIONS(379),
    [sym_keyword_fetch] = ACTIONS(379),
    [sym_keyword_limit] = ACTIONS(379),
    [sym_keyword_rand] = ACTIONS(379),
    [sym_keyword_collate] = ACTIONS(379),
    [sym_keyword_numeric] = ACTIONS(379),
    [sym_keyword_asc] = ACTIONS(379),
    [sym_keyword_desc] = ACTIONS(379),
    [sym_keyword_and] = ACTIONS(379),
    [sym_keyword_or] = ACTIONS(379),
    [sym_keyword_is] = ACTIONS(379),
    [sym_keyword_not] = ACTIONS(381),
    [sym_keyword_contains] = ACTIONS(381),
    [sym_keyword_contains_not] = ACTIONS(379),
    [sym_keyword_contains_all] = ACTIONS(379),
    [sym_keyword_contains_any] = ACTIONS(379),
    [sym_keyword_contains_none] = ACTIONS(379),
    [sym_keyword_inside] = ACTIONS(379),
    [sym_keyword_in] = ACTIONS(381),
    [sym_keyword_not_inside] = ACTIONS(379),
    [sym_keyword_all_inside] = ACTIONS(379),
    [sym_keyword_any_inside] = ACTIONS(379),
    [sym_keyword_none_inside] = ACTIONS(379),
    [sym_keyword_outside] = ACTIONS(379),
    [sym_keyword_intersects] = ACTIONS(379),
    [sym_keyword_flexible] = ACTIONS(379),
    [sym_keyword_readonly] = ACTIONS(379),
    [sym_keyword_type] = ACTIONS(379),
    [sym_keyword_default] = ACTIONS(379),
    [sym_keyword_assert] = ACTIONS(379),
    [sym_keyword_permissions] = ACTIONS(379),
    [sym_keyword_for] = ACTIONS(379),
    [sym_keyword_comment] = ACTIONS(379),
    [anon_sym_EQ] = ACTIONS(381),
    [anon_sym_COMMA] = ACTIONS(379),
    [anon_sym_RPAREN] = ACTIONS(379),
    [anon_sym_RBRACE] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PERCENT] = ACTIONS(379),
    [anon_sym_AT] = ACTIONS(381),
    [anon_sym_LT_PIPE] = ACTIONS(379),
    [anon_sym_AMP_AMP] = ACTIONS(379),
    [anon_sym_PIPE_PIPE] = ACTIONS(379),
    [anon_sym_QMARK_QMARK] = ACTIONS(379),
    [anon_sym_QMARK_COLON] = ACTIONS(379),
    [anon_sym_BANG_EQ] = ACTIONS(379),
    [anon_sym_EQ_EQ] = ACTIONS(379),
    [anon_sym_QMARK_EQ] = ACTIONS(379),
    [anon_sym_STAR_EQ] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(379),
    [anon_sym_BANG_TILDE] = ACTIONS(379),
    [anon_sym_STAR_TILDE] = ACTIONS(379),
    [anon_sym_LT_EQ] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_PLUS_EQ] = ACTIONS(379),
    [anon_sym_DASH_EQ] = ACTIONS(379),
    [anon_sym_u00d7] = ACTIONS(379),
    [anon_sym_SLASH] = ACTIONS(381),
    [anon_sym_u00f7] = ACTIONS(379),
    [anon_sym_STAR_STAR] = ACTIONS(379),
    [anon_sym_u220b] = ACTIONS(379),
    [anon_sym_u220c] = ACTIONS(379),
    [anon_sym_u2287] = ACTIONS(379),
    [anon_sym_u2283] = ACTIONS(379),
    [anon_sym_u2285] = ACTIONS(379),
    [anon_sym_u2208] = ACTIONS(379),
    [anon_sym_u2209] = ACTIONS(379),
    [anon_sym_u2286] = ACTIONS(379),
    [anon_sym_u2282] = ACTIONS(379),
    [anon_sym_u2284] = ACTIONS(379),
    [anon_sym_AT_AT] = ACTIONS(379),
  },
  [STATE(218)] = {
    [sym_array] = STATE(284),
    [sym_object] = STATE(284),
    [sym_record_id_value] = STATE(347),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_order] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_split] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(619),
    [sym_record_id_ident] = ACTIONS(619),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(219)] = {
    [sym_array] = STATE(284),
    [sym_object] = STATE(284),
    [sym_record_id_value] = STATE(321),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_order] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_split] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(621),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(619),
    [sym_record_id_ident] = ACTIONS(619),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(220)] = {
    [sym_filter] = STATE(341),
    [sym_path_element] = STATE(210),
    [sym_graph_path] = STATE(341),
    [sym_subscript] = STATE(341),
    [aux_sym_path_repeat1] = STATE(210),
    [ts_builtin_sym_end] = ACTIONS(212),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(212),
    [sym_keyword_explain] = ACTIONS(212),
    [sym_keyword_parallel] = ACTIONS(212),
    [sym_keyword_timeout] = ACTIONS(212),
    [sym_keyword_fetch] = ACTIONS(212),
    [sym_keyword_limit] = ACTIONS(212),
    [sym_keyword_order] = ACTIONS(212),
    [sym_keyword_with] = ACTIONS(212),
    [sym_keyword_where] = ACTIONS(212),
    [sym_keyword_split] = ACTIONS(212),
    [sym_keyword_group] = ACTIONS(212),
    [sym_keyword_and] = ACTIONS(212),
    [sym_keyword_or] = ACTIONS(214),
    [sym_keyword_is] = ACTIONS(212),
    [sym_keyword_not] = ACTIONS(214),
    [sym_keyword_contains] = ACTIONS(214),
    [sym_keyword_contains_not] = ACTIONS(212),
    [sym_keyword_contains_all] = ACTIONS(212),
    [sym_keyword_contains_any] = ACTIONS(212),
    [sym_keyword_contains_none] = ACTIONS(212),
    [sym_keyword_inside] = ACTIONS(212),
    [sym_keyword_in] = ACTIONS(214),
    [sym_keyword_not_inside] = ACTIONS(212),
    [sym_keyword_all_inside] = ACTIONS(212),
    [sym_keyword_any_inside] = ACTIONS(212),
    [sym_keyword_none_inside] = ACTIONS(212),
    [sym_keyword_outside] = ACTIONS(212),
    [sym_keyword_intersects] = ACTIONS(212),
    [anon_sym_EQ] = ACTIONS(214),
    [anon_sym_COMMA] = ACTIONS(212),
    [anon_sym_DASH_GT] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(625),
    [anon_sym_LT] = ACTIONS(214),
    [anon_sym_GT] = ACTIONS(214),
    [anon_sym_LT_DASH] = ACTIONS(627),
    [anon_sym_LT_DASH_GT] = ACTIONS(623),
    [anon_sym_STAR] = ACTIONS(214),
    [anon_sym_DOT] = ACTIONS(629),
    [anon_sym_DASH] = ACTIONS(214),
    [anon_sym_PERCENT] = ACTIONS(212),
    [anon_sym_AT] = ACTIONS(214),
    [anon_sym_LT_PIPE] = ACTIONS(212),
    [anon_sym_AMP_AMP] = ACTIONS(212),
    [anon_sym_PIPE_PIPE] = ACTIONS(212),
    [anon_sym_QMARK_QMARK] = ACTIONS(212),
    [anon_sym_QMARK_COLON] = ACTIONS(212),
    [anon_sym_BANG_EQ] = ACTIONS(212),
    [anon_sym_EQ_EQ] = ACTIONS(212),
    [anon_sym_QMARK_EQ] = ACTIONS(212),
    [anon_sym_STAR_EQ] = ACTIONS(212),
    [anon_sym_TILDE] = ACTIONS(212),
    [anon_sym_BANG_TILDE] = ACTIONS(212),
    [anon_sym_STAR_TILDE] = ACTIONS(212),
    [anon_sym_LT_EQ] = ACTIONS(212),
    [anon_sym_GT_EQ] = ACTIONS(212),
    [anon_sym_PLUS] = ACTIONS(214),
    [anon_sym_PLUS_EQ] = ACTIONS(212),
    [anon_sym_DASH_EQ] = ACTIONS(212),
    [anon_sym_u00d7] = ACTIONS(212),
    [anon_sym_SLASH] = ACTIONS(214),
    [anon_sym_u00f7] = ACTIONS(212),
    [anon_sym_STAR_STAR] = ACTIONS(212),
    [anon_sym_u220b] = ACTIONS(212),
    [anon_sym_u220c] = ACTIONS(212),
    [anon_sym_u2287] = ACTIONS(212),
    [anon_sym_u2283] = ACTIONS(212),
    [anon_sym_u2285] = ACTIONS(212),
    [anon_sym_u2208] = ACTIONS(212),
    [anon_sym_u2209] = ACTIONS(212),
    [anon_sym_u2286] = ACTIONS(212),
    [anon_sym_u2282] = ACTIONS(212),
    [anon_sym_u2284] = ACTIONS(212),
    [anon_sym_AT_AT] = ACTIONS(212),
  },
  [STATE(221)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_value] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_rand] = ACTIONS(236),
    [sym_keyword_collate] = ACTIONS(236),
    [sym_keyword_numeric] = ACTIONS(236),
    [sym_keyword_asc] = ACTIONS(236),
    [sym_keyword_desc] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(236),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [sym_keyword_flexible] = ACTIONS(236),
    [sym_keyword_readonly] = ACTIONS(236),
    [sym_keyword_type] = ACTIONS(236),
    [sym_keyword_default] = ACTIONS(236),
    [sym_keyword_assert] = ACTIONS(236),
    [sym_keyword_permissions] = ACTIONS(236),
    [sym_keyword_for] = ACTIONS(236),
    [sym_keyword_comment] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_RBRACE] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(222)] = {
    [sym_array] = STATE(138),
    [sym_object] = STATE(138),
    [sym_record_id_value] = STATE(166),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_value] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_flexible] = ACTIONS(537),
    [sym_keyword_readonly] = ACTIONS(537),
    [sym_keyword_type] = ACTIONS(537),
    [sym_keyword_default] = ACTIONS(537),
    [sym_keyword_assert] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_for] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(563),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(565),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(569),
    [sym_record_id_ident] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(223)] = {
    [sym_array] = STATE(138),
    [sym_object] = STATE(138),
    [sym_record_id_value] = STATE(171),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_value] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_flexible] = ACTIONS(316),
    [sym_keyword_readonly] = ACTIONS(316),
    [sym_keyword_type] = ACTIONS(316),
    [sym_keyword_default] = ACTIONS(316),
    [sym_keyword_assert] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_for] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(571),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(565),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(569),
    [sym_record_id_ident] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(224)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_value] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_flexible] = ACTIONS(537),
    [sym_keyword_readonly] = ACTIONS(537),
    [sym_keyword_type] = ACTIONS(537),
    [sym_keyword_default] = ACTIONS(537),
    [sym_keyword_assert] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_for] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(225)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_value] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_flexible] = ACTIONS(316),
    [sym_keyword_readonly] = ACTIONS(316),
    [sym_keyword_type] = ACTIONS(316),
    [sym_keyword_default] = ACTIONS(316),
    [sym_keyword_assert] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_for] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(226)] = {
    [sym_array] = STATE(243),
    [sym_object] = STATE(243),
    [sym_record_id_value] = STATE(301),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_order] = ACTIONS(316),
    [sym_keyword_split] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(581),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(579),
    [sym_record_id_ident] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(227)] = {
    [sym_array] = STATE(138),
    [sym_object] = STATE(138),
    [sym_record_id_value] = STATE(166),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_value] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_flexible] = ACTIONS(537),
    [sym_keyword_readonly] = ACTIONS(537),
    [sym_keyword_type] = ACTIONS(537),
    [sym_keyword_default] = ACTIONS(537),
    [sym_keyword_assert] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(563),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(565),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(569),
    [sym_record_id_ident] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(228)] = {
    [sym_array] = STATE(138),
    [sym_object] = STATE(138),
    [sym_record_id_value] = STATE(171),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_value] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_flexible] = ACTIONS(316),
    [sym_keyword_readonly] = ACTIONS(316),
    [sym_keyword_type] = ACTIONS(316),
    [sym_keyword_default] = ACTIONS(316),
    [sym_keyword_assert] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(571),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(565),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(569),
    [sym_record_id_ident] = ACTIONS(569),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(229)] = {
    [sym_array] = STATE(243),
    [sym_object] = STATE(243),
    [sym_record_id_value] = STATE(294),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_order] = ACTIONS(537),
    [sym_keyword_split] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(573),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(579),
    [sym_record_id_ident] = ACTIONS(579),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(230)] = {
    [sym_argument_list] = STATE(292),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_order] = ACTIONS(278),
    [sym_keyword_with] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_split] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(280),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_LPAREN] = ACTIONS(643),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(231)] = {
    [aux_sym_function_call_repeat1] = STATE(1857),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_order] = ACTIONS(304),
    [sym_keyword_with] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_split] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(306),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_RPAREN] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(304),
    [anon_sym_COLON_COLON] = ACTIONS(308),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(232)] = {
    [sym_array] = STATE(284),
    [sym_object] = STATE(284),
    [sym_record_id_value] = STATE(347),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_order] = ACTIONS(537),
    [sym_keyword_split] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(613),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(619),
    [sym_record_id_ident] = ACTIONS(619),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(233)] = {
    [sym_array] = STATE(284),
    [sym_object] = STATE(284),
    [sym_record_id_value] = STATE(321),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_order] = ACTIONS(316),
    [sym_keyword_split] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(621),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(619),
    [sym_record_id_ident] = ACTIONS(619),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(234)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_value] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_flexible] = ACTIONS(537),
    [sym_keyword_readonly] = ACTIONS(537),
    [sym_keyword_type] = ACTIONS(537),
    [sym_keyword_default] = ACTIONS(537),
    [sym_keyword_assert] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(235)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_value] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_flexible] = ACTIONS(316),
    [sym_keyword_readonly] = ACTIONS(316),
    [sym_keyword_type] = ACTIONS(316),
    [sym_keyword_default] = ACTIONS(316),
    [sym_keyword_assert] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(236)] = {
    [aux_sym_duration_repeat1] = STATE(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(179),
    [sym_keyword_explain] = ACTIONS(179),
    [sym_keyword_parallel] = ACTIONS(179),
    [sym_keyword_timeout] = ACTIONS(179),
    [sym_keyword_fetch] = ACTIONS(179),
    [sym_keyword_limit] = ACTIONS(179),
    [sym_keyword_order] = ACTIONS(179),
    [sym_keyword_with] = ACTIONS(179),
    [sym_keyword_where] = ACTIONS(179),
    [sym_keyword_split] = ACTIONS(179),
    [sym_keyword_group] = ACTIONS(179),
    [sym_keyword_and] = ACTIONS(179),
    [sym_keyword_or] = ACTIONS(181),
    [sym_keyword_is] = ACTIONS(179),
    [sym_keyword_not] = ACTIONS(181),
    [sym_keyword_contains] = ACTIONS(181),
    [sym_keyword_contains_not] = ACTIONS(179),
    [sym_keyword_contains_all] = ACTIONS(179),
    [sym_keyword_contains_any] = ACTIONS(179),
    [sym_keyword_contains_none] = ACTIONS(179),
    [sym_keyword_inside] = ACTIONS(179),
    [sym_keyword_in] = ACTIONS(181),
    [sym_keyword_not_inside] = ACTIONS(179),
    [sym_keyword_all_inside] = ACTIONS(179),
    [sym_keyword_any_inside] = ACTIONS(179),
    [sym_keyword_none_inside] = ACTIONS(179),
    [sym_keyword_outside] = ACTIONS(179),
    [sym_keyword_intersects] = ACTIONS(179),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_COMMA] = ACTIONS(179),
    [anon_sym_RPAREN] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(179),
    [anon_sym_LBRACK] = ACTIONS(179),
    [anon_sym_RBRACE] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH_GT] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_DOT] = ACTIONS(179),
    [sym_duration_part] = ACTIONS(645),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_PERCENT] = ACTIONS(179),
    [anon_sym_AT] = ACTIONS(181),
    [anon_sym_LT_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_QMARK_QMARK] = ACTIONS(179),
    [anon_sym_QMARK_COLON] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_QMARK_EQ] = ACTIONS(179),
    [anon_sym_STAR_EQ] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG_TILDE] = ACTIONS(179),
    [anon_sym_STAR_TILDE] = ACTIONS(179),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_PLUS] = ACTIONS(181),
    [anon_sym_PLUS_EQ] = ACTIONS(179),
    [anon_sym_DASH_EQ] = ACTIONS(179),
    [anon_sym_u00d7] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(181),
    [anon_sym_u00f7] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(179),
    [anon_sym_u220b] = ACTIONS(179),
    [anon_sym_u220c] = ACTIONS(179),
    [anon_sym_u2287] = ACTIONS(179),
    [anon_sym_u2283] = ACTIONS(179),
    [anon_sym_u2285] = ACTIONS(179),
    [anon_sym_u2208] = ACTIONS(179),
    [anon_sym_u2209] = ACTIONS(179),
    [anon_sym_u2286] = ACTIONS(179),
    [anon_sym_u2282] = ACTIONS(179),
    [anon_sym_u2284] = ACTIONS(179),
    [anon_sym_AT_AT] = ACTIONS(179),
  },
  [STATE(237)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_order] = ACTIONS(93),
    [sym_keyword_with] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_split] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(194),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_COLON_COLON] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(238)] = {
    [aux_sym_duration_repeat1] = STATE(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(173),
    [sym_keyword_explain] = ACTIONS(173),
    [sym_keyword_parallel] = ACTIONS(173),
    [sym_keyword_timeout] = ACTIONS(173),
    [sym_keyword_fetch] = ACTIONS(173),
    [sym_keyword_limit] = ACTIONS(173),
    [sym_keyword_order] = ACTIONS(173),
    [sym_keyword_with] = ACTIONS(173),
    [sym_keyword_where] = ACTIONS(173),
    [sym_keyword_split] = ACTIONS(173),
    [sym_keyword_group] = ACTIONS(173),
    [sym_keyword_and] = ACTIONS(173),
    [sym_keyword_or] = ACTIONS(175),
    [sym_keyword_is] = ACTIONS(173),
    [sym_keyword_not] = ACTIONS(175),
    [sym_keyword_contains] = ACTIONS(175),
    [sym_keyword_contains_not] = ACTIONS(173),
    [sym_keyword_contains_all] = ACTIONS(173),
    [sym_keyword_contains_any] = ACTIONS(173),
    [sym_keyword_contains_none] = ACTIONS(173),
    [sym_keyword_inside] = ACTIONS(173),
    [sym_keyword_in] = ACTIONS(175),
    [sym_keyword_not_inside] = ACTIONS(173),
    [sym_keyword_all_inside] = ACTIONS(173),
    [sym_keyword_any_inside] = ACTIONS(173),
    [sym_keyword_none_inside] = ACTIONS(173),
    [sym_keyword_outside] = ACTIONS(173),
    [sym_keyword_intersects] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(175),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_RPAREN] = ACTIONS(173),
    [anon_sym_DASH_GT] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(173),
    [anon_sym_RBRACE] = ACTIONS(173),
    [anon_sym_LT] = ACTIONS(175),
    [anon_sym_GT] = ACTIONS(175),
    [anon_sym_LT_DASH] = ACTIONS(175),
    [anon_sym_LT_DASH_GT] = ACTIONS(173),
    [anon_sym_STAR] = ACTIONS(175),
    [anon_sym_DOT] = ACTIONS(173),
    [sym_duration_part] = ACTIONS(648),
    [anon_sym_DASH] = ACTIONS(175),
    [anon_sym_PERCENT] = ACTIONS(173),
    [anon_sym_AT] = ACTIONS(175),
    [anon_sym_LT_PIPE] = ACTIONS(173),
    [anon_sym_AMP_AMP] = ACTIONS(173),
    [anon_sym_PIPE_PIPE] = ACTIONS(173),
    [anon_sym_QMARK_QMARK] = ACTIONS(173),
    [anon_sym_QMARK_COLON] = ACTIONS(173),
    [anon_sym_BANG_EQ] = ACTIONS(173),
    [anon_sym_EQ_EQ] = ACTIONS(173),
    [anon_sym_QMARK_EQ] = ACTIONS(173),
    [anon_sym_STAR_EQ] = ACTIONS(173),
    [anon_sym_TILDE] = ACTIONS(173),
    [anon_sym_BANG_TILDE] = ACTIONS(173),
    [anon_sym_STAR_TILDE] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(173),
    [anon_sym_GT_EQ] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(175),
    [anon_sym_PLUS_EQ] = ACTIONS(173),
    [anon_sym_DASH_EQ] = ACTIONS(173),
    [anon_sym_u00d7] = ACTIONS(173),
    [anon_sym_SLASH] = ACTIONS(175),
    [anon_sym_u00f7] = ACTIONS(173),
    [anon_sym_STAR_STAR] = ACTIONS(173),
    [anon_sym_u220b] = ACTIONS(173),
    [anon_sym_u220c] = ACTIONS(173),
    [anon_sym_u2287] = ACTIONS(173),
    [anon_sym_u2283] = ACTIONS(173),
    [anon_sym_u2285] = ACTIONS(173),
    [anon_sym_u2208] = ACTIONS(173),
    [anon_sym_u2209] = ACTIONS(173),
    [anon_sym_u2286] = ACTIONS(173),
    [anon_sym_u2282] = ACTIONS(173),
    [anon_sym_u2284] = ACTIONS(173),
    [anon_sym_AT_AT] = ACTIONS(173),
  },
  [STATE(239)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_merge] = ACTIONS(288),
    [sym_keyword_patch] = ACTIONS(288),
    [sym_keyword_replace] = ACTIONS(288),
    [sym_keyword_unset] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(652),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(240)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(252),
    [sym_keyword_explain] = ACTIONS(252),
    [sym_keyword_parallel] = ACTIONS(252),
    [sym_keyword_timeout] = ACTIONS(252),
    [sym_keyword_fetch] = ACTIONS(252),
    [sym_keyword_limit] = ACTIONS(252),
    [sym_keyword_order] = ACTIONS(252),
    [sym_keyword_with] = ACTIONS(252),
    [sym_keyword_where] = ACTIONS(252),
    [sym_keyword_split] = ACTIONS(252),
    [sym_keyword_group] = ACTIONS(252),
    [sym_keyword_and] = ACTIONS(252),
    [sym_keyword_or] = ACTIONS(254),
    [sym_keyword_is] = ACTIONS(252),
    [sym_keyword_not] = ACTIONS(254),
    [sym_keyword_contains] = ACTIONS(254),
    [sym_keyword_contains_not] = ACTIONS(252),
    [sym_keyword_contains_all] = ACTIONS(252),
    [sym_keyword_contains_any] = ACTIONS(252),
    [sym_keyword_contains_none] = ACTIONS(252),
    [sym_keyword_inside] = ACTIONS(252),
    [sym_keyword_in] = ACTIONS(254),
    [sym_keyword_not_inside] = ACTIONS(252),
    [sym_keyword_all_inside] = ACTIONS(252),
    [sym_keyword_any_inside] = ACTIONS(252),
    [sym_keyword_none_inside] = ACTIONS(252),
    [sym_keyword_outside] = ACTIONS(252),
    [sym_keyword_intersects] = ACTIONS(252),
    [anon_sym_EQ] = ACTIONS(254),
    [anon_sym_COMMA] = ACTIONS(252),
    [anon_sym_RPAREN] = ACTIONS(252),
    [anon_sym_DASH_GT] = ACTIONS(252),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_RBRACE] = ACTIONS(252),
    [anon_sym_LT] = ACTIONS(254),
    [anon_sym_GT] = ACTIONS(254),
    [anon_sym_LT_DASH] = ACTIONS(254),
    [anon_sym_LT_DASH_GT] = ACTIONS(252),
    [anon_sym_STAR] = ACTIONS(254),
    [anon_sym_DOT] = ACTIONS(254),
    [anon_sym_DOT_DOT] = ACTIONS(252),
    [anon_sym_DASH] = ACTIONS(254),
    [anon_sym_PERCENT] = ACTIONS(252),
    [anon_sym_AT] = ACTIONS(254),
    [anon_sym_LT_PIPE] = ACTIONS(252),
    [anon_sym_AMP_AMP] = ACTIONS(252),
    [anon_sym_PIPE_PIPE] = ACTIONS(252),
    [anon_sym_QMARK_QMARK] = ACTIONS(252),
    [anon_sym_QMARK_COLON] = ACTIONS(252),
    [anon_sym_BANG_EQ] = ACTIONS(252),
    [anon_sym_EQ_EQ] = ACTIONS(252),
    [anon_sym_QMARK_EQ] = ACTIONS(252),
    [anon_sym_STAR_EQ] = ACTIONS(252),
    [anon_sym_TILDE] = ACTIONS(252),
    [anon_sym_BANG_TILDE] = ACTIONS(252),
    [anon_sym_STAR_TILDE] = ACTIONS(252),
    [anon_sym_LT_EQ] = ACTIONS(252),
    [anon_sym_GT_EQ] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(254),
    [anon_sym_PLUS_EQ] = ACTIONS(252),
    [anon_sym_DASH_EQ] = ACTIONS(252),
    [anon_sym_u00d7] = ACTIONS(252),
    [anon_sym_SLASH] = ACTIONS(254),
    [anon_sym_u00f7] = ACTIONS(252),
    [anon_sym_STAR_STAR] = ACTIONS(252),
    [anon_sym_u220b] = ACTIONS(252),
    [anon_sym_u220c] = ACTIONS(252),
    [anon_sym_u2287] = ACTIONS(252),
    [anon_sym_u2283] = ACTIONS(252),
    [anon_sym_u2285] = ACTIONS(252),
    [anon_sym_u2208] = ACTIONS(252),
    [anon_sym_u2209] = ACTIONS(252),
    [anon_sym_u2286] = ACTIONS(252),
    [anon_sym_u2282] = ACTIONS(252),
    [anon_sym_u2284] = ACTIONS(252),
    [anon_sym_AT_AT] = ACTIONS(252),
  },
  [STATE(241)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_order] = ACTIONS(186),
    [sym_keyword_with] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_split] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(188),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(188),
    [anon_sym_DOT_DOT] = ACTIONS(654),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(242)] = {
    [ts_builtin_sym_end] = ACTIONS(93),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_order] = ACTIONS(93),
    [sym_keyword_with] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_split] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_COLON] = ACTIONS(194),
    [anon_sym_COLON_COLON] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(243)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(240),
    [sym_keyword_explain] = ACTIONS(240),
    [sym_keyword_parallel] = ACTIONS(240),
    [sym_keyword_timeout] = ACTIONS(240),
    [sym_keyword_fetch] = ACTIONS(240),
    [sym_keyword_limit] = ACTIONS(240),
    [sym_keyword_order] = ACTIONS(240),
    [sym_keyword_with] = ACTIONS(240),
    [sym_keyword_where] = ACTIONS(240),
    [sym_keyword_split] = ACTIONS(240),
    [sym_keyword_group] = ACTIONS(240),
    [sym_keyword_and] = ACTIONS(240),
    [sym_keyword_or] = ACTIONS(242),
    [sym_keyword_is] = ACTIONS(240),
    [sym_keyword_not] = ACTIONS(242),
    [sym_keyword_contains] = ACTIONS(242),
    [sym_keyword_contains_not] = ACTIONS(240),
    [sym_keyword_contains_all] = ACTIONS(240),
    [sym_keyword_contains_any] = ACTIONS(240),
    [sym_keyword_contains_none] = ACTIONS(240),
    [sym_keyword_inside] = ACTIONS(240),
    [sym_keyword_in] = ACTIONS(242),
    [sym_keyword_not_inside] = ACTIONS(240),
    [sym_keyword_all_inside] = ACTIONS(240),
    [sym_keyword_any_inside] = ACTIONS(240),
    [sym_keyword_none_inside] = ACTIONS(240),
    [sym_keyword_outside] = ACTIONS(240),
    [sym_keyword_intersects] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_RPAREN] = ACTIONS(240),
    [anon_sym_DASH_GT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(240),
    [anon_sym_RBRACE] = ACTIONS(240),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_DASH] = ACTIONS(242),
    [anon_sym_LT_DASH_GT] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_DOT_DOT] = ACTIONS(240),
    [anon_sym_DASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LT_PIPE] = ACTIONS(240),
    [anon_sym_AMP_AMP] = ACTIONS(240),
    [anon_sym_PIPE_PIPE] = ACTIONS(240),
    [anon_sym_QMARK_QMARK] = ACTIONS(240),
    [anon_sym_QMARK_COLON] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_QMARK_EQ] = ACTIONS(240),
    [anon_sym_STAR_EQ] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(240),
    [anon_sym_BANG_TILDE] = ACTIONS(240),
    [anon_sym_STAR_TILDE] = ACTIONS(240),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_PLUS] = ACTIONS(242),
    [anon_sym_PLUS_EQ] = ACTIONS(240),
    [anon_sym_DASH_EQ] = ACTIONS(240),
    [anon_sym_u00d7] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_u00f7] = ACTIONS(240),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_u220b] = ACTIONS(240),
    [anon_sym_u220c] = ACTIONS(240),
    [anon_sym_u2287] = ACTIONS(240),
    [anon_sym_u2283] = ACTIONS(240),
    [anon_sym_u2285] = ACTIONS(240),
    [anon_sym_u2208] = ACTIONS(240),
    [anon_sym_u2209] = ACTIONS(240),
    [anon_sym_u2286] = ACTIONS(240),
    [anon_sym_u2282] = ACTIONS(240),
    [anon_sym_u2284] = ACTIONS(240),
    [anon_sym_AT_AT] = ACTIONS(240),
  },
  [STATE(244)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(93),
    [sym_keyword_explain] = ACTIONS(93),
    [sym_keyword_parallel] = ACTIONS(93),
    [sym_keyword_timeout] = ACTIONS(93),
    [sym_keyword_fetch] = ACTIONS(93),
    [sym_keyword_limit] = ACTIONS(93),
    [sym_keyword_order] = ACTIONS(93),
    [sym_keyword_with] = ACTIONS(93),
    [sym_keyword_where] = ACTIONS(93),
    [sym_keyword_split] = ACTIONS(93),
    [sym_keyword_group] = ACTIONS(93),
    [sym_keyword_and] = ACTIONS(93),
    [sym_keyword_or] = ACTIONS(95),
    [sym_keyword_is] = ACTIONS(93),
    [sym_keyword_not] = ACTIONS(95),
    [sym_keyword_contains] = ACTIONS(95),
    [sym_keyword_contains_not] = ACTIONS(93),
    [sym_keyword_contains_all] = ACTIONS(93),
    [sym_keyword_contains_any] = ACTIONS(93),
    [sym_keyword_contains_none] = ACTIONS(93),
    [sym_keyword_inside] = ACTIONS(93),
    [sym_keyword_in] = ACTIONS(95),
    [sym_keyword_not_inside] = ACTIONS(93),
    [sym_keyword_all_inside] = ACTIONS(93),
    [sym_keyword_any_inside] = ACTIONS(93),
    [sym_keyword_none_inside] = ACTIONS(93),
    [sym_keyword_outside] = ACTIONS(93),
    [sym_keyword_intersects] = ACTIONS(93),
    [anon_sym_EQ] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(93),
    [anon_sym_LPAREN] = ACTIONS(93),
    [anon_sym_RPAREN] = ACTIONS(93),
    [anon_sym_DASH_GT] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(93),
    [anon_sym_RBRACE] = ACTIONS(93),
    [anon_sym_LT] = ACTIONS(95),
    [anon_sym_GT] = ACTIONS(95),
    [anon_sym_LT_DASH] = ACTIONS(95),
    [anon_sym_LT_DASH_GT] = ACTIONS(93),
    [anon_sym_STAR] = ACTIONS(95),
    [anon_sym_DOT] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(95),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_AT] = ACTIONS(95),
    [anon_sym_LT_PIPE] = ACTIONS(93),
    [anon_sym_AMP_AMP] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(93),
    [anon_sym_QMARK_QMARK] = ACTIONS(93),
    [anon_sym_QMARK_COLON] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_QMARK_EQ] = ACTIONS(93),
    [anon_sym_STAR_EQ] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(93),
    [anon_sym_BANG_TILDE] = ACTIONS(93),
    [anon_sym_STAR_TILDE] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(93),
    [anon_sym_GT_EQ] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(95),
    [anon_sym_PLUS_EQ] = ACTIONS(93),
    [anon_sym_DASH_EQ] = ACTIONS(93),
    [anon_sym_u00d7] = ACTIONS(93),
    [anon_sym_SLASH] = ACTIONS(95),
    [anon_sym_u00f7] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(93),
    [anon_sym_u220b] = ACTIONS(93),
    [anon_sym_u220c] = ACTIONS(93),
    [anon_sym_u2287] = ACTIONS(93),
    [anon_sym_u2283] = ACTIONS(93),
    [anon_sym_u2285] = ACTIONS(93),
    [anon_sym_u2208] = ACTIONS(93),
    [anon_sym_u2209] = ACTIONS(93),
    [anon_sym_u2286] = ACTIONS(93),
    [anon_sym_u2282] = ACTIONS(93),
    [anon_sym_u2284] = ACTIONS(93),
    [anon_sym_AT_AT] = ACTIONS(93),
  },
  [STATE(245)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_rand] = ACTIONS(288),
    [sym_keyword_collate] = ACTIONS(288),
    [sym_keyword_numeric] = ACTIONS(288),
    [sym_keyword_asc] = ACTIONS(288),
    [sym_keyword_desc] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(656),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(658),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(246)] = {
    [aux_sym_duration_repeat1] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(173),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(173),
    [sym_keyword_explain] = ACTIONS(173),
    [sym_keyword_parallel] = ACTIONS(173),
    [sym_keyword_timeout] = ACTIONS(173),
    [sym_keyword_fetch] = ACTIONS(173),
    [sym_keyword_limit] = ACTIONS(173),
    [sym_keyword_order] = ACTIONS(173),
    [sym_keyword_with] = ACTIONS(173),
    [sym_keyword_where] = ACTIONS(173),
    [sym_keyword_split] = ACTIONS(173),
    [sym_keyword_group] = ACTIONS(173),
    [sym_keyword_and] = ACTIONS(173),
    [sym_keyword_or] = ACTIONS(175),
    [sym_keyword_is] = ACTIONS(173),
    [sym_keyword_not] = ACTIONS(175),
    [sym_keyword_contains] = ACTIONS(175),
    [sym_keyword_contains_not] = ACTIONS(173),
    [sym_keyword_contains_all] = ACTIONS(173),
    [sym_keyword_contains_any] = ACTIONS(173),
    [sym_keyword_contains_none] = ACTIONS(173),
    [sym_keyword_inside] = ACTIONS(173),
    [sym_keyword_in] = ACTIONS(175),
    [sym_keyword_not_inside] = ACTIONS(173),
    [sym_keyword_all_inside] = ACTIONS(173),
    [sym_keyword_any_inside] = ACTIONS(173),
    [sym_keyword_none_inside] = ACTIONS(173),
    [sym_keyword_outside] = ACTIONS(173),
    [sym_keyword_intersects] = ACTIONS(173),
    [anon_sym_EQ] = ACTIONS(175),
    [anon_sym_COMMA] = ACTIONS(173),
    [anon_sym_DASH_GT] = ACTIONS(173),
    [anon_sym_LBRACK] = ACTIONS(173),
    [anon_sym_LT] = ACTIONS(175),
    [anon_sym_GT] = ACTIONS(175),
    [anon_sym_LT_DASH] = ACTIONS(175),
    [anon_sym_LT_DASH_GT] = ACTIONS(173),
    [anon_sym_STAR] = ACTIONS(175),
    [anon_sym_DOT] = ACTIONS(173),
    [sym_duration_part] = ACTIONS(660),
    [anon_sym_DASH] = ACTIONS(175),
    [anon_sym_PERCENT] = ACTIONS(173),
    [anon_sym_AT] = ACTIONS(175),
    [anon_sym_LT_PIPE] = ACTIONS(173),
    [anon_sym_AMP_AMP] = ACTIONS(173),
    [anon_sym_PIPE_PIPE] = ACTIONS(173),
    [anon_sym_QMARK_QMARK] = ACTIONS(173),
    [anon_sym_QMARK_COLON] = ACTIONS(173),
    [anon_sym_BANG_EQ] = ACTIONS(173),
    [anon_sym_EQ_EQ] = ACTIONS(173),
    [anon_sym_QMARK_EQ] = ACTIONS(173),
    [anon_sym_STAR_EQ] = ACTIONS(173),
    [anon_sym_TILDE] = ACTIONS(173),
    [anon_sym_BANG_TILDE] = ACTIONS(173),
    [anon_sym_STAR_TILDE] = ACTIONS(173),
    [anon_sym_LT_EQ] = ACTIONS(173),
    [anon_sym_GT_EQ] = ACTIONS(173),
    [anon_sym_PLUS] = ACTIONS(175),
    [anon_sym_PLUS_EQ] = ACTIONS(173),
    [anon_sym_DASH_EQ] = ACTIONS(173),
    [anon_sym_u00d7] = ACTIONS(173),
    [anon_sym_SLASH] = ACTIONS(175),
    [anon_sym_u00f7] = ACTIONS(173),
    [anon_sym_STAR_STAR] = ACTIONS(173),
    [anon_sym_u220b] = ACTIONS(173),
    [anon_sym_u220c] = ACTIONS(173),
    [anon_sym_u2287] = ACTIONS(173),
    [anon_sym_u2283] = ACTIONS(173),
    [anon_sym_u2285] = ACTIONS(173),
    [anon_sym_u2208] = ACTIONS(173),
    [anon_sym_u2209] = ACTIONS(173),
    [anon_sym_u2286] = ACTIONS(173),
    [anon_sym_u2282] = ACTIONS(173),
    [anon_sym_u2284] = ACTIONS(173),
    [anon_sym_AT_AT] = ACTIONS(173),
  },
  [STATE(247)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(248)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(249)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(256),
    [sym_keyword_explain] = ACTIONS(256),
    [sym_keyword_parallel] = ACTIONS(256),
    [sym_keyword_timeout] = ACTIONS(256),
    [sym_keyword_fetch] = ACTIONS(256),
    [sym_keyword_limit] = ACTIONS(256),
    [sym_keyword_order] = ACTIONS(256),
    [sym_keyword_with] = ACTIONS(256),
    [sym_keyword_where] = ACTIONS(256),
    [sym_keyword_split] = ACTIONS(256),
    [sym_keyword_group] = ACTIONS(256),
    [sym_keyword_and] = ACTIONS(256),
    [sym_keyword_or] = ACTIONS(258),
    [sym_keyword_is] = ACTIONS(256),
    [sym_keyword_not] = ACTIONS(258),
    [sym_keyword_contains] = ACTIONS(258),
    [sym_keyword_contains_not] = ACTIONS(256),
    [sym_keyword_contains_all] = ACTIONS(256),
    [sym_keyword_contains_any] = ACTIONS(256),
    [sym_keyword_contains_none] = ACTIONS(256),
    [sym_keyword_inside] = ACTIONS(256),
    [sym_keyword_in] = ACTIONS(258),
    [sym_keyword_not_inside] = ACTIONS(256),
    [sym_keyword_all_inside] = ACTIONS(256),
    [sym_keyword_any_inside] = ACTIONS(256),
    [sym_keyword_none_inside] = ACTIONS(256),
    [sym_keyword_outside] = ACTIONS(256),
    [sym_keyword_intersects] = ACTIONS(256),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_COMMA] = ACTIONS(256),
    [anon_sym_RPAREN] = ACTIONS(256),
    [anon_sym_DASH_GT] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(256),
    [anon_sym_RBRACE] = ACTIONS(256),
    [anon_sym_LT] = ACTIONS(258),
    [anon_sym_GT] = ACTIONS(258),
    [anon_sym_LT_DASH] = ACTIONS(258),
    [anon_sym_LT_DASH_GT] = ACTIONS(256),
    [anon_sym_STAR] = ACTIONS(258),
    [anon_sym_DOT] = ACTIONS(258),
    [anon_sym_DOT_DOT] = ACTIONS(256),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_PERCENT] = ACTIONS(256),
    [anon_sym_AT] = ACTIONS(258),
    [anon_sym_LT_PIPE] = ACTIONS(256),
    [anon_sym_AMP_AMP] = ACTIONS(256),
    [anon_sym_PIPE_PIPE] = ACTIONS(256),
    [anon_sym_QMARK_QMARK] = ACTIONS(256),
    [anon_sym_QMARK_COLON] = ACTIONS(256),
    [anon_sym_BANG_EQ] = ACTIONS(256),
    [anon_sym_EQ_EQ] = ACTIONS(256),
    [anon_sym_QMARK_EQ] = ACTIONS(256),
    [anon_sym_STAR_EQ] = ACTIONS(256),
    [anon_sym_TILDE] = ACTIONS(256),
    [anon_sym_BANG_TILDE] = ACTIONS(256),
    [anon_sym_STAR_TILDE] = ACTIONS(256),
    [anon_sym_LT_EQ] = ACTIONS(256),
    [anon_sym_GT_EQ] = ACTIONS(256),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_PLUS_EQ] = ACTIONS(256),
    [anon_sym_DASH_EQ] = ACTIONS(256),
    [anon_sym_u00d7] = ACTIONS(256),
    [anon_sym_SLASH] = ACTIONS(258),
    [anon_sym_u00f7] = ACTIONS(256),
    [anon_sym_STAR_STAR] = ACTIONS(256),
    [anon_sym_u220b] = ACTIONS(256),
    [anon_sym_u220c] = ACTIONS(256),
    [anon_sym_u2287] = ACTIONS(256),
    [anon_sym_u2283] = ACTIONS(256),
    [anon_sym_u2285] = ACTIONS(256),
    [anon_sym_u2208] = ACTIONS(256),
    [anon_sym_u2209] = ACTIONS(256),
    [anon_sym_u2286] = ACTIONS(256),
    [anon_sym_u2282] = ACTIONS(256),
    [anon_sym_u2284] = ACTIONS(256),
    [anon_sym_AT_AT] = ACTIONS(256),
  },
  [STATE(250)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_with] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(662),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(664),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(251)] = {
    [aux_sym_duration_repeat1] = STATE(251),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(179),
    [sym_keyword_explain] = ACTIONS(179),
    [sym_keyword_parallel] = ACTIONS(179),
    [sym_keyword_timeout] = ACTIONS(179),
    [sym_keyword_fetch] = ACTIONS(179),
    [sym_keyword_limit] = ACTIONS(179),
    [sym_keyword_order] = ACTIONS(179),
    [sym_keyword_with] = ACTIONS(179),
    [sym_keyword_where] = ACTIONS(179),
    [sym_keyword_split] = ACTIONS(179),
    [sym_keyword_group] = ACTIONS(179),
    [sym_keyword_and] = ACTIONS(179),
    [sym_keyword_or] = ACTIONS(181),
    [sym_keyword_is] = ACTIONS(179),
    [sym_keyword_not] = ACTIONS(181),
    [sym_keyword_contains] = ACTIONS(181),
    [sym_keyword_contains_not] = ACTIONS(179),
    [sym_keyword_contains_all] = ACTIONS(179),
    [sym_keyword_contains_any] = ACTIONS(179),
    [sym_keyword_contains_none] = ACTIONS(179),
    [sym_keyword_inside] = ACTIONS(179),
    [sym_keyword_in] = ACTIONS(181),
    [sym_keyword_not_inside] = ACTIONS(179),
    [sym_keyword_all_inside] = ACTIONS(179),
    [sym_keyword_any_inside] = ACTIONS(179),
    [sym_keyword_none_inside] = ACTIONS(179),
    [sym_keyword_outside] = ACTIONS(179),
    [sym_keyword_intersects] = ACTIONS(179),
    [anon_sym_EQ] = ACTIONS(181),
    [anon_sym_COMMA] = ACTIONS(179),
    [anon_sym_DASH_GT] = ACTIONS(179),
    [anon_sym_LBRACK] = ACTIONS(179),
    [anon_sym_LT] = ACTIONS(181),
    [anon_sym_GT] = ACTIONS(181),
    [anon_sym_LT_DASH] = ACTIONS(181),
    [anon_sym_LT_DASH_GT] = ACTIONS(179),
    [anon_sym_STAR] = ACTIONS(181),
    [anon_sym_DOT] = ACTIONS(179),
    [sym_duration_part] = ACTIONS(666),
    [anon_sym_DASH] = ACTIONS(181),
    [anon_sym_PERCENT] = ACTIONS(179),
    [anon_sym_AT] = ACTIONS(181),
    [anon_sym_LT_PIPE] = ACTIONS(179),
    [anon_sym_AMP_AMP] = ACTIONS(179),
    [anon_sym_PIPE_PIPE] = ACTIONS(179),
    [anon_sym_QMARK_QMARK] = ACTIONS(179),
    [anon_sym_QMARK_COLON] = ACTIONS(179),
    [anon_sym_BANG_EQ] = ACTIONS(179),
    [anon_sym_EQ_EQ] = ACTIONS(179),
    [anon_sym_QMARK_EQ] = ACTIONS(179),
    [anon_sym_STAR_EQ] = ACTIONS(179),
    [anon_sym_TILDE] = ACTIONS(179),
    [anon_sym_BANG_TILDE] = ACTIONS(179),
    [anon_sym_STAR_TILDE] = ACTIONS(179),
    [anon_sym_LT_EQ] = ACTIONS(179),
    [anon_sym_GT_EQ] = ACTIONS(179),
    [anon_sym_PLUS] = ACTIONS(181),
    [anon_sym_PLUS_EQ] = ACTIONS(179),
    [anon_sym_DASH_EQ] = ACTIONS(179),
    [anon_sym_u00d7] = ACTIONS(179),
    [anon_sym_SLASH] = ACTIONS(181),
    [anon_sym_u00f7] = ACTIONS(179),
    [anon_sym_STAR_STAR] = ACTIONS(179),
    [anon_sym_u220b] = ACTIONS(179),
    [anon_sym_u220c] = ACTIONS(179),
    [anon_sym_u2287] = ACTIONS(179),
    [anon_sym_u2283] = ACTIONS(179),
    [anon_sym_u2285] = ACTIONS(179),
    [anon_sym_u2208] = ACTIONS(179),
    [anon_sym_u2209] = ACTIONS(179),
    [anon_sym_u2286] = ACTIONS(179),
    [anon_sym_u2282] = ACTIONS(179),
    [anon_sym_u2284] = ACTIONS(179),
    [anon_sym_AT_AT] = ACTIONS(179),
  },
  [STATE(252)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(244),
    [sym_keyword_explain] = ACTIONS(244),
    [sym_keyword_parallel] = ACTIONS(244),
    [sym_keyword_timeout] = ACTIONS(244),
    [sym_keyword_fetch] = ACTIONS(244),
    [sym_keyword_limit] = ACTIONS(244),
    [sym_keyword_order] = ACTIONS(244),
    [sym_keyword_with] = ACTIONS(244),
    [sym_keyword_where] = ACTIONS(244),
    [sym_keyword_split] = ACTIONS(244),
    [sym_keyword_group] = ACTIONS(244),
    [sym_keyword_and] = ACTIONS(244),
    [sym_keyword_or] = ACTIONS(246),
    [sym_keyword_is] = ACTIONS(244),
    [sym_keyword_not] = ACTIONS(246),
    [sym_keyword_contains] = ACTIONS(246),
    [sym_keyword_contains_not] = ACTIONS(244),
    [sym_keyword_contains_all] = ACTIONS(244),
    [sym_keyword_contains_any] = ACTIONS(244),
    [sym_keyword_contains_none] = ACTIONS(244),
    [sym_keyword_inside] = ACTIONS(244),
    [sym_keyword_in] = ACTIONS(246),
    [sym_keyword_not_inside] = ACTIONS(244),
    [sym_keyword_all_inside] = ACTIONS(244),
    [sym_keyword_any_inside] = ACTIONS(244),
    [sym_keyword_none_inside] = ACTIONS(244),
    [sym_keyword_outside] = ACTIONS(244),
    [sym_keyword_intersects] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(246),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_RPAREN] = ACTIONS(244),
    [anon_sym_DASH_GT] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(244),
    [anon_sym_RBRACE] = ACTIONS(244),
    [anon_sym_LT] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(246),
    [anon_sym_LT_DASH] = ACTIONS(246),
    [anon_sym_LT_DASH_GT] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(246),
    [anon_sym_DOT_DOT] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(246),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_AT] = ACTIONS(246),
    [anon_sym_LT_PIPE] = ACTIONS(244),
    [anon_sym_AMP_AMP] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(244),
    [anon_sym_QMARK_QMARK] = ACTIONS(244),
    [anon_sym_QMARK_COLON] = ACTIONS(244),
    [anon_sym_BANG_EQ] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(244),
    [anon_sym_QMARK_EQ] = ACTIONS(244),
    [anon_sym_STAR_EQ] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_BANG_TILDE] = ACTIONS(244),
    [anon_sym_STAR_TILDE] = ACTIONS(244),
    [anon_sym_LT_EQ] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(246),
    [anon_sym_PLUS_EQ] = ACTIONS(244),
    [anon_sym_DASH_EQ] = ACTIONS(244),
    [anon_sym_u00d7] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(246),
    [anon_sym_u00f7] = ACTIONS(244),
    [anon_sym_STAR_STAR] = ACTIONS(244),
    [anon_sym_u220b] = ACTIONS(244),
    [anon_sym_u220c] = ACTIONS(244),
    [anon_sym_u2287] = ACTIONS(244),
    [anon_sym_u2283] = ACTIONS(244),
    [anon_sym_u2285] = ACTIONS(244),
    [anon_sym_u2208] = ACTIONS(244),
    [anon_sym_u2209] = ACTIONS(244),
    [anon_sym_u2286] = ACTIONS(244),
    [anon_sym_u2282] = ACTIONS(244),
    [anon_sym_u2284] = ACTIONS(244),
    [anon_sym_AT_AT] = ACTIONS(244),
  },
  [STATE(253)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(232),
    [sym_keyword_explain] = ACTIONS(232),
    [sym_keyword_parallel] = ACTIONS(232),
    [sym_keyword_timeout] = ACTIONS(232),
    [sym_keyword_fetch] = ACTIONS(232),
    [sym_keyword_limit] = ACTIONS(232),
    [sym_keyword_order] = ACTIONS(232),
    [sym_keyword_with] = ACTIONS(232),
    [sym_keyword_where] = ACTIONS(232),
    [sym_keyword_split] = ACTIONS(232),
    [sym_keyword_group] = ACTIONS(232),
    [sym_keyword_and] = ACTIONS(232),
    [sym_keyword_or] = ACTIONS(234),
    [sym_keyword_is] = ACTIONS(232),
    [sym_keyword_not] = ACTIONS(234),
    [sym_keyword_contains] = ACTIONS(234),
    [sym_keyword_contains_not] = ACTIONS(232),
    [sym_keyword_contains_all] = ACTIONS(232),
    [sym_keyword_contains_any] = ACTIONS(232),
    [sym_keyword_contains_none] = ACTIONS(232),
    [sym_keyword_inside] = ACTIONS(232),
    [sym_keyword_in] = ACTIONS(234),
    [sym_keyword_not_inside] = ACTIONS(232),
    [sym_keyword_all_inside] = ACTIONS(232),
    [sym_keyword_any_inside] = ACTIONS(232),
    [sym_keyword_none_inside] = ACTIONS(232),
    [sym_keyword_outside] = ACTIONS(232),
    [sym_keyword_intersects] = ACTIONS(232),
    [anon_sym_EQ] = ACTIONS(234),
    [anon_sym_COMMA] = ACTIONS(232),
    [anon_sym_RPAREN] = ACTIONS(232),
    [anon_sym_DASH_GT] = ACTIONS(232),
    [anon_sym_LBRACK] = ACTIONS(232),
    [anon_sym_RBRACE] = ACTIONS(232),
    [anon_sym_LT] = ACTIONS(234),
    [anon_sym_GT] = ACTIONS(234),
    [anon_sym_LT_DASH] = ACTIONS(234),
    [anon_sym_LT_DASH_GT] = ACTIONS(232),
    [anon_sym_STAR] = ACTIONS(234),
    [anon_sym_DOT] = ACTIONS(234),
    [anon_sym_DOT_DOT] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(234),
    [anon_sym_PERCENT] = ACTIONS(232),
    [anon_sym_AT] = ACTIONS(234),
    [anon_sym_LT_PIPE] = ACTIONS(232),
    [anon_sym_AMP_AMP] = ACTIONS(232),
    [anon_sym_PIPE_PIPE] = ACTIONS(232),
    [anon_sym_QMARK_QMARK] = ACTIONS(232),
    [anon_sym_QMARK_COLON] = ACTIONS(232),
    [anon_sym_BANG_EQ] = ACTIONS(232),
    [anon_sym_EQ_EQ] = ACTIONS(232),
    [anon_sym_QMARK_EQ] = ACTIONS(232),
    [anon_sym_STAR_EQ] = ACTIONS(232),
    [anon_sym_TILDE] = ACTIONS(232),
    [anon_sym_BANG_TILDE] = ACTIONS(232),
    [anon_sym_STAR_TILDE] = ACTIONS(232),
    [anon_sym_LT_EQ] = ACTIONS(232),
    [anon_sym_GT_EQ] = ACTIONS(232),
    [anon_sym_PLUS] = ACTIONS(234),
    [anon_sym_PLUS_EQ] = ACTIONS(232),
    [anon_sym_DASH_EQ] = ACTIONS(232),
    [anon_sym_u00d7] = ACTIONS(232),
    [anon_sym_SLASH] = ACTIONS(234),
    [anon_sym_u00f7] = ACTIONS(232),
    [anon_sym_STAR_STAR] = ACTIONS(232),
    [anon_sym_u220b] = ACTIONS(232),
    [anon_sym_u220c] = ACTIONS(232),
    [anon_sym_u2287] = ACTIONS(232),
    [anon_sym_u2283] = ACTIONS(232),
    [anon_sym_u2285] = ACTIONS(232),
    [anon_sym_u2208] = ACTIONS(232),
    [anon_sym_u2209] = ACTIONS(232),
    [anon_sym_u2286] = ACTIONS(232),
    [anon_sym_u2282] = ACTIONS(232),
    [anon_sym_u2284] = ACTIONS(232),
    [anon_sym_AT_AT] = ACTIONS(232),
  },
  [STATE(254)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_changefeed] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(255)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_changefeed] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(256)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_drop] = ACTIONS(537),
    [sym_keyword_schemafull] = ACTIONS(537),
    [sym_keyword_schemaless] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_for] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(257)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_drop] = ACTIONS(316),
    [sym_keyword_schemafull] = ACTIONS(316),
    [sym_keyword_schemaless] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_for] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(258)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(208),
    [sym_keyword_explain] = ACTIONS(208),
    [sym_keyword_parallel] = ACTIONS(208),
    [sym_keyword_timeout] = ACTIONS(208),
    [sym_keyword_fetch] = ACTIONS(208),
    [sym_keyword_limit] = ACTIONS(208),
    [sym_keyword_order] = ACTIONS(208),
    [sym_keyword_with] = ACTIONS(208),
    [sym_keyword_where] = ACTIONS(208),
    [sym_keyword_split] = ACTIONS(208),
    [sym_keyword_group] = ACTIONS(208),
    [sym_keyword_and] = ACTIONS(208),
    [sym_keyword_or] = ACTIONS(210),
    [sym_keyword_is] = ACTIONS(208),
    [sym_keyword_not] = ACTIONS(210),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(208),
    [sym_keyword_contains_all] = ACTIONS(208),
    [sym_keyword_contains_any] = ACTIONS(208),
    [sym_keyword_contains_none] = ACTIONS(208),
    [sym_keyword_inside] = ACTIONS(208),
    [sym_keyword_in] = ACTIONS(210),
    [sym_keyword_not_inside] = ACTIONS(208),
    [sym_keyword_all_inside] = ACTIONS(208),
    [sym_keyword_any_inside] = ACTIONS(208),
    [sym_keyword_none_inside] = ACTIONS(208),
    [sym_keyword_outside] = ACTIONS(208),
    [sym_keyword_intersects] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(208),
    [anon_sym_RPAREN] = ACTIONS(208),
    [anon_sym_DASH_GT] = ACTIONS(208),
    [anon_sym_LBRACK] = ACTIONS(208),
    [anon_sym_RBRACE] = ACTIONS(208),
    [anon_sym_LT] = ACTIONS(210),
    [anon_sym_GT] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(210),
    [anon_sym_LT_DASH_GT] = ACTIONS(208),
    [anon_sym_STAR] = ACTIONS(210),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_DOT_DOT] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(210),
    [anon_sym_PERCENT] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(210),
    [anon_sym_LT_PIPE] = ACTIONS(208),
    [anon_sym_AMP_AMP] = ACTIONS(208),
    [anon_sym_PIPE_PIPE] = ACTIONS(208),
    [anon_sym_QMARK_QMARK] = ACTIONS(208),
    [anon_sym_QMARK_COLON] = ACTIONS(208),
    [anon_sym_BANG_EQ] = ACTIONS(208),
    [anon_sym_EQ_EQ] = ACTIONS(208),
    [anon_sym_QMARK_EQ] = ACTIONS(208),
    [anon_sym_STAR_EQ] = ACTIONS(208),
    [anon_sym_TILDE] = ACTIONS(208),
    [anon_sym_BANG_TILDE] = ACTIONS(208),
    [anon_sym_STAR_TILDE] = ACTIONS(208),
    [anon_sym_LT_EQ] = ACTIONS(208),
    [anon_sym_GT_EQ] = ACTIONS(208),
    [anon_sym_PLUS] = ACTIONS(210),
    [anon_sym_PLUS_EQ] = ACTIONS(208),
    [anon_sym_DASH_EQ] = ACTIONS(208),
    [anon_sym_u00d7] = ACTIONS(208),
    [anon_sym_SLASH] = ACTIONS(210),
    [anon_sym_u00f7] = ACTIONS(208),
    [anon_sym_STAR_STAR] = ACTIONS(208),
    [anon_sym_u220b] = ACTIONS(208),
    [anon_sym_u220c] = ACTIONS(208),
    [anon_sym_u2287] = ACTIONS(208),
    [anon_sym_u2283] = ACTIONS(208),
    [anon_sym_u2285] = ACTIONS(208),
    [anon_sym_u2208] = ACTIONS(208),
    [anon_sym_u2209] = ACTIONS(208),
    [anon_sym_u2286] = ACTIONS(208),
    [anon_sym_u2282] = ACTIONS(208),
    [anon_sym_u2284] = ACTIONS(208),
    [anon_sym_AT_AT] = ACTIONS(208),
  },
  [STATE(259)] = {
    [aux_sym_function_call_repeat1] = STATE(1799),
    [ts_builtin_sym_end] = ACTIONS(304),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_order] = ACTIONS(304),
    [sym_keyword_with] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_split] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(306),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_COLON_COLON] = ACTIONS(308),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(260)] = {
    [sym_argument_list] = STATE(345),
    [ts_builtin_sym_end] = ACTIONS(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_order] = ACTIONS(278),
    [sym_keyword_with] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_split] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(280),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_LPAREN] = ACTIONS(669),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(261)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_merge] = ACTIONS(288),
    [sym_keyword_patch] = ACTIONS(288),
    [sym_keyword_replace] = ACTIONS(288),
    [sym_keyword_unset] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(673),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(262)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(248),
    [sym_keyword_explain] = ACTIONS(248),
    [sym_keyword_parallel] = ACTIONS(248),
    [sym_keyword_timeout] = ACTIONS(248),
    [sym_keyword_fetch] = ACTIONS(248),
    [sym_keyword_limit] = ACTIONS(248),
    [sym_keyword_order] = ACTIONS(248),
    [sym_keyword_with] = ACTIONS(248),
    [sym_keyword_where] = ACTIONS(248),
    [sym_keyword_split] = ACTIONS(248),
    [sym_keyword_group] = ACTIONS(248),
    [sym_keyword_and] = ACTIONS(248),
    [sym_keyword_or] = ACTIONS(250),
    [sym_keyword_is] = ACTIONS(248),
    [sym_keyword_not] = ACTIONS(250),
    [sym_keyword_contains] = ACTIONS(250),
    [sym_keyword_contains_not] = ACTIONS(248),
    [sym_keyword_contains_all] = ACTIONS(248),
    [sym_keyword_contains_any] = ACTIONS(248),
    [sym_keyword_contains_none] = ACTIONS(248),
    [sym_keyword_inside] = ACTIONS(248),
    [sym_keyword_in] = ACTIONS(250),
    [sym_keyword_not_inside] = ACTIONS(248),
    [sym_keyword_all_inside] = ACTIONS(248),
    [sym_keyword_any_inside] = ACTIONS(248),
    [sym_keyword_none_inside] = ACTIONS(248),
    [sym_keyword_outside] = ACTIONS(248),
    [sym_keyword_intersects] = ACTIONS(248),
    [anon_sym_EQ] = ACTIONS(250),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_RPAREN] = ACTIONS(248),
    [anon_sym_DASH_GT] = ACTIONS(248),
    [anon_sym_LBRACK] = ACTIONS(248),
    [anon_sym_RBRACE] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_LT_DASH] = ACTIONS(250),
    [anon_sym_LT_DASH_GT] = ACTIONS(248),
    [anon_sym_STAR] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(250),
    [anon_sym_DOT_DOT] = ACTIONS(248),
    [anon_sym_DASH] = ACTIONS(250),
    [anon_sym_PERCENT] = ACTIONS(248),
    [anon_sym_AT] = ACTIONS(250),
    [anon_sym_LT_PIPE] = ACTIONS(248),
    [anon_sym_AMP_AMP] = ACTIONS(248),
    [anon_sym_PIPE_PIPE] = ACTIONS(248),
    [anon_sym_QMARK_QMARK] = ACTIONS(248),
    [anon_sym_QMARK_COLON] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_QMARK_EQ] = ACTIONS(248),
    [anon_sym_STAR_EQ] = ACTIONS(248),
    [anon_sym_TILDE] = ACTIONS(248),
    [anon_sym_BANG_TILDE] = ACTIONS(248),
    [anon_sym_STAR_TILDE] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(250),
    [anon_sym_PLUS_EQ] = ACTIONS(248),
    [anon_sym_DASH_EQ] = ACTIONS(248),
    [anon_sym_u00d7] = ACTIONS(248),
    [anon_sym_SLASH] = ACTIONS(250),
    [anon_sym_u00f7] = ACTIONS(248),
    [anon_sym_STAR_STAR] = ACTIONS(248),
    [anon_sym_u220b] = ACTIONS(248),
    [anon_sym_u220c] = ACTIONS(248),
    [anon_sym_u2287] = ACTIONS(248),
    [anon_sym_u2283] = ACTIONS(248),
    [anon_sym_u2285] = ACTIONS(248),
    [anon_sym_u2208] = ACTIONS(248),
    [anon_sym_u2209] = ACTIONS(248),
    [anon_sym_u2286] = ACTIONS(248),
    [anon_sym_u2282] = ACTIONS(248),
    [anon_sym_u2284] = ACTIONS(248),
    [anon_sym_AT_AT] = ACTIONS(248),
  },
  [STATE(263)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_changefeed] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(264)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_order] = ACTIONS(304),
    [sym_keyword_with] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_split] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(306),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_RPAREN] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(265)] = {
    [ts_builtin_sym_end] = ACTIONS(244),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(244),
    [sym_keyword_explain] = ACTIONS(244),
    [sym_keyword_parallel] = ACTIONS(244),
    [sym_keyword_timeout] = ACTIONS(244),
    [sym_keyword_fetch] = ACTIONS(244),
    [sym_keyword_limit] = ACTIONS(244),
    [sym_keyword_order] = ACTIONS(244),
    [sym_keyword_with] = ACTIONS(244),
    [sym_keyword_where] = ACTIONS(244),
    [sym_keyword_split] = ACTIONS(244),
    [sym_keyword_group] = ACTIONS(244),
    [sym_keyword_and] = ACTIONS(244),
    [sym_keyword_or] = ACTIONS(246),
    [sym_keyword_is] = ACTIONS(244),
    [sym_keyword_not] = ACTIONS(246),
    [sym_keyword_contains] = ACTIONS(246),
    [sym_keyword_contains_not] = ACTIONS(244),
    [sym_keyword_contains_all] = ACTIONS(244),
    [sym_keyword_contains_any] = ACTIONS(244),
    [sym_keyword_contains_none] = ACTIONS(244),
    [sym_keyword_inside] = ACTIONS(244),
    [sym_keyword_in] = ACTIONS(246),
    [sym_keyword_not_inside] = ACTIONS(244),
    [sym_keyword_all_inside] = ACTIONS(244),
    [sym_keyword_any_inside] = ACTIONS(244),
    [sym_keyword_none_inside] = ACTIONS(244),
    [sym_keyword_outside] = ACTIONS(244),
    [sym_keyword_intersects] = ACTIONS(244),
    [anon_sym_EQ] = ACTIONS(246),
    [anon_sym_COMMA] = ACTIONS(244),
    [anon_sym_DASH_GT] = ACTIONS(244),
    [anon_sym_LBRACK] = ACTIONS(244),
    [anon_sym_LT] = ACTIONS(246),
    [anon_sym_GT] = ACTIONS(246),
    [anon_sym_LT_DASH] = ACTIONS(246),
    [anon_sym_LT_DASH_GT] = ACTIONS(244),
    [anon_sym_STAR] = ACTIONS(246),
    [anon_sym_DOT] = ACTIONS(246),
    [anon_sym_DOT_DOT] = ACTIONS(244),
    [anon_sym_DASH] = ACTIONS(246),
    [anon_sym_PERCENT] = ACTIONS(244),
    [anon_sym_AT] = ACTIONS(246),
    [anon_sym_LT_PIPE] = ACTIONS(244),
    [anon_sym_AMP_AMP] = ACTIONS(244),
    [anon_sym_PIPE_PIPE] = ACTIONS(244),
    [anon_sym_QMARK_QMARK] = ACTIONS(244),
    [anon_sym_QMARK_COLON] = ACTIONS(244),
    [anon_sym_BANG_EQ] = ACTIONS(244),
    [anon_sym_EQ_EQ] = ACTIONS(244),
    [anon_sym_QMARK_EQ] = ACTIONS(244),
    [anon_sym_STAR_EQ] = ACTIONS(244),
    [anon_sym_TILDE] = ACTIONS(244),
    [anon_sym_BANG_TILDE] = ACTIONS(244),
    [anon_sym_STAR_TILDE] = ACTIONS(244),
    [anon_sym_LT_EQ] = ACTIONS(244),
    [anon_sym_GT_EQ] = ACTIONS(244),
    [anon_sym_PLUS] = ACTIONS(246),
    [anon_sym_PLUS_EQ] = ACTIONS(244),
    [anon_sym_DASH_EQ] = ACTIONS(244),
    [anon_sym_u00d7] = ACTIONS(244),
    [anon_sym_SLASH] = ACTIONS(246),
    [anon_sym_u00f7] = ACTIONS(244),
    [anon_sym_STAR_STAR] = ACTIONS(244),
    [anon_sym_u220b] = ACTIONS(244),
    [anon_sym_u220c] = ACTIONS(244),
    [anon_sym_u2287] = ACTIONS(244),
    [anon_sym_u2283] = ACTIONS(244),
    [anon_sym_u2285] = ACTIONS(244),
    [anon_sym_u2208] = ACTIONS(244),
    [anon_sym_u2209] = ACTIONS(244),
    [anon_sym_u2286] = ACTIONS(244),
    [anon_sym_u2282] = ACTIONS(244),
    [anon_sym_u2284] = ACTIONS(244),
    [anon_sym_AT_AT] = ACTIONS(244),
  },
  [STATE(266)] = {
    [ts_builtin_sym_end] = ACTIONS(208),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(208),
    [sym_keyword_explain] = ACTIONS(208),
    [sym_keyword_parallel] = ACTIONS(208),
    [sym_keyword_timeout] = ACTIONS(208),
    [sym_keyword_fetch] = ACTIONS(208),
    [sym_keyword_limit] = ACTIONS(208),
    [sym_keyword_order] = ACTIONS(208),
    [sym_keyword_with] = ACTIONS(208),
    [sym_keyword_where] = ACTIONS(208),
    [sym_keyword_split] = ACTIONS(208),
    [sym_keyword_group] = ACTIONS(208),
    [sym_keyword_and] = ACTIONS(208),
    [sym_keyword_or] = ACTIONS(210),
    [sym_keyword_is] = ACTIONS(208),
    [sym_keyword_not] = ACTIONS(210),
    [sym_keyword_contains] = ACTIONS(210),
    [sym_keyword_contains_not] = ACTIONS(208),
    [sym_keyword_contains_all] = ACTIONS(208),
    [sym_keyword_contains_any] = ACTIONS(208),
    [sym_keyword_contains_none] = ACTIONS(208),
    [sym_keyword_inside] = ACTIONS(208),
    [sym_keyword_in] = ACTIONS(210),
    [sym_keyword_not_inside] = ACTIONS(208),
    [sym_keyword_all_inside] = ACTIONS(208),
    [sym_keyword_any_inside] = ACTIONS(208),
    [sym_keyword_none_inside] = ACTIONS(208),
    [sym_keyword_outside] = ACTIONS(208),
    [sym_keyword_intersects] = ACTIONS(208),
    [anon_sym_EQ] = ACTIONS(210),
    [anon_sym_COMMA] = ACTIONS(208),
    [anon_sym_DASH_GT] = ACTIONS(208),
    [anon_sym_LBRACK] = ACTIONS(208),
    [anon_sym_LT] = ACTIONS(210),
    [anon_sym_GT] = ACTIONS(210),
    [anon_sym_LT_DASH] = ACTIONS(210),
    [anon_sym_LT_DASH_GT] = ACTIONS(208),
    [anon_sym_STAR] = ACTIONS(210),
    [anon_sym_DOT] = ACTIONS(210),
    [anon_sym_DOT_DOT] = ACTIONS(208),
    [anon_sym_DASH] = ACTIONS(210),
    [anon_sym_PERCENT] = ACTIONS(208),
    [anon_sym_AT] = ACTIONS(210),
    [anon_sym_LT_PIPE] = ACTIONS(208),
    [anon_sym_AMP_AMP] = ACTIONS(208),
    [anon_sym_PIPE_PIPE] = ACTIONS(208),
    [anon_sym_QMARK_QMARK] = ACTIONS(208),
    [anon_sym_QMARK_COLON] = ACTIONS(208),
    [anon_sym_BANG_EQ] = ACTIONS(208),
    [anon_sym_EQ_EQ] = ACTIONS(208),
    [anon_sym_QMARK_EQ] = ACTIONS(208),
    [anon_sym_STAR_EQ] = ACTIONS(208),
    [anon_sym_TILDE] = ACTIONS(208),
    [anon_sym_BANG_TILDE] = ACTIONS(208),
    [anon_sym_STAR_TILDE] = ACTIONS(208),
    [anon_sym_LT_EQ] = ACTIONS(208),
    [anon_sym_GT_EQ] = ACTIONS(208),
    [anon_sym_PLUS] = ACTIONS(210),
    [anon_sym_PLUS_EQ] = ACTIONS(208),
    [anon_sym_DASH_EQ] = ACTIONS(208),
    [anon_sym_u00d7] = ACTIONS(208),
    [anon_sym_SLASH] = ACTIONS(210),
    [anon_sym_u00f7] = ACTIONS(208),
    [anon_sym_STAR_STAR] = ACTIONS(208),
    [anon_sym_u220b] = ACTIONS(208),
    [anon_sym_u220c] = ACTIONS(208),
    [anon_sym_u2287] = ACTIONS(208),
    [anon_sym_u2283] = ACTIONS(208),
    [anon_sym_u2285] = ACTIONS(208),
    [anon_sym_u2208] = ACTIONS(208),
    [anon_sym_u2209] = ACTIONS(208),
    [anon_sym_u2286] = ACTIONS(208),
    [anon_sym_u2282] = ACTIONS(208),
    [anon_sym_u2284] = ACTIONS(208),
    [anon_sym_AT_AT] = ACTIONS(208),
  },
  [STATE(267)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_order] = ACTIONS(186),
    [sym_keyword_with] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_split] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(188),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_RPAREN] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_RBRACE] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(268)] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_order] = ACTIONS(186),
    [sym_keyword_with] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_split] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(188),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(188),
    [anon_sym_DOT_DOT] = ACTIONS(675),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(269)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(310),
    [sym_keyword_explain] = ACTIONS(310),
    [sym_keyword_parallel] = ACTIONS(310),
    [sym_keyword_timeout] = ACTIONS(310),
    [sym_keyword_fetch] = ACTIONS(310),
    [sym_keyword_limit] = ACTIONS(310),
    [sym_keyword_order] = ACTIONS(310),
    [sym_keyword_with] = ACTIONS(310),
    [sym_keyword_where] = ACTIONS(310),
    [sym_keyword_split] = ACTIONS(310),
    [sym_keyword_group] = ACTIONS(310),
    [sym_keyword_and] = ACTIONS(310),
    [sym_keyword_or] = ACTIONS(312),
    [sym_keyword_is] = ACTIONS(310),
    [sym_keyword_not] = ACTIONS(312),
    [sym_keyword_contains] = ACTIONS(312),
    [sym_keyword_contains_not] = ACTIONS(310),
    [sym_keyword_contains_all] = ACTIONS(310),
    [sym_keyword_contains_any] = ACTIONS(310),
    [sym_keyword_contains_none] = ACTIONS(310),
    [sym_keyword_inside] = ACTIONS(310),
    [sym_keyword_in] = ACTIONS(312),
    [sym_keyword_not_inside] = ACTIONS(310),
    [sym_keyword_all_inside] = ACTIONS(310),
    [sym_keyword_any_inside] = ACTIONS(310),
    [sym_keyword_none_inside] = ACTIONS(310),
    [sym_keyword_outside] = ACTIONS(310),
    [sym_keyword_intersects] = ACTIONS(310),
    [anon_sym_EQ] = ACTIONS(312),
    [anon_sym_COMMA] = ACTIONS(310),
    [anon_sym_RPAREN] = ACTIONS(310),
    [anon_sym_DASH_GT] = ACTIONS(310),
    [anon_sym_LBRACK] = ACTIONS(310),
    [anon_sym_RBRACE] = ACTIONS(310),
    [anon_sym_LT] = ACTIONS(312),
    [anon_sym_GT] = ACTIONS(312),
    [anon_sym_LT_DASH] = ACTIONS(312),
    [anon_sym_LT_DASH_GT] = ACTIONS(310),
    [anon_sym_STAR] = ACTIONS(312),
    [anon_sym_DOT] = ACTIONS(310),
    [anon_sym_DASH] = ACTIONS(312),
    [anon_sym_PERCENT] = ACTIONS(310),
    [anon_sym_AT] = ACTIONS(312),
    [anon_sym_LT_PIPE] = ACTIONS(310),
    [anon_sym_AMP_AMP] = ACTIONS(310),
    [anon_sym_PIPE_PIPE] = ACTIONS(310),
    [anon_sym_QMARK_QMARK] = ACTIONS(310),
    [anon_sym_QMARK_COLON] = ACTIONS(310),
    [anon_sym_BANG_EQ] = ACTIONS(310),
    [anon_sym_EQ_EQ] = ACTIONS(310),
    [anon_sym_QMARK_EQ] = ACTIONS(310),
    [anon_sym_STAR_EQ] = ACTIONS(310),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG_TILDE] = ACTIONS(310),
    [anon_sym_STAR_TILDE] = ACTIONS(310),
    [anon_sym_LT_EQ] = ACTIONS(310),
    [anon_sym_GT_EQ] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(312),
    [anon_sym_PLUS_EQ] = ACTIONS(310),
    [anon_sym_DASH_EQ] = ACTIONS(310),
    [anon_sym_u00d7] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(312),
    [anon_sym_u00f7] = ACTIONS(310),
    [anon_sym_STAR_STAR] = ACTIONS(310),
    [anon_sym_u220b] = ACTIONS(310),
    [anon_sym_u220c] = ACTIONS(310),
    [anon_sym_u2287] = ACTIONS(310),
    [anon_sym_u2283] = ACTIONS(310),
    [anon_sym_u2285] = ACTIONS(310),
    [anon_sym_u2208] = ACTIONS(310),
    [anon_sym_u2209] = ACTIONS(310),
    [anon_sym_u2286] = ACTIONS(310),
    [anon_sym_u2282] = ACTIONS(310),
    [anon_sym_u2284] = ACTIONS(310),
    [anon_sym_AT_AT] = ACTIONS(310),
  },
  [STATE(270)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(347),
    [sym_keyword_explain] = ACTIONS(347),
    [sym_keyword_parallel] = ACTIONS(347),
    [sym_keyword_timeout] = ACTIONS(347),
    [sym_keyword_fetch] = ACTIONS(347),
    [sym_keyword_limit] = ACTIONS(347),
    [sym_keyword_order] = ACTIONS(347),
    [sym_keyword_with] = ACTIONS(347),
    [sym_keyword_where] = ACTIONS(347),
    [sym_keyword_split] = ACTIONS(347),
    [sym_keyword_group] = ACTIONS(347),
    [sym_keyword_and] = ACTIONS(347),
    [sym_keyword_or] = ACTIONS(349),
    [sym_keyword_is] = ACTIONS(347),
    [sym_keyword_not] = ACTIONS(349),
    [sym_keyword_contains] = ACTIONS(349),
    [sym_keyword_contains_not] = ACTIONS(347),
    [sym_keyword_contains_all] = ACTIONS(347),
    [sym_keyword_contains_any] = ACTIONS(347),
    [sym_keyword_contains_none] = ACTIONS(347),
    [sym_keyword_inside] = ACTIONS(347),
    [sym_keyword_in] = ACTIONS(349),
    [sym_keyword_not_inside] = ACTIONS(347),
    [sym_keyword_all_inside] = ACTIONS(347),
    [sym_keyword_any_inside] = ACTIONS(347),
    [sym_keyword_none_inside] = ACTIONS(347),
    [sym_keyword_outside] = ACTIONS(347),
    [sym_keyword_intersects] = ACTIONS(347),
    [anon_sym_EQ] = ACTIONS(349),
    [anon_sym_COMMA] = ACTIONS(347),
    [anon_sym_RPAREN] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(347),
    [anon_sym_LBRACK] = ACTIONS(347),
    [anon_sym_RBRACE] = ACTIONS(347),
    [anon_sym_LT] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(349),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_DASH_GT] = ACTIONS(347),
    [anon_sym_STAR] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_AT] = ACTIONS(349),
    [anon_sym_LT_PIPE] = ACTIONS(347),
    [anon_sym_AMP_AMP] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(347),
    [anon_sym_QMARK_QMARK] = ACTIONS(347),
    [anon_sym_QMARK_COLON] = ACTIONS(347),
    [anon_sym_BANG_EQ] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(347),
    [anon_sym_QMARK_EQ] = ACTIONS(347),
    [anon_sym_STAR_EQ] = ACTIONS(347),
    [anon_sym_TILDE] = ACTIONS(347),
    [anon_sym_BANG_TILDE] = ACTIONS(347),
    [anon_sym_STAR_TILDE] = ACTIONS(347),
    [anon_sym_LT_EQ] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_PLUS_EQ] = ACTIONS(347),
    [anon_sym_DASH_EQ] = ACTIONS(347),
    [anon_sym_u00d7] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_u00f7] = ACTIONS(347),
    [anon_sym_STAR_STAR] = ACTIONS(347),
    [anon_sym_u220b] = ACTIONS(347),
    [anon_sym_u220c] = ACTIONS(347),
    [anon_sym_u2287] = ACTIONS(347),
    [anon_sym_u2283] = ACTIONS(347),
    [anon_sym_u2285] = ACTIONS(347),
    [anon_sym_u2208] = ACTIONS(347),
    [anon_sym_u2209] = ACTIONS(347),
    [anon_sym_u2286] = ACTIONS(347),
    [anon_sym_u2282] = ACTIONS(347),
    [anon_sym_u2284] = ACTIONS(347),
    [anon_sym_AT_AT] = ACTIONS(347),
  },
  [STATE(271)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_order] = ACTIONS(204),
    [sym_keyword_with] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_split] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(272)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(359),
    [sym_keyword_explain] = ACTIONS(359),
    [sym_keyword_parallel] = ACTIONS(359),
    [sym_keyword_timeout] = ACTIONS(359),
    [sym_keyword_fetch] = ACTIONS(359),
    [sym_keyword_limit] = ACTIONS(359),
    [sym_keyword_order] = ACTIONS(359),
    [sym_keyword_with] = ACTIONS(359),
    [sym_keyword_where] = ACTIONS(359),
    [sym_keyword_split] = ACTIONS(359),
    [sym_keyword_group] = ACTIONS(359),
    [sym_keyword_and] = ACTIONS(359),
    [sym_keyword_or] = ACTIONS(361),
    [sym_keyword_is] = ACTIONS(359),
    [sym_keyword_not] = ACTIONS(361),
    [sym_keyword_contains] = ACTIONS(361),
    [sym_keyword_contains_not] = ACTIONS(359),
    [sym_keyword_contains_all] = ACTIONS(359),
    [sym_keyword_contains_any] = ACTIONS(359),
    [sym_keyword_contains_none] = ACTIONS(359),
    [sym_keyword_inside] = ACTIONS(359),
    [sym_keyword_in] = ACTIONS(361),
    [sym_keyword_not_inside] = ACTIONS(359),
    [sym_keyword_all_inside] = ACTIONS(359),
    [sym_keyword_any_inside] = ACTIONS(359),
    [sym_keyword_none_inside] = ACTIONS(359),
    [sym_keyword_outside] = ACTIONS(359),
    [sym_keyword_intersects] = ACTIONS(359),
    [anon_sym_EQ] = ACTIONS(361),
    [anon_sym_COMMA] = ACTIONS(359),
    [anon_sym_RPAREN] = ACTIONS(359),
    [anon_sym_DASH_GT] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_RBRACE] = ACTIONS(359),
    [anon_sym_LT] = ACTIONS(361),
    [anon_sym_GT] = ACTIONS(361),
    [anon_sym_LT_DASH] = ACTIONS(361),
    [anon_sym_LT_DASH_GT] = ACTIONS(359),
    [anon_sym_STAR] = ACTIONS(361),
    [anon_sym_DOT] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [anon_sym_PERCENT] = ACTIONS(359),
    [anon_sym_AT] = ACTIONS(361),
    [anon_sym_LT_PIPE] = ACTIONS(359),
    [anon_sym_AMP_AMP] = ACTIONS(359),
    [anon_sym_PIPE_PIPE] = ACTIONS(359),
    [anon_sym_QMARK_QMARK] = ACTIONS(359),
    [anon_sym_QMARK_COLON] = ACTIONS(359),
    [anon_sym_BANG_EQ] = ACTIONS(359),
    [anon_sym_EQ_EQ] = ACTIONS(359),
    [anon_sym_QMARK_EQ] = ACTIONS(359),
    [anon_sym_STAR_EQ] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(359),
    [anon_sym_BANG_TILDE] = ACTIONS(359),
    [anon_sym_STAR_TILDE] = ACTIONS(359),
    [anon_sym_LT_EQ] = ACTIONS(359),
    [anon_sym_GT_EQ] = ACTIONS(359),
    [anon_sym_PLUS] = ACTIONS(361),
    [anon_sym_PLUS_EQ] = ACTIONS(359),
    [anon_sym_DASH_EQ] = ACTIONS(359),
    [anon_sym_u00d7] = ACTIONS(359),
    [anon_sym_SLASH] = ACTIONS(361),
    [anon_sym_u00f7] = ACTIONS(359),
    [anon_sym_STAR_STAR] = ACTIONS(359),
    [anon_sym_u220b] = ACTIONS(359),
    [anon_sym_u220c] = ACTIONS(359),
    [anon_sym_u2287] = ACTIONS(359),
    [anon_sym_u2283] = ACTIONS(359),
    [anon_sym_u2285] = ACTIONS(359),
    [anon_sym_u2208] = ACTIONS(359),
    [anon_sym_u2209] = ACTIONS(359),
    [anon_sym_u2286] = ACTIONS(359),
    [anon_sym_u2282] = ACTIONS(359),
    [anon_sym_u2284] = ACTIONS(359),
    [anon_sym_AT_AT] = ACTIONS(359),
  },
  [STATE(273)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(326),
    [sym_keyword_explain] = ACTIONS(326),
    [sym_keyword_parallel] = ACTIONS(326),
    [sym_keyword_timeout] = ACTIONS(326),
    [sym_keyword_fetch] = ACTIONS(326),
    [sym_keyword_limit] = ACTIONS(326),
    [sym_keyword_order] = ACTIONS(326),
    [sym_keyword_with] = ACTIONS(326),
    [sym_keyword_where] = ACTIONS(326),
    [sym_keyword_split] = ACTIONS(326),
    [sym_keyword_group] = ACTIONS(326),
    [sym_keyword_and] = ACTIONS(326),
    [sym_keyword_or] = ACTIONS(328),
    [sym_keyword_is] = ACTIONS(326),
    [sym_keyword_not] = ACTIONS(328),
    [sym_keyword_contains] = ACTIONS(328),
    [sym_keyword_contains_not] = ACTIONS(326),
    [sym_keyword_contains_all] = ACTIONS(326),
    [sym_keyword_contains_any] = ACTIONS(326),
    [sym_keyword_contains_none] = ACTIONS(326),
    [sym_keyword_inside] = ACTIONS(326),
    [sym_keyword_in] = ACTIONS(328),
    [sym_keyword_not_inside] = ACTIONS(326),
    [sym_keyword_all_inside] = ACTIONS(326),
    [sym_keyword_any_inside] = ACTIONS(326),
    [sym_keyword_none_inside] = ACTIONS(326),
    [sym_keyword_outside] = ACTIONS(326),
    [sym_keyword_intersects] = ACTIONS(326),
    [anon_sym_EQ] = ACTIONS(328),
    [anon_sym_COMMA] = ACTIONS(326),
    [anon_sym_RPAREN] = ACTIONS(326),
    [anon_sym_DASH_GT] = ACTIONS(326),
    [anon_sym_LBRACK] = ACTIONS(326),
    [anon_sym_RBRACE] = ACTIONS(326),
    [anon_sym_LT] = ACTIONS(328),
    [anon_sym_GT] = ACTIONS(328),
    [anon_sym_LT_DASH] = ACTIONS(328),
    [anon_sym_LT_DASH_GT] = ACTIONS(326),
    [anon_sym_STAR] = ACTIONS(328),
    [anon_sym_DOT] = ACTIONS(326),
    [anon_sym_DASH] = ACTIONS(328),
    [anon_sym_PERCENT] = ACTIONS(326),
    [anon_sym_AT] = ACTIONS(328),
    [anon_sym_LT_PIPE] = ACTIONS(326),
    [anon_sym_AMP_AMP] = ACTIONS(326),
    [anon_sym_PIPE_PIPE] = ACTIONS(326),
    [anon_sym_QMARK_QMARK] = ACTIONS(326),
    [anon_sym_QMARK_COLON] = ACTIONS(326),
    [anon_sym_BANG_EQ] = ACTIONS(326),
    [anon_sym_EQ_EQ] = ACTIONS(326),
    [anon_sym_QMARK_EQ] = ACTIONS(326),
    [anon_sym_STAR_EQ] = ACTIONS(326),
    [anon_sym_TILDE] = ACTIONS(326),
    [anon_sym_BANG_TILDE] = ACTIONS(326),
    [anon_sym_STAR_TILDE] = ACTIONS(326),
    [anon_sym_LT_EQ] = ACTIONS(326),
    [anon_sym_GT_EQ] = ACTIONS(326),
    [anon_sym_PLUS] = ACTIONS(328),
    [anon_sym_PLUS_EQ] = ACTIONS(326),
    [anon_sym_DASH_EQ] = ACTIONS(326),
    [anon_sym_u00d7] = ACTIONS(326),
    [anon_sym_SLASH] = ACTIONS(328),
    [anon_sym_u00f7] = ACTIONS(326),
    [anon_sym_STAR_STAR] = ACTIONS(326),
    [anon_sym_u220b] = ACTIONS(326),
    [anon_sym_u220c] = ACTIONS(326),
    [anon_sym_u2287] = ACTIONS(326),
    [anon_sym_u2283] = ACTIONS(326),
    [anon_sym_u2285] = ACTIONS(326),
    [anon_sym_u2208] = ACTIONS(326),
    [anon_sym_u2209] = ACTIONS(326),
    [anon_sym_u2286] = ACTIONS(326),
    [anon_sym_u2282] = ACTIONS(326),
    [anon_sym_u2284] = ACTIONS(326),
    [anon_sym_AT_AT] = ACTIONS(326),
  },
  [STATE(274)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(284),
    [sym_keyword_explain] = ACTIONS(284),
    [sym_keyword_parallel] = ACTIONS(284),
    [sym_keyword_timeout] = ACTIONS(284),
    [sym_keyword_fetch] = ACTIONS(284),
    [sym_keyword_limit] = ACTIONS(284),
    [sym_keyword_order] = ACTIONS(284),
    [sym_keyword_with] = ACTIONS(284),
    [sym_keyword_where] = ACTIONS(284),
    [sym_keyword_split] = ACTIONS(284),
    [sym_keyword_group] = ACTIONS(284),
    [sym_keyword_and] = ACTIONS(284),
    [sym_keyword_or] = ACTIONS(286),
    [sym_keyword_is] = ACTIONS(284),
    [sym_keyword_not] = ACTIONS(286),
    [sym_keyword_contains] = ACTIONS(286),
    [sym_keyword_contains_not] = ACTIONS(284),
    [sym_keyword_contains_all] = ACTIONS(284),
    [sym_keyword_contains_any] = ACTIONS(284),
    [sym_keyword_contains_none] = ACTIONS(284),
    [sym_keyword_inside] = ACTIONS(284),
    [sym_keyword_in] = ACTIONS(286),
    [sym_keyword_not_inside] = ACTIONS(284),
    [sym_keyword_all_inside] = ACTIONS(284),
    [sym_keyword_any_inside] = ACTIONS(284),
    [sym_keyword_none_inside] = ACTIONS(284),
    [sym_keyword_outside] = ACTIONS(284),
    [sym_keyword_intersects] = ACTIONS(284),
    [anon_sym_EQ] = ACTIONS(286),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_RPAREN] = ACTIONS(284),
    [anon_sym_DASH_GT] = ACTIONS(284),
    [anon_sym_LBRACK] = ACTIONS(284),
    [anon_sym_RBRACE] = ACTIONS(284),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_LT_DASH] = ACTIONS(286),
    [anon_sym_LT_DASH_GT] = ACTIONS(284),
    [anon_sym_STAR] = ACTIONS(286),
    [anon_sym_DOT] = ACTIONS(284),
    [anon_sym_DASH] = ACTIONS(286),
    [anon_sym_PERCENT] = ACTIONS(284),
    [anon_sym_AT] = ACTIONS(286),
    [anon_sym_LT_PIPE] = ACTIONS(284),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_PIPE_PIPE] = ACTIONS(284),
    [anon_sym_QMARK_QMARK] = ACTIONS(284),
    [anon_sym_QMARK_COLON] = ACTIONS(284),
    [anon_sym_BANG_EQ] = ACTIONS(284),
    [anon_sym_EQ_EQ] = ACTIONS(284),
    [anon_sym_QMARK_EQ] = ACTIONS(284),
    [anon_sym_STAR_EQ] = ACTIONS(284),
    [anon_sym_TILDE] = ACTIONS(284),
    [anon_sym_BANG_TILDE] = ACTIONS(284),
    [anon_sym_STAR_TILDE] = ACTIONS(284),
    [anon_sym_LT_EQ] = ACTIONS(284),
    [anon_sym_GT_EQ] = ACTIONS(284),
    [anon_sym_PLUS] = ACTIONS(286),
    [anon_sym_PLUS_EQ] = ACTIONS(284),
    [anon_sym_DASH_EQ] = ACTIONS(284),
    [anon_sym_u00d7] = ACTIONS(284),
    [anon_sym_SLASH] = ACTIONS(286),
    [anon_sym_u00f7] = ACTIONS(284),
    [anon_sym_STAR_STAR] = ACTIONS(284),
    [anon_sym_u220b] = ACTIONS(284),
    [anon_sym_u220c] = ACTIONS(284),
    [anon_sym_u2287] = ACTIONS(284),
    [anon_sym_u2283] = ACTIONS(284),
    [anon_sym_u2285] = ACTIONS(284),
    [anon_sym_u2208] = ACTIONS(284),
    [anon_sym_u2209] = ACTIONS(284),
    [anon_sym_u2286] = ACTIONS(284),
    [anon_sym_u2282] = ACTIONS(284),
    [anon_sym_u2284] = ACTIONS(284),
    [anon_sym_AT_AT] = ACTIONS(284),
  },
  [STATE(275)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(292),
    [sym_keyword_explain] = ACTIONS(292),
    [sym_keyword_parallel] = ACTIONS(292),
    [sym_keyword_timeout] = ACTIONS(292),
    [sym_keyword_fetch] = ACTIONS(292),
    [sym_keyword_limit] = ACTIONS(292),
    [sym_keyword_order] = ACTIONS(292),
    [sym_keyword_with] = ACTIONS(292),
    [sym_keyword_where] = ACTIONS(292),
    [sym_keyword_split] = ACTIONS(292),
    [sym_keyword_group] = ACTIONS(292),
    [sym_keyword_and] = ACTIONS(292),
    [sym_keyword_or] = ACTIONS(294),
    [sym_keyword_is] = ACTIONS(292),
    [sym_keyword_not] = ACTIONS(294),
    [sym_keyword_contains] = ACTIONS(294),
    [sym_keyword_contains_not] = ACTIONS(292),
    [sym_keyword_contains_all] = ACTIONS(292),
    [sym_keyword_contains_any] = ACTIONS(292),
    [sym_keyword_contains_none] = ACTIONS(292),
    [sym_keyword_inside] = ACTIONS(292),
    [sym_keyword_in] = ACTIONS(294),
    [sym_keyword_not_inside] = ACTIONS(292),
    [sym_keyword_all_inside] = ACTIONS(292),
    [sym_keyword_any_inside] = ACTIONS(292),
    [sym_keyword_none_inside] = ACTIONS(292),
    [sym_keyword_outside] = ACTIONS(292),
    [sym_keyword_intersects] = ACTIONS(292),
    [anon_sym_EQ] = ACTIONS(294),
    [anon_sym_COMMA] = ACTIONS(292),
    [anon_sym_RPAREN] = ACTIONS(292),
    [anon_sym_DASH_GT] = ACTIONS(292),
    [anon_sym_LBRACK] = ACTIONS(292),
    [anon_sym_RBRACE] = ACTIONS(292),
    [anon_sym_LT] = ACTIONS(294),
    [anon_sym_GT] = ACTIONS(294),
    [anon_sym_LT_DASH] = ACTIONS(294),
    [anon_sym_LT_DASH_GT] = ACTIONS(292),
    [anon_sym_STAR] = ACTIONS(294),
    [anon_sym_DOT] = ACTIONS(292),
    [anon_sym_DASH] = ACTIONS(294),
    [anon_sym_PERCENT] = ACTIONS(292),
    [anon_sym_AT] = ACTIONS(294),
    [anon_sym_LT_PIPE] = ACTIONS(292),
    [anon_sym_AMP_AMP] = ACTIONS(292),
    [anon_sym_PIPE_PIPE] = ACTIONS(292),
    [anon_sym_QMARK_QMARK] = ACTIONS(292),
    [anon_sym_QMARK_COLON] = ACTIONS(292),
    [anon_sym_BANG_EQ] = ACTIONS(292),
    [anon_sym_EQ_EQ] = ACTIONS(292),
    [anon_sym_QMARK_EQ] = ACTIONS(292),
    [anon_sym_STAR_EQ] = ACTIONS(292),
    [anon_sym_TILDE] = ACTIONS(292),
    [anon_sym_BANG_TILDE] = ACTIONS(292),
    [anon_sym_STAR_TILDE] = ACTIONS(292),
    [anon_sym_LT_EQ] = ACTIONS(292),
    [anon_sym_GT_EQ] = ACTIONS(292),
    [anon_sym_PLUS] = ACTIONS(294),
    [anon_sym_PLUS_EQ] = ACTIONS(292),
    [anon_sym_DASH_EQ] = ACTIONS(292),
    [anon_sym_u00d7] = ACTIONS(292),
    [anon_sym_SLASH] = ACTIONS(294),
    [anon_sym_u00f7] = ACTIONS(292),
    [anon_sym_STAR_STAR] = ACTIONS(292),
    [anon_sym_u220b] = ACTIONS(292),
    [anon_sym_u220c] = ACTIONS(292),
    [anon_sym_u2287] = ACTIONS(292),
    [anon_sym_u2283] = ACTIONS(292),
    [anon_sym_u2285] = ACTIONS(292),
    [anon_sym_u2208] = ACTIONS(292),
    [anon_sym_u2209] = ACTIONS(292),
    [anon_sym_u2286] = ACTIONS(292),
    [anon_sym_u2282] = ACTIONS(292),
    [anon_sym_u2284] = ACTIONS(292),
    [anon_sym_AT_AT] = ACTIONS(292),
  },
  [STATE(276)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_order] = ACTIONS(190),
    [sym_keyword_with] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_split] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(192),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(192),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_RPAREN] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_RBRACE] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_PERCENT] = ACTIONS(190),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [STATE(277)] = {
    [ts_builtin_sym_end] = ACTIONS(252),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(252),
    [sym_keyword_explain] = ACTIONS(252),
    [sym_keyword_parallel] = ACTIONS(252),
    [sym_keyword_timeout] = ACTIONS(252),
    [sym_keyword_fetch] = ACTIONS(252),
    [sym_keyword_limit] = ACTIONS(252),
    [sym_keyword_order] = ACTIONS(252),
    [sym_keyword_with] = ACTIONS(252),
    [sym_keyword_where] = ACTIONS(252),
    [sym_keyword_split] = ACTIONS(252),
    [sym_keyword_group] = ACTIONS(252),
    [sym_keyword_and] = ACTIONS(252),
    [sym_keyword_or] = ACTIONS(254),
    [sym_keyword_is] = ACTIONS(252),
    [sym_keyword_not] = ACTIONS(254),
    [sym_keyword_contains] = ACTIONS(254),
    [sym_keyword_contains_not] = ACTIONS(252),
    [sym_keyword_contains_all] = ACTIONS(252),
    [sym_keyword_contains_any] = ACTIONS(252),
    [sym_keyword_contains_none] = ACTIONS(252),
    [sym_keyword_inside] = ACTIONS(252),
    [sym_keyword_in] = ACTIONS(254),
    [sym_keyword_not_inside] = ACTIONS(252),
    [sym_keyword_all_inside] = ACTIONS(252),
    [sym_keyword_any_inside] = ACTIONS(252),
    [sym_keyword_none_inside] = ACTIONS(252),
    [sym_keyword_outside] = ACTIONS(252),
    [sym_keyword_intersects] = ACTIONS(252),
    [anon_sym_EQ] = ACTIONS(254),
    [anon_sym_COMMA] = ACTIONS(252),
    [anon_sym_DASH_GT] = ACTIONS(252),
    [anon_sym_LBRACK] = ACTIONS(252),
    [anon_sym_LT] = ACTIONS(254),
    [anon_sym_GT] = ACTIONS(254),
    [anon_sym_LT_DASH] = ACTIONS(254),
    [anon_sym_LT_DASH_GT] = ACTIONS(252),
    [anon_sym_STAR] = ACTIONS(254),
    [anon_sym_DOT] = ACTIONS(254),
    [anon_sym_DOT_DOT] = ACTIONS(252),
    [anon_sym_DASH] = ACTIONS(254),
    [anon_sym_PERCENT] = ACTIONS(252),
    [anon_sym_AT] = ACTIONS(254),
    [anon_sym_LT_PIPE] = ACTIONS(252),
    [anon_sym_AMP_AMP] = ACTIONS(252),
    [anon_sym_PIPE_PIPE] = ACTIONS(252),
    [anon_sym_QMARK_QMARK] = ACTIONS(252),
    [anon_sym_QMARK_COLON] = ACTIONS(252),
    [anon_sym_BANG_EQ] = ACTIONS(252),
    [anon_sym_EQ_EQ] = ACTIONS(252),
    [anon_sym_QMARK_EQ] = ACTIONS(252),
    [anon_sym_STAR_EQ] = ACTIONS(252),
    [anon_sym_TILDE] = ACTIONS(252),
    [anon_sym_BANG_TILDE] = ACTIONS(252),
    [anon_sym_STAR_TILDE] = ACTIONS(252),
    [anon_sym_LT_EQ] = ACTIONS(252),
    [anon_sym_GT_EQ] = ACTIONS(252),
    [anon_sym_PLUS] = ACTIONS(254),
    [anon_sym_PLUS_EQ] = ACTIONS(252),
    [anon_sym_DASH_EQ] = ACTIONS(252),
    [anon_sym_u00d7] = ACTIONS(252),
    [anon_sym_SLASH] = ACTIONS(254),
    [anon_sym_u00f7] = ACTIONS(252),
    [anon_sym_STAR_STAR] = ACTIONS(252),
    [anon_sym_u220b] = ACTIONS(252),
    [anon_sym_u220c] = ACTIONS(252),
    [anon_sym_u2287] = ACTIONS(252),
    [anon_sym_u2283] = ACTIONS(252),
    [anon_sym_u2285] = ACTIONS(252),
    [anon_sym_u2208] = ACTIONS(252),
    [anon_sym_u2209] = ACTIONS(252),
    [anon_sym_u2286] = ACTIONS(252),
    [anon_sym_u2282] = ACTIONS(252),
    [anon_sym_u2284] = ACTIONS(252),
    [anon_sym_AT_AT] = ACTIONS(252),
  },
  [STATE(278)] = {
    [ts_builtin_sym_end] = ACTIONS(232),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(232),
    [sym_keyword_explain] = ACTIONS(232),
    [sym_keyword_parallel] = ACTIONS(232),
    [sym_keyword_timeout] = ACTIONS(232),
    [sym_keyword_fetch] = ACTIONS(232),
    [sym_keyword_limit] = ACTIONS(232),
    [sym_keyword_order] = ACTIONS(232),
    [sym_keyword_with] = ACTIONS(232),
    [sym_keyword_where] = ACTIONS(232),
    [sym_keyword_split] = ACTIONS(232),
    [sym_keyword_group] = ACTIONS(232),
    [sym_keyword_and] = ACTIONS(232),
    [sym_keyword_or] = ACTIONS(234),
    [sym_keyword_is] = ACTIONS(232),
    [sym_keyword_not] = ACTIONS(234),
    [sym_keyword_contains] = ACTIONS(234),
    [sym_keyword_contains_not] = ACTIONS(232),
    [sym_keyword_contains_all] = ACTIONS(232),
    [sym_keyword_contains_any] = ACTIONS(232),
    [sym_keyword_contains_none] = ACTIONS(232),
    [sym_keyword_inside] = ACTIONS(232),
    [sym_keyword_in] = ACTIONS(234),
    [sym_keyword_not_inside] = ACTIONS(232),
    [sym_keyword_all_inside] = ACTIONS(232),
    [sym_keyword_any_inside] = ACTIONS(232),
    [sym_keyword_none_inside] = ACTIONS(232),
    [sym_keyword_outside] = ACTIONS(232),
    [sym_keyword_intersects] = ACTIONS(232),
    [anon_sym_EQ] = ACTIONS(234),
    [anon_sym_COMMA] = ACTIONS(232),
    [anon_sym_DASH_GT] = ACTIONS(232),
    [anon_sym_LBRACK] = ACTIONS(232),
    [anon_sym_LT] = ACTIONS(234),
    [anon_sym_GT] = ACTIONS(234),
    [anon_sym_LT_DASH] = ACTIONS(234),
    [anon_sym_LT_DASH_GT] = ACTIONS(232),
    [anon_sym_STAR] = ACTIONS(234),
    [anon_sym_DOT] = ACTIONS(234),
    [anon_sym_DOT_DOT] = ACTIONS(232),
    [anon_sym_DASH] = ACTIONS(234),
    [anon_sym_PERCENT] = ACTIONS(232),
    [anon_sym_AT] = ACTIONS(234),
    [anon_sym_LT_PIPE] = ACTIONS(232),
    [anon_sym_AMP_AMP] = ACTIONS(232),
    [anon_sym_PIPE_PIPE] = ACTIONS(232),
    [anon_sym_QMARK_QMARK] = ACTIONS(232),
    [anon_sym_QMARK_COLON] = ACTIONS(232),
    [anon_sym_BANG_EQ] = ACTIONS(232),
    [anon_sym_EQ_EQ] = ACTIONS(232),
    [anon_sym_QMARK_EQ] = ACTIONS(232),
    [anon_sym_STAR_EQ] = ACTIONS(232),
    [anon_sym_TILDE] = ACTIONS(232),
    [anon_sym_BANG_TILDE] = ACTIONS(232),
    [anon_sym_STAR_TILDE] = ACTIONS(232),
    [anon_sym_LT_EQ] = ACTIONS(232),
    [anon_sym_GT_EQ] = ACTIONS(232),
    [anon_sym_PLUS] = ACTIONS(234),
    [anon_sym_PLUS_EQ] = ACTIONS(232),
    [anon_sym_DASH_EQ] = ACTIONS(232),
    [anon_sym_u00d7] = ACTIONS(232),
    [anon_sym_SLASH] = ACTIONS(234),
    [anon_sym_u00f7] = ACTIONS(232),
    [anon_sym_STAR_STAR] = ACTIONS(232),
    [anon_sym_u220b] = ACTIONS(232),
    [anon_sym_u220c] = ACTIONS(232),
    [anon_sym_u2287] = ACTIONS(232),
    [anon_sym_u2283] = ACTIONS(232),
    [anon_sym_u2285] = ACTIONS(232),
    [anon_sym_u2208] = ACTIONS(232),
    [anon_sym_u2209] = ACTIONS(232),
    [anon_sym_u2286] = ACTIONS(232),
    [anon_sym_u2282] = ACTIONS(232),
    [anon_sym_u2284] = ACTIONS(232),
    [anon_sym_AT_AT] = ACTIONS(232),
  },
  [STATE(279)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_order] = ACTIONS(278),
    [sym_keyword_with] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_split] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(280),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_RPAREN] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(280)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_content] = ACTIONS(537),
    [sym_keyword_set] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(281)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_content] = ACTIONS(316),
    [sym_keyword_set] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(282)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(283)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(284)] = {
    [ts_builtin_sym_end] = ACTIONS(240),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(240),
    [sym_keyword_explain] = ACTIONS(240),
    [sym_keyword_parallel] = ACTIONS(240),
    [sym_keyword_timeout] = ACTIONS(240),
    [sym_keyword_fetch] = ACTIONS(240),
    [sym_keyword_limit] = ACTIONS(240),
    [sym_keyword_order] = ACTIONS(240),
    [sym_keyword_with] = ACTIONS(240),
    [sym_keyword_where] = ACTIONS(240),
    [sym_keyword_split] = ACTIONS(240),
    [sym_keyword_group] = ACTIONS(240),
    [sym_keyword_and] = ACTIONS(240),
    [sym_keyword_or] = ACTIONS(242),
    [sym_keyword_is] = ACTIONS(240),
    [sym_keyword_not] = ACTIONS(242),
    [sym_keyword_contains] = ACTIONS(242),
    [sym_keyword_contains_not] = ACTIONS(240),
    [sym_keyword_contains_all] = ACTIONS(240),
    [sym_keyword_contains_any] = ACTIONS(240),
    [sym_keyword_contains_none] = ACTIONS(240),
    [sym_keyword_inside] = ACTIONS(240),
    [sym_keyword_in] = ACTIONS(242),
    [sym_keyword_not_inside] = ACTIONS(240),
    [sym_keyword_all_inside] = ACTIONS(240),
    [sym_keyword_any_inside] = ACTIONS(240),
    [sym_keyword_none_inside] = ACTIONS(240),
    [sym_keyword_outside] = ACTIONS(240),
    [sym_keyword_intersects] = ACTIONS(240),
    [anon_sym_EQ] = ACTIONS(242),
    [anon_sym_COMMA] = ACTIONS(240),
    [anon_sym_DASH_GT] = ACTIONS(240),
    [anon_sym_LBRACK] = ACTIONS(240),
    [anon_sym_LT] = ACTIONS(242),
    [anon_sym_GT] = ACTIONS(242),
    [anon_sym_LT_DASH] = ACTIONS(242),
    [anon_sym_LT_DASH_GT] = ACTIONS(240),
    [anon_sym_STAR] = ACTIONS(242),
    [anon_sym_DOT] = ACTIONS(242),
    [anon_sym_DOT_DOT] = ACTIONS(240),
    [anon_sym_DASH] = ACTIONS(242),
    [anon_sym_PERCENT] = ACTIONS(240),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LT_PIPE] = ACTIONS(240),
    [anon_sym_AMP_AMP] = ACTIONS(240),
    [anon_sym_PIPE_PIPE] = ACTIONS(240),
    [anon_sym_QMARK_QMARK] = ACTIONS(240),
    [anon_sym_QMARK_COLON] = ACTIONS(240),
    [anon_sym_BANG_EQ] = ACTIONS(240),
    [anon_sym_EQ_EQ] = ACTIONS(240),
    [anon_sym_QMARK_EQ] = ACTIONS(240),
    [anon_sym_STAR_EQ] = ACTIONS(240),
    [anon_sym_TILDE] = ACTIONS(240),
    [anon_sym_BANG_TILDE] = ACTIONS(240),
    [anon_sym_STAR_TILDE] = ACTIONS(240),
    [anon_sym_LT_EQ] = ACTIONS(240),
    [anon_sym_GT_EQ] = ACTIONS(240),
    [anon_sym_PLUS] = ACTIONS(242),
    [anon_sym_PLUS_EQ] = ACTIONS(240),
    [anon_sym_DASH_EQ] = ACTIONS(240),
    [anon_sym_u00d7] = ACTIONS(240),
    [anon_sym_SLASH] = ACTIONS(242),
    [anon_sym_u00f7] = ACTIONS(240),
    [anon_sym_STAR_STAR] = ACTIONS(240),
    [anon_sym_u220b] = ACTIONS(240),
    [anon_sym_u220c] = ACTIONS(240),
    [anon_sym_u2287] = ACTIONS(240),
    [anon_sym_u2283] = ACTIONS(240),
    [anon_sym_u2285] = ACTIONS(240),
    [anon_sym_u2208] = ACTIONS(240),
    [anon_sym_u2209] = ACTIONS(240),
    [anon_sym_u2286] = ACTIONS(240),
    [anon_sym_u2282] = ACTIONS(240),
    [anon_sym_u2284] = ACTIONS(240),
    [anon_sym_AT_AT] = ACTIONS(240),
  },
  [STATE(285)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_with] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(290),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(288),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(286)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(260),
    [sym_keyword_explain] = ACTIONS(260),
    [sym_keyword_parallel] = ACTIONS(260),
    [sym_keyword_timeout] = ACTIONS(260),
    [sym_keyword_fetch] = ACTIONS(260),
    [sym_keyword_limit] = ACTIONS(260),
    [sym_keyword_order] = ACTIONS(260),
    [sym_keyword_with] = ACTIONS(260),
    [sym_keyword_where] = ACTIONS(260),
    [sym_keyword_split] = ACTIONS(260),
    [sym_keyword_group] = ACTIONS(260),
    [sym_keyword_and] = ACTIONS(260),
    [sym_keyword_or] = ACTIONS(262),
    [sym_keyword_is] = ACTIONS(260),
    [sym_keyword_not] = ACTIONS(262),
    [sym_keyword_contains] = ACTIONS(262),
    [sym_keyword_contains_not] = ACTIONS(260),
    [sym_keyword_contains_all] = ACTIONS(260),
    [sym_keyword_contains_any] = ACTIONS(260),
    [sym_keyword_contains_none] = ACTIONS(260),
    [sym_keyword_inside] = ACTIONS(260),
    [sym_keyword_in] = ACTIONS(262),
    [sym_keyword_not_inside] = ACTIONS(260),
    [sym_keyword_all_inside] = ACTIONS(260),
    [sym_keyword_any_inside] = ACTIONS(260),
    [sym_keyword_none_inside] = ACTIONS(260),
    [sym_keyword_outside] = ACTIONS(260),
    [sym_keyword_intersects] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(262),
    [anon_sym_COMMA] = ACTIONS(260),
    [anon_sym_RPAREN] = ACTIONS(260),
    [anon_sym_DASH_GT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(260),
    [anon_sym_RBRACE] = ACTIONS(260),
    [anon_sym_LT] = ACTIONS(262),
    [anon_sym_GT] = ACTIONS(262),
    [anon_sym_LT_DASH] = ACTIONS(262),
    [anon_sym_LT_DASH_GT] = ACTIONS(260),
    [anon_sym_STAR] = ACTIONS(262),
    [anon_sym_DOT] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(262),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_AT] = ACTIONS(262),
    [anon_sym_LT_PIPE] = ACTIONS(260),
    [anon_sym_AMP_AMP] = ACTIONS(260),
    [anon_sym_PIPE_PIPE] = ACTIONS(260),
    [anon_sym_QMARK_QMARK] = ACTIONS(260),
    [anon_sym_QMARK_COLON] = ACTIONS(260),
    [anon_sym_BANG_EQ] = ACTIONS(260),
    [anon_sym_EQ_EQ] = ACTIONS(260),
    [anon_sym_QMARK_EQ] = ACTIONS(260),
    [anon_sym_STAR_EQ] = ACTIONS(260),
    [anon_sym_TILDE] = ACTIONS(260),
    [anon_sym_BANG_TILDE] = ACTIONS(260),
    [anon_sym_STAR_TILDE] = ACTIONS(260),
    [anon_sym_LT_EQ] = ACTIONS(260),
    [anon_sym_GT_EQ] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(262),
    [anon_sym_PLUS_EQ] = ACTIONS(260),
    [anon_sym_DASH_EQ] = ACTIONS(260),
    [anon_sym_u00d7] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(262),
    [anon_sym_u00f7] = ACTIONS(260),
    [anon_sym_STAR_STAR] = ACTIONS(260),
    [anon_sym_u220b] = ACTIONS(260),
    [anon_sym_u220c] = ACTIONS(260),
    [anon_sym_u2287] = ACTIONS(260),
    [anon_sym_u2283] = ACTIONS(260),
    [anon_sym_u2285] = ACTIONS(260),
    [anon_sym_u2208] = ACTIONS(260),
    [anon_sym_u2209] = ACTIONS(260),
    [anon_sym_u2286] = ACTIONS(260),
    [anon_sym_u2282] = ACTIONS(260),
    [anon_sym_u2284] = ACTIONS(260),
    [anon_sym_AT_AT] = ACTIONS(260),
  },
  [STATE(287)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_rand] = ACTIONS(288),
    [sym_keyword_collate] = ACTIONS(288),
    [sym_keyword_numeric] = ACTIONS(288),
    [sym_keyword_asc] = ACTIONS(288),
    [sym_keyword_desc] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(677),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(288)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(343),
    [sym_keyword_explain] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(343),
    [sym_keyword_timeout] = ACTIONS(343),
    [sym_keyword_fetch] = ACTIONS(343),
    [sym_keyword_limit] = ACTIONS(343),
    [sym_keyword_order] = ACTIONS(343),
    [sym_keyword_with] = ACTIONS(343),
    [sym_keyword_where] = ACTIONS(343),
    [sym_keyword_split] = ACTIONS(343),
    [sym_keyword_group] = ACTIONS(343),
    [sym_keyword_and] = ACTIONS(343),
    [sym_keyword_or] = ACTIONS(345),
    [sym_keyword_is] = ACTIONS(343),
    [sym_keyword_not] = ACTIONS(345),
    [sym_keyword_contains] = ACTIONS(345),
    [sym_keyword_contains_not] = ACTIONS(343),
    [sym_keyword_contains_all] = ACTIONS(343),
    [sym_keyword_contains_any] = ACTIONS(343),
    [sym_keyword_contains_none] = ACTIONS(343),
    [sym_keyword_inside] = ACTIONS(343),
    [sym_keyword_in] = ACTIONS(345),
    [sym_keyword_not_inside] = ACTIONS(343),
    [sym_keyword_all_inside] = ACTIONS(343),
    [sym_keyword_any_inside] = ACTIONS(343),
    [sym_keyword_none_inside] = ACTIONS(343),
    [sym_keyword_outside] = ACTIONS(343),
    [sym_keyword_intersects] = ACTIONS(343),
    [anon_sym_EQ] = ACTIONS(345),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_RPAREN] = ACTIONS(343),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(343),
    [anon_sym_RBRACE] = ACTIONS(343),
    [anon_sym_LT] = ACTIONS(345),
    [anon_sym_GT] = ACTIONS(345),
    [anon_sym_LT_DASH] = ACTIONS(345),
    [anon_sym_LT_DASH_GT] = ACTIONS(343),
    [anon_sym_STAR] = ACTIONS(345),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_PERCENT] = ACTIONS(343),
    [anon_sym_AT] = ACTIONS(345),
    [anon_sym_LT_PIPE] = ACTIONS(343),
    [anon_sym_AMP_AMP] = ACTIONS(343),
    [anon_sym_PIPE_PIPE] = ACTIONS(343),
    [anon_sym_QMARK_QMARK] = ACTIONS(343),
    [anon_sym_QMARK_COLON] = ACTIONS(343),
    [anon_sym_BANG_EQ] = ACTIONS(343),
    [anon_sym_EQ_EQ] = ACTIONS(343),
    [anon_sym_QMARK_EQ] = ACTIONS(343),
    [anon_sym_STAR_EQ] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(343),
    [anon_sym_BANG_TILDE] = ACTIONS(343),
    [anon_sym_STAR_TILDE] = ACTIONS(343),
    [anon_sym_LT_EQ] = ACTIONS(343),
    [anon_sym_GT_EQ] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_PLUS_EQ] = ACTIONS(343),
    [anon_sym_DASH_EQ] = ACTIONS(343),
    [anon_sym_u00d7] = ACTIONS(343),
    [anon_sym_SLASH] = ACTIONS(345),
    [anon_sym_u00f7] = ACTIONS(343),
    [anon_sym_STAR_STAR] = ACTIONS(343),
    [anon_sym_u220b] = ACTIONS(343),
    [anon_sym_u220c] = ACTIONS(343),
    [anon_sym_u2287] = ACTIONS(343),
    [anon_sym_u2283] = ACTIONS(343),
    [anon_sym_u2285] = ACTIONS(343),
    [anon_sym_u2208] = ACTIONS(343),
    [anon_sym_u2209] = ACTIONS(343),
    [anon_sym_u2286] = ACTIONS(343),
    [anon_sym_u2282] = ACTIONS(343),
    [anon_sym_u2284] = ACTIONS(343),
    [anon_sym_AT_AT] = ACTIONS(343),
  },
  [STATE(289)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_with] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(679),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(681),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(290)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(351),
    [sym_keyword_explain] = ACTIONS(351),
    [sym_keyword_parallel] = ACTIONS(351),
    [sym_keyword_timeout] = ACTIONS(351),
    [sym_keyword_fetch] = ACTIONS(351),
    [sym_keyword_limit] = ACTIONS(351),
    [sym_keyword_order] = ACTIONS(351),
    [sym_keyword_with] = ACTIONS(351),
    [sym_keyword_where] = ACTIONS(351),
    [sym_keyword_split] = ACTIONS(351),
    [sym_keyword_group] = ACTIONS(351),
    [sym_keyword_and] = ACTIONS(351),
    [sym_keyword_or] = ACTIONS(353),
    [sym_keyword_is] = ACTIONS(351),
    [sym_keyword_not] = ACTIONS(353),
    [sym_keyword_contains] = ACTIONS(353),
    [sym_keyword_contains_not] = ACTIONS(351),
    [sym_keyword_contains_all] = ACTIONS(351),
    [sym_keyword_contains_any] = ACTIONS(351),
    [sym_keyword_contains_none] = ACTIONS(351),
    [sym_keyword_inside] = ACTIONS(351),
    [sym_keyword_in] = ACTIONS(353),
    [sym_keyword_not_inside] = ACTIONS(351),
    [sym_keyword_all_inside] = ACTIONS(351),
    [sym_keyword_any_inside] = ACTIONS(351),
    [sym_keyword_none_inside] = ACTIONS(351),
    [sym_keyword_outside] = ACTIONS(351),
    [sym_keyword_intersects] = ACTIONS(351),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_COMMA] = ACTIONS(351),
    [anon_sym_RPAREN] = ACTIONS(351),
    [anon_sym_DASH_GT] = ACTIONS(351),
    [anon_sym_LBRACK] = ACTIONS(351),
    [anon_sym_RBRACE] = ACTIONS(351),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH_GT] = ACTIONS(351),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [anon_sym_LT_PIPE] = ACTIONS(351),
    [anon_sym_AMP_AMP] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(351),
    [anon_sym_QMARK_QMARK] = ACTIONS(351),
    [anon_sym_QMARK_COLON] = ACTIONS(351),
    [anon_sym_BANG_EQ] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(351),
    [anon_sym_QMARK_EQ] = ACTIONS(351),
    [anon_sym_STAR_EQ] = ACTIONS(351),
    [anon_sym_TILDE] = ACTIONS(351),
    [anon_sym_BANG_TILDE] = ACTIONS(351),
    [anon_sym_STAR_TILDE] = ACTIONS(351),
    [anon_sym_LT_EQ] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(353),
    [anon_sym_PLUS_EQ] = ACTIONS(351),
    [anon_sym_DASH_EQ] = ACTIONS(351),
    [anon_sym_u00d7] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(353),
    [anon_sym_u00f7] = ACTIONS(351),
    [anon_sym_STAR_STAR] = ACTIONS(351),
    [anon_sym_u220b] = ACTIONS(351),
    [anon_sym_u220c] = ACTIONS(351),
    [anon_sym_u2287] = ACTIONS(351),
    [anon_sym_u2283] = ACTIONS(351),
    [anon_sym_u2285] = ACTIONS(351),
    [anon_sym_u2208] = ACTIONS(351),
    [anon_sym_u2209] = ACTIONS(351),
    [anon_sym_u2286] = ACTIONS(351),
    [anon_sym_u2282] = ACTIONS(351),
    [anon_sym_u2284] = ACTIONS(351),
    [anon_sym_AT_AT] = ACTIONS(351),
  },
  [STATE(291)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_order] = ACTIONS(355),
    [sym_keyword_with] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_split] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(357),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_RPAREN] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(292)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_order] = ACTIONS(355),
    [sym_keyword_with] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_split] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(357),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_RPAREN] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_RBRACE] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(293)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(300),
    [sym_keyword_explain] = ACTIONS(300),
    [sym_keyword_parallel] = ACTIONS(300),
    [sym_keyword_timeout] = ACTIONS(300),
    [sym_keyword_fetch] = ACTIONS(300),
    [sym_keyword_limit] = ACTIONS(300),
    [sym_keyword_order] = ACTIONS(300),
    [sym_keyword_with] = ACTIONS(300),
    [sym_keyword_where] = ACTIONS(300),
    [sym_keyword_split] = ACTIONS(300),
    [sym_keyword_group] = ACTIONS(300),
    [sym_keyword_and] = ACTIONS(300),
    [sym_keyword_or] = ACTIONS(302),
    [sym_keyword_is] = ACTIONS(300),
    [sym_keyword_not] = ACTIONS(302),
    [sym_keyword_contains] = ACTIONS(302),
    [sym_keyword_contains_not] = ACTIONS(300),
    [sym_keyword_contains_all] = ACTIONS(300),
    [sym_keyword_contains_any] = ACTIONS(300),
    [sym_keyword_contains_none] = ACTIONS(300),
    [sym_keyword_inside] = ACTIONS(300),
    [sym_keyword_in] = ACTIONS(302),
    [sym_keyword_not_inside] = ACTIONS(300),
    [sym_keyword_all_inside] = ACTIONS(300),
    [sym_keyword_any_inside] = ACTIONS(300),
    [sym_keyword_none_inside] = ACTIONS(300),
    [sym_keyword_outside] = ACTIONS(300),
    [sym_keyword_intersects] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(300),
    [anon_sym_RPAREN] = ACTIONS(300),
    [anon_sym_DASH_GT] = ACTIONS(300),
    [anon_sym_LBRACK] = ACTIONS(300),
    [anon_sym_RBRACE] = ACTIONS(300),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_LT_DASH] = ACTIONS(302),
    [anon_sym_LT_DASH_GT] = ACTIONS(300),
    [anon_sym_STAR] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(300),
    [anon_sym_DASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(300),
    [anon_sym_AT] = ACTIONS(302),
    [anon_sym_LT_PIPE] = ACTIONS(300),
    [anon_sym_AMP_AMP] = ACTIONS(300),
    [anon_sym_PIPE_PIPE] = ACTIONS(300),
    [anon_sym_QMARK_QMARK] = ACTIONS(300),
    [anon_sym_QMARK_COLON] = ACTIONS(300),
    [anon_sym_BANG_EQ] = ACTIONS(300),
    [anon_sym_EQ_EQ] = ACTIONS(300),
    [anon_sym_QMARK_EQ] = ACTIONS(300),
    [anon_sym_STAR_EQ] = ACTIONS(300),
    [anon_sym_TILDE] = ACTIONS(300),
    [anon_sym_BANG_TILDE] = ACTIONS(300),
    [anon_sym_STAR_TILDE] = ACTIONS(300),
    [anon_sym_LT_EQ] = ACTIONS(300),
    [anon_sym_GT_EQ] = ACTIONS(300),
    [anon_sym_PLUS] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(300),
    [anon_sym_DASH_EQ] = ACTIONS(300),
    [anon_sym_u00d7] = ACTIONS(300),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_u00f7] = ACTIONS(300),
    [anon_sym_STAR_STAR] = ACTIONS(300),
    [anon_sym_u220b] = ACTIONS(300),
    [anon_sym_u220c] = ACTIONS(300),
    [anon_sym_u2287] = ACTIONS(300),
    [anon_sym_u2283] = ACTIONS(300),
    [anon_sym_u2285] = ACTIONS(300),
    [anon_sym_u2208] = ACTIONS(300),
    [anon_sym_u2209] = ACTIONS(300),
    [anon_sym_u2286] = ACTIONS(300),
    [anon_sym_u2282] = ACTIONS(300),
    [anon_sym_u2284] = ACTIONS(300),
    [anon_sym_AT_AT] = ACTIONS(300),
  },
  [STATE(294)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(314),
    [sym_keyword_order] = ACTIONS(314),
    [sym_keyword_with] = ACTIONS(314),
    [sym_keyword_where] = ACTIONS(314),
    [sym_keyword_split] = ACTIONS(314),
    [sym_keyword_group] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(314),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(314),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(314),
    [sym_keyword_contains_all] = ACTIONS(314),
    [sym_keyword_contains_any] = ACTIONS(314),
    [sym_keyword_contains_none] = ACTIONS(314),
    [sym_keyword_inside] = ACTIONS(314),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(314),
    [sym_keyword_all_inside] = ACTIONS(314),
    [sym_keyword_any_inside] = ACTIONS(314),
    [sym_keyword_none_inside] = ACTIONS(314),
    [sym_keyword_outside] = ACTIONS(314),
    [sym_keyword_intersects] = ACTIONS(314),
    [anon_sym_EQ] = ACTIONS(316),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(314),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(295)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(318),
    [sym_keyword_explain] = ACTIONS(318),
    [sym_keyword_parallel] = ACTIONS(318),
    [sym_keyword_timeout] = ACTIONS(318),
    [sym_keyword_fetch] = ACTIONS(318),
    [sym_keyword_limit] = ACTIONS(318),
    [sym_keyword_order] = ACTIONS(318),
    [sym_keyword_with] = ACTIONS(318),
    [sym_keyword_where] = ACTIONS(318),
    [sym_keyword_split] = ACTIONS(318),
    [sym_keyword_group] = ACTIONS(318),
    [sym_keyword_and] = ACTIONS(318),
    [sym_keyword_or] = ACTIONS(320),
    [sym_keyword_is] = ACTIONS(318),
    [sym_keyword_not] = ACTIONS(320),
    [sym_keyword_contains] = ACTIONS(320),
    [sym_keyword_contains_not] = ACTIONS(318),
    [sym_keyword_contains_all] = ACTIONS(318),
    [sym_keyword_contains_any] = ACTIONS(318),
    [sym_keyword_contains_none] = ACTIONS(318),
    [sym_keyword_inside] = ACTIONS(318),
    [sym_keyword_in] = ACTIONS(320),
    [sym_keyword_not_inside] = ACTIONS(318),
    [sym_keyword_all_inside] = ACTIONS(318),
    [sym_keyword_any_inside] = ACTIONS(318),
    [sym_keyword_none_inside] = ACTIONS(318),
    [sym_keyword_outside] = ACTIONS(318),
    [sym_keyword_intersects] = ACTIONS(318),
    [anon_sym_EQ] = ACTIONS(320),
    [anon_sym_COMMA] = ACTIONS(318),
    [anon_sym_RPAREN] = ACTIONS(318),
    [anon_sym_DASH_GT] = ACTIONS(318),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_RBRACE] = ACTIONS(318),
    [anon_sym_LT] = ACTIONS(320),
    [anon_sym_GT] = ACTIONS(320),
    [anon_sym_LT_DASH] = ACTIONS(320),
    [anon_sym_LT_DASH_GT] = ACTIONS(318),
    [anon_sym_STAR] = ACTIONS(320),
    [anon_sym_DOT] = ACTIONS(318),
    [anon_sym_DASH] = ACTIONS(320),
    [anon_sym_PERCENT] = ACTIONS(318),
    [anon_sym_AT] = ACTIONS(320),
    [anon_sym_LT_PIPE] = ACTIONS(318),
    [anon_sym_AMP_AMP] = ACTIONS(318),
    [anon_sym_PIPE_PIPE] = ACTIONS(318),
    [anon_sym_QMARK_QMARK] = ACTIONS(318),
    [anon_sym_QMARK_COLON] = ACTIONS(318),
    [anon_sym_BANG_EQ] = ACTIONS(318),
    [anon_sym_EQ_EQ] = ACTIONS(318),
    [anon_sym_QMARK_EQ] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(318),
    [anon_sym_TILDE] = ACTIONS(318),
    [anon_sym_BANG_TILDE] = ACTIONS(318),
    [anon_sym_STAR_TILDE] = ACTIONS(318),
    [anon_sym_LT_EQ] = ACTIONS(318),
    [anon_sym_GT_EQ] = ACTIONS(318),
    [anon_sym_PLUS] = ACTIONS(320),
    [anon_sym_PLUS_EQ] = ACTIONS(318),
    [anon_sym_DASH_EQ] = ACTIONS(318),
    [anon_sym_u00d7] = ACTIONS(318),
    [anon_sym_SLASH] = ACTIONS(320),
    [anon_sym_u00f7] = ACTIONS(318),
    [anon_sym_STAR_STAR] = ACTIONS(318),
    [anon_sym_u220b] = ACTIONS(318),
    [anon_sym_u220c] = ACTIONS(318),
    [anon_sym_u2287] = ACTIONS(318),
    [anon_sym_u2283] = ACTIONS(318),
    [anon_sym_u2285] = ACTIONS(318),
    [anon_sym_u2208] = ACTIONS(318),
    [anon_sym_u2209] = ACTIONS(318),
    [anon_sym_u2286] = ACTIONS(318),
    [anon_sym_u2282] = ACTIONS(318),
    [anon_sym_u2284] = ACTIONS(318),
    [anon_sym_AT_AT] = ACTIONS(318),
  },
  [STATE(296)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(322),
    [sym_keyword_explain] = ACTIONS(322),
    [sym_keyword_parallel] = ACTIONS(322),
    [sym_keyword_timeout] = ACTIONS(322),
    [sym_keyword_fetch] = ACTIONS(322),
    [sym_keyword_limit] = ACTIONS(322),
    [sym_keyword_order] = ACTIONS(322),
    [sym_keyword_with] = ACTIONS(322),
    [sym_keyword_where] = ACTIONS(322),
    [sym_keyword_split] = ACTIONS(322),
    [sym_keyword_group] = ACTIONS(322),
    [sym_keyword_and] = ACTIONS(322),
    [sym_keyword_or] = ACTIONS(324),
    [sym_keyword_is] = ACTIONS(322),
    [sym_keyword_not] = ACTIONS(324),
    [sym_keyword_contains] = ACTIONS(324),
    [sym_keyword_contains_not] = ACTIONS(322),
    [sym_keyword_contains_all] = ACTIONS(322),
    [sym_keyword_contains_any] = ACTIONS(322),
    [sym_keyword_contains_none] = ACTIONS(322),
    [sym_keyword_inside] = ACTIONS(322),
    [sym_keyword_in] = ACTIONS(324),
    [sym_keyword_not_inside] = ACTIONS(322),
    [sym_keyword_all_inside] = ACTIONS(322),
    [sym_keyword_any_inside] = ACTIONS(322),
    [sym_keyword_none_inside] = ACTIONS(322),
    [sym_keyword_outside] = ACTIONS(322),
    [sym_keyword_intersects] = ACTIONS(322),
    [anon_sym_EQ] = ACTIONS(324),
    [anon_sym_COMMA] = ACTIONS(322),
    [anon_sym_RPAREN] = ACTIONS(322),
    [anon_sym_DASH_GT] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(322),
    [anon_sym_RBRACE] = ACTIONS(322),
    [anon_sym_LT] = ACTIONS(324),
    [anon_sym_GT] = ACTIONS(324),
    [anon_sym_LT_DASH] = ACTIONS(324),
    [anon_sym_LT_DASH_GT] = ACTIONS(322),
    [anon_sym_STAR] = ACTIONS(324),
    [anon_sym_DOT] = ACTIONS(322),
    [anon_sym_DASH] = ACTIONS(324),
    [anon_sym_PERCENT] = ACTIONS(322),
    [anon_sym_AT] = ACTIONS(324),
    [anon_sym_LT_PIPE] = ACTIONS(322),
    [anon_sym_AMP_AMP] = ACTIONS(322),
    [anon_sym_PIPE_PIPE] = ACTIONS(322),
    [anon_sym_QMARK_QMARK] = ACTIONS(322),
    [anon_sym_QMARK_COLON] = ACTIONS(322),
    [anon_sym_BANG_EQ] = ACTIONS(322),
    [anon_sym_EQ_EQ] = ACTIONS(322),
    [anon_sym_QMARK_EQ] = ACTIONS(322),
    [anon_sym_STAR_EQ] = ACTIONS(322),
    [anon_sym_TILDE] = ACTIONS(322),
    [anon_sym_BANG_TILDE] = ACTIONS(322),
    [anon_sym_STAR_TILDE] = ACTIONS(322),
    [anon_sym_LT_EQ] = ACTIONS(322),
    [anon_sym_GT_EQ] = ACTIONS(322),
    [anon_sym_PLUS] = ACTIONS(324),
    [anon_sym_PLUS_EQ] = ACTIONS(322),
    [anon_sym_DASH_EQ] = ACTIONS(322),
    [anon_sym_u00d7] = ACTIONS(322),
    [anon_sym_SLASH] = ACTIONS(324),
    [anon_sym_u00f7] = ACTIONS(322),
    [anon_sym_STAR_STAR] = ACTIONS(322),
    [anon_sym_u220b] = ACTIONS(322),
    [anon_sym_u220c] = ACTIONS(322),
    [anon_sym_u2287] = ACTIONS(322),
    [anon_sym_u2283] = ACTIONS(322),
    [anon_sym_u2285] = ACTIONS(322),
    [anon_sym_u2208] = ACTIONS(322),
    [anon_sym_u2209] = ACTIONS(322),
    [anon_sym_u2286] = ACTIONS(322),
    [anon_sym_u2282] = ACTIONS(322),
    [anon_sym_u2284] = ACTIONS(322),
    [anon_sym_AT_AT] = ACTIONS(322),
  },
  [STATE(297)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(298)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(299)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(365),
    [sym_keyword_explain] = ACTIONS(365),
    [sym_keyword_parallel] = ACTIONS(365),
    [sym_keyword_timeout] = ACTIONS(365),
    [sym_keyword_fetch] = ACTIONS(365),
    [sym_keyword_limit] = ACTIONS(365),
    [sym_keyword_order] = ACTIONS(365),
    [sym_keyword_with] = ACTIONS(365),
    [sym_keyword_where] = ACTIONS(365),
    [sym_keyword_split] = ACTIONS(365),
    [sym_keyword_group] = ACTIONS(365),
    [sym_keyword_and] = ACTIONS(365),
    [sym_keyword_or] = ACTIONS(367),
    [sym_keyword_is] = ACTIONS(365),
    [sym_keyword_not] = ACTIONS(367),
    [sym_keyword_contains] = ACTIONS(367),
    [sym_keyword_contains_not] = ACTIONS(365),
    [sym_keyword_contains_all] = ACTIONS(365),
    [sym_keyword_contains_any] = ACTIONS(365),
    [sym_keyword_contains_none] = ACTIONS(365),
    [sym_keyword_inside] = ACTIONS(365),
    [sym_keyword_in] = ACTIONS(367),
    [sym_keyword_not_inside] = ACTIONS(365),
    [sym_keyword_all_inside] = ACTIONS(365),
    [sym_keyword_any_inside] = ACTIONS(365),
    [sym_keyword_none_inside] = ACTIONS(365),
    [sym_keyword_outside] = ACTIONS(365),
    [sym_keyword_intersects] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(367),
    [anon_sym_COMMA] = ACTIONS(365),
    [anon_sym_RPAREN] = ACTIONS(365),
    [anon_sym_DASH_GT] = ACTIONS(365),
    [anon_sym_LBRACK] = ACTIONS(365),
    [anon_sym_RBRACE] = ACTIONS(365),
    [anon_sym_LT] = ACTIONS(367),
    [anon_sym_GT] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(367),
    [anon_sym_LT_DASH_GT] = ACTIONS(365),
    [anon_sym_STAR] = ACTIONS(367),
    [anon_sym_DOT] = ACTIONS(365),
    [anon_sym_DASH] = ACTIONS(367),
    [anon_sym_PERCENT] = ACTIONS(365),
    [anon_sym_AT] = ACTIONS(367),
    [anon_sym_LT_PIPE] = ACTIONS(365),
    [anon_sym_AMP_AMP] = ACTIONS(365),
    [anon_sym_PIPE_PIPE] = ACTIONS(365),
    [anon_sym_QMARK_QMARK] = ACTIONS(365),
    [anon_sym_QMARK_COLON] = ACTIONS(365),
    [anon_sym_BANG_EQ] = ACTIONS(365),
    [anon_sym_EQ_EQ] = ACTIONS(365),
    [anon_sym_QMARK_EQ] = ACTIONS(365),
    [anon_sym_STAR_EQ] = ACTIONS(365),
    [anon_sym_TILDE] = ACTIONS(365),
    [anon_sym_BANG_TILDE] = ACTIONS(365),
    [anon_sym_STAR_TILDE] = ACTIONS(365),
    [anon_sym_LT_EQ] = ACTIONS(365),
    [anon_sym_GT_EQ] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(367),
    [anon_sym_PLUS_EQ] = ACTIONS(365),
    [anon_sym_DASH_EQ] = ACTIONS(365),
    [anon_sym_u00d7] = ACTIONS(365),
    [anon_sym_SLASH] = ACTIONS(367),
    [anon_sym_u00f7] = ACTIONS(365),
    [anon_sym_STAR_STAR] = ACTIONS(365),
    [anon_sym_u220b] = ACTIONS(365),
    [anon_sym_u220c] = ACTIONS(365),
    [anon_sym_u2287] = ACTIONS(365),
    [anon_sym_u2283] = ACTIONS(365),
    [anon_sym_u2285] = ACTIONS(365),
    [anon_sym_u2208] = ACTIONS(365),
    [anon_sym_u2209] = ACTIONS(365),
    [anon_sym_u2286] = ACTIONS(365),
    [anon_sym_u2282] = ACTIONS(365),
    [anon_sym_u2284] = ACTIONS(365),
    [anon_sym_AT_AT] = ACTIONS(365),
  },
  [STATE(300)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(369),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_with] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(371),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(371),
    [sym_keyword_contains] = ACTIONS(371),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(371),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_RPAREN] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(369),
    [anon_sym_RBRACE] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(371),
    [anon_sym_LT_DASH_GT] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(371),
    [anon_sym_DOT] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(371),
    [anon_sym_LT_PIPE] = ACTIONS(369),
    [anon_sym_AMP_AMP] = ACTIONS(369),
    [anon_sym_PIPE_PIPE] = ACTIONS(369),
    [anon_sym_QMARK_QMARK] = ACTIONS(369),
    [anon_sym_QMARK_COLON] = ACTIONS(369),
    [anon_sym_BANG_EQ] = ACTIONS(369),
    [anon_sym_EQ_EQ] = ACTIONS(369),
    [anon_sym_QMARK_EQ] = ACTIONS(369),
    [anon_sym_STAR_EQ] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_BANG_TILDE] = ACTIONS(369),
    [anon_sym_STAR_TILDE] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(371),
    [anon_sym_PLUS_EQ] = ACTIONS(369),
    [anon_sym_DASH_EQ] = ACTIONS(369),
    [anon_sym_u00d7] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_u00f7] = ACTIONS(369),
    [anon_sym_STAR_STAR] = ACTIONS(369),
    [anon_sym_u220b] = ACTIONS(369),
    [anon_sym_u220c] = ACTIONS(369),
    [anon_sym_u2287] = ACTIONS(369),
    [anon_sym_u2283] = ACTIONS(369),
    [anon_sym_u2285] = ACTIONS(369),
    [anon_sym_u2208] = ACTIONS(369),
    [anon_sym_u2209] = ACTIONS(369),
    [anon_sym_u2286] = ACTIONS(369),
    [anon_sym_u2282] = ACTIONS(369),
    [anon_sym_u2284] = ACTIONS(369),
    [anon_sym_AT_AT] = ACTIONS(369),
  },
  [STATE(301)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_order] = ACTIONS(264),
    [sym_keyword_with] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_split] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(266),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(266),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(302)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_order] = ACTIONS(264),
    [sym_keyword_with] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_split] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(266),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(683),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_RPAREN] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_RBRACE] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(303)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(337),
    [sym_keyword_explain] = ACTIONS(337),
    [sym_keyword_parallel] = ACTIONS(337),
    [sym_keyword_timeout] = ACTIONS(337),
    [sym_keyword_fetch] = ACTIONS(337),
    [sym_keyword_limit] = ACTIONS(337),
    [sym_keyword_order] = ACTIONS(337),
    [sym_keyword_with] = ACTIONS(337),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_split] = ACTIONS(337),
    [sym_keyword_group] = ACTIONS(337),
    [sym_keyword_and] = ACTIONS(337),
    [sym_keyword_or] = ACTIONS(339),
    [sym_keyword_is] = ACTIONS(337),
    [sym_keyword_not] = ACTIONS(339),
    [sym_keyword_contains] = ACTIONS(339),
    [sym_keyword_contains_not] = ACTIONS(337),
    [sym_keyword_contains_all] = ACTIONS(337),
    [sym_keyword_contains_any] = ACTIONS(337),
    [sym_keyword_contains_none] = ACTIONS(337),
    [sym_keyword_inside] = ACTIONS(337),
    [sym_keyword_in] = ACTIONS(339),
    [sym_keyword_not_inside] = ACTIONS(337),
    [sym_keyword_all_inside] = ACTIONS(337),
    [sym_keyword_any_inside] = ACTIONS(337),
    [sym_keyword_none_inside] = ACTIONS(337),
    [sym_keyword_outside] = ACTIONS(337),
    [sym_keyword_intersects] = ACTIONS(337),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_COMMA] = ACTIONS(337),
    [anon_sym_RPAREN] = ACTIONS(337),
    [anon_sym_DASH_GT] = ACTIONS(337),
    [anon_sym_LBRACK] = ACTIONS(337),
    [anon_sym_RBRACE] = ACTIONS(337),
    [anon_sym_LT] = ACTIONS(339),
    [anon_sym_GT] = ACTIONS(339),
    [anon_sym_LT_DASH] = ACTIONS(339),
    [anon_sym_LT_DASH_GT] = ACTIONS(337),
    [anon_sym_STAR] = ACTIONS(339),
    [anon_sym_DOT] = ACTIONS(337),
    [anon_sym_DASH] = ACTIONS(339),
    [anon_sym_PERCENT] = ACTIONS(337),
    [anon_sym_AT] = ACTIONS(339),
    [anon_sym_LT_PIPE] = ACTIONS(337),
    [anon_sym_AMP_AMP] = ACTIONS(337),
    [anon_sym_PIPE_PIPE] = ACTIONS(337),
    [anon_sym_QMARK_QMARK] = ACTIONS(337),
    [anon_sym_QMARK_COLON] = ACTIONS(337),
    [anon_sym_BANG_EQ] = ACTIONS(337),
    [anon_sym_EQ_EQ] = ACTIONS(337),
    [anon_sym_QMARK_EQ] = ACTIONS(337),
    [anon_sym_STAR_EQ] = ACTIONS(337),
    [anon_sym_TILDE] = ACTIONS(337),
    [anon_sym_BANG_TILDE] = ACTIONS(337),
    [anon_sym_STAR_TILDE] = ACTIONS(337),
    [anon_sym_LT_EQ] = ACTIONS(337),
    [anon_sym_GT_EQ] = ACTIONS(337),
    [anon_sym_PLUS] = ACTIONS(339),
    [anon_sym_PLUS_EQ] = ACTIONS(337),
    [anon_sym_DASH_EQ] = ACTIONS(337),
    [anon_sym_u00d7] = ACTIONS(337),
    [anon_sym_SLASH] = ACTIONS(339),
    [anon_sym_u00f7] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(337),
    [anon_sym_u220b] = ACTIONS(337),
    [anon_sym_u220c] = ACTIONS(337),
    [anon_sym_u2287] = ACTIONS(337),
    [anon_sym_u2283] = ACTIONS(337),
    [anon_sym_u2285] = ACTIONS(337),
    [anon_sym_u2208] = ACTIONS(337),
    [anon_sym_u2209] = ACTIONS(337),
    [anon_sym_u2286] = ACTIONS(337),
    [anon_sym_u2282] = ACTIONS(337),
    [anon_sym_u2284] = ACTIONS(337),
    [anon_sym_AT_AT] = ACTIONS(337),
  },
  [STATE(304)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(270),
    [sym_keyword_explain] = ACTIONS(270),
    [sym_keyword_parallel] = ACTIONS(270),
    [sym_keyword_timeout] = ACTIONS(270),
    [sym_keyword_fetch] = ACTIONS(270),
    [sym_keyword_limit] = ACTIONS(270),
    [sym_keyword_order] = ACTIONS(270),
    [sym_keyword_with] = ACTIONS(270),
    [sym_keyword_where] = ACTIONS(270),
    [sym_keyword_split] = ACTIONS(270),
    [sym_keyword_group] = ACTIONS(270),
    [sym_keyword_and] = ACTIONS(270),
    [sym_keyword_or] = ACTIONS(272),
    [sym_keyword_is] = ACTIONS(270),
    [sym_keyword_not] = ACTIONS(272),
    [sym_keyword_contains] = ACTIONS(272),
    [sym_keyword_contains_not] = ACTIONS(270),
    [sym_keyword_contains_all] = ACTIONS(270),
    [sym_keyword_contains_any] = ACTIONS(270),
    [sym_keyword_contains_none] = ACTIONS(270),
    [sym_keyword_inside] = ACTIONS(270),
    [sym_keyword_in] = ACTIONS(272),
    [sym_keyword_not_inside] = ACTIONS(270),
    [sym_keyword_all_inside] = ACTIONS(270),
    [sym_keyword_any_inside] = ACTIONS(270),
    [sym_keyword_none_inside] = ACTIONS(270),
    [sym_keyword_outside] = ACTIONS(270),
    [sym_keyword_intersects] = ACTIONS(270),
    [anon_sym_EQ] = ACTIONS(272),
    [anon_sym_COMMA] = ACTIONS(270),
    [anon_sym_RPAREN] = ACTIONS(270),
    [anon_sym_DASH_GT] = ACTIONS(270),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_RBRACE] = ACTIONS(270),
    [anon_sym_LT] = ACTIONS(272),
    [anon_sym_GT] = ACTIONS(272),
    [anon_sym_LT_DASH] = ACTIONS(272),
    [anon_sym_LT_DASH_GT] = ACTIONS(270),
    [anon_sym_STAR] = ACTIONS(272),
    [anon_sym_DOT] = ACTIONS(270),
    [anon_sym_DASH] = ACTIONS(272),
    [anon_sym_PERCENT] = ACTIONS(270),
    [anon_sym_AT] = ACTIONS(272),
    [anon_sym_LT_PIPE] = ACTIONS(270),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_PIPE_PIPE] = ACTIONS(270),
    [anon_sym_QMARK_QMARK] = ACTIONS(270),
    [anon_sym_QMARK_COLON] = ACTIONS(270),
    [anon_sym_BANG_EQ] = ACTIONS(270),
    [anon_sym_EQ_EQ] = ACTIONS(270),
    [anon_sym_QMARK_EQ] = ACTIONS(270),
    [anon_sym_STAR_EQ] = ACTIONS(270),
    [anon_sym_TILDE] = ACTIONS(270),
    [anon_sym_BANG_TILDE] = ACTIONS(270),
    [anon_sym_STAR_TILDE] = ACTIONS(270),
    [anon_sym_LT_EQ] = ACTIONS(270),
    [anon_sym_GT_EQ] = ACTIONS(270),
    [anon_sym_PLUS] = ACTIONS(272),
    [anon_sym_PLUS_EQ] = ACTIONS(270),
    [anon_sym_DASH_EQ] = ACTIONS(270),
    [anon_sym_u00d7] = ACTIONS(270),
    [anon_sym_SLASH] = ACTIONS(272),
    [anon_sym_u00f7] = ACTIONS(270),
    [anon_sym_STAR_STAR] = ACTIONS(270),
    [anon_sym_u220b] = ACTIONS(270),
    [anon_sym_u220c] = ACTIONS(270),
    [anon_sym_u2287] = ACTIONS(270),
    [anon_sym_u2283] = ACTIONS(270),
    [anon_sym_u2285] = ACTIONS(270),
    [anon_sym_u2208] = ACTIONS(270),
    [anon_sym_u2209] = ACTIONS(270),
    [anon_sym_u2286] = ACTIONS(270),
    [anon_sym_u2282] = ACTIONS(270),
    [anon_sym_u2284] = ACTIONS(270),
    [anon_sym_AT_AT] = ACTIONS(270),
  },
  [STATE(305)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(274),
    [sym_keyword_explain] = ACTIONS(274),
    [sym_keyword_parallel] = ACTIONS(274),
    [sym_keyword_timeout] = ACTIONS(274),
    [sym_keyword_fetch] = ACTIONS(274),
    [sym_keyword_limit] = ACTIONS(274),
    [sym_keyword_order] = ACTIONS(274),
    [sym_keyword_with] = ACTIONS(274),
    [sym_keyword_where] = ACTIONS(274),
    [sym_keyword_split] = ACTIONS(274),
    [sym_keyword_group] = ACTIONS(274),
    [sym_keyword_and] = ACTIONS(274),
    [sym_keyword_or] = ACTIONS(276),
    [sym_keyword_is] = ACTIONS(274),
    [sym_keyword_not] = ACTIONS(276),
    [sym_keyword_contains] = ACTIONS(276),
    [sym_keyword_contains_not] = ACTIONS(274),
    [sym_keyword_contains_all] = ACTIONS(274),
    [sym_keyword_contains_any] = ACTIONS(274),
    [sym_keyword_contains_none] = ACTIONS(274),
    [sym_keyword_inside] = ACTIONS(274),
    [sym_keyword_in] = ACTIONS(276),
    [sym_keyword_not_inside] = ACTIONS(274),
    [sym_keyword_all_inside] = ACTIONS(274),
    [sym_keyword_any_inside] = ACTIONS(274),
    [sym_keyword_none_inside] = ACTIONS(274),
    [sym_keyword_outside] = ACTIONS(274),
    [sym_keyword_intersects] = ACTIONS(274),
    [anon_sym_EQ] = ACTIONS(276),
    [anon_sym_COMMA] = ACTIONS(274),
    [anon_sym_RPAREN] = ACTIONS(274),
    [anon_sym_DASH_GT] = ACTIONS(274),
    [anon_sym_LBRACK] = ACTIONS(274),
    [anon_sym_RBRACE] = ACTIONS(274),
    [anon_sym_LT] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(276),
    [anon_sym_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_DASH_GT] = ACTIONS(274),
    [anon_sym_STAR] = ACTIONS(276),
    [anon_sym_DOT] = ACTIONS(274),
    [anon_sym_DASH] = ACTIONS(276),
    [anon_sym_PERCENT] = ACTIONS(274),
    [anon_sym_AT] = ACTIONS(276),
    [anon_sym_LT_PIPE] = ACTIONS(274),
    [anon_sym_AMP_AMP] = ACTIONS(274),
    [anon_sym_PIPE_PIPE] = ACTIONS(274),
    [anon_sym_QMARK_QMARK] = ACTIONS(274),
    [anon_sym_QMARK_COLON] = ACTIONS(274),
    [anon_sym_BANG_EQ] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(274),
    [anon_sym_QMARK_EQ] = ACTIONS(274),
    [anon_sym_STAR_EQ] = ACTIONS(274),
    [anon_sym_TILDE] = ACTIONS(274),
    [anon_sym_BANG_TILDE] = ACTIONS(274),
    [anon_sym_STAR_TILDE] = ACTIONS(274),
    [anon_sym_LT_EQ] = ACTIONS(274),
    [anon_sym_GT_EQ] = ACTIONS(274),
    [anon_sym_PLUS] = ACTIONS(276),
    [anon_sym_PLUS_EQ] = ACTIONS(274),
    [anon_sym_DASH_EQ] = ACTIONS(274),
    [anon_sym_u00d7] = ACTIONS(274),
    [anon_sym_SLASH] = ACTIONS(276),
    [anon_sym_u00f7] = ACTIONS(274),
    [anon_sym_STAR_STAR] = ACTIONS(274),
    [anon_sym_u220b] = ACTIONS(274),
    [anon_sym_u220c] = ACTIONS(274),
    [anon_sym_u2287] = ACTIONS(274),
    [anon_sym_u2283] = ACTIONS(274),
    [anon_sym_u2285] = ACTIONS(274),
    [anon_sym_u2208] = ACTIONS(274),
    [anon_sym_u2209] = ACTIONS(274),
    [anon_sym_u2286] = ACTIONS(274),
    [anon_sym_u2282] = ACTIONS(274),
    [anon_sym_u2284] = ACTIONS(274),
    [anon_sym_AT_AT] = ACTIONS(274),
  },
  [STATE(306)] = {
    [ts_builtin_sym_end] = ACTIONS(248),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(248),
    [sym_keyword_explain] = ACTIONS(248),
    [sym_keyword_parallel] = ACTIONS(248),
    [sym_keyword_timeout] = ACTIONS(248),
    [sym_keyword_fetch] = ACTIONS(248),
    [sym_keyword_limit] = ACTIONS(248),
    [sym_keyword_order] = ACTIONS(248),
    [sym_keyword_with] = ACTIONS(248),
    [sym_keyword_where] = ACTIONS(248),
    [sym_keyword_split] = ACTIONS(248),
    [sym_keyword_group] = ACTIONS(248),
    [sym_keyword_and] = ACTIONS(248),
    [sym_keyword_or] = ACTIONS(250),
    [sym_keyword_is] = ACTIONS(248),
    [sym_keyword_not] = ACTIONS(250),
    [sym_keyword_contains] = ACTIONS(250),
    [sym_keyword_contains_not] = ACTIONS(248),
    [sym_keyword_contains_all] = ACTIONS(248),
    [sym_keyword_contains_any] = ACTIONS(248),
    [sym_keyword_contains_none] = ACTIONS(248),
    [sym_keyword_inside] = ACTIONS(248),
    [sym_keyword_in] = ACTIONS(250),
    [sym_keyword_not_inside] = ACTIONS(248),
    [sym_keyword_all_inside] = ACTIONS(248),
    [sym_keyword_any_inside] = ACTIONS(248),
    [sym_keyword_none_inside] = ACTIONS(248),
    [sym_keyword_outside] = ACTIONS(248),
    [sym_keyword_intersects] = ACTIONS(248),
    [anon_sym_EQ] = ACTIONS(250),
    [anon_sym_COMMA] = ACTIONS(248),
    [anon_sym_DASH_GT] = ACTIONS(248),
    [anon_sym_LBRACK] = ACTIONS(248),
    [anon_sym_LT] = ACTIONS(250),
    [anon_sym_GT] = ACTIONS(250),
    [anon_sym_LT_DASH] = ACTIONS(250),
    [anon_sym_LT_DASH_GT] = ACTIONS(248),
    [anon_sym_STAR] = ACTIONS(250),
    [anon_sym_DOT] = ACTIONS(250),
    [anon_sym_DOT_DOT] = ACTIONS(248),
    [anon_sym_DASH] = ACTIONS(250),
    [anon_sym_PERCENT] = ACTIONS(248),
    [anon_sym_AT] = ACTIONS(250),
    [anon_sym_LT_PIPE] = ACTIONS(248),
    [anon_sym_AMP_AMP] = ACTIONS(248),
    [anon_sym_PIPE_PIPE] = ACTIONS(248),
    [anon_sym_QMARK_QMARK] = ACTIONS(248),
    [anon_sym_QMARK_COLON] = ACTIONS(248),
    [anon_sym_BANG_EQ] = ACTIONS(248),
    [anon_sym_EQ_EQ] = ACTIONS(248),
    [anon_sym_QMARK_EQ] = ACTIONS(248),
    [anon_sym_STAR_EQ] = ACTIONS(248),
    [anon_sym_TILDE] = ACTIONS(248),
    [anon_sym_BANG_TILDE] = ACTIONS(248),
    [anon_sym_STAR_TILDE] = ACTIONS(248),
    [anon_sym_LT_EQ] = ACTIONS(248),
    [anon_sym_GT_EQ] = ACTIONS(248),
    [anon_sym_PLUS] = ACTIONS(250),
    [anon_sym_PLUS_EQ] = ACTIONS(248),
    [anon_sym_DASH_EQ] = ACTIONS(248),
    [anon_sym_u00d7] = ACTIONS(248),
    [anon_sym_SLASH] = ACTIONS(250),
    [anon_sym_u00f7] = ACTIONS(248),
    [anon_sym_STAR_STAR] = ACTIONS(248),
    [anon_sym_u220b] = ACTIONS(248),
    [anon_sym_u220c] = ACTIONS(248),
    [anon_sym_u2287] = ACTIONS(248),
    [anon_sym_u2283] = ACTIONS(248),
    [anon_sym_u2285] = ACTIONS(248),
    [anon_sym_u2208] = ACTIONS(248),
    [anon_sym_u2209] = ACTIONS(248),
    [anon_sym_u2286] = ACTIONS(248),
    [anon_sym_u2282] = ACTIONS(248),
    [anon_sym_u2284] = ACTIONS(248),
    [anon_sym_AT_AT] = ACTIONS(248),
  },
  [STATE(307)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_changefeed] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(308)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_drop] = ACTIONS(537),
    [sym_keyword_schemafull] = ACTIONS(537),
    [sym_keyword_schemaless] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_for] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(309)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_drop] = ACTIONS(316),
    [sym_keyword_schemafull] = ACTIONS(316),
    [sym_keyword_schemaless] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_for] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(310)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(662),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(685),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(311)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_merge] = ACTIONS(288),
    [sym_keyword_patch] = ACTIONS(288),
    [sym_keyword_unset] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(687),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(312)] = {
    [ts_builtin_sym_end] = ACTIONS(256),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(256),
    [sym_keyword_explain] = ACTIONS(256),
    [sym_keyword_parallel] = ACTIONS(256),
    [sym_keyword_timeout] = ACTIONS(256),
    [sym_keyword_fetch] = ACTIONS(256),
    [sym_keyword_limit] = ACTIONS(256),
    [sym_keyword_order] = ACTIONS(256),
    [sym_keyword_with] = ACTIONS(256),
    [sym_keyword_where] = ACTIONS(256),
    [sym_keyword_split] = ACTIONS(256),
    [sym_keyword_group] = ACTIONS(256),
    [sym_keyword_and] = ACTIONS(256),
    [sym_keyword_or] = ACTIONS(258),
    [sym_keyword_is] = ACTIONS(256),
    [sym_keyword_not] = ACTIONS(258),
    [sym_keyword_contains] = ACTIONS(258),
    [sym_keyword_contains_not] = ACTIONS(256),
    [sym_keyword_contains_all] = ACTIONS(256),
    [sym_keyword_contains_any] = ACTIONS(256),
    [sym_keyword_contains_none] = ACTIONS(256),
    [sym_keyword_inside] = ACTIONS(256),
    [sym_keyword_in] = ACTIONS(258),
    [sym_keyword_not_inside] = ACTIONS(256),
    [sym_keyword_all_inside] = ACTIONS(256),
    [sym_keyword_any_inside] = ACTIONS(256),
    [sym_keyword_none_inside] = ACTIONS(256),
    [sym_keyword_outside] = ACTIONS(256),
    [sym_keyword_intersects] = ACTIONS(256),
    [anon_sym_EQ] = ACTIONS(258),
    [anon_sym_COMMA] = ACTIONS(256),
    [anon_sym_DASH_GT] = ACTIONS(256),
    [anon_sym_LBRACK] = ACTIONS(256),
    [anon_sym_LT] = ACTIONS(258),
    [anon_sym_GT] = ACTIONS(258),
    [anon_sym_LT_DASH] = ACTIONS(258),
    [anon_sym_LT_DASH_GT] = ACTIONS(256),
    [anon_sym_STAR] = ACTIONS(258),
    [anon_sym_DOT] = ACTIONS(258),
    [anon_sym_DOT_DOT] = ACTIONS(256),
    [anon_sym_DASH] = ACTIONS(258),
    [anon_sym_PERCENT] = ACTIONS(256),
    [anon_sym_AT] = ACTIONS(258),
    [anon_sym_LT_PIPE] = ACTIONS(256),
    [anon_sym_AMP_AMP] = ACTIONS(256),
    [anon_sym_PIPE_PIPE] = ACTIONS(256),
    [anon_sym_QMARK_QMARK] = ACTIONS(256),
    [anon_sym_QMARK_COLON] = ACTIONS(256),
    [anon_sym_BANG_EQ] = ACTIONS(256),
    [anon_sym_EQ_EQ] = ACTIONS(256),
    [anon_sym_QMARK_EQ] = ACTIONS(256),
    [anon_sym_STAR_EQ] = ACTIONS(256),
    [anon_sym_TILDE] = ACTIONS(256),
    [anon_sym_BANG_TILDE] = ACTIONS(256),
    [anon_sym_STAR_TILDE] = ACTIONS(256),
    [anon_sym_LT_EQ] = ACTIONS(256),
    [anon_sym_GT_EQ] = ACTIONS(256),
    [anon_sym_PLUS] = ACTIONS(258),
    [anon_sym_PLUS_EQ] = ACTIONS(256),
    [anon_sym_DASH_EQ] = ACTIONS(256),
    [anon_sym_u00d7] = ACTIONS(256),
    [anon_sym_SLASH] = ACTIONS(258),
    [anon_sym_u00f7] = ACTIONS(256),
    [anon_sym_STAR_STAR] = ACTIONS(256),
    [anon_sym_u220b] = ACTIONS(256),
    [anon_sym_u220c] = ACTIONS(256),
    [anon_sym_u2287] = ACTIONS(256),
    [anon_sym_u2283] = ACTIONS(256),
    [anon_sym_u2285] = ACTIONS(256),
    [anon_sym_u2208] = ACTIONS(256),
    [anon_sym_u2209] = ACTIONS(256),
    [anon_sym_u2286] = ACTIONS(256),
    [anon_sym_u2282] = ACTIONS(256),
    [anon_sym_u2284] = ACTIONS(256),
    [anon_sym_AT_AT] = ACTIONS(256),
  },
  [STATE(313)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(296),
    [sym_keyword_explain] = ACTIONS(296),
    [sym_keyword_parallel] = ACTIONS(296),
    [sym_keyword_timeout] = ACTIONS(296),
    [sym_keyword_fetch] = ACTIONS(296),
    [sym_keyword_limit] = ACTIONS(296),
    [sym_keyword_order] = ACTIONS(296),
    [sym_keyword_with] = ACTIONS(296),
    [sym_keyword_where] = ACTIONS(296),
    [sym_keyword_split] = ACTIONS(296),
    [sym_keyword_group] = ACTIONS(296),
    [sym_keyword_and] = ACTIONS(296),
    [sym_keyword_or] = ACTIONS(298),
    [sym_keyword_is] = ACTIONS(296),
    [sym_keyword_not] = ACTIONS(298),
    [sym_keyword_contains] = ACTIONS(298),
    [sym_keyword_contains_not] = ACTIONS(296),
    [sym_keyword_contains_all] = ACTIONS(296),
    [sym_keyword_contains_any] = ACTIONS(296),
    [sym_keyword_contains_none] = ACTIONS(296),
    [sym_keyword_inside] = ACTIONS(296),
    [sym_keyword_in] = ACTIONS(298),
    [sym_keyword_not_inside] = ACTIONS(296),
    [sym_keyword_all_inside] = ACTIONS(296),
    [sym_keyword_any_inside] = ACTIONS(296),
    [sym_keyword_none_inside] = ACTIONS(296),
    [sym_keyword_outside] = ACTIONS(296),
    [sym_keyword_intersects] = ACTIONS(296),
    [anon_sym_EQ] = ACTIONS(298),
    [anon_sym_COMMA] = ACTIONS(296),
    [anon_sym_RPAREN] = ACTIONS(296),
    [anon_sym_DASH_GT] = ACTIONS(296),
    [anon_sym_LBRACK] = ACTIONS(296),
    [anon_sym_RBRACE] = ACTIONS(296),
    [anon_sym_LT] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(298),
    [anon_sym_LT_DASH] = ACTIONS(298),
    [anon_sym_LT_DASH_GT] = ACTIONS(296),
    [anon_sym_STAR] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(296),
    [anon_sym_DASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(296),
    [anon_sym_AT] = ACTIONS(298),
    [anon_sym_LT_PIPE] = ACTIONS(296),
    [anon_sym_AMP_AMP] = ACTIONS(296),
    [anon_sym_PIPE_PIPE] = ACTIONS(296),
    [anon_sym_QMARK_QMARK] = ACTIONS(296),
    [anon_sym_QMARK_COLON] = ACTIONS(296),
    [anon_sym_BANG_EQ] = ACTIONS(296),
    [anon_sym_EQ_EQ] = ACTIONS(296),
    [anon_sym_QMARK_EQ] = ACTIONS(296),
    [anon_sym_STAR_EQ] = ACTIONS(296),
    [anon_sym_TILDE] = ACTIONS(296),
    [anon_sym_BANG_TILDE] = ACTIONS(296),
    [anon_sym_STAR_TILDE] = ACTIONS(296),
    [anon_sym_LT_EQ] = ACTIONS(296),
    [anon_sym_GT_EQ] = ACTIONS(296),
    [anon_sym_PLUS] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(296),
    [anon_sym_DASH_EQ] = ACTIONS(296),
    [anon_sym_u00d7] = ACTIONS(296),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_u00f7] = ACTIONS(296),
    [anon_sym_STAR_STAR] = ACTIONS(296),
    [anon_sym_u220b] = ACTIONS(296),
    [anon_sym_u220c] = ACTIONS(296),
    [anon_sym_u2287] = ACTIONS(296),
    [anon_sym_u2283] = ACTIONS(296),
    [anon_sym_u2285] = ACTIONS(296),
    [anon_sym_u2208] = ACTIONS(296),
    [anon_sym_u2209] = ACTIONS(296),
    [anon_sym_u2286] = ACTIONS(296),
    [anon_sym_u2282] = ACTIONS(296),
    [anon_sym_u2284] = ACTIONS(296),
    [anon_sym_AT_AT] = ACTIONS(296),
  },
  [STATE(314)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(315)] = {
    [ts_builtin_sym_end] = ACTIONS(270),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(270),
    [sym_keyword_explain] = ACTIONS(270),
    [sym_keyword_parallel] = ACTIONS(270),
    [sym_keyword_timeout] = ACTIONS(270),
    [sym_keyword_fetch] = ACTIONS(270),
    [sym_keyword_limit] = ACTIONS(270),
    [sym_keyword_order] = ACTIONS(270),
    [sym_keyword_with] = ACTIONS(270),
    [sym_keyword_where] = ACTIONS(270),
    [sym_keyword_split] = ACTIONS(270),
    [sym_keyword_group] = ACTIONS(270),
    [sym_keyword_and] = ACTIONS(270),
    [sym_keyword_or] = ACTIONS(272),
    [sym_keyword_is] = ACTIONS(270),
    [sym_keyword_not] = ACTIONS(272),
    [sym_keyword_contains] = ACTIONS(272),
    [sym_keyword_contains_not] = ACTIONS(270),
    [sym_keyword_contains_all] = ACTIONS(270),
    [sym_keyword_contains_any] = ACTIONS(270),
    [sym_keyword_contains_none] = ACTIONS(270),
    [sym_keyword_inside] = ACTIONS(270),
    [sym_keyword_in] = ACTIONS(272),
    [sym_keyword_not_inside] = ACTIONS(270),
    [sym_keyword_all_inside] = ACTIONS(270),
    [sym_keyword_any_inside] = ACTIONS(270),
    [sym_keyword_none_inside] = ACTIONS(270),
    [sym_keyword_outside] = ACTIONS(270),
    [sym_keyword_intersects] = ACTIONS(270),
    [anon_sym_EQ] = ACTIONS(272),
    [anon_sym_COMMA] = ACTIONS(270),
    [anon_sym_DASH_GT] = ACTIONS(270),
    [anon_sym_LBRACK] = ACTIONS(270),
    [anon_sym_LT] = ACTIONS(272),
    [anon_sym_GT] = ACTIONS(272),
    [anon_sym_LT_DASH] = ACTIONS(272),
    [anon_sym_LT_DASH_GT] = ACTIONS(270),
    [anon_sym_STAR] = ACTIONS(272),
    [anon_sym_DOT] = ACTIONS(270),
    [anon_sym_DASH] = ACTIONS(272),
    [anon_sym_PERCENT] = ACTIONS(270),
    [anon_sym_AT] = ACTIONS(272),
    [anon_sym_LT_PIPE] = ACTIONS(270),
    [anon_sym_AMP_AMP] = ACTIONS(270),
    [anon_sym_PIPE_PIPE] = ACTIONS(270),
    [anon_sym_QMARK_QMARK] = ACTIONS(270),
    [anon_sym_QMARK_COLON] = ACTIONS(270),
    [anon_sym_BANG_EQ] = ACTIONS(270),
    [anon_sym_EQ_EQ] = ACTIONS(270),
    [anon_sym_QMARK_EQ] = ACTIONS(270),
    [anon_sym_STAR_EQ] = ACTIONS(270),
    [anon_sym_TILDE] = ACTIONS(270),
    [anon_sym_BANG_TILDE] = ACTIONS(270),
    [anon_sym_STAR_TILDE] = ACTIONS(270),
    [anon_sym_LT_EQ] = ACTIONS(270),
    [anon_sym_GT_EQ] = ACTIONS(270),
    [anon_sym_PLUS] = ACTIONS(272),
    [anon_sym_PLUS_EQ] = ACTIONS(270),
    [anon_sym_DASH_EQ] = ACTIONS(270),
    [anon_sym_u00d7] = ACTIONS(270),
    [anon_sym_SLASH] = ACTIONS(272),
    [anon_sym_u00f7] = ACTIONS(270),
    [anon_sym_STAR_STAR] = ACTIONS(270),
    [anon_sym_u220b] = ACTIONS(270),
    [anon_sym_u220c] = ACTIONS(270),
    [anon_sym_u2287] = ACTIONS(270),
    [anon_sym_u2283] = ACTIONS(270),
    [anon_sym_u2285] = ACTIONS(270),
    [anon_sym_u2208] = ACTIONS(270),
    [anon_sym_u2209] = ACTIONS(270),
    [anon_sym_u2286] = ACTIONS(270),
    [anon_sym_u2282] = ACTIONS(270),
    [anon_sym_u2284] = ACTIONS(270),
    [anon_sym_AT_AT] = ACTIONS(270),
  },
  [STATE(316)] = {
    [ts_builtin_sym_end] = ACTIONS(274),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(274),
    [sym_keyword_explain] = ACTIONS(274),
    [sym_keyword_parallel] = ACTIONS(274),
    [sym_keyword_timeout] = ACTIONS(274),
    [sym_keyword_fetch] = ACTIONS(274),
    [sym_keyword_limit] = ACTIONS(274),
    [sym_keyword_order] = ACTIONS(274),
    [sym_keyword_with] = ACTIONS(274),
    [sym_keyword_where] = ACTIONS(274),
    [sym_keyword_split] = ACTIONS(274),
    [sym_keyword_group] = ACTIONS(274),
    [sym_keyword_and] = ACTIONS(274),
    [sym_keyword_or] = ACTIONS(276),
    [sym_keyword_is] = ACTIONS(274),
    [sym_keyword_not] = ACTIONS(276),
    [sym_keyword_contains] = ACTIONS(276),
    [sym_keyword_contains_not] = ACTIONS(274),
    [sym_keyword_contains_all] = ACTIONS(274),
    [sym_keyword_contains_any] = ACTIONS(274),
    [sym_keyword_contains_none] = ACTIONS(274),
    [sym_keyword_inside] = ACTIONS(274),
    [sym_keyword_in] = ACTIONS(276),
    [sym_keyword_not_inside] = ACTIONS(274),
    [sym_keyword_all_inside] = ACTIONS(274),
    [sym_keyword_any_inside] = ACTIONS(274),
    [sym_keyword_none_inside] = ACTIONS(274),
    [sym_keyword_outside] = ACTIONS(274),
    [sym_keyword_intersects] = ACTIONS(274),
    [anon_sym_EQ] = ACTIONS(276),
    [anon_sym_COMMA] = ACTIONS(274),
    [anon_sym_DASH_GT] = ACTIONS(274),
    [anon_sym_LBRACK] = ACTIONS(274),
    [anon_sym_LT] = ACTIONS(276),
    [anon_sym_GT] = ACTIONS(276),
    [anon_sym_LT_DASH] = ACTIONS(276),
    [anon_sym_LT_DASH_GT] = ACTIONS(274),
    [anon_sym_STAR] = ACTIONS(276),
    [anon_sym_DOT] = ACTIONS(274),
    [anon_sym_DASH] = ACTIONS(276),
    [anon_sym_PERCENT] = ACTIONS(274),
    [anon_sym_AT] = ACTIONS(276),
    [anon_sym_LT_PIPE] = ACTIONS(274),
    [anon_sym_AMP_AMP] = ACTIONS(274),
    [anon_sym_PIPE_PIPE] = ACTIONS(274),
    [anon_sym_QMARK_QMARK] = ACTIONS(274),
    [anon_sym_QMARK_COLON] = ACTIONS(274),
    [anon_sym_BANG_EQ] = ACTIONS(274),
    [anon_sym_EQ_EQ] = ACTIONS(274),
    [anon_sym_QMARK_EQ] = ACTIONS(274),
    [anon_sym_STAR_EQ] = ACTIONS(274),
    [anon_sym_TILDE] = ACTIONS(274),
    [anon_sym_BANG_TILDE] = ACTIONS(274),
    [anon_sym_STAR_TILDE] = ACTIONS(274),
    [anon_sym_LT_EQ] = ACTIONS(274),
    [anon_sym_GT_EQ] = ACTIONS(274),
    [anon_sym_PLUS] = ACTIONS(276),
    [anon_sym_PLUS_EQ] = ACTIONS(274),
    [anon_sym_DASH_EQ] = ACTIONS(274),
    [anon_sym_u00d7] = ACTIONS(274),
    [anon_sym_SLASH] = ACTIONS(276),
    [anon_sym_u00f7] = ACTIONS(274),
    [anon_sym_STAR_STAR] = ACTIONS(274),
    [anon_sym_u220b] = ACTIONS(274),
    [anon_sym_u220c] = ACTIONS(274),
    [anon_sym_u2287] = ACTIONS(274),
    [anon_sym_u2283] = ACTIONS(274),
    [anon_sym_u2285] = ACTIONS(274),
    [anon_sym_u2208] = ACTIONS(274),
    [anon_sym_u2209] = ACTIONS(274),
    [anon_sym_u2286] = ACTIONS(274),
    [anon_sym_u2282] = ACTIONS(274),
    [anon_sym_u2284] = ACTIONS(274),
    [anon_sym_AT_AT] = ACTIONS(274),
  },
  [STATE(317)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(318)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(319)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(320)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(321)] = {
    [ts_builtin_sym_end] = ACTIONS(264),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_order] = ACTIONS(264),
    [sym_keyword_with] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_split] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(266),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(266),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(322)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(323)] = {
    [ts_builtin_sym_end] = ACTIONS(304),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(304),
    [sym_keyword_explain] = ACTIONS(304),
    [sym_keyword_parallel] = ACTIONS(304),
    [sym_keyword_timeout] = ACTIONS(304),
    [sym_keyword_fetch] = ACTIONS(304),
    [sym_keyword_limit] = ACTIONS(304),
    [sym_keyword_order] = ACTIONS(304),
    [sym_keyword_with] = ACTIONS(304),
    [sym_keyword_where] = ACTIONS(304),
    [sym_keyword_split] = ACTIONS(304),
    [sym_keyword_group] = ACTIONS(304),
    [sym_keyword_and] = ACTIONS(304),
    [sym_keyword_or] = ACTIONS(306),
    [sym_keyword_is] = ACTIONS(304),
    [sym_keyword_not] = ACTIONS(306),
    [sym_keyword_contains] = ACTIONS(306),
    [sym_keyword_contains_not] = ACTIONS(304),
    [sym_keyword_contains_all] = ACTIONS(304),
    [sym_keyword_contains_any] = ACTIONS(304),
    [sym_keyword_contains_none] = ACTIONS(304),
    [sym_keyword_inside] = ACTIONS(304),
    [sym_keyword_in] = ACTIONS(306),
    [sym_keyword_not_inside] = ACTIONS(304),
    [sym_keyword_all_inside] = ACTIONS(304),
    [sym_keyword_any_inside] = ACTIONS(304),
    [sym_keyword_none_inside] = ACTIONS(304),
    [sym_keyword_outside] = ACTIONS(304),
    [sym_keyword_intersects] = ACTIONS(304),
    [anon_sym_EQ] = ACTIONS(306),
    [anon_sym_COMMA] = ACTIONS(304),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(306),
    [anon_sym_GT] = ACTIONS(306),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(306),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(306),
    [anon_sym_PERCENT] = ACTIONS(304),
    [anon_sym_AT] = ACTIONS(306),
    [anon_sym_LT_PIPE] = ACTIONS(304),
    [anon_sym_AMP_AMP] = ACTIONS(304),
    [anon_sym_PIPE_PIPE] = ACTIONS(304),
    [anon_sym_QMARK_QMARK] = ACTIONS(304),
    [anon_sym_QMARK_COLON] = ACTIONS(304),
    [anon_sym_BANG_EQ] = ACTIONS(304),
    [anon_sym_EQ_EQ] = ACTIONS(304),
    [anon_sym_QMARK_EQ] = ACTIONS(304),
    [anon_sym_STAR_EQ] = ACTIONS(304),
    [anon_sym_TILDE] = ACTIONS(304),
    [anon_sym_BANG_TILDE] = ACTIONS(304),
    [anon_sym_STAR_TILDE] = ACTIONS(304),
    [anon_sym_LT_EQ] = ACTIONS(304),
    [anon_sym_GT_EQ] = ACTIONS(304),
    [anon_sym_PLUS] = ACTIONS(306),
    [anon_sym_PLUS_EQ] = ACTIONS(304),
    [anon_sym_DASH_EQ] = ACTIONS(304),
    [anon_sym_u00d7] = ACTIONS(304),
    [anon_sym_SLASH] = ACTIONS(306),
    [anon_sym_u00f7] = ACTIONS(304),
    [anon_sym_STAR_STAR] = ACTIONS(304),
    [anon_sym_u220b] = ACTIONS(304),
    [anon_sym_u220c] = ACTIONS(304),
    [anon_sym_u2287] = ACTIONS(304),
    [anon_sym_u2283] = ACTIONS(304),
    [anon_sym_u2285] = ACTIONS(304),
    [anon_sym_u2208] = ACTIONS(304),
    [anon_sym_u2209] = ACTIONS(304),
    [anon_sym_u2286] = ACTIONS(304),
    [anon_sym_u2282] = ACTIONS(304),
    [anon_sym_u2284] = ACTIONS(304),
    [anon_sym_AT_AT] = ACTIONS(304),
  },
  [STATE(324)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(325)] = {
    [ts_builtin_sym_end] = ACTIONS(278),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(278),
    [sym_keyword_explain] = ACTIONS(278),
    [sym_keyword_parallel] = ACTIONS(278),
    [sym_keyword_timeout] = ACTIONS(278),
    [sym_keyword_fetch] = ACTIONS(278),
    [sym_keyword_limit] = ACTIONS(278),
    [sym_keyword_order] = ACTIONS(278),
    [sym_keyword_with] = ACTIONS(278),
    [sym_keyword_where] = ACTIONS(278),
    [sym_keyword_split] = ACTIONS(278),
    [sym_keyword_group] = ACTIONS(278),
    [sym_keyword_and] = ACTIONS(278),
    [sym_keyword_or] = ACTIONS(280),
    [sym_keyword_is] = ACTIONS(278),
    [sym_keyword_not] = ACTIONS(280),
    [sym_keyword_contains] = ACTIONS(280),
    [sym_keyword_contains_not] = ACTIONS(278),
    [sym_keyword_contains_all] = ACTIONS(278),
    [sym_keyword_contains_any] = ACTIONS(278),
    [sym_keyword_contains_none] = ACTIONS(278),
    [sym_keyword_inside] = ACTIONS(278),
    [sym_keyword_in] = ACTIONS(280),
    [sym_keyword_not_inside] = ACTIONS(278),
    [sym_keyword_all_inside] = ACTIONS(278),
    [sym_keyword_any_inside] = ACTIONS(278),
    [sym_keyword_none_inside] = ACTIONS(278),
    [sym_keyword_outside] = ACTIONS(278),
    [sym_keyword_intersects] = ACTIONS(278),
    [anon_sym_EQ] = ACTIONS(280),
    [anon_sym_COMMA] = ACTIONS(278),
    [anon_sym_DASH_GT] = ACTIONS(278),
    [anon_sym_LBRACK] = ACTIONS(278),
    [anon_sym_LT] = ACTIONS(280),
    [anon_sym_GT] = ACTIONS(280),
    [anon_sym_LT_DASH] = ACTIONS(280),
    [anon_sym_LT_DASH_GT] = ACTIONS(278),
    [anon_sym_STAR] = ACTIONS(280),
    [anon_sym_DOT] = ACTIONS(278),
    [anon_sym_DASH] = ACTIONS(280),
    [anon_sym_PERCENT] = ACTIONS(278),
    [anon_sym_AT] = ACTIONS(280),
    [anon_sym_LT_PIPE] = ACTIONS(278),
    [anon_sym_AMP_AMP] = ACTIONS(278),
    [anon_sym_PIPE_PIPE] = ACTIONS(278),
    [anon_sym_QMARK_QMARK] = ACTIONS(278),
    [anon_sym_QMARK_COLON] = ACTIONS(278),
    [anon_sym_BANG_EQ] = ACTIONS(278),
    [anon_sym_EQ_EQ] = ACTIONS(278),
    [anon_sym_QMARK_EQ] = ACTIONS(278),
    [anon_sym_STAR_EQ] = ACTIONS(278),
    [anon_sym_TILDE] = ACTIONS(278),
    [anon_sym_BANG_TILDE] = ACTIONS(278),
    [anon_sym_STAR_TILDE] = ACTIONS(278),
    [anon_sym_LT_EQ] = ACTIONS(278),
    [anon_sym_GT_EQ] = ACTIONS(278),
    [anon_sym_PLUS] = ACTIONS(280),
    [anon_sym_PLUS_EQ] = ACTIONS(278),
    [anon_sym_DASH_EQ] = ACTIONS(278),
    [anon_sym_u00d7] = ACTIONS(278),
    [anon_sym_SLASH] = ACTIONS(280),
    [anon_sym_u00f7] = ACTIONS(278),
    [anon_sym_STAR_STAR] = ACTIONS(278),
    [anon_sym_u220b] = ACTIONS(278),
    [anon_sym_u220c] = ACTIONS(278),
    [anon_sym_u2287] = ACTIONS(278),
    [anon_sym_u2283] = ACTIONS(278),
    [anon_sym_u2285] = ACTIONS(278),
    [anon_sym_u2208] = ACTIONS(278),
    [anon_sym_u2209] = ACTIONS(278),
    [anon_sym_u2286] = ACTIONS(278),
    [anon_sym_u2282] = ACTIONS(278),
    [anon_sym_u2284] = ACTIONS(278),
    [anon_sym_AT_AT] = ACTIONS(278),
  },
  [STATE(326)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_content] = ACTIONS(316),
    [sym_keyword_set] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(327)] = {
    [ts_builtin_sym_end] = ACTIONS(310),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(310),
    [sym_keyword_explain] = ACTIONS(310),
    [sym_keyword_parallel] = ACTIONS(310),
    [sym_keyword_timeout] = ACTIONS(310),
    [sym_keyword_fetch] = ACTIONS(310),
    [sym_keyword_limit] = ACTIONS(310),
    [sym_keyword_order] = ACTIONS(310),
    [sym_keyword_with] = ACTIONS(310),
    [sym_keyword_where] = ACTIONS(310),
    [sym_keyword_split] = ACTIONS(310),
    [sym_keyword_group] = ACTIONS(310),
    [sym_keyword_and] = ACTIONS(310),
    [sym_keyword_or] = ACTIONS(312),
    [sym_keyword_is] = ACTIONS(310),
    [sym_keyword_not] = ACTIONS(312),
    [sym_keyword_contains] = ACTIONS(312),
    [sym_keyword_contains_not] = ACTIONS(310),
    [sym_keyword_contains_all] = ACTIONS(310),
    [sym_keyword_contains_any] = ACTIONS(310),
    [sym_keyword_contains_none] = ACTIONS(310),
    [sym_keyword_inside] = ACTIONS(310),
    [sym_keyword_in] = ACTIONS(312),
    [sym_keyword_not_inside] = ACTIONS(310),
    [sym_keyword_all_inside] = ACTIONS(310),
    [sym_keyword_any_inside] = ACTIONS(310),
    [sym_keyword_none_inside] = ACTIONS(310),
    [sym_keyword_outside] = ACTIONS(310),
    [sym_keyword_intersects] = ACTIONS(310),
    [anon_sym_EQ] = ACTIONS(312),
    [anon_sym_COMMA] = ACTIONS(310),
    [anon_sym_DASH_GT] = ACTIONS(310),
    [anon_sym_LBRACK] = ACTIONS(310),
    [anon_sym_LT] = ACTIONS(312),
    [anon_sym_GT] = ACTIONS(312),
    [anon_sym_LT_DASH] = ACTIONS(312),
    [anon_sym_LT_DASH_GT] = ACTIONS(310),
    [anon_sym_STAR] = ACTIONS(312),
    [anon_sym_DOT] = ACTIONS(310),
    [anon_sym_DASH] = ACTIONS(312),
    [anon_sym_PERCENT] = ACTIONS(310),
    [anon_sym_AT] = ACTIONS(312),
    [anon_sym_LT_PIPE] = ACTIONS(310),
    [anon_sym_AMP_AMP] = ACTIONS(310),
    [anon_sym_PIPE_PIPE] = ACTIONS(310),
    [anon_sym_QMARK_QMARK] = ACTIONS(310),
    [anon_sym_QMARK_COLON] = ACTIONS(310),
    [anon_sym_BANG_EQ] = ACTIONS(310),
    [anon_sym_EQ_EQ] = ACTIONS(310),
    [anon_sym_QMARK_EQ] = ACTIONS(310),
    [anon_sym_STAR_EQ] = ACTIONS(310),
    [anon_sym_TILDE] = ACTIONS(310),
    [anon_sym_BANG_TILDE] = ACTIONS(310),
    [anon_sym_STAR_TILDE] = ACTIONS(310),
    [anon_sym_LT_EQ] = ACTIONS(310),
    [anon_sym_GT_EQ] = ACTIONS(310),
    [anon_sym_PLUS] = ACTIONS(312),
    [anon_sym_PLUS_EQ] = ACTIONS(310),
    [anon_sym_DASH_EQ] = ACTIONS(310),
    [anon_sym_u00d7] = ACTIONS(310),
    [anon_sym_SLASH] = ACTIONS(312),
    [anon_sym_u00f7] = ACTIONS(310),
    [anon_sym_STAR_STAR] = ACTIONS(310),
    [anon_sym_u220b] = ACTIONS(310),
    [anon_sym_u220c] = ACTIONS(310),
    [anon_sym_u2287] = ACTIONS(310),
    [anon_sym_u2283] = ACTIONS(310),
    [anon_sym_u2285] = ACTIONS(310),
    [anon_sym_u2208] = ACTIONS(310),
    [anon_sym_u2209] = ACTIONS(310),
    [anon_sym_u2286] = ACTIONS(310),
    [anon_sym_u2282] = ACTIONS(310),
    [anon_sym_u2284] = ACTIONS(310),
    [anon_sym_AT_AT] = ACTIONS(310),
  },
  [STATE(328)] = {
    [ts_builtin_sym_end] = ACTIONS(347),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(347),
    [sym_keyword_explain] = ACTIONS(347),
    [sym_keyword_parallel] = ACTIONS(347),
    [sym_keyword_timeout] = ACTIONS(347),
    [sym_keyword_fetch] = ACTIONS(347),
    [sym_keyword_limit] = ACTIONS(347),
    [sym_keyword_order] = ACTIONS(347),
    [sym_keyword_with] = ACTIONS(347),
    [sym_keyword_where] = ACTIONS(347),
    [sym_keyword_split] = ACTIONS(347),
    [sym_keyword_group] = ACTIONS(347),
    [sym_keyword_and] = ACTIONS(347),
    [sym_keyword_or] = ACTIONS(349),
    [sym_keyword_is] = ACTIONS(347),
    [sym_keyword_not] = ACTIONS(349),
    [sym_keyword_contains] = ACTIONS(349),
    [sym_keyword_contains_not] = ACTIONS(347),
    [sym_keyword_contains_all] = ACTIONS(347),
    [sym_keyword_contains_any] = ACTIONS(347),
    [sym_keyword_contains_none] = ACTIONS(347),
    [sym_keyword_inside] = ACTIONS(347),
    [sym_keyword_in] = ACTIONS(349),
    [sym_keyword_not_inside] = ACTIONS(347),
    [sym_keyword_all_inside] = ACTIONS(347),
    [sym_keyword_any_inside] = ACTIONS(347),
    [sym_keyword_none_inside] = ACTIONS(347),
    [sym_keyword_outside] = ACTIONS(347),
    [sym_keyword_intersects] = ACTIONS(347),
    [anon_sym_EQ] = ACTIONS(349),
    [anon_sym_COMMA] = ACTIONS(347),
    [anon_sym_DASH_GT] = ACTIONS(347),
    [anon_sym_LBRACK] = ACTIONS(347),
    [anon_sym_LT] = ACTIONS(349),
    [anon_sym_GT] = ACTIONS(349),
    [anon_sym_LT_DASH] = ACTIONS(349),
    [anon_sym_LT_DASH_GT] = ACTIONS(347),
    [anon_sym_STAR] = ACTIONS(349),
    [anon_sym_DOT] = ACTIONS(347),
    [anon_sym_DASH] = ACTIONS(349),
    [anon_sym_PERCENT] = ACTIONS(347),
    [anon_sym_AT] = ACTIONS(349),
    [anon_sym_LT_PIPE] = ACTIONS(347),
    [anon_sym_AMP_AMP] = ACTIONS(347),
    [anon_sym_PIPE_PIPE] = ACTIONS(347),
    [anon_sym_QMARK_QMARK] = ACTIONS(347),
    [anon_sym_QMARK_COLON] = ACTIONS(347),
    [anon_sym_BANG_EQ] = ACTIONS(347),
    [anon_sym_EQ_EQ] = ACTIONS(347),
    [anon_sym_QMARK_EQ] = ACTIONS(347),
    [anon_sym_STAR_EQ] = ACTIONS(347),
    [anon_sym_TILDE] = ACTIONS(347),
    [anon_sym_BANG_TILDE] = ACTIONS(347),
    [anon_sym_STAR_TILDE] = ACTIONS(347),
    [anon_sym_LT_EQ] = ACTIONS(347),
    [anon_sym_GT_EQ] = ACTIONS(347),
    [anon_sym_PLUS] = ACTIONS(349),
    [anon_sym_PLUS_EQ] = ACTIONS(347),
    [anon_sym_DASH_EQ] = ACTIONS(347),
    [anon_sym_u00d7] = ACTIONS(347),
    [anon_sym_SLASH] = ACTIONS(349),
    [anon_sym_u00f7] = ACTIONS(347),
    [anon_sym_STAR_STAR] = ACTIONS(347),
    [anon_sym_u220b] = ACTIONS(347),
    [anon_sym_u220c] = ACTIONS(347),
    [anon_sym_u2287] = ACTIONS(347),
    [anon_sym_u2283] = ACTIONS(347),
    [anon_sym_u2285] = ACTIONS(347),
    [anon_sym_u2208] = ACTIONS(347),
    [anon_sym_u2209] = ACTIONS(347),
    [anon_sym_u2286] = ACTIONS(347),
    [anon_sym_u2282] = ACTIONS(347),
    [anon_sym_u2284] = ACTIONS(347),
    [anon_sym_AT_AT] = ACTIONS(347),
  },
  [STATE(329)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_content] = ACTIONS(537),
    [sym_keyword_set] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(330)] = {
    [ts_builtin_sym_end] = ACTIONS(326),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(326),
    [sym_keyword_explain] = ACTIONS(326),
    [sym_keyword_parallel] = ACTIONS(326),
    [sym_keyword_timeout] = ACTIONS(326),
    [sym_keyword_fetch] = ACTIONS(326),
    [sym_keyword_limit] = ACTIONS(326),
    [sym_keyword_order] = ACTIONS(326),
    [sym_keyword_with] = ACTIONS(326),
    [sym_keyword_where] = ACTIONS(326),
    [sym_keyword_split] = ACTIONS(326),
    [sym_keyword_group] = ACTIONS(326),
    [sym_keyword_and] = ACTIONS(326),
    [sym_keyword_or] = ACTIONS(328),
    [sym_keyword_is] = ACTIONS(326),
    [sym_keyword_not] = ACTIONS(328),
    [sym_keyword_contains] = ACTIONS(328),
    [sym_keyword_contains_not] = ACTIONS(326),
    [sym_keyword_contains_all] = ACTIONS(326),
    [sym_keyword_contains_any] = ACTIONS(326),
    [sym_keyword_contains_none] = ACTIONS(326),
    [sym_keyword_inside] = ACTIONS(326),
    [sym_keyword_in] = ACTIONS(328),
    [sym_keyword_not_inside] = ACTIONS(326),
    [sym_keyword_all_inside] = ACTIONS(326),
    [sym_keyword_any_inside] = ACTIONS(326),
    [sym_keyword_none_inside] = ACTIONS(326),
    [sym_keyword_outside] = ACTIONS(326),
    [sym_keyword_intersects] = ACTIONS(326),
    [anon_sym_EQ] = ACTIONS(328),
    [anon_sym_COMMA] = ACTIONS(326),
    [anon_sym_DASH_GT] = ACTIONS(326),
    [anon_sym_LBRACK] = ACTIONS(326),
    [anon_sym_LT] = ACTIONS(328),
    [anon_sym_GT] = ACTIONS(328),
    [anon_sym_LT_DASH] = ACTIONS(328),
    [anon_sym_LT_DASH_GT] = ACTIONS(326),
    [anon_sym_STAR] = ACTIONS(328),
    [anon_sym_DOT] = ACTIONS(326),
    [anon_sym_DASH] = ACTIONS(328),
    [anon_sym_PERCENT] = ACTIONS(326),
    [anon_sym_AT] = ACTIONS(328),
    [anon_sym_LT_PIPE] = ACTIONS(326),
    [anon_sym_AMP_AMP] = ACTIONS(326),
    [anon_sym_PIPE_PIPE] = ACTIONS(326),
    [anon_sym_QMARK_QMARK] = ACTIONS(326),
    [anon_sym_QMARK_COLON] = ACTIONS(326),
    [anon_sym_BANG_EQ] = ACTIONS(326),
    [anon_sym_EQ_EQ] = ACTIONS(326),
    [anon_sym_QMARK_EQ] = ACTIONS(326),
    [anon_sym_STAR_EQ] = ACTIONS(326),
    [anon_sym_TILDE] = ACTIONS(326),
    [anon_sym_BANG_TILDE] = ACTIONS(326),
    [anon_sym_STAR_TILDE] = ACTIONS(326),
    [anon_sym_LT_EQ] = ACTIONS(326),
    [anon_sym_GT_EQ] = ACTIONS(326),
    [anon_sym_PLUS] = ACTIONS(328),
    [anon_sym_PLUS_EQ] = ACTIONS(326),
    [anon_sym_DASH_EQ] = ACTIONS(326),
    [anon_sym_u00d7] = ACTIONS(326),
    [anon_sym_SLASH] = ACTIONS(328),
    [anon_sym_u00f7] = ACTIONS(326),
    [anon_sym_STAR_STAR] = ACTIONS(326),
    [anon_sym_u220b] = ACTIONS(326),
    [anon_sym_u220c] = ACTIONS(326),
    [anon_sym_u2287] = ACTIONS(326),
    [anon_sym_u2283] = ACTIONS(326),
    [anon_sym_u2285] = ACTIONS(326),
    [anon_sym_u2208] = ACTIONS(326),
    [anon_sym_u2209] = ACTIONS(326),
    [anon_sym_u2286] = ACTIONS(326),
    [anon_sym_u2282] = ACTIONS(326),
    [anon_sym_u2284] = ACTIONS(326),
    [anon_sym_AT_AT] = ACTIONS(326),
  },
  [STATE(331)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(332)] = {
    [ts_builtin_sym_end] = ACTIONS(284),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(284),
    [sym_keyword_explain] = ACTIONS(284),
    [sym_keyword_parallel] = ACTIONS(284),
    [sym_keyword_timeout] = ACTIONS(284),
    [sym_keyword_fetch] = ACTIONS(284),
    [sym_keyword_limit] = ACTIONS(284),
    [sym_keyword_order] = ACTIONS(284),
    [sym_keyword_with] = ACTIONS(284),
    [sym_keyword_where] = ACTIONS(284),
    [sym_keyword_split] = ACTIONS(284),
    [sym_keyword_group] = ACTIONS(284),
    [sym_keyword_and] = ACTIONS(284),
    [sym_keyword_or] = ACTIONS(286),
    [sym_keyword_is] = ACTIONS(284),
    [sym_keyword_not] = ACTIONS(286),
    [sym_keyword_contains] = ACTIONS(286),
    [sym_keyword_contains_not] = ACTIONS(284),
    [sym_keyword_contains_all] = ACTIONS(284),
    [sym_keyword_contains_any] = ACTIONS(284),
    [sym_keyword_contains_none] = ACTIONS(284),
    [sym_keyword_inside] = ACTIONS(284),
    [sym_keyword_in] = ACTIONS(286),
    [sym_keyword_not_inside] = ACTIONS(284),
    [sym_keyword_all_inside] = ACTIONS(284),
    [sym_keyword_any_inside] = ACTIONS(284),
    [sym_keyword_none_inside] = ACTIONS(284),
    [sym_keyword_outside] = ACTIONS(284),
    [sym_keyword_intersects] = ACTIONS(284),
    [anon_sym_EQ] = ACTIONS(286),
    [anon_sym_COMMA] = ACTIONS(284),
    [anon_sym_DASH_GT] = ACTIONS(284),
    [anon_sym_LBRACK] = ACTIONS(284),
    [anon_sym_LT] = ACTIONS(286),
    [anon_sym_GT] = ACTIONS(286),
    [anon_sym_LT_DASH] = ACTIONS(286),
    [anon_sym_LT_DASH_GT] = ACTIONS(284),
    [anon_sym_STAR] = ACTIONS(286),
    [anon_sym_DOT] = ACTIONS(284),
    [anon_sym_DASH] = ACTIONS(286),
    [anon_sym_PERCENT] = ACTIONS(284),
    [anon_sym_AT] = ACTIONS(286),
    [anon_sym_LT_PIPE] = ACTIONS(284),
    [anon_sym_AMP_AMP] = ACTIONS(284),
    [anon_sym_PIPE_PIPE] = ACTIONS(284),
    [anon_sym_QMARK_QMARK] = ACTIONS(284),
    [anon_sym_QMARK_COLON] = ACTIONS(284),
    [anon_sym_BANG_EQ] = ACTIONS(284),
    [anon_sym_EQ_EQ] = ACTIONS(284),
    [anon_sym_QMARK_EQ] = ACTIONS(284),
    [anon_sym_STAR_EQ] = ACTIONS(284),
    [anon_sym_TILDE] = ACTIONS(284),
    [anon_sym_BANG_TILDE] = ACTIONS(284),
    [anon_sym_STAR_TILDE] = ACTIONS(284),
    [anon_sym_LT_EQ] = ACTIONS(284),
    [anon_sym_GT_EQ] = ACTIONS(284),
    [anon_sym_PLUS] = ACTIONS(286),
    [anon_sym_PLUS_EQ] = ACTIONS(284),
    [anon_sym_DASH_EQ] = ACTIONS(284),
    [anon_sym_u00d7] = ACTIONS(284),
    [anon_sym_SLASH] = ACTIONS(286),
    [anon_sym_u00f7] = ACTIONS(284),
    [anon_sym_STAR_STAR] = ACTIONS(284),
    [anon_sym_u220b] = ACTIONS(284),
    [anon_sym_u220c] = ACTIONS(284),
    [anon_sym_u2287] = ACTIONS(284),
    [anon_sym_u2283] = ACTIONS(284),
    [anon_sym_u2285] = ACTIONS(284),
    [anon_sym_u2208] = ACTIONS(284),
    [anon_sym_u2209] = ACTIONS(284),
    [anon_sym_u2286] = ACTIONS(284),
    [anon_sym_u2282] = ACTIONS(284),
    [anon_sym_u2284] = ACTIONS(284),
    [anon_sym_AT_AT] = ACTIONS(284),
  },
  [STATE(333)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_with] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(290),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(288),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(334)] = {
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_order] = ACTIONS(204),
    [sym_keyword_with] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_split] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_DASH_GT] = ACTIONS(304),
    [anon_sym_LBRACK] = ACTIONS(304),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_LT_DASH] = ACTIONS(306),
    [anon_sym_LT_DASH_GT] = ACTIONS(304),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DOT] = ACTIONS(304),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(335)] = {
    [ts_builtin_sym_end] = ACTIONS(292),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(292),
    [sym_keyword_explain] = ACTIONS(292),
    [sym_keyword_parallel] = ACTIONS(292),
    [sym_keyword_timeout] = ACTIONS(292),
    [sym_keyword_fetch] = ACTIONS(292),
    [sym_keyword_limit] = ACTIONS(292),
    [sym_keyword_order] = ACTIONS(292),
    [sym_keyword_with] = ACTIONS(292),
    [sym_keyword_where] = ACTIONS(292),
    [sym_keyword_split] = ACTIONS(292),
    [sym_keyword_group] = ACTIONS(292),
    [sym_keyword_and] = ACTIONS(292),
    [sym_keyword_or] = ACTIONS(294),
    [sym_keyword_is] = ACTIONS(292),
    [sym_keyword_not] = ACTIONS(294),
    [sym_keyword_contains] = ACTIONS(294),
    [sym_keyword_contains_not] = ACTIONS(292),
    [sym_keyword_contains_all] = ACTIONS(292),
    [sym_keyword_contains_any] = ACTIONS(292),
    [sym_keyword_contains_none] = ACTIONS(292),
    [sym_keyword_inside] = ACTIONS(292),
    [sym_keyword_in] = ACTIONS(294),
    [sym_keyword_not_inside] = ACTIONS(292),
    [sym_keyword_all_inside] = ACTIONS(292),
    [sym_keyword_any_inside] = ACTIONS(292),
    [sym_keyword_none_inside] = ACTIONS(292),
    [sym_keyword_outside] = ACTIONS(292),
    [sym_keyword_intersects] = ACTIONS(292),
    [anon_sym_EQ] = ACTIONS(294),
    [anon_sym_COMMA] = ACTIONS(292),
    [anon_sym_DASH_GT] = ACTIONS(292),
    [anon_sym_LBRACK] = ACTIONS(292),
    [anon_sym_LT] = ACTIONS(294),
    [anon_sym_GT] = ACTIONS(294),
    [anon_sym_LT_DASH] = ACTIONS(294),
    [anon_sym_LT_DASH_GT] = ACTIONS(292),
    [anon_sym_STAR] = ACTIONS(294),
    [anon_sym_DOT] = ACTIONS(292),
    [anon_sym_DASH] = ACTIONS(294),
    [anon_sym_PERCENT] = ACTIONS(292),
    [anon_sym_AT] = ACTIONS(294),
    [anon_sym_LT_PIPE] = ACTIONS(292),
    [anon_sym_AMP_AMP] = ACTIONS(292),
    [anon_sym_PIPE_PIPE] = ACTIONS(292),
    [anon_sym_QMARK_QMARK] = ACTIONS(292),
    [anon_sym_QMARK_COLON] = ACTIONS(292),
    [anon_sym_BANG_EQ] = ACTIONS(292),
    [anon_sym_EQ_EQ] = ACTIONS(292),
    [anon_sym_QMARK_EQ] = ACTIONS(292),
    [anon_sym_STAR_EQ] = ACTIONS(292),
    [anon_sym_TILDE] = ACTIONS(292),
    [anon_sym_BANG_TILDE] = ACTIONS(292),
    [anon_sym_STAR_TILDE] = ACTIONS(292),
    [anon_sym_LT_EQ] = ACTIONS(292),
    [anon_sym_GT_EQ] = ACTIONS(292),
    [anon_sym_PLUS] = ACTIONS(294),
    [anon_sym_PLUS_EQ] = ACTIONS(292),
    [anon_sym_DASH_EQ] = ACTIONS(292),
    [anon_sym_u00d7] = ACTIONS(292),
    [anon_sym_SLASH] = ACTIONS(294),
    [anon_sym_u00f7] = ACTIONS(292),
    [anon_sym_STAR_STAR] = ACTIONS(292),
    [anon_sym_u220b] = ACTIONS(292),
    [anon_sym_u220c] = ACTIONS(292),
    [anon_sym_u2287] = ACTIONS(292),
    [anon_sym_u2283] = ACTIONS(292),
    [anon_sym_u2285] = ACTIONS(292),
    [anon_sym_u2208] = ACTIONS(292),
    [anon_sym_u2209] = ACTIONS(292),
    [anon_sym_u2286] = ACTIONS(292),
    [anon_sym_u2282] = ACTIONS(292),
    [anon_sym_u2284] = ACTIONS(292),
    [anon_sym_AT_AT] = ACTIONS(292),
  },
  [STATE(336)] = {
    [ts_builtin_sym_end] = ACTIONS(190),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(190),
    [sym_keyword_explain] = ACTIONS(190),
    [sym_keyword_parallel] = ACTIONS(190),
    [sym_keyword_timeout] = ACTIONS(190),
    [sym_keyword_fetch] = ACTIONS(190),
    [sym_keyword_limit] = ACTIONS(190),
    [sym_keyword_order] = ACTIONS(190),
    [sym_keyword_with] = ACTIONS(190),
    [sym_keyword_where] = ACTIONS(190),
    [sym_keyword_split] = ACTIONS(190),
    [sym_keyword_group] = ACTIONS(190),
    [sym_keyword_and] = ACTIONS(190),
    [sym_keyword_or] = ACTIONS(192),
    [sym_keyword_is] = ACTIONS(190),
    [sym_keyword_not] = ACTIONS(192),
    [sym_keyword_contains] = ACTIONS(192),
    [sym_keyword_contains_not] = ACTIONS(190),
    [sym_keyword_contains_all] = ACTIONS(190),
    [sym_keyword_contains_any] = ACTIONS(190),
    [sym_keyword_contains_none] = ACTIONS(190),
    [sym_keyword_inside] = ACTIONS(190),
    [sym_keyword_in] = ACTIONS(192),
    [sym_keyword_not_inside] = ACTIONS(190),
    [sym_keyword_all_inside] = ACTIONS(190),
    [sym_keyword_any_inside] = ACTIONS(190),
    [sym_keyword_none_inside] = ACTIONS(190),
    [sym_keyword_outside] = ACTIONS(190),
    [sym_keyword_intersects] = ACTIONS(190),
    [anon_sym_EQ] = ACTIONS(192),
    [anon_sym_COMMA] = ACTIONS(190),
    [anon_sym_DASH_GT] = ACTIONS(190),
    [anon_sym_LBRACK] = ACTIONS(190),
    [anon_sym_LT] = ACTIONS(192),
    [anon_sym_GT] = ACTIONS(192),
    [anon_sym_LT_DASH] = ACTIONS(192),
    [anon_sym_LT_DASH_GT] = ACTIONS(190),
    [anon_sym_STAR] = ACTIONS(192),
    [anon_sym_DOT] = ACTIONS(190),
    [anon_sym_DASH] = ACTIONS(192),
    [anon_sym_PERCENT] = ACTIONS(190),
    [anon_sym_AT] = ACTIONS(192),
    [anon_sym_LT_PIPE] = ACTIONS(190),
    [anon_sym_AMP_AMP] = ACTIONS(190),
    [anon_sym_PIPE_PIPE] = ACTIONS(190),
    [anon_sym_QMARK_QMARK] = ACTIONS(190),
    [anon_sym_QMARK_COLON] = ACTIONS(190),
    [anon_sym_BANG_EQ] = ACTIONS(190),
    [anon_sym_EQ_EQ] = ACTIONS(190),
    [anon_sym_QMARK_EQ] = ACTIONS(190),
    [anon_sym_STAR_EQ] = ACTIONS(190),
    [anon_sym_TILDE] = ACTIONS(190),
    [anon_sym_BANG_TILDE] = ACTIONS(190),
    [anon_sym_STAR_TILDE] = ACTIONS(190),
    [anon_sym_LT_EQ] = ACTIONS(190),
    [anon_sym_GT_EQ] = ACTIONS(190),
    [anon_sym_PLUS] = ACTIONS(192),
    [anon_sym_PLUS_EQ] = ACTIONS(190),
    [anon_sym_DASH_EQ] = ACTIONS(190),
    [anon_sym_u00d7] = ACTIONS(190),
    [anon_sym_SLASH] = ACTIONS(192),
    [anon_sym_u00f7] = ACTIONS(190),
    [anon_sym_STAR_STAR] = ACTIONS(190),
    [anon_sym_u220b] = ACTIONS(190),
    [anon_sym_u220c] = ACTIONS(190),
    [anon_sym_u2287] = ACTIONS(190),
    [anon_sym_u2283] = ACTIONS(190),
    [anon_sym_u2285] = ACTIONS(190),
    [anon_sym_u2208] = ACTIONS(190),
    [anon_sym_u2209] = ACTIONS(190),
    [anon_sym_u2286] = ACTIONS(190),
    [anon_sym_u2282] = ACTIONS(190),
    [anon_sym_u2284] = ACTIONS(190),
    [anon_sym_AT_AT] = ACTIONS(190),
  },
  [STATE(337)] = {
    [ts_builtin_sym_end] = ACTIONS(337),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(337),
    [sym_keyword_explain] = ACTIONS(337),
    [sym_keyword_parallel] = ACTIONS(337),
    [sym_keyword_timeout] = ACTIONS(337),
    [sym_keyword_fetch] = ACTIONS(337),
    [sym_keyword_limit] = ACTIONS(337),
    [sym_keyword_order] = ACTIONS(337),
    [sym_keyword_with] = ACTIONS(337),
    [sym_keyword_where] = ACTIONS(337),
    [sym_keyword_split] = ACTIONS(337),
    [sym_keyword_group] = ACTIONS(337),
    [sym_keyword_and] = ACTIONS(337),
    [sym_keyword_or] = ACTIONS(339),
    [sym_keyword_is] = ACTIONS(337),
    [sym_keyword_not] = ACTIONS(339),
    [sym_keyword_contains] = ACTIONS(339),
    [sym_keyword_contains_not] = ACTIONS(337),
    [sym_keyword_contains_all] = ACTIONS(337),
    [sym_keyword_contains_any] = ACTIONS(337),
    [sym_keyword_contains_none] = ACTIONS(337),
    [sym_keyword_inside] = ACTIONS(337),
    [sym_keyword_in] = ACTIONS(339),
    [sym_keyword_not_inside] = ACTIONS(337),
    [sym_keyword_all_inside] = ACTIONS(337),
    [sym_keyword_any_inside] = ACTIONS(337),
    [sym_keyword_none_inside] = ACTIONS(337),
    [sym_keyword_outside] = ACTIONS(337),
    [sym_keyword_intersects] = ACTIONS(337),
    [anon_sym_EQ] = ACTIONS(339),
    [anon_sym_COMMA] = ACTIONS(337),
    [anon_sym_DASH_GT] = ACTIONS(337),
    [anon_sym_LBRACK] = ACTIONS(337),
    [anon_sym_LT] = ACTIONS(339),
    [anon_sym_GT] = ACTIONS(339),
    [anon_sym_LT_DASH] = ACTIONS(339),
    [anon_sym_LT_DASH_GT] = ACTIONS(337),
    [anon_sym_STAR] = ACTIONS(339),
    [anon_sym_DOT] = ACTIONS(337),
    [anon_sym_DASH] = ACTIONS(339),
    [anon_sym_PERCENT] = ACTIONS(337),
    [anon_sym_AT] = ACTIONS(339),
    [anon_sym_LT_PIPE] = ACTIONS(337),
    [anon_sym_AMP_AMP] = ACTIONS(337),
    [anon_sym_PIPE_PIPE] = ACTIONS(337),
    [anon_sym_QMARK_QMARK] = ACTIONS(337),
    [anon_sym_QMARK_COLON] = ACTIONS(337),
    [anon_sym_BANG_EQ] = ACTIONS(337),
    [anon_sym_EQ_EQ] = ACTIONS(337),
    [anon_sym_QMARK_EQ] = ACTIONS(337),
    [anon_sym_STAR_EQ] = ACTIONS(337),
    [anon_sym_TILDE] = ACTIONS(337),
    [anon_sym_BANG_TILDE] = ACTIONS(337),
    [anon_sym_STAR_TILDE] = ACTIONS(337),
    [anon_sym_LT_EQ] = ACTIONS(337),
    [anon_sym_GT_EQ] = ACTIONS(337),
    [anon_sym_PLUS] = ACTIONS(339),
    [anon_sym_PLUS_EQ] = ACTIONS(337),
    [anon_sym_DASH_EQ] = ACTIONS(337),
    [anon_sym_u00d7] = ACTIONS(337),
    [anon_sym_SLASH] = ACTIONS(339),
    [anon_sym_u00f7] = ACTIONS(337),
    [anon_sym_STAR_STAR] = ACTIONS(337),
    [anon_sym_u220b] = ACTIONS(337),
    [anon_sym_u220c] = ACTIONS(337),
    [anon_sym_u2287] = ACTIONS(337),
    [anon_sym_u2283] = ACTIONS(337),
    [anon_sym_u2285] = ACTIONS(337),
    [anon_sym_u2208] = ACTIONS(337),
    [anon_sym_u2209] = ACTIONS(337),
    [anon_sym_u2286] = ACTIONS(337),
    [anon_sym_u2282] = ACTIONS(337),
    [anon_sym_u2284] = ACTIONS(337),
    [anon_sym_AT_AT] = ACTIONS(337),
  },
  [STATE(338)] = {
    [ts_builtin_sym_end] = ACTIONS(260),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(260),
    [sym_keyword_explain] = ACTIONS(260),
    [sym_keyword_parallel] = ACTIONS(260),
    [sym_keyword_timeout] = ACTIONS(260),
    [sym_keyword_fetch] = ACTIONS(260),
    [sym_keyword_limit] = ACTIONS(260),
    [sym_keyword_order] = ACTIONS(260),
    [sym_keyword_with] = ACTIONS(260),
    [sym_keyword_where] = ACTIONS(260),
    [sym_keyword_split] = ACTIONS(260),
    [sym_keyword_group] = ACTIONS(260),
    [sym_keyword_and] = ACTIONS(260),
    [sym_keyword_or] = ACTIONS(262),
    [sym_keyword_is] = ACTIONS(260),
    [sym_keyword_not] = ACTIONS(262),
    [sym_keyword_contains] = ACTIONS(262),
    [sym_keyword_contains_not] = ACTIONS(260),
    [sym_keyword_contains_all] = ACTIONS(260),
    [sym_keyword_contains_any] = ACTIONS(260),
    [sym_keyword_contains_none] = ACTIONS(260),
    [sym_keyword_inside] = ACTIONS(260),
    [sym_keyword_in] = ACTIONS(262),
    [sym_keyword_not_inside] = ACTIONS(260),
    [sym_keyword_all_inside] = ACTIONS(260),
    [sym_keyword_any_inside] = ACTIONS(260),
    [sym_keyword_none_inside] = ACTIONS(260),
    [sym_keyword_outside] = ACTIONS(260),
    [sym_keyword_intersects] = ACTIONS(260),
    [anon_sym_EQ] = ACTIONS(262),
    [anon_sym_COMMA] = ACTIONS(260),
    [anon_sym_DASH_GT] = ACTIONS(260),
    [anon_sym_LBRACK] = ACTIONS(260),
    [anon_sym_LT] = ACTIONS(262),
    [anon_sym_GT] = ACTIONS(262),
    [anon_sym_LT_DASH] = ACTIONS(262),
    [anon_sym_LT_DASH_GT] = ACTIONS(260),
    [anon_sym_STAR] = ACTIONS(262),
    [anon_sym_DOT] = ACTIONS(260),
    [anon_sym_DASH] = ACTIONS(262),
    [anon_sym_PERCENT] = ACTIONS(260),
    [anon_sym_AT] = ACTIONS(262),
    [anon_sym_LT_PIPE] = ACTIONS(260),
    [anon_sym_AMP_AMP] = ACTIONS(260),
    [anon_sym_PIPE_PIPE] = ACTIONS(260),
    [anon_sym_QMARK_QMARK] = ACTIONS(260),
    [anon_sym_QMARK_COLON] = ACTIONS(260),
    [anon_sym_BANG_EQ] = ACTIONS(260),
    [anon_sym_EQ_EQ] = ACTIONS(260),
    [anon_sym_QMARK_EQ] = ACTIONS(260),
    [anon_sym_STAR_EQ] = ACTIONS(260),
    [anon_sym_TILDE] = ACTIONS(260),
    [anon_sym_BANG_TILDE] = ACTIONS(260),
    [anon_sym_STAR_TILDE] = ACTIONS(260),
    [anon_sym_LT_EQ] = ACTIONS(260),
    [anon_sym_GT_EQ] = ACTIONS(260),
    [anon_sym_PLUS] = ACTIONS(262),
    [anon_sym_PLUS_EQ] = ACTIONS(260),
    [anon_sym_DASH_EQ] = ACTIONS(260),
    [anon_sym_u00d7] = ACTIONS(260),
    [anon_sym_SLASH] = ACTIONS(262),
    [anon_sym_u00f7] = ACTIONS(260),
    [anon_sym_STAR_STAR] = ACTIONS(260),
    [anon_sym_u220b] = ACTIONS(260),
    [anon_sym_u220c] = ACTIONS(260),
    [anon_sym_u2287] = ACTIONS(260),
    [anon_sym_u2283] = ACTIONS(260),
    [anon_sym_u2285] = ACTIONS(260),
    [anon_sym_u2208] = ACTIONS(260),
    [anon_sym_u2209] = ACTIONS(260),
    [anon_sym_u2286] = ACTIONS(260),
    [anon_sym_u2282] = ACTIONS(260),
    [anon_sym_u2284] = ACTIONS(260),
    [anon_sym_AT_AT] = ACTIONS(260),
  },
  [STATE(339)] = {
    [ts_builtin_sym_end] = ACTIONS(296),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(296),
    [sym_keyword_explain] = ACTIONS(296),
    [sym_keyword_parallel] = ACTIONS(296),
    [sym_keyword_timeout] = ACTIONS(296),
    [sym_keyword_fetch] = ACTIONS(296),
    [sym_keyword_limit] = ACTIONS(296),
    [sym_keyword_order] = ACTIONS(296),
    [sym_keyword_with] = ACTIONS(296),
    [sym_keyword_where] = ACTIONS(296),
    [sym_keyword_split] = ACTIONS(296),
    [sym_keyword_group] = ACTIONS(296),
    [sym_keyword_and] = ACTIONS(296),
    [sym_keyword_or] = ACTIONS(298),
    [sym_keyword_is] = ACTIONS(296),
    [sym_keyword_not] = ACTIONS(298),
    [sym_keyword_contains] = ACTIONS(298),
    [sym_keyword_contains_not] = ACTIONS(296),
    [sym_keyword_contains_all] = ACTIONS(296),
    [sym_keyword_contains_any] = ACTIONS(296),
    [sym_keyword_contains_none] = ACTIONS(296),
    [sym_keyword_inside] = ACTIONS(296),
    [sym_keyword_in] = ACTIONS(298),
    [sym_keyword_not_inside] = ACTIONS(296),
    [sym_keyword_all_inside] = ACTIONS(296),
    [sym_keyword_any_inside] = ACTIONS(296),
    [sym_keyword_none_inside] = ACTIONS(296),
    [sym_keyword_outside] = ACTIONS(296),
    [sym_keyword_intersects] = ACTIONS(296),
    [anon_sym_EQ] = ACTIONS(298),
    [anon_sym_COMMA] = ACTIONS(296),
    [anon_sym_DASH_GT] = ACTIONS(296),
    [anon_sym_LBRACK] = ACTIONS(296),
    [anon_sym_LT] = ACTIONS(298),
    [anon_sym_GT] = ACTIONS(298),
    [anon_sym_LT_DASH] = ACTIONS(298),
    [anon_sym_LT_DASH_GT] = ACTIONS(296),
    [anon_sym_STAR] = ACTIONS(298),
    [anon_sym_DOT] = ACTIONS(296),
    [anon_sym_DASH] = ACTIONS(298),
    [anon_sym_PERCENT] = ACTIONS(296),
    [anon_sym_AT] = ACTIONS(298),
    [anon_sym_LT_PIPE] = ACTIONS(296),
    [anon_sym_AMP_AMP] = ACTIONS(296),
    [anon_sym_PIPE_PIPE] = ACTIONS(296),
    [anon_sym_QMARK_QMARK] = ACTIONS(296),
    [anon_sym_QMARK_COLON] = ACTIONS(296),
    [anon_sym_BANG_EQ] = ACTIONS(296),
    [anon_sym_EQ_EQ] = ACTIONS(296),
    [anon_sym_QMARK_EQ] = ACTIONS(296),
    [anon_sym_STAR_EQ] = ACTIONS(296),
    [anon_sym_TILDE] = ACTIONS(296),
    [anon_sym_BANG_TILDE] = ACTIONS(296),
    [anon_sym_STAR_TILDE] = ACTIONS(296),
    [anon_sym_LT_EQ] = ACTIONS(296),
    [anon_sym_GT_EQ] = ACTIONS(296),
    [anon_sym_PLUS] = ACTIONS(298),
    [anon_sym_PLUS_EQ] = ACTIONS(296),
    [anon_sym_DASH_EQ] = ACTIONS(296),
    [anon_sym_u00d7] = ACTIONS(296),
    [anon_sym_SLASH] = ACTIONS(298),
    [anon_sym_u00f7] = ACTIONS(296),
    [anon_sym_STAR_STAR] = ACTIONS(296),
    [anon_sym_u220b] = ACTIONS(296),
    [anon_sym_u220c] = ACTIONS(296),
    [anon_sym_u2287] = ACTIONS(296),
    [anon_sym_u2283] = ACTIONS(296),
    [anon_sym_u2285] = ACTIONS(296),
    [anon_sym_u2208] = ACTIONS(296),
    [anon_sym_u2209] = ACTIONS(296),
    [anon_sym_u2286] = ACTIONS(296),
    [anon_sym_u2282] = ACTIONS(296),
    [anon_sym_u2284] = ACTIONS(296),
    [anon_sym_AT_AT] = ACTIONS(296),
  },
  [STATE(340)] = {
    [ts_builtin_sym_end] = ACTIONS(343),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(343),
    [sym_keyword_explain] = ACTIONS(343),
    [sym_keyword_parallel] = ACTIONS(343),
    [sym_keyword_timeout] = ACTIONS(343),
    [sym_keyword_fetch] = ACTIONS(343),
    [sym_keyword_limit] = ACTIONS(343),
    [sym_keyword_order] = ACTIONS(343),
    [sym_keyword_with] = ACTIONS(343),
    [sym_keyword_where] = ACTIONS(343),
    [sym_keyword_split] = ACTIONS(343),
    [sym_keyword_group] = ACTIONS(343),
    [sym_keyword_and] = ACTIONS(343),
    [sym_keyword_or] = ACTIONS(345),
    [sym_keyword_is] = ACTIONS(343),
    [sym_keyword_not] = ACTIONS(345),
    [sym_keyword_contains] = ACTIONS(345),
    [sym_keyword_contains_not] = ACTIONS(343),
    [sym_keyword_contains_all] = ACTIONS(343),
    [sym_keyword_contains_any] = ACTIONS(343),
    [sym_keyword_contains_none] = ACTIONS(343),
    [sym_keyword_inside] = ACTIONS(343),
    [sym_keyword_in] = ACTIONS(345),
    [sym_keyword_not_inside] = ACTIONS(343),
    [sym_keyword_all_inside] = ACTIONS(343),
    [sym_keyword_any_inside] = ACTIONS(343),
    [sym_keyword_none_inside] = ACTIONS(343),
    [sym_keyword_outside] = ACTIONS(343),
    [sym_keyword_intersects] = ACTIONS(343),
    [anon_sym_EQ] = ACTIONS(345),
    [anon_sym_COMMA] = ACTIONS(343),
    [anon_sym_DASH_GT] = ACTIONS(343),
    [anon_sym_LBRACK] = ACTIONS(343),
    [anon_sym_LT] = ACTIONS(345),
    [anon_sym_GT] = ACTIONS(345),
    [anon_sym_LT_DASH] = ACTIONS(345),
    [anon_sym_LT_DASH_GT] = ACTIONS(343),
    [anon_sym_STAR] = ACTIONS(345),
    [anon_sym_DOT] = ACTIONS(343),
    [anon_sym_DASH] = ACTIONS(345),
    [anon_sym_PERCENT] = ACTIONS(343),
    [anon_sym_AT] = ACTIONS(345),
    [anon_sym_LT_PIPE] = ACTIONS(343),
    [anon_sym_AMP_AMP] = ACTIONS(343),
    [anon_sym_PIPE_PIPE] = ACTIONS(343),
    [anon_sym_QMARK_QMARK] = ACTIONS(343),
    [anon_sym_QMARK_COLON] = ACTIONS(343),
    [anon_sym_BANG_EQ] = ACTIONS(343),
    [anon_sym_EQ_EQ] = ACTIONS(343),
    [anon_sym_QMARK_EQ] = ACTIONS(343),
    [anon_sym_STAR_EQ] = ACTIONS(343),
    [anon_sym_TILDE] = ACTIONS(343),
    [anon_sym_BANG_TILDE] = ACTIONS(343),
    [anon_sym_STAR_TILDE] = ACTIONS(343),
    [anon_sym_LT_EQ] = ACTIONS(343),
    [anon_sym_GT_EQ] = ACTIONS(343),
    [anon_sym_PLUS] = ACTIONS(345),
    [anon_sym_PLUS_EQ] = ACTIONS(343),
    [anon_sym_DASH_EQ] = ACTIONS(343),
    [anon_sym_u00d7] = ACTIONS(343),
    [anon_sym_SLASH] = ACTIONS(345),
    [anon_sym_u00f7] = ACTIONS(343),
    [anon_sym_STAR_STAR] = ACTIONS(343),
    [anon_sym_u220b] = ACTIONS(343),
    [anon_sym_u220c] = ACTIONS(343),
    [anon_sym_u2287] = ACTIONS(343),
    [anon_sym_u2283] = ACTIONS(343),
    [anon_sym_u2285] = ACTIONS(343),
    [anon_sym_u2208] = ACTIONS(343),
    [anon_sym_u2209] = ACTIONS(343),
    [anon_sym_u2286] = ACTIONS(343),
    [anon_sym_u2282] = ACTIONS(343),
    [anon_sym_u2284] = ACTIONS(343),
    [anon_sym_AT_AT] = ACTIONS(343),
  },
  [STATE(341)] = {
    [ts_builtin_sym_end] = ACTIONS(359),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(359),
    [sym_keyword_explain] = ACTIONS(359),
    [sym_keyword_parallel] = ACTIONS(359),
    [sym_keyword_timeout] = ACTIONS(359),
    [sym_keyword_fetch] = ACTIONS(359),
    [sym_keyword_limit] = ACTIONS(359),
    [sym_keyword_order] = ACTIONS(359),
    [sym_keyword_with] = ACTIONS(359),
    [sym_keyword_where] = ACTIONS(359),
    [sym_keyword_split] = ACTIONS(359),
    [sym_keyword_group] = ACTIONS(359),
    [sym_keyword_and] = ACTIONS(359),
    [sym_keyword_or] = ACTIONS(361),
    [sym_keyword_is] = ACTIONS(359),
    [sym_keyword_not] = ACTIONS(361),
    [sym_keyword_contains] = ACTIONS(361),
    [sym_keyword_contains_not] = ACTIONS(359),
    [sym_keyword_contains_all] = ACTIONS(359),
    [sym_keyword_contains_any] = ACTIONS(359),
    [sym_keyword_contains_none] = ACTIONS(359),
    [sym_keyword_inside] = ACTIONS(359),
    [sym_keyword_in] = ACTIONS(361),
    [sym_keyword_not_inside] = ACTIONS(359),
    [sym_keyword_all_inside] = ACTIONS(359),
    [sym_keyword_any_inside] = ACTIONS(359),
    [sym_keyword_none_inside] = ACTIONS(359),
    [sym_keyword_outside] = ACTIONS(359),
    [sym_keyword_intersects] = ACTIONS(359),
    [anon_sym_EQ] = ACTIONS(361),
    [anon_sym_COMMA] = ACTIONS(359),
    [anon_sym_DASH_GT] = ACTIONS(359),
    [anon_sym_LBRACK] = ACTIONS(359),
    [anon_sym_LT] = ACTIONS(361),
    [anon_sym_GT] = ACTIONS(361),
    [anon_sym_LT_DASH] = ACTIONS(361),
    [anon_sym_LT_DASH_GT] = ACTIONS(359),
    [anon_sym_STAR] = ACTIONS(361),
    [anon_sym_DOT] = ACTIONS(359),
    [anon_sym_DASH] = ACTIONS(361),
    [anon_sym_PERCENT] = ACTIONS(359),
    [anon_sym_AT] = ACTIONS(361),
    [anon_sym_LT_PIPE] = ACTIONS(359),
    [anon_sym_AMP_AMP] = ACTIONS(359),
    [anon_sym_PIPE_PIPE] = ACTIONS(359),
    [anon_sym_QMARK_QMARK] = ACTIONS(359),
    [anon_sym_QMARK_COLON] = ACTIONS(359),
    [anon_sym_BANG_EQ] = ACTIONS(359),
    [anon_sym_EQ_EQ] = ACTIONS(359),
    [anon_sym_QMARK_EQ] = ACTIONS(359),
    [anon_sym_STAR_EQ] = ACTIONS(359),
    [anon_sym_TILDE] = ACTIONS(359),
    [anon_sym_BANG_TILDE] = ACTIONS(359),
    [anon_sym_STAR_TILDE] = ACTIONS(359),
    [anon_sym_LT_EQ] = ACTIONS(359),
    [anon_sym_GT_EQ] = ACTIONS(359),
    [anon_sym_PLUS] = ACTIONS(361),
    [anon_sym_PLUS_EQ] = ACTIONS(359),
    [anon_sym_DASH_EQ] = ACTIONS(359),
    [anon_sym_u00d7] = ACTIONS(359),
    [anon_sym_SLASH] = ACTIONS(361),
    [anon_sym_u00f7] = ACTIONS(359),
    [anon_sym_STAR_STAR] = ACTIONS(359),
    [anon_sym_u220b] = ACTIONS(359),
    [anon_sym_u220c] = ACTIONS(359),
    [anon_sym_u2287] = ACTIONS(359),
    [anon_sym_u2283] = ACTIONS(359),
    [anon_sym_u2285] = ACTIONS(359),
    [anon_sym_u2208] = ACTIONS(359),
    [anon_sym_u2209] = ACTIONS(359),
    [anon_sym_u2286] = ACTIONS(359),
    [anon_sym_u2282] = ACTIONS(359),
    [anon_sym_u2284] = ACTIONS(359),
    [anon_sym_AT_AT] = ACTIONS(359),
  },
  [STATE(342)] = {
    [ts_builtin_sym_end] = ACTIONS(186),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(186),
    [sym_keyword_explain] = ACTIONS(186),
    [sym_keyword_parallel] = ACTIONS(186),
    [sym_keyword_timeout] = ACTIONS(186),
    [sym_keyword_fetch] = ACTIONS(186),
    [sym_keyword_limit] = ACTIONS(186),
    [sym_keyword_order] = ACTIONS(186),
    [sym_keyword_with] = ACTIONS(186),
    [sym_keyword_where] = ACTIONS(186),
    [sym_keyword_split] = ACTIONS(186),
    [sym_keyword_group] = ACTIONS(186),
    [sym_keyword_and] = ACTIONS(186),
    [sym_keyword_or] = ACTIONS(188),
    [sym_keyword_is] = ACTIONS(186),
    [sym_keyword_not] = ACTIONS(188),
    [sym_keyword_contains] = ACTIONS(188),
    [sym_keyword_contains_not] = ACTIONS(186),
    [sym_keyword_contains_all] = ACTIONS(186),
    [sym_keyword_contains_any] = ACTIONS(186),
    [sym_keyword_contains_none] = ACTIONS(186),
    [sym_keyword_inside] = ACTIONS(186),
    [sym_keyword_in] = ACTIONS(188),
    [sym_keyword_not_inside] = ACTIONS(186),
    [sym_keyword_all_inside] = ACTIONS(186),
    [sym_keyword_any_inside] = ACTIONS(186),
    [sym_keyword_none_inside] = ACTIONS(186),
    [sym_keyword_outside] = ACTIONS(186),
    [sym_keyword_intersects] = ACTIONS(186),
    [anon_sym_EQ] = ACTIONS(188),
    [anon_sym_COMMA] = ACTIONS(186),
    [anon_sym_DASH_GT] = ACTIONS(186),
    [anon_sym_LBRACK] = ACTIONS(186),
    [anon_sym_LT] = ACTIONS(188),
    [anon_sym_GT] = ACTIONS(188),
    [anon_sym_LT_DASH] = ACTIONS(188),
    [anon_sym_LT_DASH_GT] = ACTIONS(186),
    [anon_sym_STAR] = ACTIONS(188),
    [anon_sym_DOT] = ACTIONS(186),
    [anon_sym_DASH] = ACTIONS(188),
    [anon_sym_PERCENT] = ACTIONS(186),
    [anon_sym_AT] = ACTIONS(188),
    [anon_sym_LT_PIPE] = ACTIONS(186),
    [anon_sym_AMP_AMP] = ACTIONS(186),
    [anon_sym_PIPE_PIPE] = ACTIONS(186),
    [anon_sym_QMARK_QMARK] = ACTIONS(186),
    [anon_sym_QMARK_COLON] = ACTIONS(186),
    [anon_sym_BANG_EQ] = ACTIONS(186),
    [anon_sym_EQ_EQ] = ACTIONS(186),
    [anon_sym_QMARK_EQ] = ACTIONS(186),
    [anon_sym_STAR_EQ] = ACTIONS(186),
    [anon_sym_TILDE] = ACTIONS(186),
    [anon_sym_BANG_TILDE] = ACTIONS(186),
    [anon_sym_STAR_TILDE] = ACTIONS(186),
    [anon_sym_LT_EQ] = ACTIONS(186),
    [anon_sym_GT_EQ] = ACTIONS(186),
    [anon_sym_PLUS] = ACTIONS(188),
    [anon_sym_PLUS_EQ] = ACTIONS(186),
    [anon_sym_DASH_EQ] = ACTIONS(186),
    [anon_sym_u00d7] = ACTIONS(186),
    [anon_sym_SLASH] = ACTIONS(188),
    [anon_sym_u00f7] = ACTIONS(186),
    [anon_sym_STAR_STAR] = ACTIONS(186),
    [anon_sym_u220b] = ACTIONS(186),
    [anon_sym_u220c] = ACTIONS(186),
    [anon_sym_u2287] = ACTIONS(186),
    [anon_sym_u2283] = ACTIONS(186),
    [anon_sym_u2285] = ACTIONS(186),
    [anon_sym_u2208] = ACTIONS(186),
    [anon_sym_u2209] = ACTIONS(186),
    [anon_sym_u2286] = ACTIONS(186),
    [anon_sym_u2282] = ACTIONS(186),
    [anon_sym_u2284] = ACTIONS(186),
    [anon_sym_AT_AT] = ACTIONS(186),
  },
  [STATE(343)] = {
    [ts_builtin_sym_end] = ACTIONS(351),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(351),
    [sym_keyword_explain] = ACTIONS(351),
    [sym_keyword_parallel] = ACTIONS(351),
    [sym_keyword_timeout] = ACTIONS(351),
    [sym_keyword_fetch] = ACTIONS(351),
    [sym_keyword_limit] = ACTIONS(351),
    [sym_keyword_order] = ACTIONS(351),
    [sym_keyword_with] = ACTIONS(351),
    [sym_keyword_where] = ACTIONS(351),
    [sym_keyword_split] = ACTIONS(351),
    [sym_keyword_group] = ACTIONS(351),
    [sym_keyword_and] = ACTIONS(351),
    [sym_keyword_or] = ACTIONS(353),
    [sym_keyword_is] = ACTIONS(351),
    [sym_keyword_not] = ACTIONS(353),
    [sym_keyword_contains] = ACTIONS(353),
    [sym_keyword_contains_not] = ACTIONS(351),
    [sym_keyword_contains_all] = ACTIONS(351),
    [sym_keyword_contains_any] = ACTIONS(351),
    [sym_keyword_contains_none] = ACTIONS(351),
    [sym_keyword_inside] = ACTIONS(351),
    [sym_keyword_in] = ACTIONS(353),
    [sym_keyword_not_inside] = ACTIONS(351),
    [sym_keyword_all_inside] = ACTIONS(351),
    [sym_keyword_any_inside] = ACTIONS(351),
    [sym_keyword_none_inside] = ACTIONS(351),
    [sym_keyword_outside] = ACTIONS(351),
    [sym_keyword_intersects] = ACTIONS(351),
    [anon_sym_EQ] = ACTIONS(353),
    [anon_sym_COMMA] = ACTIONS(351),
    [anon_sym_DASH_GT] = ACTIONS(351),
    [anon_sym_LBRACK] = ACTIONS(351),
    [anon_sym_LT] = ACTIONS(353),
    [anon_sym_GT] = ACTIONS(353),
    [anon_sym_LT_DASH] = ACTIONS(353),
    [anon_sym_LT_DASH_GT] = ACTIONS(351),
    [anon_sym_STAR] = ACTIONS(353),
    [anon_sym_DOT] = ACTIONS(351),
    [anon_sym_DASH] = ACTIONS(353),
    [anon_sym_PERCENT] = ACTIONS(351),
    [anon_sym_AT] = ACTIONS(353),
    [anon_sym_LT_PIPE] = ACTIONS(351),
    [anon_sym_AMP_AMP] = ACTIONS(351),
    [anon_sym_PIPE_PIPE] = ACTIONS(351),
    [anon_sym_QMARK_QMARK] = ACTIONS(351),
    [anon_sym_QMARK_COLON] = ACTIONS(351),
    [anon_sym_BANG_EQ] = ACTIONS(351),
    [anon_sym_EQ_EQ] = ACTIONS(351),
    [anon_sym_QMARK_EQ] = ACTIONS(351),
    [anon_sym_STAR_EQ] = ACTIONS(351),
    [anon_sym_TILDE] = ACTIONS(351),
    [anon_sym_BANG_TILDE] = ACTIONS(351),
    [anon_sym_STAR_TILDE] = ACTIONS(351),
    [anon_sym_LT_EQ] = ACTIONS(351),
    [anon_sym_GT_EQ] = ACTIONS(351),
    [anon_sym_PLUS] = ACTIONS(353),
    [anon_sym_PLUS_EQ] = ACTIONS(351),
    [anon_sym_DASH_EQ] = ACTIONS(351),
    [anon_sym_u00d7] = ACTIONS(351),
    [anon_sym_SLASH] = ACTIONS(353),
    [anon_sym_u00f7] = ACTIONS(351),
    [anon_sym_STAR_STAR] = ACTIONS(351),
    [anon_sym_u220b] = ACTIONS(351),
    [anon_sym_u220c] = ACTIONS(351),
    [anon_sym_u2287] = ACTIONS(351),
    [anon_sym_u2283] = ACTIONS(351),
    [anon_sym_u2285] = ACTIONS(351),
    [anon_sym_u2208] = ACTIONS(351),
    [anon_sym_u2209] = ACTIONS(351),
    [anon_sym_u2286] = ACTIONS(351),
    [anon_sym_u2282] = ACTIONS(351),
    [anon_sym_u2284] = ACTIONS(351),
    [anon_sym_AT_AT] = ACTIONS(351),
  },
  [STATE(344)] = {
    [ts_builtin_sym_end] = ACTIONS(355),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_order] = ACTIONS(355),
    [sym_keyword_with] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_split] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(357),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(345)] = {
    [ts_builtin_sym_end] = ACTIONS(355),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(355),
    [sym_keyword_explain] = ACTIONS(355),
    [sym_keyword_parallel] = ACTIONS(355),
    [sym_keyword_timeout] = ACTIONS(355),
    [sym_keyword_fetch] = ACTIONS(355),
    [sym_keyword_limit] = ACTIONS(355),
    [sym_keyword_order] = ACTIONS(355),
    [sym_keyword_with] = ACTIONS(355),
    [sym_keyword_where] = ACTIONS(355),
    [sym_keyword_split] = ACTIONS(355),
    [sym_keyword_group] = ACTIONS(355),
    [sym_keyword_and] = ACTIONS(355),
    [sym_keyword_or] = ACTIONS(357),
    [sym_keyword_is] = ACTIONS(355),
    [sym_keyword_not] = ACTIONS(357),
    [sym_keyword_contains] = ACTIONS(357),
    [sym_keyword_contains_not] = ACTIONS(355),
    [sym_keyword_contains_all] = ACTIONS(355),
    [sym_keyword_contains_any] = ACTIONS(355),
    [sym_keyword_contains_none] = ACTIONS(355),
    [sym_keyword_inside] = ACTIONS(355),
    [sym_keyword_in] = ACTIONS(357),
    [sym_keyword_not_inside] = ACTIONS(355),
    [sym_keyword_all_inside] = ACTIONS(355),
    [sym_keyword_any_inside] = ACTIONS(355),
    [sym_keyword_none_inside] = ACTIONS(355),
    [sym_keyword_outside] = ACTIONS(355),
    [sym_keyword_intersects] = ACTIONS(355),
    [anon_sym_EQ] = ACTIONS(357),
    [anon_sym_COMMA] = ACTIONS(355),
    [anon_sym_DASH_GT] = ACTIONS(355),
    [anon_sym_LBRACK] = ACTIONS(355),
    [anon_sym_LT] = ACTIONS(357),
    [anon_sym_GT] = ACTIONS(357),
    [anon_sym_LT_DASH] = ACTIONS(357),
    [anon_sym_LT_DASH_GT] = ACTIONS(355),
    [anon_sym_STAR] = ACTIONS(357),
    [anon_sym_DOT] = ACTIONS(355),
    [anon_sym_DASH] = ACTIONS(357),
    [anon_sym_PERCENT] = ACTIONS(355),
    [anon_sym_AT] = ACTIONS(357),
    [anon_sym_LT_PIPE] = ACTIONS(355),
    [anon_sym_AMP_AMP] = ACTIONS(355),
    [anon_sym_PIPE_PIPE] = ACTIONS(355),
    [anon_sym_QMARK_QMARK] = ACTIONS(355),
    [anon_sym_QMARK_COLON] = ACTIONS(355),
    [anon_sym_BANG_EQ] = ACTIONS(355),
    [anon_sym_EQ_EQ] = ACTIONS(355),
    [anon_sym_QMARK_EQ] = ACTIONS(355),
    [anon_sym_STAR_EQ] = ACTIONS(355),
    [anon_sym_TILDE] = ACTIONS(355),
    [anon_sym_BANG_TILDE] = ACTIONS(355),
    [anon_sym_STAR_TILDE] = ACTIONS(355),
    [anon_sym_LT_EQ] = ACTIONS(355),
    [anon_sym_GT_EQ] = ACTIONS(355),
    [anon_sym_PLUS] = ACTIONS(357),
    [anon_sym_PLUS_EQ] = ACTIONS(355),
    [anon_sym_DASH_EQ] = ACTIONS(355),
    [anon_sym_u00d7] = ACTIONS(355),
    [anon_sym_SLASH] = ACTIONS(357),
    [anon_sym_u00f7] = ACTIONS(355),
    [anon_sym_STAR_STAR] = ACTIONS(355),
    [anon_sym_u220b] = ACTIONS(355),
    [anon_sym_u220c] = ACTIONS(355),
    [anon_sym_u2287] = ACTIONS(355),
    [anon_sym_u2283] = ACTIONS(355),
    [anon_sym_u2285] = ACTIONS(355),
    [anon_sym_u2208] = ACTIONS(355),
    [anon_sym_u2209] = ACTIONS(355),
    [anon_sym_u2286] = ACTIONS(355),
    [anon_sym_u2282] = ACTIONS(355),
    [anon_sym_u2284] = ACTIONS(355),
    [anon_sym_AT_AT] = ACTIONS(355),
  },
  [STATE(346)] = {
    [ts_builtin_sym_end] = ACTIONS(300),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(300),
    [sym_keyword_explain] = ACTIONS(300),
    [sym_keyword_parallel] = ACTIONS(300),
    [sym_keyword_timeout] = ACTIONS(300),
    [sym_keyword_fetch] = ACTIONS(300),
    [sym_keyword_limit] = ACTIONS(300),
    [sym_keyword_order] = ACTIONS(300),
    [sym_keyword_with] = ACTIONS(300),
    [sym_keyword_where] = ACTIONS(300),
    [sym_keyword_split] = ACTIONS(300),
    [sym_keyword_group] = ACTIONS(300),
    [sym_keyword_and] = ACTIONS(300),
    [sym_keyword_or] = ACTIONS(302),
    [sym_keyword_is] = ACTIONS(300),
    [sym_keyword_not] = ACTIONS(302),
    [sym_keyword_contains] = ACTIONS(302),
    [sym_keyword_contains_not] = ACTIONS(300),
    [sym_keyword_contains_all] = ACTIONS(300),
    [sym_keyword_contains_any] = ACTIONS(300),
    [sym_keyword_contains_none] = ACTIONS(300),
    [sym_keyword_inside] = ACTIONS(300),
    [sym_keyword_in] = ACTIONS(302),
    [sym_keyword_not_inside] = ACTIONS(300),
    [sym_keyword_all_inside] = ACTIONS(300),
    [sym_keyword_any_inside] = ACTIONS(300),
    [sym_keyword_none_inside] = ACTIONS(300),
    [sym_keyword_outside] = ACTIONS(300),
    [sym_keyword_intersects] = ACTIONS(300),
    [anon_sym_EQ] = ACTIONS(302),
    [anon_sym_COMMA] = ACTIONS(300),
    [anon_sym_DASH_GT] = ACTIONS(300),
    [anon_sym_LBRACK] = ACTIONS(300),
    [anon_sym_LT] = ACTIONS(302),
    [anon_sym_GT] = ACTIONS(302),
    [anon_sym_LT_DASH] = ACTIONS(302),
    [anon_sym_LT_DASH_GT] = ACTIONS(300),
    [anon_sym_STAR] = ACTIONS(302),
    [anon_sym_DOT] = ACTIONS(300),
    [anon_sym_DASH] = ACTIONS(302),
    [anon_sym_PERCENT] = ACTIONS(300),
    [anon_sym_AT] = ACTIONS(302),
    [anon_sym_LT_PIPE] = ACTIONS(300),
    [anon_sym_AMP_AMP] = ACTIONS(300),
    [anon_sym_PIPE_PIPE] = ACTIONS(300),
    [anon_sym_QMARK_QMARK] = ACTIONS(300),
    [anon_sym_QMARK_COLON] = ACTIONS(300),
    [anon_sym_BANG_EQ] = ACTIONS(300),
    [anon_sym_EQ_EQ] = ACTIONS(300),
    [anon_sym_QMARK_EQ] = ACTIONS(300),
    [anon_sym_STAR_EQ] = ACTIONS(300),
    [anon_sym_TILDE] = ACTIONS(300),
    [anon_sym_BANG_TILDE] = ACTIONS(300),
    [anon_sym_STAR_TILDE] = ACTIONS(300),
    [anon_sym_LT_EQ] = ACTIONS(300),
    [anon_sym_GT_EQ] = ACTIONS(300),
    [anon_sym_PLUS] = ACTIONS(302),
    [anon_sym_PLUS_EQ] = ACTIONS(300),
    [anon_sym_DASH_EQ] = ACTIONS(300),
    [anon_sym_u00d7] = ACTIONS(300),
    [anon_sym_SLASH] = ACTIONS(302),
    [anon_sym_u00f7] = ACTIONS(300),
    [anon_sym_STAR_STAR] = ACTIONS(300),
    [anon_sym_u220b] = ACTIONS(300),
    [anon_sym_u220c] = ACTIONS(300),
    [anon_sym_u2287] = ACTIONS(300),
    [anon_sym_u2283] = ACTIONS(300),
    [anon_sym_u2285] = ACTIONS(300),
    [anon_sym_u2208] = ACTIONS(300),
    [anon_sym_u2209] = ACTIONS(300),
    [anon_sym_u2286] = ACTIONS(300),
    [anon_sym_u2282] = ACTIONS(300),
    [anon_sym_u2284] = ACTIONS(300),
    [anon_sym_AT_AT] = ACTIONS(300),
  },
  [STATE(347)] = {
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(314),
    [sym_keyword_order] = ACTIONS(314),
    [sym_keyword_with] = ACTIONS(314),
    [sym_keyword_where] = ACTIONS(314),
    [sym_keyword_split] = ACTIONS(314),
    [sym_keyword_group] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(314),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(314),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(314),
    [sym_keyword_contains_all] = ACTIONS(314),
    [sym_keyword_contains_any] = ACTIONS(314),
    [sym_keyword_contains_none] = ACTIONS(314),
    [sym_keyword_inside] = ACTIONS(314),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(314),
    [sym_keyword_all_inside] = ACTIONS(314),
    [sym_keyword_any_inside] = ACTIONS(314),
    [sym_keyword_none_inside] = ACTIONS(314),
    [sym_keyword_outside] = ACTIONS(314),
    [sym_keyword_intersects] = ACTIONS(314),
    [anon_sym_EQ] = ACTIONS(316),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(348)] = {
    [ts_builtin_sym_end] = ACTIONS(318),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(318),
    [sym_keyword_explain] = ACTIONS(318),
    [sym_keyword_parallel] = ACTIONS(318),
    [sym_keyword_timeout] = ACTIONS(318),
    [sym_keyword_fetch] = ACTIONS(318),
    [sym_keyword_limit] = ACTIONS(318),
    [sym_keyword_order] = ACTIONS(318),
    [sym_keyword_with] = ACTIONS(318),
    [sym_keyword_where] = ACTIONS(318),
    [sym_keyword_split] = ACTIONS(318),
    [sym_keyword_group] = ACTIONS(318),
    [sym_keyword_and] = ACTIONS(318),
    [sym_keyword_or] = ACTIONS(320),
    [sym_keyword_is] = ACTIONS(318),
    [sym_keyword_not] = ACTIONS(320),
    [sym_keyword_contains] = ACTIONS(320),
    [sym_keyword_contains_not] = ACTIONS(318),
    [sym_keyword_contains_all] = ACTIONS(318),
    [sym_keyword_contains_any] = ACTIONS(318),
    [sym_keyword_contains_none] = ACTIONS(318),
    [sym_keyword_inside] = ACTIONS(318),
    [sym_keyword_in] = ACTIONS(320),
    [sym_keyword_not_inside] = ACTIONS(318),
    [sym_keyword_all_inside] = ACTIONS(318),
    [sym_keyword_any_inside] = ACTIONS(318),
    [sym_keyword_none_inside] = ACTIONS(318),
    [sym_keyword_outside] = ACTIONS(318),
    [sym_keyword_intersects] = ACTIONS(318),
    [anon_sym_EQ] = ACTIONS(320),
    [anon_sym_COMMA] = ACTIONS(318),
    [anon_sym_DASH_GT] = ACTIONS(318),
    [anon_sym_LBRACK] = ACTIONS(318),
    [anon_sym_LT] = ACTIONS(320),
    [anon_sym_GT] = ACTIONS(320),
    [anon_sym_LT_DASH] = ACTIONS(320),
    [anon_sym_LT_DASH_GT] = ACTIONS(318),
    [anon_sym_STAR] = ACTIONS(320),
    [anon_sym_DOT] = ACTIONS(318),
    [anon_sym_DASH] = ACTIONS(320),
    [anon_sym_PERCENT] = ACTIONS(318),
    [anon_sym_AT] = ACTIONS(320),
    [anon_sym_LT_PIPE] = ACTIONS(318),
    [anon_sym_AMP_AMP] = ACTIONS(318),
    [anon_sym_PIPE_PIPE] = ACTIONS(318),
    [anon_sym_QMARK_QMARK] = ACTIONS(318),
    [anon_sym_QMARK_COLON] = ACTIONS(318),
    [anon_sym_BANG_EQ] = ACTIONS(318),
    [anon_sym_EQ_EQ] = ACTIONS(318),
    [anon_sym_QMARK_EQ] = ACTIONS(318),
    [anon_sym_STAR_EQ] = ACTIONS(318),
    [anon_sym_TILDE] = ACTIONS(318),
    [anon_sym_BANG_TILDE] = ACTIONS(318),
    [anon_sym_STAR_TILDE] = ACTIONS(318),
    [anon_sym_LT_EQ] = ACTIONS(318),
    [anon_sym_GT_EQ] = ACTIONS(318),
    [anon_sym_PLUS] = ACTIONS(320),
    [anon_sym_PLUS_EQ] = ACTIONS(318),
    [anon_sym_DASH_EQ] = ACTIONS(318),
    [anon_sym_u00d7] = ACTIONS(318),
    [anon_sym_SLASH] = ACTIONS(320),
    [anon_sym_u00f7] = ACTIONS(318),
    [anon_sym_STAR_STAR] = ACTIONS(318),
    [anon_sym_u220b] = ACTIONS(318),
    [anon_sym_u220c] = ACTIONS(318),
    [anon_sym_u2287] = ACTIONS(318),
    [anon_sym_u2283] = ACTIONS(318),
    [anon_sym_u2285] = ACTIONS(318),
    [anon_sym_u2208] = ACTIONS(318),
    [anon_sym_u2209] = ACTIONS(318),
    [anon_sym_u2286] = ACTIONS(318),
    [anon_sym_u2282] = ACTIONS(318),
    [anon_sym_u2284] = ACTIONS(318),
    [anon_sym_AT_AT] = ACTIONS(318),
  },
  [STATE(349)] = {
    [ts_builtin_sym_end] = ACTIONS(322),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(322),
    [sym_keyword_explain] = ACTIONS(322),
    [sym_keyword_parallel] = ACTIONS(322),
    [sym_keyword_timeout] = ACTIONS(322),
    [sym_keyword_fetch] = ACTIONS(322),
    [sym_keyword_limit] = ACTIONS(322),
    [sym_keyword_order] = ACTIONS(322),
    [sym_keyword_with] = ACTIONS(322),
    [sym_keyword_where] = ACTIONS(322),
    [sym_keyword_split] = ACTIONS(322),
    [sym_keyword_group] = ACTIONS(322),
    [sym_keyword_and] = ACTIONS(322),
    [sym_keyword_or] = ACTIONS(324),
    [sym_keyword_is] = ACTIONS(322),
    [sym_keyword_not] = ACTIONS(324),
    [sym_keyword_contains] = ACTIONS(324),
    [sym_keyword_contains_not] = ACTIONS(322),
    [sym_keyword_contains_all] = ACTIONS(322),
    [sym_keyword_contains_any] = ACTIONS(322),
    [sym_keyword_contains_none] = ACTIONS(322),
    [sym_keyword_inside] = ACTIONS(322),
    [sym_keyword_in] = ACTIONS(324),
    [sym_keyword_not_inside] = ACTIONS(322),
    [sym_keyword_all_inside] = ACTIONS(322),
    [sym_keyword_any_inside] = ACTIONS(322),
    [sym_keyword_none_inside] = ACTIONS(322),
    [sym_keyword_outside] = ACTIONS(322),
    [sym_keyword_intersects] = ACTIONS(322),
    [anon_sym_EQ] = ACTIONS(324),
    [anon_sym_COMMA] = ACTIONS(322),
    [anon_sym_DASH_GT] = ACTIONS(322),
    [anon_sym_LBRACK] = ACTIONS(322),
    [anon_sym_LT] = ACTIONS(324),
    [anon_sym_GT] = ACTIONS(324),
    [anon_sym_LT_DASH] = ACTIONS(324),
    [anon_sym_LT_DASH_GT] = ACTIONS(322),
    [anon_sym_STAR] = ACTIONS(324),
    [anon_sym_DOT] = ACTIONS(322),
    [anon_sym_DASH] = ACTIONS(324),
    [anon_sym_PERCENT] = ACTIONS(322),
    [anon_sym_AT] = ACTIONS(324),
    [anon_sym_LT_PIPE] = ACTIONS(322),
    [anon_sym_AMP_AMP] = ACTIONS(322),
    [anon_sym_PIPE_PIPE] = ACTIONS(322),
    [anon_sym_QMARK_QMARK] = ACTIONS(322),
    [anon_sym_QMARK_COLON] = ACTIONS(322),
    [anon_sym_BANG_EQ] = ACTIONS(322),
    [anon_sym_EQ_EQ] = ACTIONS(322),
    [anon_sym_QMARK_EQ] = ACTIONS(322),
    [anon_sym_STAR_EQ] = ACTIONS(322),
    [anon_sym_TILDE] = ACTIONS(322),
    [anon_sym_BANG_TILDE] = ACTIONS(322),
    [anon_sym_STAR_TILDE] = ACTIONS(322),
    [anon_sym_LT_EQ] = ACTIONS(322),
    [anon_sym_GT_EQ] = ACTIONS(322),
    [anon_sym_PLUS] = ACTIONS(324),
    [anon_sym_PLUS_EQ] = ACTIONS(322),
    [anon_sym_DASH_EQ] = ACTIONS(322),
    [anon_sym_u00d7] = ACTIONS(322),
    [anon_sym_SLASH] = ACTIONS(324),
    [anon_sym_u00f7] = ACTIONS(322),
    [anon_sym_STAR_STAR] = ACTIONS(322),
    [anon_sym_u220b] = ACTIONS(322),
    [anon_sym_u220c] = ACTIONS(322),
    [anon_sym_u2287] = ACTIONS(322),
    [anon_sym_u2283] = ACTIONS(322),
    [anon_sym_u2285] = ACTIONS(322),
    [anon_sym_u2208] = ACTIONS(322),
    [anon_sym_u2209] = ACTIONS(322),
    [anon_sym_u2286] = ACTIONS(322),
    [anon_sym_u2282] = ACTIONS(322),
    [anon_sym_u2284] = ACTIONS(322),
    [anon_sym_AT_AT] = ACTIONS(322),
  },
  [STATE(350)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_changefeed] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(351)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_changefeed] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(352)] = {
    [ts_builtin_sym_end] = ACTIONS(365),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(365),
    [sym_keyword_explain] = ACTIONS(365),
    [sym_keyword_parallel] = ACTIONS(365),
    [sym_keyword_timeout] = ACTIONS(365),
    [sym_keyword_fetch] = ACTIONS(365),
    [sym_keyword_limit] = ACTIONS(365),
    [sym_keyword_order] = ACTIONS(365),
    [sym_keyword_with] = ACTIONS(365),
    [sym_keyword_where] = ACTIONS(365),
    [sym_keyword_split] = ACTIONS(365),
    [sym_keyword_group] = ACTIONS(365),
    [sym_keyword_and] = ACTIONS(365),
    [sym_keyword_or] = ACTIONS(367),
    [sym_keyword_is] = ACTIONS(365),
    [sym_keyword_not] = ACTIONS(367),
    [sym_keyword_contains] = ACTIONS(367),
    [sym_keyword_contains_not] = ACTIONS(365),
    [sym_keyword_contains_all] = ACTIONS(365),
    [sym_keyword_contains_any] = ACTIONS(365),
    [sym_keyword_contains_none] = ACTIONS(365),
    [sym_keyword_inside] = ACTIONS(365),
    [sym_keyword_in] = ACTIONS(367),
    [sym_keyword_not_inside] = ACTIONS(365),
    [sym_keyword_all_inside] = ACTIONS(365),
    [sym_keyword_any_inside] = ACTIONS(365),
    [sym_keyword_none_inside] = ACTIONS(365),
    [sym_keyword_outside] = ACTIONS(365),
    [sym_keyword_intersects] = ACTIONS(365),
    [anon_sym_EQ] = ACTIONS(367),
    [anon_sym_COMMA] = ACTIONS(365),
    [anon_sym_DASH_GT] = ACTIONS(365),
    [anon_sym_LBRACK] = ACTIONS(365),
    [anon_sym_LT] = ACTIONS(367),
    [anon_sym_GT] = ACTIONS(367),
    [anon_sym_LT_DASH] = ACTIONS(367),
    [anon_sym_LT_DASH_GT] = ACTIONS(365),
    [anon_sym_STAR] = ACTIONS(367),
    [anon_sym_DOT] = ACTIONS(365),
    [anon_sym_DASH] = ACTIONS(367),
    [anon_sym_PERCENT] = ACTIONS(365),
    [anon_sym_AT] = ACTIONS(367),
    [anon_sym_LT_PIPE] = ACTIONS(365),
    [anon_sym_AMP_AMP] = ACTIONS(365),
    [anon_sym_PIPE_PIPE] = ACTIONS(365),
    [anon_sym_QMARK_QMARK] = ACTIONS(365),
    [anon_sym_QMARK_COLON] = ACTIONS(365),
    [anon_sym_BANG_EQ] = ACTIONS(365),
    [anon_sym_EQ_EQ] = ACTIONS(365),
    [anon_sym_QMARK_EQ] = ACTIONS(365),
    [anon_sym_STAR_EQ] = ACTIONS(365),
    [anon_sym_TILDE] = ACTIONS(365),
    [anon_sym_BANG_TILDE] = ACTIONS(365),
    [anon_sym_STAR_TILDE] = ACTIONS(365),
    [anon_sym_LT_EQ] = ACTIONS(365),
    [anon_sym_GT_EQ] = ACTIONS(365),
    [anon_sym_PLUS] = ACTIONS(367),
    [anon_sym_PLUS_EQ] = ACTIONS(365),
    [anon_sym_DASH_EQ] = ACTIONS(365),
    [anon_sym_u00d7] = ACTIONS(365),
    [anon_sym_SLASH] = ACTIONS(367),
    [anon_sym_u00f7] = ACTIONS(365),
    [anon_sym_STAR_STAR] = ACTIONS(365),
    [anon_sym_u220b] = ACTIONS(365),
    [anon_sym_u220c] = ACTIONS(365),
    [anon_sym_u2287] = ACTIONS(365),
    [anon_sym_u2283] = ACTIONS(365),
    [anon_sym_u2285] = ACTIONS(365),
    [anon_sym_u2208] = ACTIONS(365),
    [anon_sym_u2209] = ACTIONS(365),
    [anon_sym_u2286] = ACTIONS(365),
    [anon_sym_u2282] = ACTIONS(365),
    [anon_sym_u2284] = ACTIONS(365),
    [anon_sym_AT_AT] = ACTIONS(365),
  },
  [STATE(353)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(679),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(689),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(354)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_value] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_flexible] = ACTIONS(288),
    [sym_keyword_readonly] = ACTIONS(288),
    [sym_keyword_type] = ACTIONS(288),
    [sym_keyword_default] = ACTIONS(288),
    [sym_keyword_assert] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(656),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(691),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(355)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_merge] = ACTIONS(288),
    [sym_keyword_patch] = ACTIONS(288),
    [sym_keyword_unset] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(693),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(356)] = {
    [ts_builtin_sym_end] = ACTIONS(369),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(369),
    [sym_keyword_explain] = ACTIONS(369),
    [sym_keyword_parallel] = ACTIONS(369),
    [sym_keyword_timeout] = ACTIONS(369),
    [sym_keyword_fetch] = ACTIONS(369),
    [sym_keyword_limit] = ACTIONS(369),
    [sym_keyword_order] = ACTIONS(369),
    [sym_keyword_with] = ACTIONS(369),
    [sym_keyword_where] = ACTIONS(369),
    [sym_keyword_split] = ACTIONS(369),
    [sym_keyword_group] = ACTIONS(369),
    [sym_keyword_and] = ACTIONS(369),
    [sym_keyword_or] = ACTIONS(371),
    [sym_keyword_is] = ACTIONS(369),
    [sym_keyword_not] = ACTIONS(371),
    [sym_keyword_contains] = ACTIONS(371),
    [sym_keyword_contains_not] = ACTIONS(369),
    [sym_keyword_contains_all] = ACTIONS(369),
    [sym_keyword_contains_any] = ACTIONS(369),
    [sym_keyword_contains_none] = ACTIONS(369),
    [sym_keyword_inside] = ACTIONS(369),
    [sym_keyword_in] = ACTIONS(371),
    [sym_keyword_not_inside] = ACTIONS(369),
    [sym_keyword_all_inside] = ACTIONS(369),
    [sym_keyword_any_inside] = ACTIONS(369),
    [sym_keyword_none_inside] = ACTIONS(369),
    [sym_keyword_outside] = ACTIONS(369),
    [sym_keyword_intersects] = ACTIONS(369),
    [anon_sym_EQ] = ACTIONS(371),
    [anon_sym_COMMA] = ACTIONS(369),
    [anon_sym_DASH_GT] = ACTIONS(369),
    [anon_sym_LBRACK] = ACTIONS(369),
    [anon_sym_LT] = ACTIONS(371),
    [anon_sym_GT] = ACTIONS(371),
    [anon_sym_LT_DASH] = ACTIONS(371),
    [anon_sym_LT_DASH_GT] = ACTIONS(369),
    [anon_sym_STAR] = ACTIONS(371),
    [anon_sym_DOT] = ACTIONS(369),
    [anon_sym_DASH] = ACTIONS(371),
    [anon_sym_PERCENT] = ACTIONS(369),
    [anon_sym_AT] = ACTIONS(371),
    [anon_sym_LT_PIPE] = ACTIONS(369),
    [anon_sym_AMP_AMP] = ACTIONS(369),
    [anon_sym_PIPE_PIPE] = ACTIONS(369),
    [anon_sym_QMARK_QMARK] = ACTIONS(369),
    [anon_sym_QMARK_COLON] = ACTIONS(369),
    [anon_sym_BANG_EQ] = ACTIONS(369),
    [anon_sym_EQ_EQ] = ACTIONS(369),
    [anon_sym_QMARK_EQ] = ACTIONS(369),
    [anon_sym_STAR_EQ] = ACTIONS(369),
    [anon_sym_TILDE] = ACTIONS(369),
    [anon_sym_BANG_TILDE] = ACTIONS(369),
    [anon_sym_STAR_TILDE] = ACTIONS(369),
    [anon_sym_LT_EQ] = ACTIONS(369),
    [anon_sym_GT_EQ] = ACTIONS(369),
    [anon_sym_PLUS] = ACTIONS(371),
    [anon_sym_PLUS_EQ] = ACTIONS(369),
    [anon_sym_DASH_EQ] = ACTIONS(369),
    [anon_sym_u00d7] = ACTIONS(369),
    [anon_sym_SLASH] = ACTIONS(371),
    [anon_sym_u00f7] = ACTIONS(369),
    [anon_sym_STAR_STAR] = ACTIONS(369),
    [anon_sym_u220b] = ACTIONS(369),
    [anon_sym_u220c] = ACTIONS(369),
    [anon_sym_u2287] = ACTIONS(369),
    [anon_sym_u2283] = ACTIONS(369),
    [anon_sym_u2285] = ACTIONS(369),
    [anon_sym_u2208] = ACTIONS(369),
    [anon_sym_u2209] = ACTIONS(369),
    [anon_sym_u2286] = ACTIONS(369),
    [anon_sym_u2282] = ACTIONS(369),
    [anon_sym_u2284] = ACTIONS(369),
    [anon_sym_AT_AT] = ACTIONS(369),
  },
  [STATE(357)] = {
    [ts_builtin_sym_end] = ACTIONS(264),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(264),
    [sym_keyword_explain] = ACTIONS(264),
    [sym_keyword_parallel] = ACTIONS(264),
    [sym_keyword_timeout] = ACTIONS(264),
    [sym_keyword_fetch] = ACTIONS(264),
    [sym_keyword_limit] = ACTIONS(264),
    [sym_keyword_order] = ACTIONS(264),
    [sym_keyword_with] = ACTIONS(264),
    [sym_keyword_where] = ACTIONS(264),
    [sym_keyword_split] = ACTIONS(264),
    [sym_keyword_group] = ACTIONS(264),
    [sym_keyword_and] = ACTIONS(264),
    [sym_keyword_or] = ACTIONS(266),
    [sym_keyword_is] = ACTIONS(264),
    [sym_keyword_not] = ACTIONS(266),
    [sym_keyword_contains] = ACTIONS(266),
    [sym_keyword_contains_not] = ACTIONS(264),
    [sym_keyword_contains_all] = ACTIONS(264),
    [sym_keyword_contains_any] = ACTIONS(264),
    [sym_keyword_contains_none] = ACTIONS(264),
    [sym_keyword_inside] = ACTIONS(264),
    [sym_keyword_in] = ACTIONS(266),
    [sym_keyword_not_inside] = ACTIONS(264),
    [sym_keyword_all_inside] = ACTIONS(264),
    [sym_keyword_any_inside] = ACTIONS(264),
    [sym_keyword_none_inside] = ACTIONS(264),
    [sym_keyword_outside] = ACTIONS(264),
    [sym_keyword_intersects] = ACTIONS(264),
    [anon_sym_EQ] = ACTIONS(695),
    [anon_sym_COMMA] = ACTIONS(264),
    [anon_sym_DASH_GT] = ACTIONS(264),
    [anon_sym_LBRACK] = ACTIONS(264),
    [anon_sym_LT] = ACTIONS(266),
    [anon_sym_GT] = ACTIONS(266),
    [anon_sym_LT_DASH] = ACTIONS(266),
    [anon_sym_LT_DASH_GT] = ACTIONS(264),
    [anon_sym_STAR] = ACTIONS(266),
    [anon_sym_DOT] = ACTIONS(264),
    [anon_sym_DASH] = ACTIONS(266),
    [anon_sym_PERCENT] = ACTIONS(264),
    [anon_sym_AT] = ACTIONS(266),
    [anon_sym_LT_PIPE] = ACTIONS(264),
    [anon_sym_AMP_AMP] = ACTIONS(264),
    [anon_sym_PIPE_PIPE] = ACTIONS(264),
    [anon_sym_QMARK_QMARK] = ACTIONS(264),
    [anon_sym_QMARK_COLON] = ACTIONS(264),
    [anon_sym_BANG_EQ] = ACTIONS(264),
    [anon_sym_EQ_EQ] = ACTIONS(264),
    [anon_sym_QMARK_EQ] = ACTIONS(264),
    [anon_sym_STAR_EQ] = ACTIONS(264),
    [anon_sym_TILDE] = ACTIONS(264),
    [anon_sym_BANG_TILDE] = ACTIONS(264),
    [anon_sym_STAR_TILDE] = ACTIONS(264),
    [anon_sym_LT_EQ] = ACTIONS(264),
    [anon_sym_GT_EQ] = ACTIONS(264),
    [anon_sym_PLUS] = ACTIONS(266),
    [anon_sym_PLUS_EQ] = ACTIONS(264),
    [anon_sym_DASH_EQ] = ACTIONS(264),
    [anon_sym_u00d7] = ACTIONS(264),
    [anon_sym_SLASH] = ACTIONS(266),
    [anon_sym_u00f7] = ACTIONS(264),
    [anon_sym_STAR_STAR] = ACTIONS(264),
    [anon_sym_u220b] = ACTIONS(264),
    [anon_sym_u220c] = ACTIONS(264),
    [anon_sym_u2287] = ACTIONS(264),
    [anon_sym_u2283] = ACTIONS(264),
    [anon_sym_u2285] = ACTIONS(264),
    [anon_sym_u2208] = ACTIONS(264),
    [anon_sym_u2209] = ACTIONS(264),
    [anon_sym_u2286] = ACTIONS(264),
    [anon_sym_u2282] = ACTIONS(264),
    [anon_sym_u2284] = ACTIONS(264),
    [anon_sym_AT_AT] = ACTIONS(264),
  },
  [STATE(358)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(359)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_RBRACK] = ACTIONS(535),
    [anon_sym_QMARK] = ACTIONS(537),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(360)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_group] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_changefeed] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(361)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_group] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_changefeed] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(362)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(363)] = {
    [sym_operator] = STATE(971),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(697),
    [sym_keyword_merge] = ACTIONS(697),
    [sym_keyword_patch] = ACTIONS(697),
    [sym_keyword_replace] = ACTIONS(697),
    [sym_keyword_unset] = ACTIONS(697),
    [sym_keyword_set] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(364)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(365)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(366)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(367)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(662),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(699),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(368)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_value] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_flexible] = ACTIONS(288),
    [sym_keyword_readonly] = ACTIONS(288),
    [sym_keyword_type] = ACTIONS(288),
    [sym_keyword_default] = ACTIONS(288),
    [sym_keyword_assert] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(656),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(701),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(369)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(370)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(371)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(372)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(373)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_RBRACK] = ACTIONS(314),
    [anon_sym_QMARK] = ACTIONS(316),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(374)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(375)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_explain] = ACTIONS(537),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(376)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_explain] = ACTIONS(316),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(377)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_value] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_flexible] = ACTIONS(288),
    [sym_keyword_readonly] = ACTIONS(288),
    [sym_keyword_type] = ACTIONS(288),
    [sym_keyword_default] = ACTIONS(288),
    [sym_keyword_assert] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(703),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(378)] = {
    [sym_operator] = STATE(971),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_content] = ACTIONS(705),
    [sym_keyword_merge] = ACTIONS(705),
    [sym_keyword_patch] = ACTIONS(705),
    [sym_keyword_replace] = ACTIONS(705),
    [sym_keyword_unset] = ACTIONS(705),
    [sym_keyword_set] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(379)] = {
    [sym_operator] = STATE(971),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_content] = ACTIONS(709),
    [sym_keyword_merge] = ACTIONS(709),
    [sym_keyword_patch] = ACTIONS(709),
    [sym_keyword_replace] = ACTIONS(709),
    [sym_keyword_unset] = ACTIONS(709),
    [sym_keyword_set] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(380)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(381)] = {
    [sym_operator] = STATE(950),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_content] = ACTIONS(709),
    [sym_keyword_merge] = ACTIONS(709),
    [sym_keyword_patch] = ACTIONS(709),
    [sym_keyword_replace] = ACTIONS(709),
    [sym_keyword_unset] = ACTIONS(709),
    [sym_keyword_set] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(382)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_return] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(383)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_return] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(384)] = {
    [sym_operator] = STATE(865),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_rand] = ACTIONS(705),
    [sym_keyword_collate] = ACTIONS(705),
    [sym_keyword_numeric] = ACTIONS(705),
    [sym_keyword_asc] = ACTIONS(705),
    [sym_keyword_desc] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(385)] = {
    [sym_operator] = STATE(861),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_fetch] = ACTIONS(697),
    [sym_keyword_limit] = ACTIONS(697),
    [sym_keyword_order] = ACTIONS(697),
    [sym_keyword_with] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_split] = ACTIONS(697),
    [sym_keyword_group] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(386)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_parallel] = ACTIONS(537),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(387)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_parallel] = ACTIONS(316),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(388)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(389)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(390)] = {
    [sym_operator] = STATE(865),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_rand] = ACTIONS(709),
    [sym_keyword_collate] = ACTIONS(709),
    [sym_keyword_numeric] = ACTIONS(709),
    [sym_keyword_asc] = ACTIONS(709),
    [sym_keyword_desc] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(391)] = {
    [sym_operator] = STATE(861),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_order] = ACTIONS(709),
    [sym_keyword_with] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_split] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(711),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(392)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_for] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(393)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_for] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(394)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(395)] = {
    [sym_operator] = STATE(931),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1261),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(713),
    [sym_keyword_explain] = ACTIONS(713),
    [sym_keyword_parallel] = ACTIONS(713),
    [sym_keyword_timeout] = ACTIONS(713),
    [sym_keyword_fetch] = ACTIONS(713),
    [sym_keyword_limit] = ACTIONS(713),
    [sym_keyword_order] = ACTIONS(713),
    [sym_keyword_where] = ACTIONS(713),
    [sym_keyword_split] = ACTIONS(713),
    [sym_keyword_group] = ACTIONS(713),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(715),
    [anon_sym_RPAREN] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(396)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(397)] = {
    [sym_operator] = STATE(865),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(717),
    [sym_keyword_explain] = ACTIONS(717),
    [sym_keyword_parallel] = ACTIONS(717),
    [sym_keyword_timeout] = ACTIONS(717),
    [sym_keyword_fetch] = ACTIONS(717),
    [sym_keyword_limit] = ACTIONS(717),
    [sym_keyword_rand] = ACTIONS(719),
    [sym_keyword_collate] = ACTIONS(719),
    [sym_keyword_numeric] = ACTIONS(719),
    [sym_keyword_asc] = ACTIONS(721),
    [sym_keyword_desc] = ACTIONS(721),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(717),
    [anon_sym_RPAREN] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(398)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_order] = ACTIONS(288),
    [sym_keyword_split] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(290),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(679),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(723),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(399)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(400)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_value] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_flexible] = ACTIONS(288),
    [sym_keyword_readonly] = ACTIONS(288),
    [sym_keyword_type] = ACTIONS(288),
    [sym_keyword_default] = ACTIONS(288),
    [sym_keyword_assert] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(725),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(401)] = {
    [sym_operator] = STATE(861),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_order] = ACTIONS(705),
    [sym_keyword_with] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_split] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(707),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(402)] = {
    [sym_operator] = STATE(950),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_content] = ACTIONS(705),
    [sym_keyword_merge] = ACTIONS(705),
    [sym_keyword_patch] = ACTIONS(705),
    [sym_keyword_replace] = ACTIONS(705),
    [sym_keyword_unset] = ACTIONS(705),
    [sym_keyword_set] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(403)] = {
    [sym_operator] = STATE(950),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(697),
    [sym_keyword_merge] = ACTIONS(697),
    [sym_keyword_patch] = ACTIONS(697),
    [sym_keyword_replace] = ACTIONS(697),
    [sym_keyword_unset] = ACTIONS(697),
    [sym_keyword_set] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(404)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(537),
    [sym_keyword_as] = ACTIONS(537),
    [sym_keyword_omit] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(405)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_permissions] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(406)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_permissions] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(407)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_for] = ACTIONS(537),
    [sym_keyword_comment] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(408)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_for] = ACTIONS(316),
    [sym_keyword_comment] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(409)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_timeout] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(410)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_timeout] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(411)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(412)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(413)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(414)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_RBRACE] = ACTIONS(314),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(415)] = {
    [sym_operator] = STATE(963),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(697),
    [sym_keyword_merge] = ACTIONS(697),
    [sym_keyword_patch] = ACTIONS(697),
    [sym_keyword_unset] = ACTIONS(697),
    [sym_keyword_set] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(416)] = {
    [sym_operator] = STATE(878),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(717),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(717),
    [sym_keyword_explain] = ACTIONS(717),
    [sym_keyword_parallel] = ACTIONS(717),
    [sym_keyword_timeout] = ACTIONS(717),
    [sym_keyword_fetch] = ACTIONS(717),
    [sym_keyword_limit] = ACTIONS(717),
    [sym_keyword_rand] = ACTIONS(719),
    [sym_keyword_collate] = ACTIONS(719),
    [sym_keyword_numeric] = ACTIONS(719),
    [sym_keyword_asc] = ACTIONS(721),
    [sym_keyword_desc] = ACTIONS(721),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(717),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(417)] = {
    [sym_operator] = STATE(878),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_rand] = ACTIONS(705),
    [sym_keyword_collate] = ACTIONS(705),
    [sym_keyword_numeric] = ACTIONS(705),
    [sym_keyword_asc] = ACTIONS(705),
    [sym_keyword_desc] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(418)] = {
    [sym_operator] = STATE(878),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_rand] = ACTIONS(709),
    [sym_keyword_collate] = ACTIONS(709),
    [sym_keyword_numeric] = ACTIONS(709),
    [sym_keyword_asc] = ACTIONS(709),
    [sym_keyword_desc] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(419)] = {
    [sym_operator] = STATE(929),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1317),
    [ts_builtin_sym_end] = ACTIONS(713),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(713),
    [sym_keyword_explain] = ACTIONS(713),
    [sym_keyword_parallel] = ACTIONS(713),
    [sym_keyword_timeout] = ACTIONS(713),
    [sym_keyword_fetch] = ACTIONS(713),
    [sym_keyword_limit] = ACTIONS(713),
    [sym_keyword_order] = ACTIONS(713),
    [sym_keyword_where] = ACTIONS(713),
    [sym_keyword_split] = ACTIONS(713),
    [sym_keyword_group] = ACTIONS(713),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(727),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(420)] = {
    [sym_operator] = STATE(855),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_order] = ACTIONS(705),
    [sym_keyword_with] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_split] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(707),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(421)] = {
    [sym_operator] = STATE(855),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_order] = ACTIONS(709),
    [sym_keyword_with] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_split] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(711),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(422)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(316),
    [sym_keyword_as] = ACTIONS(316),
    [sym_keyword_omit] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(423)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(729),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(424)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_changefeed] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(425)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_drop] = ACTIONS(288),
    [sym_keyword_schemafull] = ACTIONS(288),
    [sym_keyword_schemaless] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(733),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(426)] = {
    [sym_where_clause] = STATE(1543),
    [sym_timeout_clause] = STATE(1836),
    [sym_parallel_clause] = STATE(2104),
    [sym_return_clause] = STATE(1679),
    [sym_operator] = STATE(954),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1293),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(735),
    [sym_keyword_return] = ACTIONS(547),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(549),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(737),
    [anon_sym_RPAREN] = ACTIONS(735),
    [anon_sym_RBRACE] = ACTIONS(735),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(427)] = {
    [sym_operator] = STATE(931),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_fetch] = ACTIONS(697),
    [sym_keyword_limit] = ACTIONS(697),
    [sym_keyword_order] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_split] = ACTIONS(697),
    [sym_keyword_group] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(428)] = {
    [sym_operator] = STATE(931),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_order] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_split] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(707),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(429)] = {
    [sym_operator] = STATE(931),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_order] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_split] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(711),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(430)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(537),
    [sym_keyword_where] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(431)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(316),
    [sym_keyword_where] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(432)] = {
    [sym_operator] = STATE(855),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_fetch] = ACTIONS(697),
    [sym_keyword_limit] = ACTIONS(697),
    [sym_keyword_order] = ACTIONS(697),
    [sym_keyword_with] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_split] = ACTIONS(697),
    [sym_keyword_group] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(433)] = {
    [sym_where_clause] = STATE(1489),
    [sym_timeout_clause] = STATE(1784),
    [sym_parallel_clause] = STATE(2041),
    [sym_return_clause] = STATE(1612),
    [sym_operator] = STATE(954),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1333),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(739),
    [sym_keyword_return] = ACTIONS(547),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(549),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(737),
    [anon_sym_RPAREN] = ACTIONS(739),
    [anon_sym_RBRACE] = ACTIONS(739),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(434)] = {
    [sym_operator] = STATE(963),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_content] = ACTIONS(705),
    [sym_keyword_merge] = ACTIONS(705),
    [sym_keyword_patch] = ACTIONS(705),
    [sym_keyword_unset] = ACTIONS(705),
    [sym_keyword_set] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(435)] = {
    [sym_operator] = STATE(963),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_content] = ACTIONS(709),
    [sym_keyword_merge] = ACTIONS(709),
    [sym_keyword_patch] = ACTIONS(709),
    [sym_keyword_unset] = ACTIONS(709),
    [sym_keyword_set] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(436)] = {
    [sym_where_clause] = STATE(1611),
    [sym_timeout_clause] = STATE(1784),
    [sym_parallel_clause] = STATE(2041),
    [sym_return_clause] = STATE(1612),
    [sym_operator] = STATE(918),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1375),
    [ts_builtin_sym_end] = ACTIONS(739),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(739),
    [sym_keyword_return] = ACTIONS(605),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(607),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(741),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(437)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(743),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(438)] = {
    [sym_where_clause] = STATE(1501),
    [sym_group_clause] = STATE(1752),
    [sym_operator] = STATE(827),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1347),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(745),
    [sym_keyword_where] = ACTIONS(747),
    [sym_keyword_group] = ACTIONS(749),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(745),
    [sym_keyword_permissions] = ACTIONS(745),
    [sym_keyword_comment] = ACTIONS(745),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(751),
    [anon_sym_RPAREN] = ACTIONS(745),
    [anon_sym_RBRACE] = ACTIONS(745),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(439)] = {
    [sym_where_clause] = STATE(1674),
    [sym_timeout_clause] = STATE(1836),
    [sym_parallel_clause] = STATE(2104),
    [sym_return_clause] = STATE(1679),
    [sym_operator] = STATE(918),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1348),
    [ts_builtin_sym_end] = ACTIONS(735),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(735),
    [sym_keyword_return] = ACTIONS(605),
    [sym_keyword_parallel] = ACTIONS(451),
    [sym_keyword_timeout] = ACTIONS(453),
    [sym_keyword_where] = ACTIONS(607),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(741),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(440)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_RPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(441)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_limit] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(442)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(753),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(443)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(444)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_changefeed] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(755),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(445)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_drop] = ACTIONS(288),
    [sym_keyword_schemafull] = ACTIONS(288),
    [sym_keyword_schemaless] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(757),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(446)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_RPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(447)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(379),
    [sym_keyword_explain] = ACTIONS(379),
    [sym_keyword_parallel] = ACTIONS(379),
    [sym_keyword_timeout] = ACTIONS(379),
    [sym_keyword_fetch] = ACTIONS(379),
    [sym_keyword_limit] = ACTIONS(379),
    [sym_keyword_order] = ACTIONS(379),
    [sym_keyword_with] = ACTIONS(379),
    [sym_keyword_where] = ACTIONS(379),
    [sym_keyword_split] = ACTIONS(379),
    [sym_keyword_group] = ACTIONS(379),
    [sym_keyword_and] = ACTIONS(379),
    [sym_keyword_or] = ACTIONS(381),
    [sym_keyword_is] = ACTIONS(379),
    [sym_keyword_not] = ACTIONS(381),
    [sym_keyword_contains] = ACTIONS(381),
    [sym_keyword_contains_not] = ACTIONS(379),
    [sym_keyword_contains_all] = ACTIONS(379),
    [sym_keyword_contains_any] = ACTIONS(379),
    [sym_keyword_contains_none] = ACTIONS(379),
    [sym_keyword_inside] = ACTIONS(379),
    [sym_keyword_in] = ACTIONS(381),
    [sym_keyword_not_inside] = ACTIONS(379),
    [sym_keyword_all_inside] = ACTIONS(379),
    [sym_keyword_any_inside] = ACTIONS(379),
    [sym_keyword_none_inside] = ACTIONS(379),
    [sym_keyword_outside] = ACTIONS(379),
    [sym_keyword_intersects] = ACTIONS(379),
    [anon_sym_EQ] = ACTIONS(381),
    [anon_sym_COMMA] = ACTIONS(379),
    [anon_sym_RPAREN] = ACTIONS(379),
    [anon_sym_RBRACE] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PERCENT] = ACTIONS(379),
    [anon_sym_AT] = ACTIONS(381),
    [anon_sym_LT_PIPE] = ACTIONS(379),
    [anon_sym_AMP_AMP] = ACTIONS(379),
    [anon_sym_PIPE_PIPE] = ACTIONS(379),
    [anon_sym_QMARK_QMARK] = ACTIONS(379),
    [anon_sym_QMARK_COLON] = ACTIONS(379),
    [anon_sym_BANG_EQ] = ACTIONS(379),
    [anon_sym_EQ_EQ] = ACTIONS(379),
    [anon_sym_QMARK_EQ] = ACTIONS(379),
    [anon_sym_STAR_EQ] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(379),
    [anon_sym_BANG_TILDE] = ACTIONS(379),
    [anon_sym_STAR_TILDE] = ACTIONS(379),
    [anon_sym_LT_EQ] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_PLUS_EQ] = ACTIONS(379),
    [anon_sym_DASH_EQ] = ACTIONS(379),
    [anon_sym_u00d7] = ACTIONS(379),
    [anon_sym_SLASH] = ACTIONS(381),
    [anon_sym_u00f7] = ACTIONS(379),
    [anon_sym_STAR_STAR] = ACTIONS(379),
    [anon_sym_u220b] = ACTIONS(379),
    [anon_sym_u220c] = ACTIONS(379),
    [anon_sym_u2287] = ACTIONS(379),
    [anon_sym_u2283] = ACTIONS(379),
    [anon_sym_u2285] = ACTIONS(379),
    [anon_sym_u2208] = ACTIONS(379),
    [anon_sym_u2209] = ACTIONS(379),
    [anon_sym_u2286] = ACTIONS(379),
    [anon_sym_u2282] = ACTIONS(379),
    [anon_sym_u2284] = ACTIONS(379),
    [anon_sym_AT_AT] = ACTIONS(379),
  },
  [STATE(448)] = {
    [sym_operator] = STATE(933),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_value] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(759),
    [sym_keyword_readonly] = ACTIONS(759),
    [sym_keyword_type] = ACTIONS(759),
    [sym_keyword_default] = ACTIONS(759),
    [sym_keyword_assert] = ACTIONS(759),
    [sym_keyword_permissions] = ACTIONS(759),
    [sym_keyword_for] = ACTIONS(759),
    [sym_keyword_comment] = ACTIONS(759),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(449)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_limit] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(450)] = {
    [sym_operator] = STATE(929),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_fetch] = ACTIONS(697),
    [sym_keyword_limit] = ACTIONS(697),
    [sym_keyword_order] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_split] = ACTIONS(697),
    [sym_keyword_group] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(451)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_fetch] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(452)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(761),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(453)] = {
    [sym_operator] = STATE(929),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_order] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_split] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(711),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(454)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(314),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(314),
    [sym_keyword_fetch] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(561),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(455)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_order] = ACTIONS(204),
    [sym_keyword_with] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_split] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_RPAREN] = ACTIONS(204),
    [anon_sym_RBRACE] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(456)] = {
    [sym_operator] = STATE(933),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_value] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_flexible] = ACTIONS(705),
    [sym_keyword_readonly] = ACTIONS(705),
    [sym_keyword_type] = ACTIONS(705),
    [sym_keyword_default] = ACTIONS(705),
    [sym_keyword_assert] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_for] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(457)] = {
    [sym_operator] = STATE(933),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_value] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_flexible] = ACTIONS(709),
    [sym_keyword_readonly] = ACTIONS(709),
    [sym_keyword_type] = ACTIONS(709),
    [sym_keyword_default] = ACTIONS(709),
    [sym_keyword_assert] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_for] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(458)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_on] = ACTIONS(537),
    [sym_keyword_as] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(459)] = {
    [sym_operator] = STATE(939),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_content] = ACTIONS(705),
    [sym_keyword_merge] = ACTIONS(705),
    [sym_keyword_patch] = ACTIONS(705),
    [sym_keyword_unset] = ACTIONS(705),
    [sym_keyword_set] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(460)] = {
    [sym_operator] = STATE(939),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(697),
    [sym_keyword_merge] = ACTIONS(697),
    [sym_keyword_patch] = ACTIONS(697),
    [sym_keyword_unset] = ACTIONS(697),
    [sym_keyword_set] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(461)] = {
    [sym_operator] = STATE(939),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_content] = ACTIONS(709),
    [sym_keyword_merge] = ACTIONS(709),
    [sym_keyword_patch] = ACTIONS(709),
    [sym_keyword_unset] = ACTIONS(709),
    [sym_keyword_set] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(462)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_on] = ACTIONS(316),
    [sym_keyword_as] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(463)] = {
    [sym_array] = STATE(28),
    [sym_object] = STATE(28),
    [sym_record_id_value] = STATE(46),
    [ts_builtin_sym_end] = ACTIONS(535),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(535),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(557),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(559),
    [sym_record_id_ident] = ACTIONS(559),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(464)] = {
    [sym_where_clause] = STATE(1530),
    [sym_group_clause] = STATE(1745),
    [sym_operator] = STATE(827),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1345),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(763),
    [sym_keyword_where] = ACTIONS(747),
    [sym_keyword_group] = ACTIONS(749),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(763),
    [sym_keyword_permissions] = ACTIONS(763),
    [sym_keyword_comment] = ACTIONS(763),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(751),
    [anon_sym_RPAREN] = ACTIONS(763),
    [anon_sym_RBRACE] = ACTIONS(763),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(465)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_order] = ACTIONS(236),
    [sym_keyword_with] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_split] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(238),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_RPAREN] = ACTIONS(236),
    [anon_sym_RBRACE] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(466)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(316),
    [sym_keyword_as] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_COMMA] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(467)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(537),
    [sym_keyword_as] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_COMMA] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(468)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_explain] = ACTIONS(375),
    [sym_keyword_parallel] = ACTIONS(375),
    [sym_keyword_timeout] = ACTIONS(375),
    [sym_keyword_fetch] = ACTIONS(375),
    [sym_keyword_limit] = ACTIONS(375),
    [sym_keyword_order] = ACTIONS(375),
    [sym_keyword_with] = ACTIONS(375),
    [sym_keyword_where] = ACTIONS(375),
    [sym_keyword_split] = ACTIONS(375),
    [sym_keyword_group] = ACTIONS(375),
    [sym_keyword_and] = ACTIONS(375),
    [sym_keyword_or] = ACTIONS(377),
    [sym_keyword_is] = ACTIONS(375),
    [sym_keyword_not] = ACTIONS(377),
    [sym_keyword_contains] = ACTIONS(377),
    [sym_keyword_contains_not] = ACTIONS(375),
    [sym_keyword_contains_all] = ACTIONS(375),
    [sym_keyword_contains_any] = ACTIONS(375),
    [sym_keyword_contains_none] = ACTIONS(375),
    [sym_keyword_inside] = ACTIONS(375),
    [sym_keyword_in] = ACTIONS(377),
    [sym_keyword_not_inside] = ACTIONS(375),
    [sym_keyword_all_inside] = ACTIONS(375),
    [sym_keyword_any_inside] = ACTIONS(375),
    [sym_keyword_none_inside] = ACTIONS(375),
    [sym_keyword_outside] = ACTIONS(375),
    [sym_keyword_intersects] = ACTIONS(375),
    [anon_sym_EQ] = ACTIONS(377),
    [anon_sym_COMMA] = ACTIONS(375),
    [anon_sym_RPAREN] = ACTIONS(375),
    [anon_sym_RBRACE] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PERCENT] = ACTIONS(375),
    [anon_sym_AT] = ACTIONS(377),
    [anon_sym_LT_PIPE] = ACTIONS(375),
    [anon_sym_AMP_AMP] = ACTIONS(375),
    [anon_sym_PIPE_PIPE] = ACTIONS(375),
    [anon_sym_QMARK_QMARK] = ACTIONS(375),
    [anon_sym_QMARK_COLON] = ACTIONS(375),
    [anon_sym_BANG_EQ] = ACTIONS(375),
    [anon_sym_EQ_EQ] = ACTIONS(375),
    [anon_sym_QMARK_EQ] = ACTIONS(375),
    [anon_sym_STAR_EQ] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(375),
    [anon_sym_BANG_TILDE] = ACTIONS(375),
    [anon_sym_STAR_TILDE] = ACTIONS(375),
    [anon_sym_LT_EQ] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(375),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_PLUS_EQ] = ACTIONS(375),
    [anon_sym_DASH_EQ] = ACTIONS(375),
    [anon_sym_u00d7] = ACTIONS(375),
    [anon_sym_SLASH] = ACTIONS(377),
    [anon_sym_u00f7] = ACTIONS(375),
    [anon_sym_STAR_STAR] = ACTIONS(375),
    [anon_sym_u220b] = ACTIONS(375),
    [anon_sym_u220c] = ACTIONS(375),
    [anon_sym_u2287] = ACTIONS(375),
    [anon_sym_u2283] = ACTIONS(375),
    [anon_sym_u2285] = ACTIONS(375),
    [anon_sym_u2208] = ACTIONS(375),
    [anon_sym_u2209] = ACTIONS(375),
    [anon_sym_u2286] = ACTIONS(375),
    [anon_sym_u2282] = ACTIONS(375),
    [anon_sym_u2284] = ACTIONS(375),
    [anon_sym_AT_AT] = ACTIONS(375),
  },
  [STATE(469)] = {
    [sym_operator] = STATE(929),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_order] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_split] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(707),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(470)] = {
    [sym_operator] = STATE(936),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_value] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_flexible] = ACTIONS(705),
    [sym_keyword_readonly] = ACTIONS(705),
    [sym_keyword_type] = ACTIONS(705),
    [sym_keyword_default] = ACTIONS(705),
    [sym_keyword_assert] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_for] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(471)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_content] = ACTIONS(288),
    [sym_keyword_set] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(765),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(472)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACK] = ACTIONS(288),
    [anon_sym_QMARK] = ACTIONS(290),
    [anon_sym_LBRACE] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(473)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [sym_keyword_then] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_LPAREN] = ACTIONS(535),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(474)] = {
    [sym_operator] = STATE(912),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(769),
    [sym_keyword_value] = ACTIONS(769),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(769),
    [sym_keyword_readonly] = ACTIONS(769),
    [sym_keyword_type] = ACTIONS(769),
    [sym_keyword_default] = ACTIONS(769),
    [sym_keyword_assert] = ACTIONS(769),
    [sym_keyword_permissions] = ACTIONS(769),
    [sym_keyword_comment] = ACTIONS(769),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(475)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(476)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_changefeed] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(773),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(477)] = {
    [sym_operator] = STATE(936),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_value] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(759),
    [sym_keyword_readonly] = ACTIONS(759),
    [sym_keyword_type] = ACTIONS(759),
    [sym_keyword_default] = ACTIONS(759),
    [sym_keyword_assert] = ACTIONS(759),
    [sym_keyword_permissions] = ACTIONS(759),
    [sym_keyword_for] = ACTIONS(759),
    [sym_keyword_comment] = ACTIONS(759),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(478)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [sym_keyword_then] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_LPAREN] = ACTIONS(314),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(479)] = {
    [sym_operator] = STATE(912),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(775),
    [sym_keyword_value] = ACTIONS(775),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(775),
    [sym_keyword_readonly] = ACTIONS(775),
    [sym_keyword_type] = ACTIONS(775),
    [sym_keyword_default] = ACTIONS(775),
    [sym_keyword_assert] = ACTIONS(775),
    [sym_keyword_permissions] = ACTIONS(775),
    [sym_keyword_comment] = ACTIONS(775),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(775),
    [anon_sym_RBRACE] = ACTIONS(775),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(480)] = {
    [sym_operator] = STATE(912),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(777),
    [sym_keyword_value] = ACTIONS(777),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(777),
    [sym_keyword_readonly] = ACTIONS(777),
    [sym_keyword_type] = ACTIONS(777),
    [sym_keyword_default] = ACTIONS(777),
    [sym_keyword_assert] = ACTIONS(777),
    [sym_keyword_permissions] = ACTIONS(777),
    [sym_keyword_comment] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(777),
    [anon_sym_RBRACE] = ACTIONS(777),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(481)] = {
    [sym_where_clause] = STATE(1530),
    [sym_group_clause] = STATE(1745),
    [sym_operator] = STATE(1021),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1404),
    [ts_builtin_sym_end] = ACTIONS(763),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(763),
    [sym_keyword_where] = ACTIONS(779),
    [sym_keyword_group] = ACTIONS(749),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(763),
    [sym_keyword_permissions] = ACTIONS(763),
    [sym_keyword_comment] = ACTIONS(763),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(781),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(482)] = {
    [sym_operator] = STATE(909),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_order] = ACTIONS(705),
    [sym_keyword_split] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(707),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(483)] = {
    [ts_builtin_sym_end] = ACTIONS(236),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(236),
    [sym_keyword_explain] = ACTIONS(236),
    [sym_keyword_parallel] = ACTIONS(236),
    [sym_keyword_timeout] = ACTIONS(236),
    [sym_keyword_fetch] = ACTIONS(236),
    [sym_keyword_limit] = ACTIONS(236),
    [sym_keyword_order] = ACTIONS(236),
    [sym_keyword_with] = ACTIONS(236),
    [sym_keyword_where] = ACTIONS(236),
    [sym_keyword_split] = ACTIONS(236),
    [sym_keyword_group] = ACTIONS(236),
    [sym_keyword_and] = ACTIONS(236),
    [sym_keyword_or] = ACTIONS(238),
    [sym_keyword_is] = ACTIONS(236),
    [sym_keyword_not] = ACTIONS(238),
    [sym_keyword_contains] = ACTIONS(238),
    [sym_keyword_contains_not] = ACTIONS(236),
    [sym_keyword_contains_all] = ACTIONS(236),
    [sym_keyword_contains_any] = ACTIONS(236),
    [sym_keyword_contains_none] = ACTIONS(236),
    [sym_keyword_inside] = ACTIONS(236),
    [sym_keyword_in] = ACTIONS(238),
    [sym_keyword_not_inside] = ACTIONS(236),
    [sym_keyword_all_inside] = ACTIONS(236),
    [sym_keyword_any_inside] = ACTIONS(236),
    [sym_keyword_none_inside] = ACTIONS(236),
    [sym_keyword_outside] = ACTIONS(236),
    [sym_keyword_intersects] = ACTIONS(236),
    [anon_sym_EQ] = ACTIONS(238),
    [anon_sym_COMMA] = ACTIONS(236),
    [anon_sym_LT] = ACTIONS(238),
    [anon_sym_GT] = ACTIONS(238),
    [anon_sym_STAR] = ACTIONS(238),
    [anon_sym_DASH] = ACTIONS(238),
    [anon_sym_PERCENT] = ACTIONS(236),
    [anon_sym_AT] = ACTIONS(238),
    [anon_sym_LT_PIPE] = ACTIONS(236),
    [anon_sym_AMP_AMP] = ACTIONS(236),
    [anon_sym_PIPE_PIPE] = ACTIONS(236),
    [anon_sym_QMARK_QMARK] = ACTIONS(236),
    [anon_sym_QMARK_COLON] = ACTIONS(236),
    [anon_sym_BANG_EQ] = ACTIONS(236),
    [anon_sym_EQ_EQ] = ACTIONS(236),
    [anon_sym_QMARK_EQ] = ACTIONS(236),
    [anon_sym_STAR_EQ] = ACTIONS(236),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_BANG_TILDE] = ACTIONS(236),
    [anon_sym_STAR_TILDE] = ACTIONS(236),
    [anon_sym_LT_EQ] = ACTIONS(236),
    [anon_sym_GT_EQ] = ACTIONS(236),
    [anon_sym_PLUS] = ACTIONS(238),
    [anon_sym_PLUS_EQ] = ACTIONS(236),
    [anon_sym_DASH_EQ] = ACTIONS(236),
    [anon_sym_u00d7] = ACTIONS(236),
    [anon_sym_SLASH] = ACTIONS(238),
    [anon_sym_u00f7] = ACTIONS(236),
    [anon_sym_STAR_STAR] = ACTIONS(236),
    [anon_sym_u220b] = ACTIONS(236),
    [anon_sym_u220c] = ACTIONS(236),
    [anon_sym_u2287] = ACTIONS(236),
    [anon_sym_u2283] = ACTIONS(236),
    [anon_sym_u2285] = ACTIONS(236),
    [anon_sym_u2208] = ACTIONS(236),
    [anon_sym_u2209] = ACTIONS(236),
    [anon_sym_u2286] = ACTIONS(236),
    [anon_sym_u2282] = ACTIONS(236),
    [anon_sym_u2284] = ACTIONS(236),
    [anon_sym_AT_AT] = ACTIONS(236),
  },
  [STATE(484)] = {
    [sym_operator] = STATE(909),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_order] = ACTIONS(709),
    [sym_keyword_split] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(711),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(485)] = {
    [sym_operator] = STATE(909),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_explain] = ACTIONS(759),
    [sym_keyword_parallel] = ACTIONS(759),
    [sym_keyword_timeout] = ACTIONS(759),
    [sym_keyword_fetch] = ACTIONS(759),
    [sym_keyword_limit] = ACTIONS(759),
    [sym_keyword_order] = ACTIONS(759),
    [sym_keyword_split] = ACTIONS(759),
    [sym_keyword_group] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(486)] = {
    [sym_operator] = STATE(912),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_value] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_flexible] = ACTIONS(709),
    [sym_keyword_readonly] = ACTIONS(709),
    [sym_keyword_type] = ACTIONS(709),
    [sym_keyword_default] = ACTIONS(709),
    [sym_keyword_assert] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(487)] = {
    [sym_where_clause] = STATE(1501),
    [sym_group_clause] = STATE(1752),
    [sym_operator] = STATE(1021),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1392),
    [ts_builtin_sym_end] = ACTIONS(745),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(745),
    [sym_keyword_where] = ACTIONS(779),
    [sym_keyword_group] = ACTIONS(749),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(745),
    [sym_keyword_permissions] = ACTIONS(745),
    [sym_keyword_comment] = ACTIONS(745),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(781),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(488)] = {
    [ts_builtin_sym_end] = ACTIONS(375),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(375),
    [sym_keyword_explain] = ACTIONS(375),
    [sym_keyword_parallel] = ACTIONS(375),
    [sym_keyword_timeout] = ACTIONS(375),
    [sym_keyword_fetch] = ACTIONS(375),
    [sym_keyword_limit] = ACTIONS(375),
    [sym_keyword_order] = ACTIONS(375),
    [sym_keyword_with] = ACTIONS(375),
    [sym_keyword_where] = ACTIONS(375),
    [sym_keyword_split] = ACTIONS(375),
    [sym_keyword_group] = ACTIONS(375),
    [sym_keyword_and] = ACTIONS(375),
    [sym_keyword_or] = ACTIONS(377),
    [sym_keyword_is] = ACTIONS(375),
    [sym_keyword_not] = ACTIONS(377),
    [sym_keyword_contains] = ACTIONS(377),
    [sym_keyword_contains_not] = ACTIONS(375),
    [sym_keyword_contains_all] = ACTIONS(375),
    [sym_keyword_contains_any] = ACTIONS(375),
    [sym_keyword_contains_none] = ACTIONS(375),
    [sym_keyword_inside] = ACTIONS(375),
    [sym_keyword_in] = ACTIONS(377),
    [sym_keyword_not_inside] = ACTIONS(375),
    [sym_keyword_all_inside] = ACTIONS(375),
    [sym_keyword_any_inside] = ACTIONS(375),
    [sym_keyword_none_inside] = ACTIONS(375),
    [sym_keyword_outside] = ACTIONS(375),
    [sym_keyword_intersects] = ACTIONS(375),
    [anon_sym_EQ] = ACTIONS(377),
    [anon_sym_COMMA] = ACTIONS(375),
    [anon_sym_LT] = ACTIONS(377),
    [anon_sym_GT] = ACTIONS(377),
    [anon_sym_STAR] = ACTIONS(377),
    [anon_sym_DASH] = ACTIONS(377),
    [anon_sym_PERCENT] = ACTIONS(375),
    [anon_sym_AT] = ACTIONS(377),
    [anon_sym_LT_PIPE] = ACTIONS(375),
    [anon_sym_AMP_AMP] = ACTIONS(375),
    [anon_sym_PIPE_PIPE] = ACTIONS(375),
    [anon_sym_QMARK_QMARK] = ACTIONS(375),
    [anon_sym_QMARK_COLON] = ACTIONS(375),
    [anon_sym_BANG_EQ] = ACTIONS(375),
    [anon_sym_EQ_EQ] = ACTIONS(375),
    [anon_sym_QMARK_EQ] = ACTIONS(375),
    [anon_sym_STAR_EQ] = ACTIONS(375),
    [anon_sym_TILDE] = ACTIONS(375),
    [anon_sym_BANG_TILDE] = ACTIONS(375),
    [anon_sym_STAR_TILDE] = ACTIONS(375),
    [anon_sym_LT_EQ] = ACTIONS(375),
    [anon_sym_GT_EQ] = ACTIONS(375),
    [anon_sym_PLUS] = ACTIONS(377),
    [anon_sym_PLUS_EQ] = ACTIONS(375),
    [anon_sym_DASH_EQ] = ACTIONS(375),
    [anon_sym_u00d7] = ACTIONS(375),
    [anon_sym_SLASH] = ACTIONS(377),
    [anon_sym_u00f7] = ACTIONS(375),
    [anon_sym_STAR_STAR] = ACTIONS(375),
    [anon_sym_u220b] = ACTIONS(375),
    [anon_sym_u220c] = ACTIONS(375),
    [anon_sym_u2287] = ACTIONS(375),
    [anon_sym_u2283] = ACTIONS(375),
    [anon_sym_u2285] = ACTIONS(375),
    [anon_sym_u2208] = ACTIONS(375),
    [anon_sym_u2209] = ACTIONS(375),
    [anon_sym_u2286] = ACTIONS(375),
    [anon_sym_u2282] = ACTIONS(375),
    [anon_sym_u2284] = ACTIONS(375),
    [anon_sym_AT_AT] = ACTIONS(375),
  },
  [STATE(489)] = {
    [ts_builtin_sym_end] = ACTIONS(379),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(379),
    [sym_keyword_explain] = ACTIONS(379),
    [sym_keyword_parallel] = ACTIONS(379),
    [sym_keyword_timeout] = ACTIONS(379),
    [sym_keyword_fetch] = ACTIONS(379),
    [sym_keyword_limit] = ACTIONS(379),
    [sym_keyword_order] = ACTIONS(379),
    [sym_keyword_with] = ACTIONS(379),
    [sym_keyword_where] = ACTIONS(379),
    [sym_keyword_split] = ACTIONS(379),
    [sym_keyword_group] = ACTIONS(379),
    [sym_keyword_and] = ACTIONS(379),
    [sym_keyword_or] = ACTIONS(381),
    [sym_keyword_is] = ACTIONS(379),
    [sym_keyword_not] = ACTIONS(381),
    [sym_keyword_contains] = ACTIONS(381),
    [sym_keyword_contains_not] = ACTIONS(379),
    [sym_keyword_contains_all] = ACTIONS(379),
    [sym_keyword_contains_any] = ACTIONS(379),
    [sym_keyword_contains_none] = ACTIONS(379),
    [sym_keyword_inside] = ACTIONS(379),
    [sym_keyword_in] = ACTIONS(381),
    [sym_keyword_not_inside] = ACTIONS(379),
    [sym_keyword_all_inside] = ACTIONS(379),
    [sym_keyword_any_inside] = ACTIONS(379),
    [sym_keyword_none_inside] = ACTIONS(379),
    [sym_keyword_outside] = ACTIONS(379),
    [sym_keyword_intersects] = ACTIONS(379),
    [anon_sym_EQ] = ACTIONS(381),
    [anon_sym_COMMA] = ACTIONS(379),
    [anon_sym_LT] = ACTIONS(381),
    [anon_sym_GT] = ACTIONS(381),
    [anon_sym_STAR] = ACTIONS(381),
    [anon_sym_DASH] = ACTIONS(381),
    [anon_sym_PERCENT] = ACTIONS(379),
    [anon_sym_AT] = ACTIONS(381),
    [anon_sym_LT_PIPE] = ACTIONS(379),
    [anon_sym_AMP_AMP] = ACTIONS(379),
    [anon_sym_PIPE_PIPE] = ACTIONS(379),
    [anon_sym_QMARK_QMARK] = ACTIONS(379),
    [anon_sym_QMARK_COLON] = ACTIONS(379),
    [anon_sym_BANG_EQ] = ACTIONS(379),
    [anon_sym_EQ_EQ] = ACTIONS(379),
    [anon_sym_QMARK_EQ] = ACTIONS(379),
    [anon_sym_STAR_EQ] = ACTIONS(379),
    [anon_sym_TILDE] = ACTIONS(379),
    [anon_sym_BANG_TILDE] = ACTIONS(379),
    [anon_sym_STAR_TILDE] = ACTIONS(379),
    [anon_sym_LT_EQ] = ACTIONS(379),
    [anon_sym_GT_EQ] = ACTIONS(379),
    [anon_sym_PLUS] = ACTIONS(381),
    [anon_sym_PLUS_EQ] = ACTIONS(379),
    [anon_sym_DASH_EQ] = ACTIONS(379),
    [anon_sym_u00d7] = ACTIONS(379),
    [anon_sym_SLASH] = ACTIONS(381),
    [anon_sym_u00f7] = ACTIONS(379),
    [anon_sym_STAR_STAR] = ACTIONS(379),
    [anon_sym_u220b] = ACTIONS(379),
    [anon_sym_u220c] = ACTIONS(379),
    [anon_sym_u2287] = ACTIONS(379),
    [anon_sym_u2283] = ACTIONS(379),
    [anon_sym_u2285] = ACTIONS(379),
    [anon_sym_u2208] = ACTIONS(379),
    [anon_sym_u2209] = ACTIONS(379),
    [anon_sym_u2286] = ACTIONS(379),
    [anon_sym_u2282] = ACTIONS(379),
    [anon_sym_u2284] = ACTIONS(379),
    [anon_sym_AT_AT] = ACTIONS(379),
  },
  [STATE(490)] = {
    [ts_builtin_sym_end] = ACTIONS(204),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(204),
    [sym_keyword_explain] = ACTIONS(204),
    [sym_keyword_parallel] = ACTIONS(204),
    [sym_keyword_timeout] = ACTIONS(204),
    [sym_keyword_fetch] = ACTIONS(204),
    [sym_keyword_limit] = ACTIONS(204),
    [sym_keyword_order] = ACTIONS(204),
    [sym_keyword_with] = ACTIONS(204),
    [sym_keyword_where] = ACTIONS(204),
    [sym_keyword_split] = ACTIONS(204),
    [sym_keyword_group] = ACTIONS(204),
    [sym_keyword_and] = ACTIONS(204),
    [sym_keyword_or] = ACTIONS(206),
    [sym_keyword_is] = ACTIONS(204),
    [sym_keyword_not] = ACTIONS(206),
    [sym_keyword_contains] = ACTIONS(206),
    [sym_keyword_contains_not] = ACTIONS(204),
    [sym_keyword_contains_all] = ACTIONS(204),
    [sym_keyword_contains_any] = ACTIONS(204),
    [sym_keyword_contains_none] = ACTIONS(204),
    [sym_keyword_inside] = ACTIONS(204),
    [sym_keyword_in] = ACTIONS(206),
    [sym_keyword_not_inside] = ACTIONS(204),
    [sym_keyword_all_inside] = ACTIONS(204),
    [sym_keyword_any_inside] = ACTIONS(204),
    [sym_keyword_none_inside] = ACTIONS(204),
    [sym_keyword_outside] = ACTIONS(204),
    [sym_keyword_intersects] = ACTIONS(204),
    [anon_sym_EQ] = ACTIONS(206),
    [anon_sym_COMMA] = ACTIONS(204),
    [anon_sym_LT] = ACTIONS(206),
    [anon_sym_GT] = ACTIONS(206),
    [anon_sym_STAR] = ACTIONS(206),
    [anon_sym_DASH] = ACTIONS(206),
    [anon_sym_PERCENT] = ACTIONS(204),
    [anon_sym_AT] = ACTIONS(206),
    [anon_sym_LT_PIPE] = ACTIONS(204),
    [anon_sym_AMP_AMP] = ACTIONS(204),
    [anon_sym_PIPE_PIPE] = ACTIONS(204),
    [anon_sym_QMARK_QMARK] = ACTIONS(204),
    [anon_sym_QMARK_COLON] = ACTIONS(204),
    [anon_sym_BANG_EQ] = ACTIONS(204),
    [anon_sym_EQ_EQ] = ACTIONS(204),
    [anon_sym_QMARK_EQ] = ACTIONS(204),
    [anon_sym_STAR_EQ] = ACTIONS(204),
    [anon_sym_TILDE] = ACTIONS(204),
    [anon_sym_BANG_TILDE] = ACTIONS(204),
    [anon_sym_STAR_TILDE] = ACTIONS(204),
    [anon_sym_LT_EQ] = ACTIONS(204),
    [anon_sym_GT_EQ] = ACTIONS(204),
    [anon_sym_PLUS] = ACTIONS(206),
    [anon_sym_PLUS_EQ] = ACTIONS(204),
    [anon_sym_DASH_EQ] = ACTIONS(204),
    [anon_sym_u00d7] = ACTIONS(204),
    [anon_sym_SLASH] = ACTIONS(206),
    [anon_sym_u00f7] = ACTIONS(204),
    [anon_sym_STAR_STAR] = ACTIONS(204),
    [anon_sym_u220b] = ACTIONS(204),
    [anon_sym_u220c] = ACTIONS(204),
    [anon_sym_u2287] = ACTIONS(204),
    [anon_sym_u2283] = ACTIONS(204),
    [anon_sym_u2285] = ACTIONS(204),
    [anon_sym_u2208] = ACTIONS(204),
    [anon_sym_u2209] = ACTIONS(204),
    [anon_sym_u2286] = ACTIONS(204),
    [anon_sym_u2282] = ACTIONS(204),
    [anon_sym_u2284] = ACTIONS(204),
    [anon_sym_AT_AT] = ACTIONS(204),
  },
  [STATE(491)] = {
    [sym_operator] = STATE(936),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_value] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_flexible] = ACTIONS(709),
    [sym_keyword_readonly] = ACTIONS(709),
    [sym_keyword_type] = ACTIONS(709),
    [sym_keyword_default] = ACTIONS(709),
    [sym_keyword_assert] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_for] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(492)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(783),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(493)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(785),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(494)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(787),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(495)] = {
    [sym_operator] = STATE(912),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(789),
    [sym_keyword_value] = ACTIONS(789),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(789),
    [sym_keyword_readonly] = ACTIONS(789),
    [sym_keyword_type] = ACTIONS(789),
    [sym_keyword_default] = ACTIONS(789),
    [sym_keyword_assert] = ACTIONS(789),
    [sym_keyword_permissions] = ACTIONS(789),
    [sym_keyword_comment] = ACTIONS(789),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(789),
    [anon_sym_RBRACE] = ACTIONS(789),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(496)] = {
    [sym_operator] = STATE(912),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_value] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_flexible] = ACTIONS(705),
    [sym_keyword_readonly] = ACTIONS(705),
    [sym_keyword_type] = ACTIONS(705),
    [sym_keyword_default] = ACTIONS(705),
    [sym_keyword_assert] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(497)] = {
    [sym_operator] = STATE(906),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_explain] = ACTIONS(759),
    [sym_keyword_parallel] = ACTIONS(759),
    [sym_keyword_timeout] = ACTIONS(759),
    [sym_keyword_fetch] = ACTIONS(759),
    [sym_keyword_limit] = ACTIONS(759),
    [sym_keyword_order] = ACTIONS(759),
    [sym_keyword_split] = ACTIONS(759),
    [sym_keyword_group] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(463),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(498)] = {
    [sym_operator] = STATE(906),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_limit] = ACTIONS(705),
    [sym_keyword_order] = ACTIONS(705),
    [sym_keyword_split] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(707),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(499)] = {
    [sym_operator] = STATE(915),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(789),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(789),
    [sym_keyword_value] = ACTIONS(789),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(789),
    [sym_keyword_readonly] = ACTIONS(789),
    [sym_keyword_type] = ACTIONS(789),
    [sym_keyword_default] = ACTIONS(789),
    [sym_keyword_assert] = ACTIONS(789),
    [sym_keyword_permissions] = ACTIONS(789),
    [sym_keyword_comment] = ACTIONS(789),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(500)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_group] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_changefeed] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(791),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(501)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(793),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(502)] = {
    [sym_operator] = STATE(906),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_limit] = ACTIONS(709),
    [sym_keyword_order] = ACTIONS(709),
    [sym_keyword_split] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(711),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(503)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(795),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(504)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_explain] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(505)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(799),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(506)] = {
    [sym_operator] = STATE(915),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_value] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_flexible] = ACTIONS(705),
    [sym_keyword_readonly] = ACTIONS(705),
    [sym_keyword_type] = ACTIONS(705),
    [sym_keyword_default] = ACTIONS(705),
    [sym_keyword_assert] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(507)] = {
    [sym_operator] = STATE(915),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(775),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(775),
    [sym_keyword_value] = ACTIONS(775),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(775),
    [sym_keyword_readonly] = ACTIONS(775),
    [sym_keyword_type] = ACTIONS(775),
    [sym_keyword_default] = ACTIONS(775),
    [sym_keyword_assert] = ACTIONS(775),
    [sym_keyword_permissions] = ACTIONS(775),
    [sym_keyword_comment] = ACTIONS(775),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(508)] = {
    [sym_operator] = STATE(915),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_value] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_flexible] = ACTIONS(709),
    [sym_keyword_readonly] = ACTIONS(709),
    [sym_keyword_type] = ACTIONS(709),
    [sym_keyword_default] = ACTIONS(709),
    [sym_keyword_assert] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(509)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(94),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(537),
    [sym_keyword_and] = ACTIONS(537),
    [sym_keyword_or] = ACTIONS(537),
    [sym_keyword_is] = ACTIONS(537),
    [sym_keyword_not] = ACTIONS(537),
    [sym_keyword_contains] = ACTIONS(537),
    [sym_keyword_contains_not] = ACTIONS(537),
    [sym_keyword_contains_all] = ACTIONS(537),
    [sym_keyword_contains_any] = ACTIONS(537),
    [sym_keyword_contains_none] = ACTIONS(537),
    [sym_keyword_inside] = ACTIONS(537),
    [sym_keyword_in] = ACTIONS(537),
    [sym_keyword_not_inside] = ACTIONS(537),
    [sym_keyword_all_inside] = ACTIONS(537),
    [sym_keyword_any_inside] = ACTIONS(537),
    [sym_keyword_none_inside] = ACTIONS(537),
    [sym_keyword_outside] = ACTIONS(537),
    [sym_keyword_intersects] = ACTIONS(537),
    [anon_sym_EQ] = ACTIONS(539),
    [anon_sym_DASH_GT] = ACTIONS(535),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(537),
    [anon_sym_GT] = ACTIONS(537),
    [anon_sym_LT_DASH] = ACTIONS(537),
    [anon_sym_LT_DASH_GT] = ACTIONS(535),
    [anon_sym_STAR] = ACTIONS(537),
    [anon_sym_DOT] = ACTIONS(535),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(537),
    [anon_sym_PERCENT] = ACTIONS(535),
    [anon_sym_AT] = ACTIONS(537),
    [anon_sym_LT_PIPE] = ACTIONS(535),
    [anon_sym_AMP_AMP] = ACTIONS(535),
    [anon_sym_PIPE_PIPE] = ACTIONS(535),
    [anon_sym_QMARK_QMARK] = ACTIONS(535),
    [anon_sym_QMARK_COLON] = ACTIONS(535),
    [anon_sym_BANG_EQ] = ACTIONS(535),
    [anon_sym_EQ_EQ] = ACTIONS(535),
    [anon_sym_QMARK_EQ] = ACTIONS(535),
    [anon_sym_STAR_EQ] = ACTIONS(535),
    [anon_sym_TILDE] = ACTIONS(535),
    [anon_sym_BANG_TILDE] = ACTIONS(535),
    [anon_sym_STAR_TILDE] = ACTIONS(535),
    [anon_sym_LT_EQ] = ACTIONS(535),
    [anon_sym_GT_EQ] = ACTIONS(535),
    [anon_sym_PLUS] = ACTIONS(537),
    [anon_sym_PLUS_EQ] = ACTIONS(535),
    [anon_sym_DASH_EQ] = ACTIONS(535),
    [anon_sym_u00d7] = ACTIONS(535),
    [anon_sym_SLASH] = ACTIONS(537),
    [anon_sym_u00f7] = ACTIONS(535),
    [anon_sym_STAR_STAR] = ACTIONS(535),
    [anon_sym_u220b] = ACTIONS(535),
    [anon_sym_u220c] = ACTIONS(535),
    [anon_sym_u2287] = ACTIONS(535),
    [anon_sym_u2283] = ACTIONS(535),
    [anon_sym_u2285] = ACTIONS(535),
    [anon_sym_u2208] = ACTIONS(535),
    [anon_sym_u2209] = ACTIONS(535),
    [anon_sym_u2286] = ACTIONS(535),
    [anon_sym_u2282] = ACTIONS(535),
    [anon_sym_u2284] = ACTIONS(535),
    [anon_sym_AT_AT] = ACTIONS(535),
  },
  [STATE(510)] = {
    [sym_operator] = STATE(915),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(777),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(777),
    [sym_keyword_value] = ACTIONS(777),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(777),
    [sym_keyword_readonly] = ACTIONS(777),
    [sym_keyword_type] = ACTIONS(777),
    [sym_keyword_default] = ACTIONS(777),
    [sym_keyword_assert] = ACTIONS(777),
    [sym_keyword_permissions] = ACTIONS(777),
    [sym_keyword_comment] = ACTIONS(777),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(511)] = {
    [sym_array] = STATE(70),
    [sym_object] = STATE(70),
    [sym_record_id_value] = STATE(100),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(316),
    [sym_keyword_and] = ACTIONS(316),
    [sym_keyword_or] = ACTIONS(316),
    [sym_keyword_is] = ACTIONS(316),
    [sym_keyword_not] = ACTIONS(316),
    [sym_keyword_contains] = ACTIONS(316),
    [sym_keyword_contains_not] = ACTIONS(316),
    [sym_keyword_contains_all] = ACTIONS(316),
    [sym_keyword_contains_any] = ACTIONS(316),
    [sym_keyword_contains_none] = ACTIONS(316),
    [sym_keyword_inside] = ACTIONS(316),
    [sym_keyword_in] = ACTIONS(316),
    [sym_keyword_not_inside] = ACTIONS(316),
    [sym_keyword_all_inside] = ACTIONS(316),
    [sym_keyword_any_inside] = ACTIONS(316),
    [sym_keyword_none_inside] = ACTIONS(316),
    [sym_keyword_outside] = ACTIONS(316),
    [sym_keyword_intersects] = ACTIONS(316),
    [anon_sym_EQ] = ACTIONS(543),
    [anon_sym_DASH_GT] = ACTIONS(314),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(316),
    [anon_sym_GT] = ACTIONS(316),
    [anon_sym_LT_DASH] = ACTIONS(316),
    [anon_sym_LT_DASH_GT] = ACTIONS(314),
    [anon_sym_STAR] = ACTIONS(316),
    [anon_sym_DOT] = ACTIONS(314),
    [sym_int] = ACTIONS(541),
    [sym_record_id_ident] = ACTIONS(541),
    [anon_sym_DASH] = ACTIONS(316),
    [anon_sym_PERCENT] = ACTIONS(314),
    [anon_sym_AT] = ACTIONS(316),
    [anon_sym_LT_PIPE] = ACTIONS(314),
    [anon_sym_AMP_AMP] = ACTIONS(314),
    [anon_sym_PIPE_PIPE] = ACTIONS(314),
    [anon_sym_QMARK_QMARK] = ACTIONS(314),
    [anon_sym_QMARK_COLON] = ACTIONS(314),
    [anon_sym_BANG_EQ] = ACTIONS(314),
    [anon_sym_EQ_EQ] = ACTIONS(314),
    [anon_sym_QMARK_EQ] = ACTIONS(314),
    [anon_sym_STAR_EQ] = ACTIONS(314),
    [anon_sym_TILDE] = ACTIONS(314),
    [anon_sym_BANG_TILDE] = ACTIONS(314),
    [anon_sym_STAR_TILDE] = ACTIONS(314),
    [anon_sym_LT_EQ] = ACTIONS(314),
    [anon_sym_GT_EQ] = ACTIONS(314),
    [anon_sym_PLUS] = ACTIONS(316),
    [anon_sym_PLUS_EQ] = ACTIONS(314),
    [anon_sym_DASH_EQ] = ACTIONS(314),
    [anon_sym_u00d7] = ACTIONS(314),
    [anon_sym_SLASH] = ACTIONS(316),
    [anon_sym_u00f7] = ACTIONS(314),
    [anon_sym_STAR_STAR] = ACTIONS(314),
    [anon_sym_u220b] = ACTIONS(314),
    [anon_sym_u220c] = ACTIONS(314),
    [anon_sym_u2287] = ACTIONS(314),
    [anon_sym_u2283] = ACTIONS(314),
    [anon_sym_u2285] = ACTIONS(314),
    [anon_sym_u2208] = ACTIONS(314),
    [anon_sym_u2209] = ACTIONS(314),
    [anon_sym_u2286] = ACTIONS(314),
    [anon_sym_u2282] = ACTIONS(314),
    [anon_sym_u2284] = ACTIONS(314),
    [anon_sym_AT_AT] = ACTIONS(314),
  },
  [STATE(512)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(801),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(513)] = {
    [sym_operator] = STATE(915),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(769),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(769),
    [sym_keyword_value] = ACTIONS(769),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_flexible] = ACTIONS(769),
    [sym_keyword_readonly] = ACTIONS(769),
    [sym_keyword_type] = ACTIONS(769),
    [sym_keyword_default] = ACTIONS(769),
    [sym_keyword_assert] = ACTIONS(769),
    [sym_keyword_permissions] = ACTIONS(769),
    [sym_keyword_comment] = ACTIONS(769),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(514)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(803),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(515)] = {
    [sym_primary_statement] = STATE(2131),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(185),
    [sym_function_call] = STATE(211),
    [sym_base_value] = STATE(211),
    [sym_cast_expression] = STATE(483),
    [sym_binary_expression] = STATE(483),
    [sym_negated_expression] = STATE(483),
    [sym_path] = STATE(483),
    [sym_graph_path] = STATE(213),
    [sym_number] = STATE(323),
    [sym_identifier] = STATE(259),
    [sym_array] = STATE(323),
    [sym_object] = STATE(323),
    [sym_object_key] = STATE(2609),
    [sym_record_id] = STATE(323),
    [sym_sub_query] = STATE(323),
    [sym_duration] = STATE(323),
    [sym_point] = STATE(323),
    [sym_range] = STATE(483),
    [aux_sym_duration_repeat1] = STATE(246),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_only] = ACTIONS(805),
    [sym_keyword_rand] = ACTIONS(807),
    [sym_keyword_true] = ACTIONS(809),
    [sym_keyword_false] = ACTIONS(809),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(809),
    [sym_keyword_null] = ACTIONS(809),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(811),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(813),
    [anon_sym_DASH_GT] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(815),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_LT_DASH] = ACTIONS(627),
    [anon_sym_LT_DASH_GT] = ACTIONS(623),
    [aux_sym_type_name_token1] = ACTIONS(819),
    [sym_string] = ACTIONS(821),
    [sym_prefixed_string] = ACTIONS(821),
    [sym_int] = ACTIONS(823),
    [sym_float] = ACTIONS(825),
    [sym_decimal] = ACTIONS(827),
    [sym_variable_name] = ACTIONS(821),
    [sym_custom_function_name] = ACTIONS(807),
    [sym_function_name] = ACTIONS(807),
    [sym_duration_part] = ACTIONS(829),
  },
  [STATE(516)] = {
    [sym_operator] = STATE(1046),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_drop] = ACTIONS(759),
    [sym_keyword_schemafull] = ACTIONS(759),
    [sym_keyword_schemaless] = ACTIONS(759),
    [sym_keyword_permissions] = ACTIONS(759),
    [sym_keyword_for] = ACTIONS(759),
    [sym_keyword_comment] = ACTIONS(759),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(517)] = {
    [sym_primary_statement] = STATE(2031),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(199),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2916),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_only] = ACTIONS(831),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(835),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(518)] = {
    [sym_primary_statement] = STATE(2131),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(177),
    [sym_function_call] = STATE(195),
    [sym_base_value] = STATE(195),
    [sym_cast_expression] = STATE(465),
    [sym_binary_expression] = STATE(465),
    [sym_negated_expression] = STATE(465),
    [sym_path] = STATE(465),
    [sym_graph_path] = STATE(196),
    [sym_number] = STATE(264),
    [sym_identifier] = STATE(231),
    [sym_array] = STATE(264),
    [sym_object] = STATE(264),
    [sym_object_key] = STATE(2630),
    [sym_record_id] = STATE(264),
    [sym_sub_query] = STATE(264),
    [sym_duration] = STATE(264),
    [sym_point] = STATE(264),
    [sym_range] = STATE(465),
    [aux_sym_duration_repeat1] = STATE(238),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_only] = ACTIONS(837),
    [sym_keyword_rand] = ACTIONS(839),
    [sym_keyword_true] = ACTIONS(841),
    [sym_keyword_false] = ACTIONS(841),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(841),
    [sym_keyword_null] = ACTIONS(841),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(843),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DASH_GT] = ACTIONS(597),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_BANG] = ACTIONS(849),
    [anon_sym_LT_DASH] = ACTIONS(601),
    [anon_sym_LT_DASH_GT] = ACTIONS(597),
    [aux_sym_type_name_token1] = ACTIONS(851),
    [sym_string] = ACTIONS(853),
    [sym_prefixed_string] = ACTIONS(853),
    [sym_int] = ACTIONS(855),
    [sym_float] = ACTIONS(857),
    [sym_decimal] = ACTIONS(859),
    [sym_variable_name] = ACTIONS(853),
    [sym_custom_function_name] = ACTIONS(839),
    [sym_function_name] = ACTIONS(839),
    [sym_duration_part] = ACTIONS(861),
  },
  [STATE(519)] = {
    [sym_primary_statement] = STATE(2602),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(718),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(863),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(520)] = {
    [sym_operator] = STATE(827),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_group] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(697),
    [sym_keyword_permissions] = ACTIONS(697),
    [sym_keyword_comment] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(521)] = {
    [sym_primary_statement] = STATE(2827),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(703),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(865),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(522)] = {
    [sym_primary_statement] = STATE(2832),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(710),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(867),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(523)] = {
    [sym_primary_statement] = STATE(2629),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(727),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(869),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(524)] = {
    [sym_primary_statement] = STATE(2753),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(706),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2900),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_RPAREN] = ACTIONS(871),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(525)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_parallel] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(873),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(526)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(875),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(527)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(877),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(528)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_return] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(879),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(529)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(881),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(530)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(883),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(531)] = {
    [sym_where_clause] = STATE(1822),
    [sym_fetch_clause] = STATE(2095),
    [sym_operator] = STATE(1027),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1578),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(885),
    [sym_keyword_fetch] = ACTIONS(489),
    [sym_keyword_where] = ACTIONS(887),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(889),
    [anon_sym_RPAREN] = ACTIONS(885),
    [anon_sym_RBRACE] = ACTIONS(885),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(532)] = {
    [sym_primary_statement] = STATE(2031),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(193),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2605),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_only] = ACTIONS(891),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(893),
    [anon_sym_BANG] = ACTIONS(895),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(533)] = {
    [sym_operator] = STATE(1035),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(534)] = {
    [sym_operator] = STATE(1035),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(535)] = {
    [sym_operator] = STATE(827),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_changefeed] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(536)] = {
    [sym_operator] = STATE(827),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_changefeed] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(537)] = {
    [sym_operator] = STATE(1046),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_drop] = ACTIONS(705),
    [sym_keyword_schemafull] = ACTIONS(705),
    [sym_keyword_schemaless] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_for] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(538)] = {
    [sym_operator] = STATE(1046),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_drop] = ACTIONS(709),
    [sym_keyword_schemafull] = ACTIONS(709),
    [sym_keyword_schemaless] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_for] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(539)] = {
    [sym_operator] = STATE(1035),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_explain] = ACTIONS(897),
    [sym_keyword_parallel] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_where] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_RPAREN] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(540)] = {
    [sym_operator] = STATE(945),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1585),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(899),
    [sym_keyword_return] = ACTIONS(899),
    [sym_keyword_timeout] = ACTIONS(899),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(899),
    [sym_keyword_set] = ACTIONS(899),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(901),
    [anon_sym_RPAREN] = ACTIONS(899),
    [anon_sym_RBRACE] = ACTIONS(899),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(541)] = {
    [sym_primary_statement] = STATE(2109),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(198),
    [sym_function_call] = STATE(114),
    [sym_base_value] = STATE(114),
    [sym_cast_expression] = STATE(109),
    [sym_binary_expression] = STATE(109),
    [sym_negated_expression] = STATE(109),
    [sym_path] = STATE(109),
    [sym_graph_path] = STATE(116),
    [sym_number] = STATE(66),
    [sym_identifier] = STATE(44),
    [sym_array] = STATE(66),
    [sym_object] = STATE(66),
    [sym_object_key] = STATE(2916),
    [sym_record_id] = STATE(66),
    [sym_sub_query] = STATE(66),
    [sym_duration] = STATE(66),
    [sym_point] = STATE(66),
    [sym_range] = STATE(109),
    [aux_sym_duration_repeat1] = STATE(16),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_rand] = ACTIONS(19),
    [sym_keyword_true] = ACTIONS(23),
    [sym_keyword_false] = ACTIONS(23),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(23),
    [sym_keyword_null] = ACTIONS(23),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(53),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(67),
    [anon_sym_DASH_GT] = ACTIONS(69),
    [anon_sym_LBRACK] = ACTIONS(71),
    [anon_sym_LBRACE] = ACTIONS(73),
    [anon_sym_LT] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(835),
    [anon_sym_LT_DASH] = ACTIONS(79),
    [anon_sym_LT_DASH_GT] = ACTIONS(69),
    [aux_sym_type_name_token1] = ACTIONS(81),
    [sym_string] = ACTIONS(83),
    [sym_prefixed_string] = ACTIONS(83),
    [sym_int] = ACTIONS(85),
    [sym_float] = ACTIONS(87),
    [sym_decimal] = ACTIONS(89),
    [sym_variable_name] = ACTIONS(83),
    [sym_custom_function_name] = ACTIONS(19),
    [sym_function_name] = ACTIONS(19),
    [sym_duration_part] = ACTIONS(91),
  },
  [STATE(542)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_permissions] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(903),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(543)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(905),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(544)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_for] = ACTIONS(288),
    [sym_keyword_comment] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(545)] = {
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_RBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(909),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(546)] = {
    [sym_primary_statement] = STATE(2129),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(178),
    [sym_function_call] = STATE(195),
    [sym_base_value] = STATE(195),
    [sym_cast_expression] = STATE(465),
    [sym_binary_expression] = STATE(465),
    [sym_negated_expression] = STATE(465),
    [sym_path] = STATE(465),
    [sym_graph_path] = STATE(196),
    [sym_number] = STATE(264),
    [sym_identifier] = STATE(231),
    [sym_array] = STATE(264),
    [sym_object] = STATE(264),
    [sym_object_key] = STATE(2630),
    [sym_record_id] = STATE(264),
    [sym_sub_query] = STATE(264),
    [sym_duration] = STATE(264),
    [sym_point] = STATE(264),
    [sym_range] = STATE(465),
    [aux_sym_duration_repeat1] = STATE(238),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(839),
    [sym_keyword_true] = ACTIONS(841),
    [sym_keyword_false] = ACTIONS(841),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(841),
    [sym_keyword_null] = ACTIONS(841),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(843),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DASH_GT] = ACTIONS(597),
    [anon_sym_LBRACK] = ACTIONS(575),
    [anon_sym_LBRACE] = ACTIONS(577),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_BANG] = ACTIONS(849),
    [anon_sym_LT_DASH] = ACTIONS(601),
    [anon_sym_LT_DASH_GT] = ACTIONS(597),
    [aux_sym_type_name_token1] = ACTIONS(851),
    [sym_string] = ACTIONS(853),
    [sym_prefixed_string] = ACTIONS(853),
    [sym_int] = ACTIONS(855),
    [sym_float] = ACTIONS(857),
    [sym_decimal] = ACTIONS(859),
    [sym_variable_name] = ACTIONS(853),
    [sym_custom_function_name] = ACTIONS(839),
    [sym_function_name] = ACTIONS(839),
    [sym_duration_part] = ACTIONS(861),
  },
  [STATE(547)] = {
    [sym_primary_statement] = STATE(2129),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(180),
    [sym_function_call] = STATE(211),
    [sym_base_value] = STATE(211),
    [sym_cast_expression] = STATE(483),
    [sym_binary_expression] = STATE(483),
    [sym_negated_expression] = STATE(483),
    [sym_path] = STATE(483),
    [sym_graph_path] = STATE(213),
    [sym_number] = STATE(323),
    [sym_identifier] = STATE(259),
    [sym_array] = STATE(323),
    [sym_object] = STATE(323),
    [sym_object_key] = STATE(2609),
    [sym_record_id] = STATE(323),
    [sym_sub_query] = STATE(323),
    [sym_duration] = STATE(323),
    [sym_point] = STATE(323),
    [sym_range] = STATE(483),
    [aux_sym_duration_repeat1] = STATE(246),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(11),
    [sym_keyword_rand] = ACTIONS(807),
    [sym_keyword_true] = ACTIONS(809),
    [sym_keyword_false] = ACTIONS(809),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(809),
    [sym_keyword_null] = ACTIONS(809),
    [sym_keyword_live] = ACTIONS(33),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(811),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(63),
    [anon_sym_LPAREN] = ACTIONS(813),
    [anon_sym_DASH_GT] = ACTIONS(623),
    [anon_sym_LBRACK] = ACTIONS(615),
    [anon_sym_LBRACE] = ACTIONS(617),
    [anon_sym_LT] = ACTIONS(815),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_LT_DASH] = ACTIONS(627),
    [anon_sym_LT_DASH_GT] = ACTIONS(623),
    [aux_sym_type_name_token1] = ACTIONS(819),
    [sym_string] = ACTIONS(821),
    [sym_prefixed_string] = ACTIONS(821),
    [sym_int] = ACTIONS(823),
    [sym_float] = ACTIONS(825),
    [sym_decimal] = ACTIONS(827),
    [sym_variable_name] = ACTIONS(821),
    [sym_custom_function_name] = ACTIONS(807),
    [sym_function_name] = ACTIONS(807),
    [sym_duration_part] = ACTIONS(829),
  },
  [STATE(548)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_timeout] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(911),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(549)] = {
    [sym_operator] = STATE(945),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(697),
    [sym_keyword_set] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(550)] = {
    [sym_where_clause] = STATE(1822),
    [sym_fetch_clause] = STATE(2095),
    [sym_operator] = STATE(997),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1672),
    [ts_builtin_sym_end] = ACTIONS(885),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(885),
    [sym_keyword_fetch] = ACTIONS(489),
    [sym_keyword_where] = ACTIONS(913),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(915),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(551)] = {
    [sym_operator] = STATE(945),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_content] = ACTIONS(705),
    [sym_keyword_set] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(552)] = {
    [sym_operator] = STATE(945),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_content] = ACTIONS(709),
    [sym_keyword_set] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(553)] = {
    [sym_operator] = STATE(954),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(554)] = {
    [sym_operator] = STATE(954),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(555)] = {
    [sym_operator] = STATE(1005),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(556)] = {
    [sym_operator] = STATE(1005),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(557)] = {
    [sym_operator] = STATE(1021),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_changefeed] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(558)] = {
    [sym_operator] = STATE(1021),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_changefeed] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(559)] = {
    [sym_operator] = STATE(1029),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_drop] = ACTIONS(705),
    [sym_keyword_schemafull] = ACTIONS(705),
    [sym_keyword_schemaless] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_for] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(560)] = {
    [sym_operator] = STATE(1029),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_drop] = ACTIONS(709),
    [sym_keyword_schemafull] = ACTIONS(709),
    [sym_keyword_schemaless] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_for] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(561)] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(288),
    [sym_keyword_where] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(917),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(562)] = {
    [sym_operator] = STATE(890),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1673),
    [ts_builtin_sym_end] = ACTIONS(899),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(899),
    [sym_keyword_return] = ACTIONS(899),
    [sym_keyword_timeout] = ACTIONS(899),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(899),
    [sym_keyword_set] = ACTIONS(899),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(919),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(563)] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(288),
    [sym_keyword_as] = ACTIONS(288),
    [sym_keyword_omit] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(921),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(564)] = {
    [sym_operator] = STATE(954),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_parallel] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_where] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_RPAREN] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(565)] = {
    [sym_operator] = STATE(954),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(566)] = {
    [sym_operator] = STATE(1005),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(897),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_explain] = ACTIONS(897),
    [sym_keyword_parallel] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_where] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(567)] = {
    [sym_operator] = STATE(1007),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1698),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(923),
    [sym_keyword_explain] = ACTIONS(923),
    [sym_keyword_parallel] = ACTIONS(923),
    [sym_keyword_timeout] = ACTIONS(923),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(925),
    [anon_sym_RPAREN] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(568)] = {
    [sym_operator] = STATE(1021),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_group] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(697),
    [sym_keyword_permissions] = ACTIONS(697),
    [sym_keyword_comment] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(569)] = {
    [sym_operator] = STATE(1007),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(927),
    [sym_keyword_explain] = ACTIONS(927),
    [sym_keyword_parallel] = ACTIONS(927),
    [sym_keyword_timeout] = ACTIONS(927),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(925),
    [anon_sym_RPAREN] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(570)] = {
    [sym_operator] = STATE(1029),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_drop] = ACTIONS(759),
    [sym_keyword_schemafull] = ACTIONS(759),
    [sym_keyword_schemaless] = ACTIONS(759),
    [sym_keyword_permissions] = ACTIONS(759),
    [sym_keyword_for] = ACTIONS(759),
    [sym_keyword_comment] = ACTIONS(759),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(571)] = {
    [sym_primary_statement] = STATE(2109),
    [sym_kill_statement] = STATE(1973),
    [sym_sleep_statement] = STATE(1973),
    [sym_break_statement] = STATE(1973),
    [sym_continue_statement] = STATE(1973),
    [sym_throw_statement] = STATE(1973),
    [sym_info_statement] = STATE(1973),
    [sym_use_statement] = STATE(1973),
    [sym_begin_statement] = STATE(1973),
    [sym_cancel_statement] = STATE(1973),
    [sym_commit_statement] = STATE(1973),
    [sym_live_select_statement] = STATE(1973),
    [sym_value] = STATE(186),
    [sym_function_call] = STATE(27),
    [sym_base_value] = STATE(27),
    [sym_cast_expression] = STATE(115),
    [sym_binary_expression] = STATE(115),
    [sym_negated_expression] = STATE(115),
    [sym_path] = STATE(115),
    [sym_graph_path] = STATE(21),
    [sym_number] = STATE(76),
    [sym_identifier] = STATE(51),
    [sym_array] = STATE(76),
    [sym_object] = STATE(76),
    [sym_object_key] = STATE(2605),
    [sym_record_id] = STATE(76),
    [sym_sub_query] = STATE(76),
    [sym_duration] = STATE(76),
    [sym_point] = STATE(76),
    [sym_range] = STATE(115),
    [aux_sym_duration_repeat1] = STATE(52),
    [sym_comment] = ACTIONS(3),
    [sym_keyword_info] = ACTIONS(5),
    [sym_keyword_throw] = ACTIONS(99),
    [sym_keyword_rand] = ACTIONS(105),
    [sym_keyword_true] = ACTIONS(107),
    [sym_keyword_false] = ACTIONS(107),
    [sym_keyword_begin] = ACTIONS(25),
    [sym_keyword_cancel] = ACTIONS(27),
    [sym_keyword_commit] = ACTIONS(29),
    [sym_keyword_none] = ACTIONS(107),
    [sym_keyword_null] = ACTIONS(107),
    [sym_keyword_live] = ACTIONS(111),
    [sym_keyword_use] = ACTIONS(35),
    [sym_keyword_count] = ACTIONS(125),
    [sym_keyword_break] = ACTIONS(57),
    [sym_keyword_continue] = ACTIONS(59),
    [sym_keyword_sleep] = ACTIONS(61),
    [sym_keyword_kill] = ACTIONS(129),
    [anon_sym_LPAREN] = ACTIONS(131),
    [anon_sym_DASH_GT] = ACTIONS(133),
    [anon_sym_LBRACK] = ACTIONS(135),
    [anon_sym_LBRACE] = ACTIONS(137),
    [anon_sym_LT] = ACTIONS(893),
    [anon_sym_BANG] = ACTIONS(895),
    [anon_sym_LT_DASH] = ACTIONS(145),
    [anon_sym_LT_DASH_GT] = ACTIONS(133),
    [aux_sym_type_name_token1] = ACTIONS(147),
    [sym_string] = ACTIONS(149),
    [sym_prefixed_string] = ACTIONS(149),
    [sym_int] = ACTIONS(151),
    [sym_float] = ACTIONS(153),
    [sym_decimal] = ACTIONS(155),
    [sym_variable_name] = ACTIONS(149),
    [sym_custom_function_name] = ACTIONS(105),
    [sym_function_name] = ACTIONS(105),
    [sym_duration_part] = ACTIONS(157),
  },
  [STATE(572)] = {
    [sym_operator] = STATE(1007),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(573)] = {
    [sym_operator] = STATE(1048),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_group] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(759),
    [sym_keyword_permissions] = ACTIONS(759),
    [sym_keyword_comment] = ACTIONS(759),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(574)] = {
    [sym_operator] = STATE(1003),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(575)] = {
    [sym_operator] = STATE(1003),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(576)] = {
    [sym_operator] = STATE(839),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACK] = ACTIONS(705),
    [anon_sym_QMARK] = ACTIONS(707),
    [anon_sym_LBRACE] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(577)] = {
    [sym_operator] = STATE(918),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(578)] = {
    [sym_operator] = STATE(1007),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(579)] = {
    [sym_operator] = STATE(1007),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(580)] = {
    [sym_operator] = STATE(1011),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(581)] = {
    [sym_operator] = STATE(1011),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(582)] = {
    [sym_operator] = STATE(918),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(583)] = {
    [sym_operator] = STATE(918),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(584)] = {
    [sym_operator] = STATE(890),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_content] = ACTIONS(705),
    [sym_keyword_set] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(585)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(929),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(586)] = {
    [sym_operator] = STATE(890),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_return] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_content] = ACTIONS(697),
    [sym_keyword_set] = ACTIONS(697),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(587)] = {
    [sym_operator] = STATE(890),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_content] = ACTIONS(709),
    [sym_keyword_set] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(588)] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_on] = ACTIONS(288),
    [sym_keyword_as] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(931),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(589)] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_as] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_RPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(933),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(590)] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [sym_keyword_then] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_LPAREN] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LBRACE] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(935),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(591)] = {
    [sym_operator] = STATE(1048),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_changefeed] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(592)] = {
    [sym_operator] = STATE(918),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(897),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_parallel] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_where] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(593)] = {
    [sym_operator] = STATE(999),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1774),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(923),
    [sym_keyword_parallel] = ACTIONS(923),
    [sym_keyword_timeout] = ACTIONS(923),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(937),
    [anon_sym_RPAREN] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(594)] = {
    [sym_operator] = STATE(839),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACK] = ACTIONS(709),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(595)] = {
    [sym_operator] = STATE(999),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1773),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(927),
    [sym_keyword_parallel] = ACTIONS(927),
    [sym_keyword_timeout] = ACTIONS(927),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(937),
    [anon_sym_RPAREN] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(596)] = {
    [sym_operator] = STATE(1011),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_return] = ACTIONS(759),
    [sym_keyword_explain] = ACTIONS(759),
    [sym_keyword_parallel] = ACTIONS(759),
    [sym_keyword_timeout] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(597)] = {
    [sym_comment] = ACTIONS(3),
    [sym_keyword_from] = ACTIONS(288),
    [sym_keyword_as] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_COMMA] = ACTIONS(288),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(650),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(939),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(598)] = {
    [sym_operator] = STATE(984),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1777),
    [ts_builtin_sym_end] = ACTIONS(923),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(923),
    [sym_keyword_explain] = ACTIONS(923),
    [sym_keyword_parallel] = ACTIONS(923),
    [sym_keyword_timeout] = ACTIONS(923),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(941),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(599)] = {
    [sym_operator] = STATE(984),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1776),
    [ts_builtin_sym_end] = ACTIONS(927),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(927),
    [sym_keyword_explain] = ACTIONS(927),
    [sym_keyword_parallel] = ACTIONS(927),
    [sym_keyword_timeout] = ACTIONS(927),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(941),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(600)] = {
    [sym_operator] = STATE(1003),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_parallel] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_RPAREN] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(601)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_limit] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(943),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(602)] = {
    [ts_builtin_sym_end] = ACTIONS(288),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(288),
    [sym_keyword_fetch] = ACTIONS(288),
    [sym_keyword_and] = ACTIONS(288),
    [sym_keyword_or] = ACTIONS(288),
    [sym_keyword_is] = ACTIONS(288),
    [sym_keyword_not] = ACTIONS(290),
    [sym_keyword_contains] = ACTIONS(290),
    [sym_keyword_contains_not] = ACTIONS(288),
    [sym_keyword_contains_all] = ACTIONS(288),
    [sym_keyword_contains_any] = ACTIONS(288),
    [sym_keyword_contains_none] = ACTIONS(288),
    [sym_keyword_inside] = ACTIONS(288),
    [sym_keyword_in] = ACTIONS(290),
    [sym_keyword_not_inside] = ACTIONS(288),
    [sym_keyword_all_inside] = ACTIONS(288),
    [sym_keyword_any_inside] = ACTIONS(288),
    [sym_keyword_none_inside] = ACTIONS(288),
    [sym_keyword_outside] = ACTIONS(288),
    [sym_keyword_intersects] = ACTIONS(288),
    [anon_sym_EQ] = ACTIONS(290),
    [anon_sym_DASH_GT] = ACTIONS(288),
    [anon_sym_LBRACK] = ACTIONS(288),
    [anon_sym_LT] = ACTIONS(290),
    [anon_sym_GT] = ACTIONS(671),
    [anon_sym_LT_DASH] = ACTIONS(290),
    [anon_sym_LT_DASH_GT] = ACTIONS(288),
    [anon_sym_STAR] = ACTIONS(290),
    [anon_sym_DOT] = ACTIONS(290),
    [anon_sym_DOT_DOT] = ACTIONS(945),
    [anon_sym_DASH] = ACTIONS(290),
    [anon_sym_PERCENT] = ACTIONS(288),
    [anon_sym_AT] = ACTIONS(290),
    [anon_sym_LT_PIPE] = ACTIONS(288),
    [anon_sym_AMP_AMP] = ACTIONS(288),
    [anon_sym_PIPE_PIPE] = ACTIONS(288),
    [anon_sym_QMARK_QMARK] = ACTIONS(288),
    [anon_sym_QMARK_COLON] = ACTIONS(288),
    [anon_sym_BANG_EQ] = ACTIONS(288),
    [anon_sym_EQ_EQ] = ACTIONS(288),
    [anon_sym_QMARK_EQ] = ACTIONS(288),
    [anon_sym_STAR_EQ] = ACTIONS(288),
    [anon_sym_TILDE] = ACTIONS(288),
    [anon_sym_BANG_TILDE] = ACTIONS(288),
    [anon_sym_STAR_TILDE] = ACTIONS(288),
    [anon_sym_LT_EQ] = ACTIONS(288),
    [anon_sym_GT_EQ] = ACTIONS(288),
    [anon_sym_PLUS] = ACTIONS(290),
    [anon_sym_PLUS_EQ] = ACTIONS(288),
    [anon_sym_DASH_EQ] = ACTIONS(288),
    [anon_sym_u00d7] = ACTIONS(288),
    [anon_sym_SLASH] = ACTIONS(290),
    [anon_sym_u00f7] = ACTIONS(288),
    [anon_sym_STAR_STAR] = ACTIONS(288),
    [anon_sym_u220b] = ACTIONS(288),
    [anon_sym_u220c] = ACTIONS(288),
    [anon_sym_u2287] = ACTIONS(288),
    [anon_sym_u2283] = ACTIONS(288),
    [anon_sym_u2285] = ACTIONS(288),
    [anon_sym_u2208] = ACTIONS(288),
    [anon_sym_u2209] = ACTIONS(288),
    [anon_sym_u2286] = ACTIONS(288),
    [anon_sym_u2282] = ACTIONS(288),
    [anon_sym_u2284] = ACTIONS(288),
    [anon_sym_AT_AT] = ACTIONS(288),
  },
  [STATE(603)] = {
    [sym_operator] = STATE(1048),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_changefeed] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(604)] = {
    [sym_operator] = STATE(999),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(605)] = {
    [sym_operator] = STATE(994),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1796),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(923),
    [sym_keyword_timeout] = ACTIONS(923),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(947),
    [anon_sym_RPAREN] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(606)] = {
    [sym_operator] = STATE(967),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1885),
    [ts_builtin_sym_end] = ACTIONS(923),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(923),
    [sym_keyword_parallel] = ACTIONS(923),
    [sym_keyword_timeout] = ACTIONS(923),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(949),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(607)] = {
    [sym_operator] = STATE(967),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1884),
    [ts_builtin_sym_end] = ACTIONS(927),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(927),
    [sym_keyword_parallel] = ACTIONS(927),
    [sym_keyword_timeout] = ACTIONS(927),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(949),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(608)] = {
    [sym_operator] = STATE(991),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_return] = ACTIONS(759),
    [sym_keyword_explain] = ACTIONS(759),
    [sym_keyword_parallel] = ACTIONS(759),
    [sym_keyword_timeout] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(609)] = {
    [sym_operator] = STATE(1027),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_fetch] = ACTIONS(705),
    [sym_keyword_where] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(610)] = {
    [sym_operator] = STATE(1027),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_fetch] = ACTIONS(709),
    [sym_keyword_where] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(611)] = {
    [sym_operator] = STATE(975),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(612)] = {
    [sym_operator] = STATE(999),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(613)] = {
    [sym_operator] = STATE(1031),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_RPAREN] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(614)] = {
    [sym_operator] = STATE(1031),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_RPAREN] = ACTIONS(705),
    [anon_sym_RBRACE] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(615)] = {
    [sym_operator] = STATE(1031),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_RPAREN] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(616)] = {
    [sym_operator] = STATE(1033),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_group] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [sym_keyword_changefeed] = ACTIONS(705),
    [sym_keyword_permissions] = ACTIONS(705),
    [sym_keyword_comment] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(617)] = {
    [sym_operator] = STATE(984),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(697),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_explain] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(618)] = {
    [sym_operator] = STATE(975),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(619)] = {
    [sym_operator] = STATE(975),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(897),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(897),
    [sym_keyword_return] = ACTIONS(897),
    [sym_keyword_parallel] = ACTIONS(897),
    [sym_keyword_timeout] = ACTIONS(897),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(620)] = {
    [sym_operator] = STATE(984),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_COMMA] = ACTIONS(705),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(621)] = {
    [sym_operator] = STATE(991),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_return] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(622)] = {
    [sym_operator] = STATE(1033),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_group] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [sym_keyword_changefeed] = ACTIONS(709),
    [sym_keyword_permissions] = ACTIONS(709),
    [sym_keyword_comment] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(623)] = {
    [sym_operator] = STATE(984),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(709),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(709),
    [sym_keyword_explain] = ACTIONS(709),
    [sym_keyword_parallel] = ACTIONS(709),
    [sym_keyword_timeout] = ACTIONS(709),
    [sym_keyword_and] = ACTIONS(709),
    [sym_keyword_or] = ACTIONS(709),
    [sym_keyword_is] = ACTIONS(709),
    [sym_keyword_not] = ACTIONS(711),
    [sym_keyword_contains] = ACTIONS(711),
    [sym_keyword_contains_not] = ACTIONS(709),
    [sym_keyword_contains_all] = ACTIONS(709),
    [sym_keyword_contains_any] = ACTIONS(709),
    [sym_keyword_contains_none] = ACTIONS(709),
    [sym_keyword_inside] = ACTIONS(709),
    [sym_keyword_in] = ACTIONS(711),
    [sym_keyword_not_inside] = ACTIONS(709),
    [sym_keyword_all_inside] = ACTIONS(709),
    [sym_keyword_any_inside] = ACTIONS(709),
    [sym_keyword_none_inside] = ACTIONS(709),
    [sym_keyword_outside] = ACTIONS(709),
    [sym_keyword_intersects] = ACTIONS(709),
    [anon_sym_EQ] = ACTIONS(711),
    [anon_sym_COMMA] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_AT] = ACTIONS(711),
    [anon_sym_LT_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_QMARK_QMARK] = ACTIONS(709),
    [anon_sym_QMARK_COLON] = ACTIONS(709),
    [anon_sym_BANG_EQ] = ACTIONS(709),
    [anon_sym_EQ_EQ] = ACTIONS(709),
    [anon_sym_QMARK_EQ] = ACTIONS(709),
    [anon_sym_STAR_EQ] = ACTIONS(709),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_BANG_TILDE] = ACTIONS(709),
    [anon_sym_STAR_TILDE] = ACTIONS(709),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_PLUS_EQ] = ACTIONS(709),
    [anon_sym_DASH_EQ] = ACTIONS(709),
    [anon_sym_u00d7] = ACTIONS(709),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_u00f7] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_u220b] = ACTIONS(709),
    [anon_sym_u220c] = ACTIONS(709),
    [anon_sym_u2287] = ACTIONS(709),
    [anon_sym_u2283] = ACTIONS(709),
    [anon_sym_u2285] = ACTIONS(709),
    [anon_sym_u2208] = ACTIONS(709),
    [anon_sym_u2209] = ACTIONS(709),
    [anon_sym_u2286] = ACTIONS(709),
    [anon_sym_u2282] = ACTIONS(709),
    [anon_sym_u2284] = ACTIONS(709),
    [anon_sym_AT_AT] = ACTIONS(709),
  },
  [STATE(624)] = {
    [sym_operator] = STATE(999),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_parallel] = ACTIONS(697),
    [sym_keyword_timeout] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(625)] = {
    [sym_operator] = STATE(1033),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(759),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_group] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [sym_keyword_changefeed] = ACTIONS(759),
    [sym_keyword_permissions] = ACTIONS(759),
    [sym_keyword_comment] = ACTIONS(759),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(626)] = {
    [sym_operator] = STATE(991),
    [sym_binary_operator] = STATE(1132),
    [ts_builtin_sym_end] = ACTIONS(705),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(705),
    [sym_keyword_return] = ACTIONS(705),
    [sym_keyword_explain] = ACTIONS(705),
    [sym_keyword_parallel] = ACTIONS(705),
    [sym_keyword_timeout] = ACTIONS(705),
    [sym_keyword_and] = ACTIONS(705),
    [sym_keyword_or] = ACTIONS(705),
    [sym_keyword_is] = ACTIONS(705),
    [sym_keyword_not] = ACTIONS(707),
    [sym_keyword_contains] = ACTIONS(707),
    [sym_keyword_contains_not] = ACTIONS(705),
    [sym_keyword_contains_all] = ACTIONS(705),
    [sym_keyword_contains_any] = ACTIONS(705),
    [sym_keyword_contains_none] = ACTIONS(705),
    [sym_keyword_inside] = ACTIONS(705),
    [sym_keyword_in] = ACTIONS(707),
    [sym_keyword_not_inside] = ACTIONS(705),
    [sym_keyword_all_inside] = ACTIONS(705),
    [sym_keyword_any_inside] = ACTIONS(705),
    [sym_keyword_none_inside] = ACTIONS(705),
    [sym_keyword_outside] = ACTIONS(705),
    [sym_keyword_intersects] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(707),
    [anon_sym_LT] = ACTIONS(707),
    [anon_sym_GT] = ACTIONS(707),
    [anon_sym_STAR] = ACTIONS(707),
    [anon_sym_DASH] = ACTIONS(707),
    [anon_sym_PERCENT] = ACTIONS(705),
    [anon_sym_AT] = ACTIONS(707),
    [anon_sym_LT_PIPE] = ACTIONS(705),
    [anon_sym_AMP_AMP] = ACTIONS(705),
    [anon_sym_PIPE_PIPE] = ACTIONS(705),
    [anon_sym_QMARK_QMARK] = ACTIONS(705),
    [anon_sym_QMARK_COLON] = ACTIONS(705),
    [anon_sym_BANG_EQ] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(705),
    [anon_sym_QMARK_EQ] = ACTIONS(705),
    [anon_sym_STAR_EQ] = ACTIONS(705),
    [anon_sym_TILDE] = ACTIONS(705),
    [anon_sym_BANG_TILDE] = ACTIONS(705),
    [anon_sym_STAR_TILDE] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(707),
    [anon_sym_PLUS_EQ] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(705),
    [anon_sym_u00d7] = ACTIONS(705),
    [anon_sym_SLASH] = ACTIONS(707),
    [anon_sym_u00f7] = ACTIONS(705),
    [anon_sym_STAR_STAR] = ACTIONS(705),
    [anon_sym_u220b] = ACTIONS(705),
    [anon_sym_u220c] = ACTIONS(705),
    [anon_sym_u2287] = ACTIONS(705),
    [anon_sym_u2283] = ACTIONS(705),
    [anon_sym_u2285] = ACTIONS(705),
    [anon_sym_u2208] = ACTIONS(705),
    [anon_sym_u2209] = ACTIONS(705),
    [anon_sym_u2286] = ACTIONS(705),
    [anon_sym_u2282] = ACTIONS(705),
    [anon_sym_u2284] = ACTIONS(705),
    [anon_sym_AT_AT] = ACTIONS(705),
  },
  [STATE(627)] = {
    [sym_operator] = STATE(994),
    [sym_binary_operator] = STATE(1132),
    [aux_sym_update_statement_repeat1] = STATE(1794),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(927),
    [sym_keyword_timeout] = ACTIONS(927),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(947),
    [anon_sym_RPAREN] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(628)] = {
    [sym_operator] = STATE(1027),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(697),
    [sym_keyword_fetch] = ACTIONS(697),
    [sym_keyword_where] = ACTIONS(697),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_COMMA] = ACTIONS(697),
    [anon_sym_RPAREN] = ACTIONS(697),
    [anon_sym_RBRACE] = ACTIONS(697),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
  [STATE(629)] = {
    [sym_operator] = STATE(1003),
    [sym_binary_operator] = STATE(1132),
    [sym_comment] = ACTIONS(3),
    [sym_semi_colon] = ACTIONS(759),
    [sym_keyword_return] = ACTIONS(759),
    [sym_keyword_parallel] = ACTIONS(759),
    [sym_keyword_timeout] = ACTIONS(759),
    [sym_keyword_and] = ACTIONS(457),
    [sym_keyword_or] = ACTIONS(457),
    [sym_keyword_is] = ACTIONS(459),
    [sym_keyword_not] = ACTIONS(461),
    [sym_keyword_contains] = ACTIONS(463),
    [sym_keyword_contains_not] = ACTIONS(457),
    [sym_keyword_contains_all] = ACTIONS(457),
    [sym_keyword_contains_any] = ACTIONS(457),
    [sym_keyword_contains_none] = ACTIONS(457),
    [sym_keyword_inside] = ACTIONS(457),
    [sym_keyword_in] = ACTIONS(463),
    [sym_keyword_not_inside] = ACTIONS(457),
    [sym_keyword_all_inside] = ACTIONS(457),
    [sym_keyword_any_inside] = ACTIONS(457),
    [sym_keyword_none_inside] = ACTIONS(457),
    [sym_keyword_outside] = ACTIONS(457),
    [sym_keyword_intersects] = ACTIONS(457),
    [anon_sym_EQ] = ACTIONS(463),
    [anon_sym_RPAREN] = ACTIONS(759),
    [anon_sym_RBRACE] = ACTIONS(759),
    [anon_sym_LT] = ACTIONS(463),
    [anon_sym_GT] = ACTIONS(463),
    [anon_sym_STAR] = ACTIONS(479),
    [anon_sym_DASH] = ACTIONS(463),
    [anon_sym_PERCENT] = ACTIONS(457),
    [anon_sym_AT] = ACTIONS(481),
    [anon_sym_LT_PIPE] = ACTIONS(483),
    [anon_sym_AMP_AMP] = ACTIONS(485),
    [anon_sym_PIPE_PIPE] = ACTIONS(485),
    [anon_sym_QMARK_QMARK] = ACTIONS(485),
    [anon_sym_QMARK_COLON] = ACTIONS(485),
    [anon_sym_BANG_EQ] = ACTIONS(485),
    [anon_sym_EQ_EQ] = ACTIONS(485),
    [anon_sym_QMARK_EQ] = ACTIONS(485),
    [anon_sym_STAR_EQ] = ACTIONS(485),
    [anon_sym_TILDE] = ACTIONS(485),
    [anon_sym_BANG_TILDE] = ACTIONS(485),
    [anon_sym_STAR_TILDE] = ACTIONS(485),
    [anon_sym_LT_EQ] = ACTIONS(485),
    [anon_sym_GT_EQ] = ACTIONS(485),
    [anon_sym_PLUS] = ACTIONS(479),
    [anon_sym_PLUS_EQ] = ACTIONS(485),
    [anon_sym_DASH_EQ] = ACTIONS(485),
    [anon_sym_u00d7] = ACTIONS(485),
    [anon_sym_SLASH] = ACTIONS(479),
    [anon_sym_u00f7] = ACTIONS(485),
    [anon_sym_STAR_STAR] = ACTIONS(485),
    [anon_sym_u220b] = ACTIONS(485),
    [anon_sym_u220c] = ACTIONS(485),
    [anon_sym_u2287] = ACTIONS(485),
    [anon_sym_u2283] = ACTIONS(485),
    [anon_sym_u2285] = ACTIONS(485),
    [anon_sym_u2208] = ACTIONS(485),
    [anon_sym_u2209] = ACTIONS(485),
    [anon_sym_u2286] = ACTIONS(485),
    [anon_sym_u2282] = ACTIONS(485),
    [anon_sym_u2284] = ACTIONS(485),
    [anon_sym_AT_AT] = ACTIONS(485),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1037), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2070), 1,
      sym_limit_clause,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(951), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [93] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(953), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1946), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(927), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [186] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(975), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [275] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(955), 1,
      anon_sym_COMMA,
    ACTIONS(188), 12,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(186), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [348] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(957), 1,
      anon_sym_COMMA,
    ACTIONS(188), 12,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(186), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [421] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(959), 1,
      anon_sym_COMMA,
    ACTIONS(188), 12,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(186), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [494] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(961), 1,
      anon_sym_COMMA,
    ACTIONS(188), 12,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(186), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [567] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(967), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [642] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(967), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(697), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [731] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(967), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [806] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1925), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(927), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [899] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(994), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 50,
      sym_semi_colon,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [974] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(994), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 50,
      sym_semi_colon,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1049] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(997), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_where,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1124] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(953), 1,
      anon_sym_COMMA,
    STATE(959), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1924), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(923), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1217] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1001), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1292] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1001), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1367] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(965), 1,
      sym_keyword_as,
    ACTIONS(967), 1,
      sym_keyword_where,
    STATE(980), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2210), 1,
      sym_where_clause,
    ACTIONS(969), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1462] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1041), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 50,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1537] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1041), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 50,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1612] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(650), 1,
      anon_sym_GT,
    ACTIONS(971), 1,
      anon_sym_DOT_DOT,
    ACTIONS(290), 12,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(288), 49,
      sym_keyword_from,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1687] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1044), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 50,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1762] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1044), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 50,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(973), 1,
      anon_sym_COMMA,
    ACTIONS(188), 12,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LT_DASH,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(186), 50,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [1910] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(975), 1,
      sym_keyword_then,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1019), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1770), 2,
      sym_block,
      sym_sub_query,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2005] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(697), 5,
      sym_semi_colon,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2094] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(997), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(697), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_where,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2183] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1941), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(923), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2276] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1001), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(897), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2365] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(994), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(697), 5,
      sym_semi_colon,
      sym_keyword_timeout,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2454] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1041), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 5,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2543] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1044), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 5,
      sym_semi_colon,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2632] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(997), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 50,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_where,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2707] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(983), 1,
      sym_keyword_as,
    STATE(902), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(981), 3,
      sym_keyword_from,
      sym_keyword_omit,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2797] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1037), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      sym_semi_colon,
      sym_keyword_limit,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2871] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1037), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      sym_semi_colon,
      sym_keyword_limit,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [2945] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1039), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3019] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1039), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3093] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(902), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      sym_keyword_from,
      sym_keyword_as,
      sym_keyword_omit,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3167] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(980), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      sym_keyword_as,
      sym_keyword_where,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3241] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(980), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      sym_keyword_as,
      sym_keyword_where,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3315] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(897), 4,
      sym_semi_colon,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3403] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(959), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3477] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(959), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(697), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3565] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(959), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3639] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(985), 1,
      anon_sym_COMMA,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2149), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3731] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(902), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      sym_keyword_from,
      sym_keyword_as,
      sym_keyword_omit,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3805] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(985), 1,
      anon_sym_COMMA,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2059), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(927), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3897] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1017), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [3971] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1017), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4059] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1039), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 4,
      sym_semi_colon,
      sym_keyword_fetch,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4147] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1025), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_for,
      sym_keyword_comment,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4235] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1017), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4309] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1025), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4383] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1025), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 49,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4457] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1009), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2070), 1,
      sym_limit_clause,
    ACTIONS(951), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4549] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(987), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2196), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4640] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1013), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4713] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1013), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4786] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1015), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4859] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1015), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [4932] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(697), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5019] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(897), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_COMMA,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5106] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1019), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_then,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5179] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1019), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      sym_keyword_then,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5252] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1023), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      sym_keyword_from,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5325] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1023), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      sym_keyword_from,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5398] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(989), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2337), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5489] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(991), 1,
      anon_sym_COMMA,
    ACTIONS(993), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2245), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5580] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(995), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5667] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2296), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5758] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(999), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5845] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(1001), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [5932] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1003), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2340), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6023] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2354), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6114] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1007), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2319), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6205] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1009), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2197), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6296] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1011), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2195), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6387] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1013), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2216), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6478] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1015), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2303), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6569] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1017), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2304), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6660] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1021), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2267), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6751] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(983), 1,
      sym_keyword_as,
    STATE(925), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(981), 2,
      sym_keyword_on,
      anon_sym_COMMA,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6840] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(925), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      sym_keyword_on,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [6913] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(1023), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7000] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(925), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      sym_keyword_on,
      sym_keyword_as,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7073] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1025), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2288), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7164] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1027), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2313), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7255] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1029), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2361), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7346] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1031), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2220), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7437] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(983), 1,
      sym_keyword_as,
    STATE(1023), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(981), 2,
      sym_keyword_from,
      anon_sym_COMMA,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7526] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(1033), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7613] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1013), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7700] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(1035), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7787] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(1015), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(759), 3,
      sym_keyword_as,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7874] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1037), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2222), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [7965] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1039), 1,
      anon_sym_COMMA,
    ACTIONS(1041), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2332), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8056] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1043), 1,
      anon_sym_RPAREN,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2309), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8147] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1045), 1,
      anon_sym_COMMA,
    ACTIONS(1047), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2334), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8238] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1009), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_limit,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8311] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8384] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1009), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_limit,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8457] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 48,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_COMMA,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8530] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1049), 1,
      anon_sym_COMMA,
    ACTIONS(1051), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(2238), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8621] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(1053), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8707] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(759), 1,
      anon_sym_RBRACK,
    ACTIONS(1055), 1,
      anon_sym_QMARK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8795] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1691), 1,
      sym_block,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8883] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(999), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [8969] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(1023), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9055] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(1001), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9141] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1977), 1,
      sym_block,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9229] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(1035), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9315] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    STATE(1384), 1,
      sym_block,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9403] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(1033), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9489] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(995), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9575] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1057), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9660] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(987), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(711), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(709), 46,
      sym_keyword_from,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9731] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1059), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9816] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(759), 1,
      ts_builtin_sym_end,
    STATE(836), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9901] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1061), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [9986] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1063), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10071] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1065), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10156] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1067), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10241] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1069), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10326] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1071), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10411] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1073), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10496] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(987), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(707), 11,
      sym_keyword_not,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_STAR,
      anon_sym_DASH,
      anon_sym_AT,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(705), 46,
      sym_keyword_from,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_is,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
      anon_sym_LT_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10567] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1075), 1,
      anon_sym_RBRACK,
    STATE(839), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10652] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(459), 1,
      sym_keyword_is,
    ACTIONS(461), 1,
      sym_keyword_not,
    ACTIONS(481), 1,
      anon_sym_AT,
    ACTIONS(483), 1,
      anon_sym_LT_PIPE,
    ACTIONS(1077), 1,
      sym_keyword_from,
    STATE(987), 1,
      sym_operator,
    STATE(1132), 1,
      sym_binary_operator,
    ACTIONS(479), 3,
      anon_sym_STAR,
      anon_sym_PLUS,
      anon_sym_SLASH,
    ACTIONS(463), 6,
      sym_keyword_contains,
      sym_keyword_in,
      anon_sym_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DASH,
    ACTIONS(457), 14,
      sym_keyword_and,
      sym_keyword_or,
      sym_keyword_contains_not,
      sym_keyword_contains_all,
      sym_keyword_contains_any,
      sym_keyword_contains_none,
      sym_keyword_inside,
      sym_keyword_not_inside,
      sym_keyword_all_inside,
      sym_keyword_any_inside,
      sym_keyword_none_inside,
      sym_keyword_outside,
      sym_keyword_intersects,
      anon_sym_PERCENT,
    ACTIONS(485), 29,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_QMARK,
      anon_sym_QMARK_COLON,
      anon_sym_BANG_EQ,
      anon_sym_EQ_EQ,
      anon_sym_QMARK_EQ,
      anon_sym_STAR_EQ,
      anon_sym_TILDE,
      anon_sym_BANG_TILDE,
      anon_sym_STAR_TILDE,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_u00d7,
      anon_sym_u00f7,
      anon_sym_STAR_STAR,
      anon_sym_u220b,
      anon_sym_u220c,
      anon_sym_u2287,
      anon_sym_u2283,
      anon_sym_u2285,
      anon_sym_u2208,
      anon_sym_u2209,
      anon_sym_u2286,
      anon_sym_u2282,
      anon_sym_u2284,
      anon_sym_AT_AT,
  [10737] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1079), 1,
      sym_keyword_value,
    ACTIONS(1083), 1,
      anon_sym_LT,
    ACTIONS(1085), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(595), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2637), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10846] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1087), 1,
      sym_keyword_value,
    ACTIONS(1089), 1,
      anon_sym_LT,
    ACTIONS(1091), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(599), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2618), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [10955] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1093), 1,
      sym_keyword_value,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(677), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11064] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1095), 1,
      sym_keyword_value,
    ACTIONS(1097), 1,
      anon_sym_LT,
    ACTIONS(1099), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(569), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2643), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11173] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1101), 1,
      sym_keyword_value,
    ACTIONS(1103), 1,
      anon_sym_LT,
    ACTIONS(1105), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(631), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2612), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11282] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1107), 1,
      sym_keyword_if,
    ACTIONS(1109), 1,
      sym_keyword_overwrite,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(712), 1,
      sym_value,
    STATE(781), 1,
      sym_if_not_exists_clause,
    STATE(2066), 1,
      sym_inclusive_predicate,
    STATE(2123), 1,
      sym_predicate,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11395] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1117), 1,
      sym_keyword_value,
    ACTIONS(1119), 1,
      anon_sym_LT,
    ACTIONS(1121), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(607), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2613), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11504] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1123), 1,
      sym_keyword_value,
    ACTIONS(1125), 1,
      anon_sym_LT,
    ACTIONS(1127), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(627), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2635), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11613] = 31,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1107), 1,
      sym_keyword_if,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1129), 1,
      sym_keyword_overwrite,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(712), 1,
      sym_value,
    STATE(774), 1,
      sym_if_not_exists_clause,
    STATE(2017), 1,
      sym_inclusive_predicate,
    STATE(2123), 1,
      sym_predicate,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11726] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      sym_keyword_if,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1131), 1,
      sym_keyword_value,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(640), 1,
      sym_value,
    STATE(1755), 1,
      sym_if_statement,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1081), 3,
      sym_keyword_diff,
      sym_keyword_before,
      sym_keyword_after,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11835] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1133), 1,
      sym_keyword_value,
    ACTIONS(1135), 1,
      sym_keyword_diff,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(663), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2128), 1,
      sym_inclusive_predicate,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [11945] = 30,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1133), 1,
      sym_keyword_value,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    ACTIONS(1141), 1,
      sym_keyword_diff,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(663), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2128), 1,
      sym_inclusive_predicate,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12055] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1143), 1,
      sym_keyword_only,
    ACTIONS(1145), 1,
      anon_sym_PIPE,
    ACTIONS(1147), 1,
      anon_sym_LT,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(562), 1,
      sym_value,
    STATE(1465), 1,
      sym_create_target,
    STATE(1621), 1,
      sym_multi_record,
    STATE(2834), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12162] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1133), 1,
      sym_keyword_value,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(663), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2128), 1,
      sym_inclusive_predicate,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12269] = 29,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1145), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      sym_keyword_only,
    ACTIONS(1153), 1,
      anon_sym_LT,
    ACTIONS(1155), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(540), 1,
      sym_value,
    STATE(1411), 1,
      sym_create_target,
    STATE(1621), 1,
      sym_multi_record,
    STATE(2600), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12376] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(712), 1,
      sym_value,
    STATE(2020), 1,
      sym_inclusive_predicate,
    STATE(2123), 1,
      sym_predicate,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12480] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1145), 1,
      anon_sym_PIPE,
    ACTIONS(1147), 1,
      anon_sym_LT,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(562), 1,
      sym_value,
    STATE(1459), 1,
      sym_create_target,
    STATE(1621), 1,
      sym_multi_record,
    STATE(2834), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12584] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1157), 1,
      anon_sym_LT,
    ACTIONS(1159), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(720), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2153), 1,
      sym_inclusive_predicate,
    STATE(2655), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12688] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(712), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2153), 1,
      sym_inclusive_predicate,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12792] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1157), 1,
      anon_sym_LT,
    ACTIONS(1159), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(720), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2218), 1,
      sym_inclusive_predicate,
    STATE(2655), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [12896] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1157), 1,
      anon_sym_LT,
    ACTIONS(1159), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(720), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2297), 1,
      sym_inclusive_predicate,
    STATE(2655), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13000] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1145), 1,
      anon_sym_PIPE,
    ACTIONS(1153), 1,
      anon_sym_LT,
    ACTIONS(1155), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(540), 1,
      sym_value,
    STATE(1387), 1,
      sym_create_target,
    STATE(1621), 1,
      sym_multi_record,
    STATE(2600), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13104] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(712), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2159), 1,
      sym_inclusive_predicate,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13208] = 28,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1115), 1,
      anon_sym_STAR,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(663), 1,
      sym_value,
    STATE(2123), 1,
      sym_predicate,
    STATE(2153), 1,
      sym_inclusive_predicate,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13312] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1161), 1,
      anon_sym_QMARK,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(647), 1,
      sym_value,
    STATE(2329), 1,
      sym_graph_predicate,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13413] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1161), 1,
      anon_sym_QMARK,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(647), 1,
      sym_value,
    STATE(2262), 1,
      sym_graph_predicate,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13514] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1161), 1,
      anon_sym_QMARK,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(647), 1,
      sym_value,
    STATE(2325), 1,
      sym_graph_predicate,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13615] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1161), 1,
      anon_sym_QMARK,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(647), 1,
      sym_value,
    STATE(2244), 1,
      sym_graph_predicate,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13716] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1167), 1,
      sym_keyword_where,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(754), 1,
      sym_value,
    STATE(2437), 1,
      sym_where_clause,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13817] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1161), 1,
      anon_sym_QMARK,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(647), 1,
      sym_value,
    STATE(2427), 1,
      sym_graph_predicate,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [13918] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1167), 1,
      sym_keyword_where,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(750), 1,
      sym_value,
    STATE(2556), 1,
      sym_where_clause,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14019] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1167), 1,
      sym_keyword_where,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(753), 1,
      sym_value,
    STATE(2495), 1,
      sym_where_clause,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14120] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1169), 1,
      sym_keyword_by,
    ACTIONS(1171), 1,
      anon_sym_LT,
    ACTIONS(1173), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(416), 1,
      sym_value,
    STATE(1580), 1,
      sym_order_criteria,
    STATE(2646), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14221] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1167), 1,
      sym_keyword_where,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(751), 1,
      sym_value,
    STATE(2413), 1,
      sym_where_clause,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14322] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1167), 1,
      sym_keyword_where,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(745), 1,
      sym_value,
    STATE(2434), 1,
      sym_where_clause,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14423] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1175), 1,
      sym_keyword_by,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1185), 1,
      anon_sym_LT,
    ACTIONS(1187), 1,
      anon_sym_BANG,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(397), 1,
      sym_value,
    STATE(1445), 1,
      sym_order_criteria,
    STATE(2669), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14524] = 27,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1161), 1,
      anon_sym_QMARK,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(647), 1,
      sym_value,
    STATE(2231), 1,
      sym_graph_predicate,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14625] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1201), 1,
      sym_keyword_only,
    ACTIONS(1203), 1,
      anon_sym_LT,
    ACTIONS(1205), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(181), 1,
      sym_value,
    STATE(2917), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14723] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1207), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(726), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14821] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1209), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [14919] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1211), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15017] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1213), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15115] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1185), 1,
      anon_sym_LT,
    ACTIONS(1187), 1,
      anon_sym_BANG,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(397), 1,
      sym_value,
    STATE(1464), 1,
      sym_order_criteria,
    STATE(2669), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15213] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1171), 1,
      anon_sym_LT,
    ACTIONS(1173), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(416), 1,
      sym_value,
    STATE(1531), 1,
      sym_order_criteria,
    STATE(2646), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15311] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1215), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(711), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15409] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1217), 1,
      anon_sym_RPAREN,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(697), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15507] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1185), 1,
      anon_sym_LT,
    ACTIONS(1187), 1,
      anon_sym_BANG,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(397), 1,
      sym_value,
    STATE(1470), 1,
      sym_order_criteria,
    STATE(2669), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15605] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1219), 1,
      anon_sym_RPAREN,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(717), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15703] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1221), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15801] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1223), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15899] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1225), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(728), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [15997] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1227), 1,
      anon_sym_RPAREN,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(686), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16095] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1229), 1,
      sym_keyword_only,
    ACTIONS(1231), 1,
      anon_sym_LT,
    ACTIONS(1233), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(426), 1,
      sym_value,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16193] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1235), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16291] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1171), 1,
      anon_sym_LT,
    ACTIONS(1173), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(416), 1,
      sym_value,
    STATE(1470), 1,
      sym_order_criteria,
    STATE(2646), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16389] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1237), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16487] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1239), 1,
      anon_sym_RPAREN,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(716), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16585] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1241), 1,
      anon_sym_RPAREN,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(709), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16683] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1243), 1,
      sym_keyword_only,
    ACTIONS(1245), 1,
      anon_sym_LT,
    ACTIONS(1247), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(176), 1,
      sym_value,
    STATE(2606), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16781] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1249), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16879] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1251), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(698), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [16977] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1253), 1,
      sym_keyword_always,
    ACTIONS(1255), 1,
      anon_sym_LT,
    ACTIONS(1257), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(480), 1,
      sym_value,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17075] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1259), 1,
      sym_keyword_only,
    ACTIONS(1261), 1,
      anon_sym_LT,
    ACTIONS(1263), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(439), 1,
      sym_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17173] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1265), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(733), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17271] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1267), 1,
      sym_keyword_always,
    ACTIONS(1269), 1,
      anon_sym_LT,
    ACTIONS(1271), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(510), 1,
      sym_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17369] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(663), 1,
      sym_value,
    STATE(2550), 1,
      sym_predicate,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17467] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1273), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17565] = 26,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1275), 1,
      anon_sym_RBRACK,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17663] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1277), 1,
      anon_sym_LT,
    ACTIONS(1279), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(535), 1,
      sym_value,
    STATE(2703), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17758] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1281), 1,
      anon_sym_LT,
    ACTIONS(1283), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(487), 1,
      sym_value,
    STATE(2691), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17853] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(700), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [17948] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(704), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18043] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(705), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18138] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(707), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18233] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(699), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18328] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1285), 1,
      anon_sym_LT,
    ACTIONS(1287), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(758), 1,
      sym_value,
    STATE(2611), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18423] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(657), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18518] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(732), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18613] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1231), 1,
      anon_sym_LT,
    ACTIONS(1233), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(433), 1,
      sym_value,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18708] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1245), 1,
      anon_sym_LT,
    ACTIONS(1247), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(179), 1,
      sym_value,
    STATE(2606), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18803] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(576), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18898] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(737), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [18993] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(691), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19088] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(655), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19183] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(594), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19278] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(702), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19373] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1289), 1,
      anon_sym_LT,
    ACTIONS(1291), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(531), 1,
      sym_value,
    STATE(2663), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19468] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1255), 1,
      anon_sym_LT,
    ACTIONS(1257), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(479), 1,
      sym_value,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19563] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1255), 1,
      anon_sym_LT,
    ACTIONS(1257), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(495), 1,
      sym_value,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19658] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(721), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19753] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1293), 1,
      anon_sym_LT,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(613), 1,
      sym_value,
    STATE(2681), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19848] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1297), 1,
      anon_sym_LT,
    ACTIONS(1299), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(630), 1,
      sym_value,
    STATE(2697), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [19943] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1255), 1,
      anon_sym_LT,
    ACTIONS(1257), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(474), 1,
      sym_value,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20038] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(675), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20133] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1277), 1,
      anon_sym_LT,
    ACTIONS(1279), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(464), 1,
      sym_value,
    STATE(2703), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20228] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1277), 1,
      anon_sym_LT,
    ACTIONS(1279), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(438), 1,
      sym_value,
    STATE(2703), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20323] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(815), 1,
      anon_sym_LT,
    ACTIONS(817), 1,
      anon_sym_BANG,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(420), 1,
      sym_value,
    STATE(2609), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20418] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(815), 1,
      anon_sym_LT,
    ACTIONS(817), 1,
      anon_sym_BANG,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(432), 1,
      sym_value,
    STATE(2609), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20513] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(815), 1,
      anon_sym_LT,
    ACTIONS(817), 1,
      anon_sym_BANG,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(421), 1,
      sym_value,
    STATE(2609), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20608] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(740), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20703] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(734), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20798] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(730), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20893] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(847), 1,
      anon_sym_LT,
    ACTIONS(849), 1,
      anon_sym_BANG,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(401), 1,
      sym_value,
    STATE(2630), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [20988] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(847), 1,
      anon_sym_LT,
    ACTIONS(849), 1,
      anon_sym_BANG,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(385), 1,
      sym_value,
    STATE(2630), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21083] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(847), 1,
      anon_sym_LT,
    ACTIONS(849), 1,
      anon_sym_BANG,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(391), 1,
      sym_value,
    STATE(2630), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21178] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(739), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21273] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1185), 1,
      anon_sym_LT,
    ACTIONS(1187), 1,
      anon_sym_BANG,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(384), 1,
      sym_value,
    STATE(2669), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21368] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1301), 1,
      anon_sym_LT,
    ACTIONS(1303), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(550), 1,
      sym_value,
    STATE(2631), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21463] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1185), 1,
      anon_sym_LT,
    ACTIONS(1187), 1,
      anon_sym_BANG,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(390), 1,
      sym_value,
    STATE(2669), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21558] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(749), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21653] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(744), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21748] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(736), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21843] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1261), 1,
      anon_sym_LT,
    ACTIONS(1263), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(436), 1,
      sym_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [21938] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1305), 1,
      anon_sym_LT,
    ACTIONS(1307), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(654), 1,
      sym_value,
    STATE(2649), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22033] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1269), 1,
      anon_sym_LT,
    ACTIONS(1271), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(507), 1,
      sym_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22128] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1269), 1,
      anon_sym_LT,
    ACTIONS(1271), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(499), 1,
      sym_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22223] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(701), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22318] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(743), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22413] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(735), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22508] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1171), 1,
      anon_sym_LT,
    ACTIONS(1173), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(417), 1,
      sym_value,
    STATE(2646), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22603] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1171), 1,
      anon_sym_LT,
    ACTIONS(1173), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(418), 1,
      sym_value,
    STATE(2646), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22698] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1309), 1,
      anon_sym_LT,
    ACTIONS(1311), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(395), 1,
      sym_value,
    STATE(2684), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22793] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1313), 1,
      anon_sym_LT,
    ACTIONS(1315), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(497), 1,
      sym_value,
    STATE(2648), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22888] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1203), 1,
      anon_sym_LT,
    ACTIONS(1205), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(182), 1,
      sym_value,
    STATE(2917), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [22983] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1317), 1,
      anon_sym_LT,
    ACTIONS(1319), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(485), 1,
      sym_value,
    STATE(2671), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23078] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1321), 1,
      anon_sym_LT,
    ACTIONS(1323), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(658), 1,
      sym_value,
    STATE(2656), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23173] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1325), 1,
      anon_sym_LT,
    ACTIONS(1327), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(448), 1,
      sym_value,
    STATE(2709), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23268] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(748), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23363] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1331), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(477), 1,
      sym_value,
    STATE(2700), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23458] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1103), 1,
      anon_sym_LT,
    ACTIONS(1105), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(644), 1,
      sym_value,
    STATE(2612), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23553] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1333), 1,
      anon_sym_LT,
    ACTIONS(1335), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(419), 1,
      sym_value,
    STATE(2672), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23648] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1147), 1,
      anon_sym_LT,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(584), 1,
      sym_value,
    STATE(2834), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23743] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1147), 1,
      anon_sym_LT,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(586), 1,
      sym_value,
    STATE(2834), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23838] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1147), 1,
      anon_sym_LT,
    ACTIONS(1149), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(587), 1,
      sym_value,
    STATE(2834), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [23933] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(752), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24028] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(75), 1,
      anon_sym_LT,
    ACTIONS(77), 1,
      anon_sym_BANG,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(692), 1,
      sym_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24123] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(755), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24218] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1337), 1,
      anon_sym_LT,
    ACTIONS(1339), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(685), 1,
      sym_value,
    STATE(2674), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24313] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(747), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24408] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(757), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24503] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1341), 1,
      anon_sym_LT,
    ACTIONS(1343), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(632), 1,
      sym_value,
    STATE(2617), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24598] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1261), 1,
      anon_sym_LT,
    ACTIONS(1263), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(592), 1,
      sym_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24693] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1125), 1,
      anon_sym_LT,
    ACTIONS(1127), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(605), 1,
      sym_value,
    STATE(2635), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24788] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(676), 1,
      sym_value,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24883] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1153), 1,
      anon_sym_LT,
    ACTIONS(1155), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(549), 1,
      sym_value,
    STATE(2600), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [24978] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1137), 1,
      anon_sym_LT,
    ACTIONS(1139), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(668), 1,
      sym_value,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25073] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1231), 1,
      anon_sym_LT,
    ACTIONS(1233), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(564), 1,
      sym_value,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25168] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1313), 1,
      anon_sym_LT,
    ACTIONS(1315), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(498), 1,
      sym_value,
    STATE(2648), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25263] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1333), 1,
      anon_sym_LT,
    ACTIONS(1335), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(450), 1,
      sym_value,
    STATE(2672), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25358] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1313), 1,
      anon_sym_LT,
    ACTIONS(1315), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(502), 1,
      sym_value,
    STATE(2648), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25453] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1317), 1,
      anon_sym_LT,
    ACTIONS(1319), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(482), 1,
      sym_value,
    STATE(2671), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25548] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1309), 1,
      anon_sym_LT,
    ACTIONS(1311), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(427), 1,
      sym_value,
    STATE(2684), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25643] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1317), 1,
      anon_sym_LT,
    ACTIONS(1319), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(484), 1,
      sym_value,
    STATE(2671), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25738] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1255), 1,
      anon_sym_LT,
    ACTIONS(1257), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(496), 1,
      sym_value,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25833] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1255), 1,
      anon_sym_LT,
    ACTIONS(1257), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(486), 1,
      sym_value,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [25928] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1345), 1,
      anon_sym_LT,
    ACTIONS(1347), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(629), 1,
      sym_value,
    STATE(2638), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26023] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1269), 1,
      anon_sym_LT,
    ACTIONS(1271), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(506), 1,
      sym_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26118] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1269), 1,
      anon_sym_LT,
    ACTIONS(1271), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(508), 1,
      sym_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26213] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1119), 1,
      anon_sym_LT,
    ACTIONS(1121), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(606), 1,
      sym_value,
    STATE(2613), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26308] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1261), 1,
      anon_sym_LT,
    ACTIONS(1263), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(577), 1,
      sym_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26403] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1261), 1,
      anon_sym_LT,
    ACTIONS(1263), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(582), 1,
      sym_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26498] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1261), 1,
      anon_sym_LT,
    ACTIONS(1263), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(583), 1,
      sym_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26593] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1349), 1,
      anon_sym_LT,
    ACTIONS(1351), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(608), 1,
      sym_value,
    STATE(2622), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26688] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1269), 1,
      anon_sym_LT,
    ACTIONS(1271), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(513), 1,
      sym_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26783] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1353), 1,
      anon_sym_LT,
    ACTIONS(1355), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(566), 1,
      sym_value,
    STATE(2661), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26878] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1083), 1,
      anon_sym_LT,
    ACTIONS(1085), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(593), 1,
      sym_value,
    STATE(2637), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [26973] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(713), 1,
      sym_value,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27068] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1231), 1,
      anon_sym_LT,
    ACTIONS(1233), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(565), 1,
      sym_value,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27163] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1111), 1,
      anon_sym_LT,
    ACTIONS(1113), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(715), 1,
      sym_value,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27258] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1357), 1,
      anon_sym_LT,
    ACTIONS(1359), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(539), 1,
      sym_value,
    STATE(2682), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27353] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1333), 1,
      anon_sym_LT,
    ACTIONS(1335), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(469), 1,
      sym_value,
    STATE(2672), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27448] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(813), 1,
      anon_sym_LPAREN,
    ACTIONS(819), 1,
      aux_sym_type_name_token1,
    ACTIONS(823), 1,
      sym_int,
    ACTIONS(825), 1,
      sym_float,
    ACTIONS(827), 1,
      sym_decimal,
    ACTIONS(829), 1,
      sym_duration_part,
    ACTIONS(1333), 1,
      anon_sym_LT,
    ACTIONS(1335), 1,
      anon_sym_BANG,
    STATE(213), 1,
      sym_graph_path,
    STATE(246), 1,
      aux_sym_duration_repeat1,
    STATE(259), 1,
      sym_identifier,
    STATE(453), 1,
      sym_value,
    STATE(2672), 1,
      sym_object_key,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(211), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(821), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(809), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(483), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(323), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27543] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1309), 1,
      anon_sym_LT,
    ACTIONS(1311), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(428), 1,
      sym_value,
    STATE(2684), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27638] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(845), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      aux_sym_type_name_token1,
    ACTIONS(855), 1,
      sym_int,
    ACTIONS(857), 1,
      sym_float,
    ACTIONS(859), 1,
      sym_decimal,
    ACTIONS(861), 1,
      sym_duration_part,
    ACTIONS(1309), 1,
      anon_sym_LT,
    ACTIONS(1311), 1,
      anon_sym_BANG,
    STATE(196), 1,
      sym_graph_path,
    STATE(231), 1,
      sym_identifier,
    STATE(238), 1,
      aux_sym_duration_repeat1,
    STATE(429), 1,
      sym_value,
    STATE(2684), 1,
      sym_object_key,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(195), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(853), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(841), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(465), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(264), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27733] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1325), 1,
      anon_sym_LT,
    ACTIONS(1327), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(456), 1,
      sym_value,
    STATE(2709), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27828] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1183), 1,
      anon_sym_LPAREN,
    ACTIONS(1189), 1,
      aux_sym_type_name_token1,
    ACTIONS(1193), 1,
      sym_int,
    ACTIONS(1195), 1,
      sym_float,
    ACTIONS(1197), 1,
      sym_decimal,
    ACTIONS(1199), 1,
      sym_duration_part,
    ACTIONS(1325), 1,
      anon_sym_LT,
    ACTIONS(1327), 1,
      anon_sym_BANG,
    STATE(125), 1,
      sym_graph_path,
    STATE(134), 1,
      aux_sym_duration_repeat1,
    STATE(135), 1,
      sym_identifier,
    STATE(457), 1,
      sym_value,
    STATE(2709), 1,
      sym_object_key,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(121), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(1191), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(1179), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(221), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(148), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [27923] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1361), 1,
      anon_sym_LT,
    ACTIONS(1363), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(596), 1,
      sym_value,
    STATE(2644), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28018] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1331), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(470), 1,
      sym_value,
    STATE(2700), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28113] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1329), 1,
      anon_sym_LT,
    ACTIONS(1331), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(126), 1,
      sym_graph_path,
    STATE(491), 1,
      sym_value,
    STATE(2700), 1,
      sym_object_key,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(128), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28208] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1089), 1,
      anon_sym_LT,
    ACTIONS(1091), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(598), 1,
      sym_value,
    STATE(2618), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28303] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(833), 1,
      anon_sym_LT,
    ACTIONS(835), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(459), 1,
      sym_value,
    STATE(2916), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28398] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(833), 1,
      anon_sym_LT,
    ACTIONS(835), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(460), 1,
      sym_value,
    STATE(2916), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28493] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(833), 1,
      anon_sym_LT,
    ACTIONS(835), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(461), 1,
      sym_value,
    STATE(2916), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28588] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1365), 1,
      anon_sym_LT,
    ACTIONS(1367), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(722), 1,
      sym_value,
    STATE(2676), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28683] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1341), 1,
      anon_sym_LT,
    ACTIONS(1343), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(619), 1,
      sym_value,
    STATE(2617), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28778] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1097), 1,
      anon_sym_LT,
    ACTIONS(1099), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(567), 1,
      sym_value,
    STATE(2643), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28873] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1153), 1,
      anon_sym_LT,
    ACTIONS(1155), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(551), 1,
      sym_value,
    STATE(2600), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [28968] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(893), 1,
      anon_sym_LT,
    ACTIONS(895), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(415), 1,
      sym_value,
    STATE(2605), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29063] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1153), 1,
      anon_sym_LT,
    ACTIONS(1155), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(552), 1,
      sym_value,
    STATE(2600), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29158] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1345), 1,
      anon_sym_LT,
    ACTIONS(1347), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(600), 1,
      sym_value,
    STATE(2638), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29253] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1369), 1,
      anon_sym_LT,
    ACTIONS(1371), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(724), 1,
      sym_value,
    STATE(2645), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29348] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1203), 1,
      anon_sym_LT,
    ACTIONS(1205), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(402), 1,
      sym_value,
    STATE(2917), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29443] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1281), 1,
      anon_sym_LT,
    ACTIONS(1283), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(481), 1,
      sym_value,
    STATE(2691), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29538] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1203), 1,
      anon_sym_LT,
    ACTIONS(1205), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(381), 1,
      sym_value,
    STATE(2917), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29633] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1373), 1,
      anon_sym_LT,
    ACTIONS(1375), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(679), 1,
      sym_value,
    STATE(2689), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29728] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1231), 1,
      anon_sym_LT,
    ACTIONS(1233), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(553), 1,
      sym_value,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29823] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1245), 1,
      anon_sym_LT,
    ACTIONS(1247), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(363), 1,
      sym_value,
    STATE(2606), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [29918] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1231), 1,
      anon_sym_LT,
    ACTIONS(1233), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(554), 1,
      sym_value,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30013] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(671), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30108] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1377), 1,
      anon_sym_LT,
    ACTIONS(1379), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(680), 1,
      sym_value,
    STATE(2698), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30203] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1103), 1,
      anon_sym_LT,
    ACTIONS(1105), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(672), 1,
      sym_value,
    STATE(2612), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30298] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1103), 1,
      anon_sym_LT,
    ACTIONS(1105), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(673), 1,
      sym_value,
    STATE(2612), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30393] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1103), 1,
      anon_sym_LT,
    ACTIONS(1105), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(674), 1,
      sym_value,
    STATE(2612), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30488] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1381), 1,
      anon_sym_LT,
    ACTIONS(1383), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(681), 1,
      sym_value,
    STATE(2694), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30583] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(893), 1,
      anon_sym_LT,
    ACTIONS(895), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(434), 1,
      sym_value,
    STATE(2605), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30678] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1125), 1,
      anon_sym_LT,
    ACTIONS(1127), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(659), 1,
      sym_value,
    STATE(2635), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30773] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(893), 1,
      anon_sym_LT,
    ACTIONS(895), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(435), 1,
      sym_value,
    STATE(2605), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30868] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1385), 1,
      anon_sym_LT,
    ACTIONS(1387), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(660), 1,
      sym_value,
    STATE(2702), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [30963] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1119), 1,
      anon_sym_LT,
    ACTIONS(1121), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(637), 1,
      sym_value,
    STATE(2613), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31058] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1119), 1,
      anon_sym_LT,
    ACTIONS(1121), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(638), 1,
      sym_value,
    STATE(2613), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31153] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1119), 1,
      anon_sym_LT,
    ACTIONS(1121), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(639), 1,
      sym_value,
    STATE(2613), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31248] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1389), 1,
      anon_sym_LT,
    ACTIONS(1391), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(570), 1,
      sym_value,
    STATE(2696), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31343] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1245), 1,
      anon_sym_LT,
    ACTIONS(1247), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(378), 1,
      sym_value,
    STATE(2606), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31438] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1083), 1,
      anon_sym_LT,
    ACTIONS(1085), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(624), 1,
      sym_value,
    STATE(2637), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31533] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1245), 1,
      anon_sym_LT,
    ACTIONS(1247), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(379), 1,
      sym_value,
    STATE(2606), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31628] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1393), 1,
      anon_sym_LT,
    ACTIONS(1395), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(661), 1,
      sym_value,
    STATE(2704), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31723] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1341), 1,
      anon_sym_LT,
    ACTIONS(1343), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(611), 1,
      sym_value,
    STATE(2617), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31818] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1089), 1,
      anon_sym_LT,
    ACTIONS(1091), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(617), 1,
      sym_value,
    STATE(2618), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [31913] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1341), 1,
      anon_sym_LT,
    ACTIONS(1343), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(618), 1,
      sym_value,
    STATE(2617), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32008] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(742), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32103] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1397), 1,
      anon_sym_LT,
    ACTIONS(1399), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(625), 1,
      sym_value,
    STATE(2708), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32198] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(669), 1,
      sym_value,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32293] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1097), 1,
      anon_sym_LT,
    ACTIONS(1099), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(572), 1,
      sym_value,
    STATE(2643), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32388] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1163), 1,
      anon_sym_LT,
    ACTIONS(1165), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(670), 1,
      sym_value,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32483] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1401), 1,
      anon_sym_LT,
    ACTIONS(1403), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(516), 1,
      sym_value,
    STATE(2707), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32578] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1089), 1,
      anon_sym_LT,
    ACTIONS(1091), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(620), 1,
      sym_value,
    STATE(2618), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32673] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1301), 1,
      anon_sym_LT,
    ACTIONS(1303), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(656), 1,
      sym_value,
    STATE(2631), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32768] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1089), 1,
      anon_sym_LT,
    ACTIONS(1091), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(623), 1,
      sym_value,
    STATE(2618), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32863] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1285), 1,
      anon_sym_LT,
    ACTIONS(1287), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(756), 1,
      sym_value,
    STATE(2611), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [32958] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1289), 1,
      anon_sym_LT,
    ACTIONS(1291), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(628), 1,
      sym_value,
    STATE(2663), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33053] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1285), 1,
      anon_sym_LT,
    ACTIONS(1287), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(746), 1,
      sym_value,
    STATE(2611), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33148] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1405), 1,
      anon_sym_LT,
    ACTIONS(1407), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(573), 1,
      sym_value,
    STATE(2711), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33243] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1349), 1,
      anon_sym_LT,
    ACTIONS(1351), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(626), 1,
      sym_value,
    STATE(2622), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33338] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1281), 1,
      anon_sym_LT,
    ACTIONS(1283), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(568), 1,
      sym_value,
    STATE(2691), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33433] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1349), 1,
      anon_sym_LT,
    ACTIONS(1351), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(621), 1,
      sym_value,
    STATE(2622), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33528] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1125), 1,
      anon_sym_LT,
    ACTIONS(1127), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(641), 1,
      sym_value,
    STATE(2635), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33623] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1277), 1,
      anon_sym_LT,
    ACTIONS(1279), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(520), 1,
      sym_value,
    STATE(2703), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33718] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1125), 1,
      anon_sym_LT,
    ACTIONS(1127), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(642), 1,
      sym_value,
    STATE(2635), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33813] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1301), 1,
      anon_sym_LT,
    ACTIONS(1303), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(643), 1,
      sym_value,
    STATE(2631), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [33908] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1301), 1,
      anon_sym_LT,
    ACTIONS(1303), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(662), 1,
      sym_value,
    STATE(2631), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34003] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1083), 1,
      anon_sym_LT,
    ACTIONS(1085), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(604), 1,
      sym_value,
    STATE(2637), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34098] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1083), 1,
      anon_sym_LT,
    ACTIONS(1085), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(612), 1,
      sym_value,
    STATE(2637), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34193] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1321), 1,
      anon_sym_LT,
    ACTIONS(1323), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(645), 1,
      sym_value,
    STATE(2656), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34288] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1321), 1,
      anon_sym_LT,
    ACTIONS(1323), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(646), 1,
      sym_value,
    STATE(2656), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34383] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1345), 1,
      anon_sym_LT,
    ACTIONS(1347), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(574), 1,
      sym_value,
    STATE(2638), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34478] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1345), 1,
      anon_sym_LT,
    ACTIONS(1347), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(575), 1,
      sym_value,
    STATE(2638), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34573] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1353), 1,
      anon_sym_LT,
    ACTIONS(1355), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(555), 1,
      sym_value,
    STATE(2661), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34668] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1353), 1,
      anon_sym_LT,
    ACTIONS(1355), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(556), 1,
      sym_value,
    STATE(2661), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34763] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1097), 1,
      anon_sym_LT,
    ACTIONS(1099), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(578), 1,
      sym_value,
    STATE(2643), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34858] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1097), 1,
      anon_sym_LT,
    ACTIONS(1099), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(579), 1,
      sym_value,
    STATE(2643), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [34953] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1337), 1,
      anon_sym_LT,
    ACTIONS(1339), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(729), 1,
      sym_value,
    STATE(2674), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35048] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1337), 1,
      anon_sym_LT,
    ACTIONS(1339), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(731), 1,
      sym_value,
    STATE(2674), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35143] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1361), 1,
      anon_sym_LT,
    ACTIONS(1363), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(580), 1,
      sym_value,
    STATE(2644), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35238] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1361), 1,
      anon_sym_LT,
    ACTIONS(1363), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(581), 1,
      sym_value,
    STATE(2644), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35333] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1365), 1,
      anon_sym_LT,
    ACTIONS(1367), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(687), 1,
      sym_value,
    STATE(2676), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35428] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1365), 1,
      anon_sym_LT,
    ACTIONS(1367), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(688), 1,
      sym_value,
    STATE(2676), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35523] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1369), 1,
      anon_sym_LT,
    ACTIONS(1371), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(689), 1,
      sym_value,
    STATE(2645), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35618] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1369), 1,
      anon_sym_LT,
    ACTIONS(1371), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(690), 1,
      sym_value,
    STATE(2645), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35713] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1373), 1,
      anon_sym_LT,
    ACTIONS(1375), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(678), 1,
      sym_value,
    STATE(2689), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35808] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1373), 1,
      anon_sym_LT,
    ACTIONS(1375), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(682), 1,
      sym_value,
    STATE(2689), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35903] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1305), 1,
      anon_sym_LT,
    ACTIONS(1307), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(693), 1,
      sym_value,
    STATE(2649), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [35998] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1305), 1,
      anon_sym_LT,
    ACTIONS(1307), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(694), 1,
      sym_value,
    STATE(2649), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36093] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1281), 1,
      anon_sym_LT,
    ACTIONS(1283), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(557), 1,
      sym_value,
    STATE(2691), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36188] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1281), 1,
      anon_sym_LT,
    ACTIONS(1283), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(558), 1,
      sym_value,
    STATE(2691), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36283] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1157), 1,
      anon_sym_LT,
    ACTIONS(1159), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(695), 1,
      sym_value,
    STATE(2655), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36378] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1157), 1,
      anon_sym_LT,
    ACTIONS(1159), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(696), 1,
      sym_value,
    STATE(2655), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36473] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1381), 1,
      anon_sym_LT,
    ACTIONS(1383), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(683), 1,
      sym_value,
    STATE(2694), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36568] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1381), 1,
      anon_sym_LT,
    ACTIONS(1383), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(684), 1,
      sym_value,
    STATE(2694), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36663] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1289), 1,
      anon_sym_LT,
    ACTIONS(1291), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(609), 1,
      sym_value,
    STATE(2663), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36758] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1289), 1,
      anon_sym_LT,
    ACTIONS(1291), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(610), 1,
      sym_value,
    STATE(2663), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36853] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1389), 1,
      anon_sym_LT,
    ACTIONS(1391), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(559), 1,
      sym_value,
    STATE(2696), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [36948] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1389), 1,
      anon_sym_LT,
    ACTIONS(1391), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(560), 1,
      sym_value,
    STATE(2696), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37043] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1293), 1,
      anon_sym_LT,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(614), 1,
      sym_value,
    STATE(2681), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37138] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1293), 1,
      anon_sym_LT,
    ACTIONS(1295), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(615), 1,
      sym_value,
    STATE(2681), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37233] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1397), 1,
      anon_sym_LT,
    ACTIONS(1399), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(616), 1,
      sym_value,
    STATE(2708), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37328] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1397), 1,
      anon_sym_LT,
    ACTIONS(1399), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(622), 1,
      sym_value,
    STATE(2708), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37423] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1357), 1,
      anon_sym_LT,
    ACTIONS(1359), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(533), 1,
      sym_value,
    STATE(2682), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37518] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1357), 1,
      anon_sym_LT,
    ACTIONS(1359), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(534), 1,
      sym_value,
    STATE(2682), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37613] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1297), 1,
      anon_sym_LT,
    ACTIONS(1299), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(664), 1,
      sym_value,
    STATE(2697), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37708] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1297), 1,
      anon_sym_LT,
    ACTIONS(1299), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(665), 1,
      sym_value,
    STATE(2697), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37803] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1377), 1,
      anon_sym_LT,
    ACTIONS(1379), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(666), 1,
      sym_value,
    STATE(2698), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37898] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1377), 1,
      anon_sym_LT,
    ACTIONS(1379), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(667), 1,
      sym_value,
    STATE(2698), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [37993] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1385), 1,
      anon_sym_LT,
    ACTIONS(1387), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(648), 1,
      sym_value,
    STATE(2702), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38088] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1385), 1,
      anon_sym_LT,
    ACTIONS(1387), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(649), 1,
      sym_value,
    STATE(2702), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38183] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1277), 1,
      anon_sym_LT,
    ACTIONS(1279), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(536), 1,
      sym_value,
    STATE(2703), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38278] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1393), 1,
      anon_sym_LT,
    ACTIONS(1395), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(651), 1,
      sym_value,
    STATE(2704), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38373] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1393), 1,
      anon_sym_LT,
    ACTIONS(1395), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(652), 1,
      sym_value,
    STATE(2704), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38468] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1401), 1,
      anon_sym_LT,
    ACTIONS(1403), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(537), 1,
      sym_value,
    STATE(2707), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38563] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1401), 1,
      anon_sym_LT,
    ACTIONS(1403), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(538), 1,
      sym_value,
    STATE(2707), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38658] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1405), 1,
      anon_sym_LT,
    ACTIONS(1407), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(591), 1,
      sym_value,
    STATE(2711), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38753] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    ACTIONS(1405), 1,
      anon_sym_LT,
    ACTIONS(1407), 1,
      anon_sym_BANG,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(603), 1,
      sym_value,
    STATE(2711), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38848] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(708), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [38943] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(719), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39038] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(131), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_BANG,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(147), 1,
      aux_sym_type_name_token1,
    ACTIONS(151), 1,
      sym_int,
    ACTIONS(153), 1,
      sym_float,
    ACTIONS(155), 1,
      sym_decimal,
    ACTIONS(157), 1,
      sym_duration_part,
    STATE(21), 1,
      sym_graph_path,
    STATE(51), 1,
      sym_identifier,
    STATE(52), 1,
      aux_sym_duration_repeat1,
    STATE(725), 1,
      sym_value,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(27), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(149), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(107), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(115), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(76), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39133] = 25,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(85), 1,
      sym_int,
    ACTIONS(87), 1,
      sym_float,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1203), 1,
      anon_sym_LT,
    ACTIONS(1205), 1,
      anon_sym_BANG,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(116), 1,
      sym_graph_path,
    STATE(403), 1,
      sym_value,
    STATE(2917), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(114), 2,
      sym_function_call,
      sym_base_value,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(83), 3,
      sym_string,
      sym_prefixed_string,
      sym_variable_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(109), 5,
      sym_cast_expression,
      sym_binary_expression,
      sym_negated_expression,
      sym_path,
      sym_range,
    STATE(66), 7,
      sym_number,
      sym_array,
      sym_object,
      sym_record_id,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39228] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2708), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39314] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2834), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39400] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2784), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39486] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(1413), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(209), 1,
      sym_function_call,
    STATE(213), 1,
      sym_graph_path,
    STATE(334), 1,
      sym_record_id,
    STATE(490), 1,
      sym_path,
    STATE(1487), 1,
      sym_base_value,
    STATE(1723), 1,
      sym_identifier,
    STATE(2648), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39572] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(1415), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(196), 1,
      sym_graph_path,
    STATE(197), 1,
      sym_function_call,
    STATE(271), 1,
      sym_record_id,
    STATE(455), 1,
      sym_path,
    STATE(1414), 1,
      sym_base_value,
    STATE(1724), 1,
      sym_identifier,
    STATE(2671), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39658] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(126), 1,
      sym_graph_path,
    STATE(129), 1,
      sym_function_call,
    STATE(1418), 1,
      sym_base_value,
    STATE(2650), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39744] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1417), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(124), 1,
      sym_function_call,
    STATE(125), 1,
      sym_graph_path,
    STATE(152), 1,
      sym_record_id,
    STATE(212), 1,
      sym_path,
    STATE(1422), 1,
      sym_base_value,
    STATE(1725), 1,
      sym_identifier,
    STATE(2677), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39830] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2888), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [39916] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2809), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40002] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2595), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40088] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(1413), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(209), 1,
      sym_function_call,
    STATE(213), 1,
      sym_graph_path,
    STATE(334), 1,
      sym_record_id,
    STATE(490), 1,
      sym_path,
    STATE(1487), 1,
      sym_base_value,
    STATE(1723), 1,
      sym_identifier,
    STATE(2672), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40174] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(1415), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(196), 1,
      sym_graph_path,
    STATE(197), 1,
      sym_function_call,
    STATE(271), 1,
      sym_record_id,
    STATE(455), 1,
      sym_path,
    STATE(1414), 1,
      sym_base_value,
    STATE(1724), 1,
      sym_identifier,
    STATE(2684), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40260] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(126), 1,
      sym_graph_path,
    STATE(129), 1,
      sym_function_call,
    STATE(1418), 1,
      sym_base_value,
    STATE(2700), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40346] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1417), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(124), 1,
      sym_function_call,
    STATE(125), 1,
      sym_graph_path,
    STATE(152), 1,
      sym_record_id,
    STATE(212), 1,
      sym_path,
    STATE(1422), 1,
      sym_base_value,
    STATE(1725), 1,
      sym_identifier,
    STATE(2709), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40432] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2916), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40518] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2600), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40604] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2917), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40690] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2604), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40776] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2612), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40862] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2605), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [40948] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2613), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41034] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2606), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41120] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2617), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41206] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2607), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41292] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2618), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41378] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2611), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41464] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2711), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41550] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2635), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41636] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2631), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41722] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2637), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41808] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2656), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41894] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2638), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [41980] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2900), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42066] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2661), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42152] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2643), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42238] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2674), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42324] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2644), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42410] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2676), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42496] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2645), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42582] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2689), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42668] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2649), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42754] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2691), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42840] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2655), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [42926] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2694), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43012] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2663), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43098] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2696), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43184] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2681), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43270] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(811), 1,
      sym_keyword_count,
    ACTIONS(1413), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(209), 1,
      sym_function_call,
    STATE(213), 1,
      sym_graph_path,
    STATE(334), 1,
      sym_record_id,
    STATE(490), 1,
      sym_path,
    STATE(1487), 1,
      sym_base_value,
    STATE(1723), 1,
      sym_identifier,
    STATE(2609), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(807), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43356] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2682), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43442] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(843), 1,
      sym_keyword_count,
    ACTIONS(1415), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(196), 1,
      sym_graph_path,
    STATE(197), 1,
      sym_function_call,
    STATE(271), 1,
      sym_record_id,
    STATE(455), 1,
      sym_path,
    STATE(1414), 1,
      sym_base_value,
    STATE(1724), 1,
      sym_identifier,
    STATE(2630), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(839), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43528] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2697), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43614] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2698), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43700] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(126), 1,
      sym_graph_path,
    STATE(129), 1,
      sym_function_call,
    STATE(1418), 1,
      sym_base_value,
    STATE(2646), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43786] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2702), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43872] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2703), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [43958] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(1181), 1,
      sym_keyword_count,
    ACTIONS(1417), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(124), 1,
      sym_function_call,
    STATE(125), 1,
      sym_graph_path,
    STATE(152), 1,
      sym_record_id,
    STATE(212), 1,
      sym_path,
    STATE(1422), 1,
      sym_base_value,
    STATE(1725), 1,
      sym_identifier,
    STATE(2669), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(1177), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [44044] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2704), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [44130] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(125), 1,
      sym_keyword_count,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(1411), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(21), 1,
      sym_graph_path,
    STATE(22), 1,
      sym_function_call,
    STATE(77), 1,
      sym_record_id,
    STATE(117), 1,
      sym_path,
    STATE(1461), 1,
      sym_base_value,
    STATE(1718), 1,
      sym_identifier,
    STATE(2707), 1,
      sym_object_key,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(105), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [44216] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(67), 1,
      anon_sym_LPAREN,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(89), 1,
      sym_decimal,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1409), 1,
      sym_variable_name,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(44), 1,
      sym_identifier,
    STATE(57), 1,
      sym_record_id,
    STATE(106), 1,
      sym_path,
    STATE(116), 1,
      sym_graph_path,
    STATE(118), 1,
      sym_function_call,
    STATE(1413), 1,
      sym_base_value,
    STATE(2622), 1,
      sym_object_key,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    ACTIONS(83), 2,
      sym_string,
      sym_prefixed_string,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    ACTIONS(23), 4,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
    STATE(66), 6,
      sym_number,
      sym_array,
      sym_object,
      sym_sub_query,
      sym_duration,
      sym_point,
  [44302] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1421), 1,
      sym_keyword_bm25,
    ACTIONS(1424), 1,
      sym_keyword_doc_ids_cache,
    ACTIONS(1427), 1,
      sym_keyword_doc_ids_order,
    ACTIONS(1430), 1,
      sym_keyword_doc_lengths_cache,
    ACTIONS(1433), 1,
      sym_keyword_doc_lengths_order,
    ACTIONS(1436), 1,
      sym_keyword_postings_cache,
    ACTIONS(1439), 1,
      sym_keyword_postings_order,
    ACTIONS(1442), 1,
      sym_keyword_terms_cache,
    ACTIONS(1445), 1,
      sym_keyword_terms_order,
    ACTIONS(1448), 1,
      sym_keyword_highlights,
    ACTIONS(1419), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1113), 10,
      sym_bm25_clause,
      sym_doc_ids_cache_clause,
      sym_doc_ids_order_clause,
      sym_doc_lengths_cache_clause,
      sym_doc_lengths_order_clause,
      sym_postings_cache_clause,
      sym_postings_order_clause,
      sym_terms_cache_clause,
      sym_terms_order_clause,
      aux_sym_search_analyzer_clause_repeat1,
  [44358] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 1,
      sym_keyword_bm25,
    ACTIONS(1455), 1,
      sym_keyword_doc_ids_cache,
    ACTIONS(1457), 1,
      sym_keyword_doc_ids_order,
    ACTIONS(1459), 1,
      sym_keyword_doc_lengths_cache,
    ACTIONS(1461), 1,
      sym_keyword_doc_lengths_order,
    ACTIONS(1463), 1,
      sym_keyword_postings_cache,
    ACTIONS(1465), 1,
      sym_keyword_postings_order,
    ACTIONS(1467), 1,
      sym_keyword_terms_cache,
    ACTIONS(1469), 1,
      sym_keyword_terms_order,
    ACTIONS(1471), 1,
      sym_keyword_highlights,
    ACTIONS(1451), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1115), 10,
      sym_bm25_clause,
      sym_doc_ids_cache_clause,
      sym_doc_ids_order_clause,
      sym_doc_lengths_cache_clause,
      sym_doc_lengths_order_clause,
      sym_postings_cache_clause,
      sym_postings_order_clause,
      sym_terms_cache_clause,
      sym_terms_order_clause,
      aux_sym_search_analyzer_clause_repeat1,
  [44414] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1453), 1,
      sym_keyword_bm25,
    ACTIONS(1455), 1,
      sym_keyword_doc_ids_cache,
    ACTIONS(1457), 1,
      sym_keyword_doc_ids_order,
    ACTIONS(1459), 1,
      sym_keyword_doc_lengths_cache,
    ACTIONS(1461), 1,
      sym_keyword_doc_lengths_order,
    ACTIONS(1463), 1,
      sym_keyword_postings_cache,
    ACTIONS(1465), 1,
      sym_keyword_postings_order,
    ACTIONS(1467), 1,
      sym_keyword_terms_cache,
    ACTIONS(1469), 1,
      sym_keyword_terms_order,
    ACTIONS(1475), 1,
      sym_keyword_highlights,
    ACTIONS(1473), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1113), 10,
      sym_bm25_clause,
      sym_doc_ids_cache_clause,
      sym_doc_ids_order_clause,
      sym_doc_lengths_cache_clause,
      sym_doc_lengths_order_clause,
      sym_postings_cache_clause,
      sym_postings_order_clause,
      sym_terms_cache_clause,
      sym_terms_order_clause,
      aux_sym_search_analyzer_clause_repeat1,
  [44470] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1479), 1,
      sym_keyword_m,
    ACTIONS(1481), 1,
      anon_sym_PIPE,
    ACTIONS(1483), 1,
      anon_sym_LT,
    STATE(1125), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(1477), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [44510] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1487), 1,
      sym_keyword_m,
    ACTIONS(1489), 1,
      anon_sym_PIPE,
    STATE(1117), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(1485), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [44547] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(471), 1,
      sym_keyword_replace,
    ACTIONS(477), 1,
      anon_sym_COMMA,
    ACTIONS(509), 1,
      sym_keyword_unset,
    ACTIONS(511), 1,
      sym_keyword_set,
    STATE(1204), 1,
      aux_sym_update_statement_repeat1,
    STATE(1383), 1,
      sym_where_clause,
    STATE(1443), 1,
      sym_return_clause,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1316), 4,
      sym_content_clause,
      sym_merge_clause,
      sym_patch_clause,
      sym_replace_clause,
  [44616] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(495), 1,
      sym_keyword_with,
    ACTIONS(497), 1,
      sym_keyword_where,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(503), 1,
      anon_sym_COMMA,
    STATE(1150), 1,
      sym_with_clause,
    STATE(1157), 1,
      sym_where_clause,
    STATE(1196), 1,
      sym_split_clause,
    STATE(1228), 1,
      aux_sym_update_statement_repeat1,
    STATE(1242), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [44691] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(495), 1,
      sym_keyword_with,
    ACTIONS(497), 1,
      sym_keyword_where,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(503), 1,
      anon_sym_COMMA,
    STATE(1153), 1,
      sym_with_clause,
    STATE(1165), 1,
      sym_where_clause,
    STATE(1197), 1,
      sym_split_clause,
    STATE(1228), 1,
      aux_sym_update_statement_repeat1,
    STATE(1230), 1,
      sym_group_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [44766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1496), 12,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      anon_sym_STAR,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1494), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [44799] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1500), 1,
      sym_keyword_not,
    ACTIONS(1502), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1498), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [44834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1506), 1,
      sym_keyword_m,
    ACTIONS(1504), 24,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
  [44867] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(471), 1,
      sym_keyword_replace,
    ACTIONS(477), 1,
      anon_sym_COMMA,
    ACTIONS(1510), 1,
      sym_keyword_unset,
    ACTIONS(1512), 1,
      sym_keyword_set,
    STATE(1204), 1,
      aux_sym_update_statement_repeat1,
    STATE(1407), 1,
      sym_where_clause,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1311), 4,
      sym_content_clause,
      sym_merge_clause,
      sym_patch_clause,
      sym_replace_clause,
  [44936] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1481), 1,
      anon_sym_PIPE,
    ACTIONS(1516), 1,
      sym_keyword_m,
    STATE(1117), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(1514), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [44973] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1487), 1,
      sym_keyword_m,
    ACTIONS(1485), 23,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_GT,
  [45005] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(471), 1,
      sym_keyword_replace,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(529), 1,
      anon_sym_COMMA,
    ACTIONS(1518), 1,
      sym_keyword_unset,
    ACTIONS(1520), 1,
      sym_keyword_set,
    STATE(1221), 1,
      aux_sym_update_statement_repeat1,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1421), 1,
      sym_where_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1358), 4,
      sym_content_clause,
      sym_merge_clause,
      sym_patch_clause,
      sym_replace_clause,
  [45073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1524), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1522), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [45105] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1528), 1,
      sym_keyword_m,
    ACTIONS(1526), 23,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_PIPE,
      anon_sym_GT,
  [45137] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    ACTIONS(515), 1,
      sym_keyword_with,
    ACTIONS(517), 1,
      sym_keyword_where,
    ACTIONS(519), 1,
      anon_sym_COMMA,
    STATE(1155), 1,
      sym_with_clause,
    STATE(1186), 1,
      sym_where_clause,
    STATE(1200), 1,
      sym_split_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1258), 1,
      aux_sym_update_statement_repeat1,
    STATE(1283), 1,
      sym_group_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [45211] = 24,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    ACTIONS(515), 1,
      sym_keyword_with,
    ACTIONS(517), 1,
      sym_keyword_where,
    ACTIONS(519), 1,
      anon_sym_COMMA,
    STATE(1156), 1,
      sym_with_clause,
    STATE(1173), 1,
      sym_where_clause,
    STATE(1208), 1,
      sym_split_clause,
    STATE(1252), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1258), 1,
      aux_sym_update_statement_repeat1,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [45285] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1502), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1498), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [45317] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1532), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1530), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [45349] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1536), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1534), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [45381] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1540), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1538), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [45413] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(471), 1,
      sym_keyword_replace,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(529), 1,
      anon_sym_COMMA,
    ACTIONS(531), 1,
      sym_keyword_unset,
    ACTIONS(533), 1,
      sym_keyword_set,
    STATE(1221), 1,
      aux_sym_update_statement_repeat1,
    STATE(1440), 1,
      sym_where_clause,
    STATE(1443), 1,
      sym_return_clause,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1364), 4,
      sym_content_clause,
      sym_merge_clause,
      sym_patch_clause,
      sym_replace_clause,
  [45481] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1544), 11,
      anon_sym_LPAREN,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_BANG,
      anon_sym_LT_DASH_GT,
      sym_string,
      sym_prefixed_string,
      sym_decimal,
      sym_variable_name,
      sym_duration_part,
    ACTIONS(1542), 13,
      sym_keyword_rand,
      sym_keyword_true,
      sym_keyword_false,
      sym_keyword_none,
      sym_keyword_null,
      sym_keyword_count,
      anon_sym_LT,
      anon_sym_LT_DASH,
      aux_sym_type_name_token1,
      sym_int,
      sym_float,
      sym_custom_function_name,
      sym_function_name,
  [45513] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    ACTIONS(551), 1,
      sym_keyword_unset,
    ACTIONS(553), 1,
      sym_keyword_set,
    ACTIONS(555), 1,
      anon_sym_COMMA,
    STATE(1257), 1,
      aux_sym_update_statement_repeat1,
    STATE(1559), 1,
      sym_where_clause,
    STATE(1616), 1,
      sym_return_clause,
    STATE(1787), 1,
      sym_timeout_clause,
    STATE(2150), 2,
      sym_parallel_clause,
      sym_patch_clause,
    ACTIONS(545), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1380), 4,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
  [45574] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1548), 1,
      sym_keyword_m,
    ACTIONS(1546), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45605] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1552), 1,
      sym_keyword_m,
    ACTIONS(1550), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1556), 1,
      sym_keyword_m,
    ACTIONS(1554), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45667] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1560), 1,
      sym_keyword_m,
    ACTIONS(1558), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45698] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1564), 1,
      sym_keyword_m,
    ACTIONS(1562), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45729] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1479), 1,
      sym_keyword_m,
    ACTIONS(1477), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45760] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1568), 1,
      sym_keyword_m,
    ACTIONS(1566), 22,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_dist,
      sym_keyword_efc,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_GT,
  [45791] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    ACTIONS(551), 1,
      sym_keyword_unset,
    ACTIONS(553), 1,
      sym_keyword_set,
    ACTIONS(555), 1,
      anon_sym_COMMA,
    STATE(1257), 1,
      aux_sym_update_statement_repeat1,
    STATE(1538), 1,
      sym_where_clause,
    STATE(1644), 1,
      sym_return_clause,
    STATE(1874), 1,
      sym_timeout_clause,
    STATE(1961), 2,
      sym_parallel_clause,
      sym_patch_clause,
    ACTIONS(1570), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1398), 4,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
  [45852] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(551), 1,
      sym_keyword_unset,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    ACTIONS(609), 1,
      sym_keyword_set,
    ACTIONS(611), 1,
      anon_sym_COMMA,
    STATE(1299), 1,
      aux_sym_update_statement_repeat1,
    STATE(1644), 1,
      sym_return_clause,
    STATE(1645), 1,
      sym_where_clause,
    STATE(1874), 1,
      sym_timeout_clause,
    ACTIONS(1570), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1961), 2,
      sym_parallel_clause,
      sym_patch_clause,
    STATE(1417), 4,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
  [45912] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(467), 1,
      sym_keyword_merge,
    ACTIONS(469), 1,
      sym_keyword_patch,
    ACTIONS(551), 1,
      sym_keyword_unset,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    ACTIONS(609), 1,
      sym_keyword_set,
    ACTIONS(611), 1,
      anon_sym_COMMA,
    STATE(1299), 1,
      aux_sym_update_statement_repeat1,
    STATE(1614), 1,
      sym_where_clause,
    STATE(1616), 1,
      sym_return_clause,
    STATE(1787), 1,
      sym_timeout_clause,
    ACTIONS(545), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(2150), 2,
      sym_parallel_clause,
      sym_patch_clause,
    STATE(1430), 4,
      sym_content_clause,
      sym_set_clause,
      sym_unset_clause,
      sym_merge_clause,
  [45972] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1572), 21,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_value,
      sym_keyword_function,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_filters,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [45999] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(497), 1,
      sym_keyword_where,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1164), 1,
      sym_where_clause,
    STATE(1194), 1,
      sym_split_clause,
    STATE(1214), 1,
      sym_group_clause,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1576), 21,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_group,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46089] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(497), 1,
      sym_keyword_where,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1165), 1,
      sym_where_clause,
    STATE(1197), 1,
      sym_split_clause,
    STATE(1230), 1,
      sym_group_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46152] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(497), 1,
      sym_keyword_where,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1157), 1,
      sym_where_clause,
    STATE(1196), 1,
      sym_split_clause,
    STATE(1242), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46215] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    ACTIONS(517), 1,
      sym_keyword_where,
    STATE(1186), 1,
      sym_where_clause,
    STATE(1200), 1,
      sym_split_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1283), 1,
      sym_group_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [46277] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    ACTIONS(517), 1,
      sym_keyword_where,
    STATE(1173), 1,
      sym_where_clause,
    STATE(1208), 1,
      sym_split_clause,
    STATE(1252), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [46339] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    ACTIONS(517), 1,
      sym_keyword_where,
    STATE(1174), 1,
      sym_where_clause,
    STATE(1201), 1,
      sym_split_clause,
    STATE(1267), 1,
      sym_group_clause,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [46401] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1194), 1,
      sym_split_clause,
    STATE(1214), 1,
      sym_group_clause,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46458] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      sym_keyword_value,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1588), 1,
      sym_keyword_default,
    ACTIONS(1590), 1,
      sym_keyword_assert,
    ACTIONS(1592), 1,
      sym_keyword_permissions,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1578), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1159), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46501] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1598), 1,
      sym_keyword_value,
    ACTIONS(1601), 1,
      sym_keyword_flexible,
    ACTIONS(1604), 1,
      sym_keyword_readonly,
    ACTIONS(1607), 1,
      sym_keyword_type,
    ACTIONS(1610), 1,
      sym_keyword_default,
    ACTIONS(1613), 1,
      sym_keyword_assert,
    ACTIONS(1616), 1,
      sym_keyword_permissions,
    ACTIONS(1619), 1,
      sym_keyword_comment,
    ACTIONS(1596), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1159), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46544] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      sym_keyword_value,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1588), 1,
      sym_keyword_default,
    ACTIONS(1590), 1,
      sym_keyword_assert,
    ACTIONS(1592), 1,
      sym_keyword_permissions,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1622), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1159), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46587] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      sym_keyword_value,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1588), 1,
      sym_keyword_default,
    ACTIONS(1590), 1,
      sym_keyword_assert,
    ACTIONS(1592), 1,
      sym_keyword_permissions,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1624), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1162), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46630] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      sym_keyword_value,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1588), 1,
      sym_keyword_default,
    ACTIONS(1590), 1,
      sym_keyword_assert,
    ACTIONS(1592), 1,
      sym_keyword_permissions,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1626), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1159), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46673] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      sym_keyword_value,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1588), 1,
      sym_keyword_default,
    ACTIONS(1590), 1,
      sym_keyword_assert,
    ACTIONS(1592), 1,
      sym_keyword_permissions,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1626), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1158), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46716] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1195), 1,
      sym_split_clause,
    STATE(1223), 1,
      sym_group_clause,
    STATE(1266), 1,
      sym_order_clause,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46773] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1196), 1,
      sym_split_clause,
    STATE(1242), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46830] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1580), 1,
      sym_keyword_value,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1588), 1,
      sym_keyword_default,
    ACTIONS(1590), 1,
      sym_keyword_assert,
    ACTIONS(1592), 1,
      sym_keyword_permissions,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1578), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1160), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [46873] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1197), 1,
      sym_split_clause,
    STATE(1230), 1,
      sym_group_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46930] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1632), 1,
      anon_sym_LPAREN,
    ACTIONS(1630), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46957] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1634), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [46981] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1601), 1,
      sym_keyword_flexible,
    ACTIONS(1604), 1,
      sym_keyword_readonly,
    ACTIONS(1607), 1,
      sym_keyword_type,
    ACTIONS(1619), 1,
      sym_keyword_comment,
    ACTIONS(1636), 1,
      sym_keyword_value,
    ACTIONS(1639), 1,
      sym_keyword_default,
    ACTIONS(1642), 1,
      sym_keyword_assert,
    ACTIONS(1645), 1,
      sym_keyword_permissions,
    ACTIONS(1596), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1170), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1648), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47047] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1650), 1,
      sym_keyword_value,
    ACTIONS(1652), 1,
      sym_keyword_default,
    ACTIONS(1654), 1,
      sym_keyword_assert,
    ACTIONS(1656), 1,
      sym_keyword_permissions,
    ACTIONS(1626), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1170), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47089] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1201), 1,
      sym_split_clause,
    STATE(1267), 1,
      sym_group_clause,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [47145] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1202), 1,
      sym_split_clause,
    STATE(1265), 1,
      sym_group_clause,
    STATE(1266), 1,
      sym_order_clause,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [47201] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1658), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47225] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1660), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_when,
      sym_keyword_then,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_fields,
      sym_keyword_columns,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [47249] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1650), 1,
      sym_keyword_value,
    ACTIONS(1652), 1,
      sym_keyword_default,
    ACTIONS(1654), 1,
      sym_keyword_assert,
    ACTIONS(1656), 1,
      sym_keyword_permissions,
    ACTIONS(1578), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1190), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1662), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47315] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1664), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47339] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1666), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47363] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1650), 1,
      sym_keyword_value,
    ACTIONS(1652), 1,
      sym_keyword_default,
    ACTIONS(1654), 1,
      sym_keyword_assert,
    ACTIONS(1656), 1,
      sym_keyword_permissions,
    ACTIONS(1578), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1170), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1668), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_when,
      sym_keyword_then,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_fields,
      sym_keyword_columns,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [47429] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1200), 1,
      sym_split_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1283), 1,
      sym_group_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [47485] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1650), 1,
      sym_keyword_value,
    ACTIONS(1652), 1,
      sym_keyword_default,
    ACTIONS(1654), 1,
      sym_keyword_assert,
    ACTIONS(1656), 1,
      sym_keyword_permissions,
    ACTIONS(1624), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1172), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47527] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1670), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47551] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(499), 1,
      sym_keyword_split,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1208), 1,
      sym_split_clause,
    STATE(1252), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [47607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1672), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47631] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1674), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(1576), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1677), 18,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_bm25,
      sym_keyword_doc_ids_cache,
      sym_keyword_doc_ids_order,
      sym_keyword_doc_lengths_cache,
      sym_keyword_doc_lengths_order,
      sym_keyword_postings_cache,
      sym_keyword_postings_order,
      sym_keyword_terms_cache,
      sym_keyword_terms_order,
      sym_keyword_highlights,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47683] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1650), 1,
      sym_keyword_value,
    ACTIONS(1652), 1,
      sym_keyword_default,
    ACTIONS(1654), 1,
      sym_keyword_assert,
    ACTIONS(1656), 1,
      sym_keyword_permissions,
    ACTIONS(1622), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1170), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47725] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1582), 1,
      sym_keyword_flexible,
    ACTIONS(1584), 1,
      sym_keyword_readonly,
    ACTIONS(1586), 1,
      sym_keyword_type,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1650), 1,
      sym_keyword_value,
    ACTIONS(1652), 1,
      sym_keyword_default,
    ACTIONS(1654), 1,
      sym_keyword_assert,
    ACTIONS(1656), 1,
      sym_keyword_permissions,
    ACTIONS(1626), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1181), 8,
      sym_type_clause,
      sym_default_clause,
      sym_readonly_clause,
      sym_value_clause,
      sym_assert_clause,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_define_field_statement_repeat2,
  [47767] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(1679), 1,
      anon_sym_EQ,
    STATE(34), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
    ACTIONS(314), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(316), 5,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [47804] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(1681), 1,
      anon_sym_EQ,
    STATE(46), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
    ACTIONS(535), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(537), 5,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [47841] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1223), 1,
      sym_group_clause,
    STATE(1266), 1,
      sym_order_clause,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47892] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1235), 1,
      sym_group_clause,
    STATE(1268), 1,
      sym_order_clause,
    STATE(1350), 1,
      sym_limit_clause,
    STATE(1488), 1,
      sym_fetch_clause,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47943] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1214), 1,
      sym_group_clause,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [47994] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1242), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48045] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    ACTIONS(501), 1,
      sym_keyword_group,
    STATE(1230), 1,
      sym_group_clause,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48096] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1283), 1,
      sym_group_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [48146] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1252), 1,
      sym_group_clause,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [48196] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1265), 1,
      sym_group_clause,
    STATE(1266), 1,
      sym_order_clause,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [48246] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1268), 1,
      sym_order_clause,
    STATE(1277), 1,
      sym_group_clause,
    STATE(1350), 1,
      sym_limit_clause,
    STATE(1488), 1,
      sym_fetch_clause,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [48296] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1685), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1687), 1,
      anon_sym_COMMA,
    STATE(1204), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 14,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_content,
      sym_keyword_merge,
      sym_keyword_patch,
      sym_keyword_replace,
      sym_keyword_unset,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48344] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1690), 16,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_for,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48366] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1696), 1,
      sym_keyword_drop,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1394), 1,
      sym_table_type_clause,
    STATE(1609), 1,
      sym_table_view_clause,
    STATE(1727), 1,
      sym_changefeed_clause,
    STATE(1901), 1,
      sym_permissions_for_clause,
    STATE(2183), 1,
      sym_comment_clause,
    ACTIONS(1698), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    ACTIONS(1692), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48412] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    ACTIONS(1708), 1,
      sym_keyword_drop,
    STATE(1397), 1,
      sym_table_type_clause,
    STATE(1560), 1,
      sym_table_view_clause,
    STATE(1728), 1,
      sym_changefeed_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1710), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    ACTIONS(1706), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48458] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(501), 1,
      sym_keyword_group,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1267), 1,
      sym_group_clause,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [48508] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1219), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1407), 1,
      sym_where_clause,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48553] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1213), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1388), 1,
      sym_where_clause,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48598] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
    STATE(1215), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1388), 1,
      sym_where_clause,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48643] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1720), 1,
      sym_keyword_drop,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1425), 1,
      sym_table_type_clause,
    STATE(1700), 1,
      sym_table_view_clause,
    STATE(1901), 1,
      sym_permissions_for_clause,
    STATE(1903), 1,
      sym_changefeed_clause,
    STATE(2183), 1,
      sym_comment_clause,
    ACTIONS(1692), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1722), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
  [48688] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1390), 1,
      sym_where_clause,
    STATE(1447), 1,
      sym_return_clause,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48733] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    STATE(1266), 1,
      sym_order_clause,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48778] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
    STATE(1390), 1,
      sym_where_clause,
    STATE(1437), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1447), 1,
      sym_return_clause,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48823] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(2175), 1,
      sym_literal_value,
    STATE(2452), 1,
      sym_type,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [48866] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(1374), 1,
      sym_type,
    STATE(2373), 1,
      sym_literal_value,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [48909] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1738), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48930] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1382), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [48975] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(2323), 1,
      sym_type,
    STATE(2373), 1,
      sym_literal_value,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49018] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1742), 1,
      anon_sym_COMMA,
    STATE(1221), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_content,
      sym_keyword_merge,
      sym_keyword_patch,
      sym_keyword_replace,
      sym_keyword_unset,
      sym_keyword_set,
  [49043] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1745), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_else,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      sym_keyword_duration,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49064] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    STATE(1268), 1,
      sym_order_clause,
    STATE(1350), 1,
      sym_limit_clause,
    STATE(1488), 1,
      sym_fetch_clause,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49109] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(2333), 1,
      sym_type,
    STATE(2373), 1,
      sym_literal_value,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49152] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
    STATE(1239), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1382), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49197] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
    STATE(1382), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1437), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49242] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49287] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1747), 1,
      anon_sym_COMMA,
    STATE(1228), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 13,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_with,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49312] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(1415), 1,
      sym_type,
    STATE(2373), 1,
      sym_literal_value,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49355] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49400] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    ACTIONS(1750), 1,
      sym_keyword_drop,
    STATE(1460), 1,
      sym_table_type_clause,
    STATE(1630), 1,
      sym_table_view_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(1829), 1,
      sym_changefeed_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1752), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
  [49445] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1397), 1,
      sym_table_type_clause,
    STATE(1560), 1,
      sym_table_view_clause,
    STATE(1728), 1,
      sym_changefeed_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1710), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    ACTIONS(1706), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49488] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(1343), 1,
      sym_type,
    STATE(2373), 1,
      sym_literal_value,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49531] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1238), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1382), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49576] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    STATE(1279), 1,
      sym_order_clause,
    STATE(1363), 1,
      sym_limit_clause,
    STATE(1444), 1,
      sym_fetch_clause,
    STATE(1624), 1,
      sym_timeout_clause,
    STATE(1832), 1,
      sym_parallel_clause,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49621] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(2373), 1,
      sym_literal_value,
    STATE(2392), 1,
      sym_type,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49664] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(1393), 1,
      sym_type,
    STATE(2373), 1,
      sym_literal_value,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49707] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1388), 1,
      sym_where_clause,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49752] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
    STATE(1388), 1,
      sym_where_clause,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1437), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49797] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    ACTIONS(1716), 1,
      anon_sym_COMMA,
    STATE(1226), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1407), 1,
      sym_where_clause,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49842] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1401), 1,
      sym_table_type_clause,
    STATE(1568), 1,
      sym_table_view_clause,
    STATE(1729), 1,
      sym_changefeed_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1758), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    ACTIONS(1756), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49885] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(493), 1,
      sym_keyword_order,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [49930] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(1913), 1,
      sym_literal_value,
    STATE(2249), 1,
      sym_type,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [49973] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(2373), 1,
      sym_literal_value,
    STATE(2428), 1,
      sym_type,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [50016] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1728), 1,
      anon_sym_LBRACK,
    ACTIONS(1730), 1,
      anon_sym_LBRACE,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1116), 1,
      sym_type_name,
    STATE(1129), 1,
      sym_duration,
    STATE(2373), 1,
      sym_literal_value,
    STATE(2412), 1,
      sym_type,
    STATE(1144), 4,
      sym_type_object,
      sym_union_type,
      sym_composite_type,
      sym_parameterized_type,
  [50059] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1760), 15,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_else,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      sym_keyword_duration,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50080] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1447), 1,
      sym_return_clause,
    STATE(1471), 1,
      sym_where_clause,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50124] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1460), 1,
      sym_table_type_clause,
    STATE(1630), 1,
      sym_table_view_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(1829), 1,
      sym_changefeed_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1752), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
  [50166] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50206] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1273), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1421), 1,
      sym_where_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50250] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1762), 1,
      anon_sym_COMMA,
    STATE(1274), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1421), 1,
      sym_where_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50294] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1278), 1,
      sym_order_clause,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50338] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1356), 1,
      sym_limit_clause,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50378] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1764), 1,
      anon_sym_COMMA,
    STATE(1254), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 12,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50402] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1249), 1,
      sym_order_clause,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50446] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1360), 1,
      sym_limit_clause,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50486] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1767), 1,
      anon_sym_COMMA,
    STATE(1257), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 12,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_content,
      sym_keyword_merge,
      sym_keyword_patch,
      sym_keyword_unset,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50510] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1770), 1,
      anon_sym_COMMA,
    STATE(1258), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_with,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
  [50534] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1773), 1,
      sym_keyword_only,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2825), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [50572] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1762), 1,
      anon_sym_COMMA,
    STATE(1447), 1,
      sym_return_clause,
    STATE(1471), 1,
      sym_where_clause,
    STATE(1596), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50616] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(715), 1,
      anon_sym_COMMA,
    STATE(1254), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(1777), 12,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50640] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1779), 14,
      sym_keyword_jwks,
      sym_keyword_eddsa,
      sym_keyword_es256,
      sym_keyword_es384,
      sym_keyword_es512,
      sym_keyword_ps256,
      sym_keyword_ps384,
      sym_keyword_ps512,
      sym_keyword_rs256,
      sym_keyword_rs384,
      sym_keyword_rs512,
      sym_keyword_hs256,
      sym_keyword_hs384,
      sym_keyword_hs512,
  [50660] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1432), 1,
      sym_table_type_clause,
    STATE(1667), 1,
      sym_table_view_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(1811), 1,
      sym_changefeed_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(1781), 2,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
  [50702] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1785), 1,
      anon_sym_PIPE,
    STATE(1264), 1,
      aux_sym_record_or_separated_repeat1,
    ACTIONS(1783), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50726] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1268), 1,
      sym_order_clause,
    STATE(1350), 1,
      sym_limit_clause,
    STATE(1488), 1,
      sym_fetch_clause,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50770] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1350), 1,
      sym_limit_clause,
    STATE(1488), 1,
      sym_fetch_clause,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50810] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1266), 1,
      sym_order_clause,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50854] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1363), 1,
      sym_limit_clause,
    STATE(1444), 1,
      sym_fetch_clause,
    STATE(1624), 1,
      sym_timeout_clause,
    STATE(1832), 1,
      sym_parallel_clause,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [50894] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1270), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1433), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50938] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1442), 1,
      sym_where_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [50982] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1762), 1,
      anon_sym_COMMA,
    STATE(1275), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1433), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51026] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1790), 1,
      anon_sym_PIPE,
    STATE(1264), 1,
      aux_sym_record_or_separated_repeat1,
    ACTIONS(1788), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51050] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1433), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51094] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1762), 1,
      anon_sym_COMMA,
    STATE(1433), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1596), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51138] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1762), 1,
      anon_sym_COMMA,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1442), 1,
      sym_where_clause,
    STATE(1596), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51182] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1247), 1,
      aux_sym_upsert_statement_repeat2,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1442), 1,
      sym_where_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51226] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1279), 1,
      sym_order_clause,
    STATE(1363), 1,
      sym_limit_clause,
    STATE(1444), 1,
      sym_fetch_clause,
    STATE(1624), 1,
      sym_timeout_clause,
    STATE(1832), 1,
      sym_parallel_clause,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51270] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1354), 1,
      sym_limit_clause,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51310] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    STATE(1368), 1,
      sym_limit_clause,
    STATE(1454), 1,
      sym_fetch_clause,
    STATE(1631), 1,
      sym_timeout_clause,
    STATE(1843), 1,
      sym_parallel_clause,
    STATE(2106), 1,
      sym_explain_clause,
    ACTIONS(1792), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51350] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    ACTIONS(1762), 1,
      anon_sym_COMMA,
    STATE(1260), 1,
      aux_sym_upsert_statement_repeat1,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1442), 1,
      sym_where_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51394] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1790), 1,
      anon_sym_PIPE,
    STATE(1272), 1,
      aux_sym_record_or_separated_repeat1,
    ACTIONS(1794), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51418] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    ACTIONS(1796), 1,
      sym_keyword_only,
    STATE(1366), 1,
      sym_identifier,
    STATE(2591), 1,
      sym_relate_subject,
    STATE(2592), 1,
      sym_object_key,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [51456] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(491), 1,
      sym_keyword_limit,
    ACTIONS(513), 1,
      sym_keyword_order,
    STATE(1253), 1,
      sym_order_clause,
    STATE(1362), 1,
      sym_limit_clause,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [51500] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1335), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(1798), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51523] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(1802), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51546] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1783), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [51565] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(1806), 1,
      sym_keyword_set,
    STATE(1662), 1,
      sym_return_clause,
    STATE(1899), 1,
      sym_timeout_clause,
    STATE(2038), 1,
      sym_parallel_clause,
    STATE(1583), 2,
      sym_content_clause,
      sym_set_clause,
    ACTIONS(1804), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51602] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    STATE(1383), 1,
      sym_where_clause,
    STATE(1443), 1,
      sym_return_clause,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51641] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 1,
      sym_keyword_unique,
    ACTIONS(1812), 1,
      sym_keyword_search,
    ACTIONS(1814), 1,
      sym_keyword_mtree,
    ACTIONS(1816), 1,
      sym_keyword_hnsw,
    ACTIONS(1808), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1309), 5,
      sym_unique_clause,
      sym_mtree_dimension_clause,
      sym_hnsw_dimension_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
  [51670] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1824), 1,
      sym_keyword_enforced,
    ACTIONS(1820), 2,
      sym_keyword_from,
      sym_keyword_in,
    ACTIONS(1822), 2,
      sym_keyword_out,
      sym_keyword_to,
    ACTIONS(1818), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51695] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1284), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(1826), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51718] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1335), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(1826), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51741] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    ACTIONS(737), 1,
      anon_sym_COMMA,
    STATE(1489), 1,
      sym_where_clause,
    STATE(1556), 1,
      aux_sym_update_statement_repeat1,
    STATE(1612), 1,
      sym_return_clause,
    STATE(1784), 1,
      sym_timeout_clause,
    STATE(2041), 1,
      sym_parallel_clause,
    ACTIONS(739), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51780] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 1,
      sym_keyword_unique,
    ACTIONS(1812), 1,
      sym_keyword_search,
    ACTIONS(1814), 1,
      sym_keyword_mtree,
    ACTIONS(1816), 1,
      sym_keyword_hnsw,
    ACTIONS(1828), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1323), 5,
      sym_unique_clause,
      sym_mtree_dimension_clause,
      sym_hnsw_dimension_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
  [51809] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1830), 1,
      sym_keyword_for,
    STATE(1305), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1738), 11,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51832] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2890), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [51867] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1834), 1,
      sym_keyword_tokenizers,
    ACTIONS(1836), 1,
      sym_keyword_function,
    ACTIONS(1838), 1,
      sym_keyword_filters,
    ACTIONS(1832), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1302), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [51896] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2632), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [51931] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1840), 1,
      anon_sym_COMMA,
    STATE(1299), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      sym_keyword_content,
      sym_keyword_merge,
      sym_keyword_patch,
      sym_keyword_unset,
      sym_keyword_set,
  [51954] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1397), 1,
      sym_table_type_clause,
    STATE(1560), 1,
      sym_table_view_clause,
    STATE(1728), 1,
      sym_changefeed_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [51993] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1845), 1,
      sym_keyword_table,
    ACTIONS(1847), 1,
      sym_keyword_root,
    ACTIONS(1851), 1,
      sym_keyword_user,
    STATE(2050), 1,
      sym_info_target,
    ACTIONS(1843), 2,
      sym_keyword_namespace,
      sym_keyword_ns,
    ACTIONS(1849), 2,
      sym_keyword_db,
      sym_keyword_database,
    STATE(2052), 5,
      sym_root_info,
      sym_namespace_info,
      sym_database_info,
      sym_table_info,
      sym_user_info,
  [52024] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1855), 1,
      sym_keyword_tokenizers,
    ACTIONS(1858), 1,
      sym_keyword_function,
    ACTIONS(1861), 1,
      sym_keyword_filters,
    ACTIONS(1864), 1,
      sym_keyword_comment,
    ACTIONS(1853), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1302), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [52053] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1871), 1,
      sym_keyword_enforced,
    ACTIONS(1873), 1,
      anon_sym_COMMA,
    STATE(1329), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(1869), 2,
      sym_keyword_out,
      sym_keyword_to,
    ACTIONS(1867), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52080] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1401), 1,
      sym_table_type_clause,
    STATE(1568), 1,
      sym_table_view_clause,
    STATE(1729), 1,
      sym_changefeed_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52119] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1877), 1,
      sym_keyword_for,
    STATE(1305), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1875), 11,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52142] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1880), 1,
      sym_keyword_index,
    ACTIONS(1882), 1,
      sym_keyword_analyzer,
    ACTIONS(1884), 1,
      sym_keyword_event,
    ACTIONS(1886), 1,
      sym_keyword_field,
    ACTIONS(1888), 1,
      sym_keyword_function,
    ACTIONS(1890), 1,
      sym_keyword_namespace,
    ACTIONS(1892), 1,
      sym_keyword_param,
    ACTIONS(1894), 1,
      sym_keyword_scope,
    ACTIONS(1896), 1,
      sym_keyword_table,
    ACTIONS(1898), 1,
      sym_keyword_token,
    ACTIONS(1900), 1,
      sym_keyword_user,
    ACTIONS(1902), 1,
      sym_keyword_database,
    ACTIONS(1904), 1,
      sym_keyword_access,
  [52185] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1908), 1,
      sym_keyword_session,
    ACTIONS(1910), 1,
      sym_keyword_signin,
    ACTIONS(1912), 1,
      sym_keyword_signup,
    ACTIONS(1906), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1331), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [52214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(93), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [52233] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 1,
      sym_keyword_unique,
    ACTIONS(1812), 1,
      sym_keyword_search,
    ACTIONS(1814), 1,
      sym_keyword_mtree,
    ACTIONS(1816), 1,
      sym_keyword_hnsw,
    ACTIONS(1914), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1315), 5,
      sym_unique_clause,
      sym_mtree_dimension_clause,
      sym_hnsw_dimension_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
  [52262] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1834), 1,
      sym_keyword_tokenizers,
    ACTIONS(1836), 1,
      sym_keyword_function,
    ACTIONS(1838), 1,
      sym_keyword_filters,
    ACTIONS(1916), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1297), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [52291] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    STATE(1382), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52330] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1353), 1,
      sym_relate_subject,
    STATE(1366), 1,
      sym_identifier,
    STATE(2662), 1,
      sym_object_key,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52365] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1287), 1,
      sym_relate_subject,
    STATE(1366), 1,
      sym_identifier,
    STATE(2662), 1,
      sym_object_key,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52400] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1834), 1,
      sym_keyword_tokenizers,
    ACTIONS(1836), 1,
      sym_keyword_function,
    ACTIONS(1838), 1,
      sym_keyword_filters,
    ACTIONS(1916), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1302), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [52429] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1920), 1,
      sym_keyword_unique,
    ACTIONS(1923), 1,
      sym_keyword_search,
    ACTIONS(1926), 1,
      sym_keyword_mtree,
    ACTIONS(1929), 1,
      sym_keyword_hnsw,
    ACTIONS(1918), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1315), 5,
      sym_unique_clause,
      sym_mtree_dimension_clause,
      sym_hnsw_dimension_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
  [52458] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(455), 1,
      sym_keyword_where,
    STATE(1407), 1,
      sym_where_clause,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52497] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(727), 1,
      anon_sym_COMMA,
    STATE(1325), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(1777), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
  [52520] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1834), 1,
      sym_keyword_tokenizers,
    ACTIONS(1836), 1,
      sym_keyword_function,
    ACTIONS(1838), 1,
      sym_keyword_filters,
    ACTIONS(1932), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1314), 5,
      sym_tokenizers_clause,
      sym_filters_clause,
      sym_function_clause,
      sym_comment_clause,
      aux_sym_define_analyzer_statement_repeat1,
  [52549] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1337), 1,
      sym_relate_subject,
    STATE(1366), 1,
      sym_identifier,
    STATE(2662), 1,
      sym_object_key,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52584] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1361), 1,
      sym_relate_subject,
    STATE(1366), 1,
      sym_identifier,
    STATE(2662), 1,
      sym_object_key,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52619] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1880), 1,
      sym_keyword_index,
    ACTIONS(1882), 1,
      sym_keyword_analyzer,
    ACTIONS(1884), 1,
      sym_keyword_event,
    ACTIONS(1890), 1,
      sym_keyword_namespace,
    ACTIONS(1894), 1,
      sym_keyword_scope,
    ACTIONS(1898), 1,
      sym_keyword_token,
    ACTIONS(1900), 1,
      sym_keyword_user,
    ACTIONS(1902), 1,
      sym_keyword_database,
    ACTIONS(1904), 1,
      sym_keyword_access,
    ACTIONS(1934), 1,
      sym_keyword_field,
    ACTIONS(1936), 1,
      sym_keyword_function,
    ACTIONS(1938), 1,
      sym_keyword_param,
    ACTIONS(1940), 1,
      sym_keyword_table,
  [52662] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1942), 13,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52681] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1810), 1,
      sym_keyword_unique,
    ACTIONS(1812), 1,
      sym_keyword_search,
    ACTIONS(1814), 1,
      sym_keyword_mtree,
    ACTIONS(1816), 1,
      sym_keyword_hnsw,
    ACTIONS(1808), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1315), 5,
      sym_unique_clause,
      sym_mtree_dimension_clause,
      sym_hnsw_dimension_clause,
      sym_search_analyzer_clause,
      aux_sym_define_index_statement_repeat1,
  [52710] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2763), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52745] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1944), 1,
      anon_sym_COMMA,
    STATE(1325), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_where,
      sym_keyword_split,
      sym_keyword_group,
  [52768] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2797), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52803] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2620), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52838] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      sym_keyword_count,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(81), 1,
      aux_sym_type_name_token1,
    ACTIONS(1775), 1,
      sym_variable_name,
    STATE(1366), 1,
      sym_identifier,
    STATE(2592), 1,
      sym_object_key,
    STATE(2628), 1,
      sym_relate_subject,
    ACTIONS(19), 3,
      sym_keyword_rand,
      sym_custom_function_name,
      sym_function_name,
    STATE(1435), 3,
      sym_function_call,
      sym_array,
      sym_record_id,
  [52873] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1949), 1,
      anon_sym_COMMA,
    STATE(1329), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(1947), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [52896] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1908), 1,
      sym_keyword_session,
    ACTIONS(1910), 1,
      sym_keyword_signin,
    ACTIONS(1912), 1,
      sym_keyword_signup,
    ACTIONS(1952), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1332), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [52925] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1908), 1,
      sym_keyword_session,
    ACTIONS(1910), 1,
      sym_keyword_signin,
    ACTIONS(1912), 1,
      sym_keyword_signup,
    ACTIONS(1952), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1336), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [52954] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1908), 1,
      sym_keyword_session,
    ACTIONS(1910), 1,
      sym_keyword_signin,
    ACTIONS(1912), 1,
      sym_keyword_signup,
    ACTIONS(1954), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1336), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [52983] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    ACTIONS(737), 1,
      anon_sym_COMMA,
    STATE(1520), 1,
      sym_where_clause,
    STATE(1556), 1,
      aux_sym_update_statement_repeat1,
    STATE(1642), 1,
      sym_return_clause,
    STATE(1860), 1,
      sym_timeout_clause,
    STATE(1960), 1,
      sym_parallel_clause,
    ACTIONS(1956), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53022] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1873), 1,
      anon_sym_COMMA,
    ACTIONS(1962), 1,
      sym_keyword_enforced,
    STATE(1303), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(1960), 2,
      sym_keyword_out,
      sym_keyword_to,
    ACTIONS(1958), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53049] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1964), 1,
      anon_sym_COMMA,
    STATE(1335), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(1576), 11,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      sym_keyword_group,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53072] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1969), 1,
      sym_keyword_comment,
    ACTIONS(1972), 1,
      sym_keyword_session,
    ACTIONS(1975), 1,
      sym_keyword_signin,
    ACTIONS(1978), 1,
      sym_keyword_signup,
    ACTIONS(1967), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1336), 5,
      sym_comment_clause,
      sym_session_clause,
      sym_signin_clause,
      sym_signup_clause,
      aux_sym_define_scope_statement_repeat1,
  [53101] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(1806), 1,
      sym_keyword_set,
    STATE(1689), 1,
      sym_return_clause,
    STATE(1828), 1,
      sym_timeout_clause,
    STATE(2122), 1,
      sym_parallel_clause,
    STATE(1566), 2,
      sym_content_clause,
      sym_set_clause,
    ACTIONS(1981), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53138] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1403), 1,
      sym_table_type_clause,
    STATE(1571), 1,
      sym_table_view_clause,
    STATE(1730), 1,
      sym_changefeed_clause,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53177] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1947), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_out,
      sym_keyword_to,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1985), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53213] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1987), 1,
      anon_sym_PIPE,
    STATE(1346), 1,
      aux_sym_record_or_separated_repeat1,
    ACTIONS(1788), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53235] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1432), 1,
      sym_table_type_clause,
    STATE(1667), 1,
      sym_table_view_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(1811), 1,
      sym_changefeed_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53273] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1989), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53291] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1993), 1,
      sym_keyword_type,
    ACTIONS(1995), 1,
      sym_keyword_dist,
    ACTIONS(1997), 1,
      sym_keyword_efc,
    ACTIONS(1999), 1,
      sym_keyword_m,
    ACTIONS(1991), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53317] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      sym_keyword_where,
    ACTIONS(749), 1,
      sym_keyword_group,
    ACTIONS(751), 1,
      anon_sym_COMMA,
    STATE(1434), 1,
      aux_sym_update_statement_repeat1,
    STATE(1501), 1,
      sym_where_clause,
    STATE(1752), 1,
      sym_group_clause,
    ACTIONS(745), 6,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53347] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2001), 1,
      anon_sym_PIPE,
    STATE(1346), 1,
      aux_sym_record_or_separated_repeat1,
    ACTIONS(1783), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53369] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(747), 1,
      sym_keyword_where,
    ACTIONS(749), 1,
      sym_keyword_group,
    ACTIONS(751), 1,
      anon_sym_COMMA,
    STATE(1434), 1,
      aux_sym_update_statement_repeat1,
    STATE(1533), 1,
      sym_where_clause,
    STATE(1722), 1,
      sym_group_clause,
    ACTIONS(2004), 6,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53399] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    ACTIONS(741), 1,
      anon_sym_COMMA,
    STATE(1611), 1,
      sym_where_clause,
    STATE(1612), 1,
      sym_return_clause,
    STATE(1665), 1,
      aux_sym_update_statement_repeat1,
    STATE(1784), 1,
      sym_timeout_clause,
    STATE(2041), 1,
      sym_parallel_clause,
    ACTIONS(739), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53437] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1485), 1,
      sym_table_type_clause,
    STATE(1699), 1,
      sym_table_view_clause,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(1900), 1,
      sym_changefeed_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53475] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1444), 1,
      sym_fetch_clause,
    STATE(1624), 1,
      sym_timeout_clause,
    STATE(1832), 1,
      sym_parallel_clause,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53509] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    STATE(1440), 1,
      sym_where_clause,
    STATE(1443), 1,
      sym_return_clause,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53547] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2010), 1,
      sym_keyword_function,
    ACTIONS(2012), 1,
      sym_keyword_param,
    ACTIONS(2014), 1,
      sym_keyword_token,
    ACTIONS(2016), 1,
      sym_keyword_user,
    ACTIONS(2006), 3,
      sym_keyword_index,
      sym_keyword_event,
      sym_keyword_field,
    ACTIONS(2008), 5,
      sym_keyword_analyzer,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_table,
      sym_keyword_database,
  [53575] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(2018), 1,
      sym_keyword_set,
    STATE(1662), 1,
      sym_return_clause,
    STATE(1899), 1,
      sym_timeout_clause,
    STATE(2038), 1,
      sym_parallel_clause,
    ACTIONS(1804), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1661), 2,
      sym_content_clause,
      sym_set_clause,
  [53611] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1488), 1,
      sym_fetch_clause,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53645] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1987), 1,
      anon_sym_PIPE,
    STATE(1341), 1,
      aux_sym_record_or_separated_repeat1,
    ACTIONS(1794), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53667] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1468), 1,
      sym_fetch_clause,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1335), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2020), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53723] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    STATE(1433), 1,
      sym_where_clause,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53761] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1702), 1,
      sym_keyword_type,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1460), 1,
      sym_table_type_clause,
    STATE(1630), 1,
      sym_table_view_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(1829), 1,
      sym_changefeed_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53799] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1441), 1,
      sym_fetch_clause,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53833] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(2018), 1,
      sym_keyword_set,
    STATE(1689), 1,
      sym_return_clause,
    STATE(1828), 1,
      sym_timeout_clause,
    STATE(2122), 1,
      sym_parallel_clause,
    ACTIONS(1981), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1610), 2,
      sym_content_clause,
      sym_set_clause,
  [53869] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1423), 1,
      sym_fetch_clause,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53903] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1454), 1,
      sym_fetch_clause,
    STATE(1631), 1,
      sym_timeout_clause,
    STATE(1843), 1,
      sym_parallel_clause,
    STATE(2106), 1,
      sym_explain_clause,
    ACTIONS(1792), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53937] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    ACTIONS(523), 1,
      sym_keyword_where,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1421), 1,
      sym_where_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [53975] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1371), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2022), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [53997] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    STATE(1786), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(2024), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_RBRACE,
  [54019] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2028), 2,
      sym_keyword_asc,
      sym_keyword_desc,
    ACTIONS(2026), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54039] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1477), 1,
      sym_fetch_clause,
    STATE(1641), 1,
      sym_timeout_clause,
    STATE(1816), 1,
      sym_parallel_clause,
    STATE(1953), 1,
      sym_explain_clause,
    ACTIONS(2030), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54073] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(1431), 1,
      sym_fetch_clause,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54107] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1357), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2032), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54129] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1800), 1,
      anon_sym_COMMA,
    STATE(1335), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2032), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      sym_keyword_order,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54151] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2034), 1,
      sym_keyword_for,
    STATE(1373), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1738), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
  [54173] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2036), 1,
      sym_keyword_for,
    STATE(1373), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1875), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
  [54195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2039), 12,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_value,
      sym_keyword_flexible,
      sym_keyword_readonly,
      sym_keyword_type,
      sym_keyword_default,
      sym_keyword_assert,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54213] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    ACTIONS(741), 1,
      anon_sym_COMMA,
    STATE(1642), 1,
      sym_return_clause,
    STATE(1643), 1,
      sym_where_clause,
    STATE(1665), 1,
      aux_sym_update_statement_repeat1,
    STATE(1860), 1,
      sym_timeout_clause,
    STATE(1960), 1,
      sym_parallel_clause,
    ACTIONS(1956), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [54251] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2043), 1,
      sym_keyword_else,
    STATE(1708), 1,
      sym_else_clause,
    STATE(1475), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(2041), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54274] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2047), 1,
      sym_keyword_enforced,
    ACTIONS(2049), 1,
      anon_sym_COMMA,
    STATE(1402), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(2045), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54297] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2047), 1,
      sym_keyword_enforced,
    ACTIONS(2049), 1,
      anon_sym_COMMA,
    STATE(1389), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(2045), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54320] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2053), 1,
      sym_keyword_type,
    ACTIONS(2055), 1,
      sym_keyword_dist,
    ACTIONS(2057), 1,
      sym_keyword_capacity,
    ACTIONS(2051), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54343] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    STATE(1538), 1,
      sym_where_clause,
    STATE(1644), 1,
      sym_return_clause,
    STATE(1874), 1,
      sym_timeout_clause,
    STATE(1961), 1,
      sym_parallel_clause,
    ACTIONS(1570), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54376] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1871), 1,
      sym_keyword_enforced,
    ACTIONS(2049), 1,
      anon_sym_COMMA,
    STATE(1402), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(1867), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54399] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54432] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54465] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2043), 1,
      sym_keyword_else,
    STATE(1762), 1,
      sym_else_clause,
    STATE(1376), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(2059), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54488] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    STATE(1559), 1,
      sym_where_clause,
    STATE(1616), 1,
      sym_return_clause,
    STATE(1787), 1,
      sym_timeout_clause,
    STATE(2150), 1,
      sym_parallel_clause,
    ACTIONS(545), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54521] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1443), 1,
      sym_return_clause,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54554] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(2063), 1,
      sym_keyword_return,
    ACTIONS(2065), 1,
      sym_keyword_set,
    STATE(1785), 1,
      sym_return_clause,
    STATE(2174), 1,
      sym_timeout_clause,
    STATE(1748), 2,
      sym_content_clause,
      sym_set_clause,
    ACTIONS(2061), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54585] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1447), 1,
      sym_return_clause,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54618] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      anon_sym_COMMA,
    ACTIONS(2069), 1,
      sym_keyword_enforced,
    STATE(1402), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(2067), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54641] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1451), 1,
      sym_return_clause,
    STATE(1686), 1,
      sym_timeout_clause,
    STATE(1856), 1,
      sym_parallel_clause,
    STATE(2119), 1,
      sym_explain_clause,
    ACTIONS(2071), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54674] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2075), 1,
      sym_keyword_with,
    ACTIONS(2077), 1,
      sym_keyword_signin,
    ACTIONS(2079), 1,
      sym_keyword_signup,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2083), 1,
      sym_keyword_authenticate,
    STATE(1676), 1,
      sym_access_record_jwt_clause,
    STATE(2107), 1,
      sym_duration_clause,
    ACTIONS(2073), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54705] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 1,
      sym_keyword_group,
    ACTIONS(779), 1,
      sym_keyword_where,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    STATE(1533), 1,
      sym_where_clause,
    STATE(1554), 1,
      aux_sym_update_statement_repeat1,
    STATE(1722), 1,
      sym_group_clause,
    ACTIONS(2004), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
  [54734] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2087), 1,
      sym_keyword_dist,
    ACTIONS(2089), 1,
      sym_keyword_efc,
    ACTIONS(2091), 1,
      sym_keyword_m,
    ACTIONS(2085), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54757] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1560), 1,
      sym_table_view_clause,
    STATE(1728), 1,
      sym_changefeed_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54790] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2097), 1,
      sym_keyword_permissions,
    ACTIONS(2093), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(2095), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1399), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [54815] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2097), 1,
      sym_keyword_permissions,
    ACTIONS(2093), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(2099), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1400), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [54840] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1568), 1,
      sym_table_view_clause,
    STATE(1729), 1,
      sym_changefeed_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54873] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    ACTIONS(549), 1,
      sym_keyword_where,
    STATE(1536), 1,
      sym_where_clause,
    STATE(1680), 1,
      sym_return_clause,
    STATE(1846), 1,
      sym_timeout_clause,
    STATE(2108), 1,
      sym_parallel_clause,
    ACTIONS(2101), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54906] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2097), 1,
      sym_keyword_permissions,
    ACTIONS(2099), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    ACTIONS(2103), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1400), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [54931] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2110), 1,
      sym_keyword_permissions,
    ACTIONS(2113), 1,
      sym_keyword_comment,
    ACTIONS(2105), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(2107), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1400), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [54956] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1571), 1,
      sym_table_view_clause,
    STATE(1730), 1,
      sym_changefeed_clause,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [54989] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2116), 1,
      anon_sym_COMMA,
    STATE(1402), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(1947), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      sym_keyword_enforced,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55010] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1694), 1,
      sym_keyword_as,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1572), 1,
      sym_table_view_clause,
    STATE(1731), 1,
      sym_changefeed_clause,
    STATE(1872), 1,
      sym_permissions_for_clause,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55043] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 1,
      sym_keyword_group,
    ACTIONS(779), 1,
      sym_keyword_where,
    ACTIONS(781), 1,
      anon_sym_COMMA,
    STATE(1501), 1,
      sym_where_clause,
    STATE(1554), 1,
      aux_sym_update_statement_repeat1,
    STATE(1752), 1,
      sym_group_clause,
    ACTIONS(745), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
  [55072] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2097), 1,
      sym_keyword_permissions,
    ACTIONS(2121), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(2123), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1396), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [55097] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2049), 1,
      anon_sym_COMMA,
    ACTIONS(2127), 1,
      sym_keyword_enforced,
    STATE(1377), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(2125), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55120] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(447), 1,
      sym_keyword_return,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55153] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1962), 1,
      sym_keyword_enforced,
    ACTIONS(2049), 1,
      anon_sym_COMMA,
    STATE(1381), 1,
      aux_sym_table_type_clause_repeat1,
    ACTIONS(1958), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55176] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2129), 1,
      anon_sym_GT,
    ACTIONS(2131), 1,
      anon_sym_DOT_DOT,
    ACTIONS(288), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55197] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2135), 1,
      sym_keyword_with,
    ACTIONS(2137), 1,
      sym_keyword_signin,
    ACTIONS(2139), 1,
      sym_keyword_signup,
    ACTIONS(2141), 1,
      sym_keyword_authenticate,
    STATE(1633), 1,
      sym_access_record_jwt_clause,
    STATE(2111), 1,
      sym_duration_clause,
    ACTIONS(2133), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55228] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(2063), 1,
      sym_keyword_return,
    ACTIONS(2065), 1,
      sym_keyword_set,
    STATE(1782), 1,
      sym_return_clause,
    STATE(2090), 1,
      sym_timeout_clause,
    STATE(1740), 2,
      sym_content_clause,
      sym_set_clause,
    ACTIONS(2143), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55259] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55287] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 1,
      anon_sym_LT_DASH,
    ACTIONS(383), 1,
      anon_sym_LBRACK,
    ACTIONS(385), 1,
      anon_sym_DOT,
    ACTIONS(69), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(113), 2,
      sym_path_element,
      aux_sym_path_repeat1,
    STATE(68), 3,
      sym_filter,
      sym_graph_path,
      sym_subscript,
  [55313] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(599), 1,
      anon_sym_LBRACK,
    ACTIONS(601), 1,
      anon_sym_LT_DASH,
    ACTIONS(603), 1,
      anon_sym_DOT,
    ACTIONS(597), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(200), 2,
      sym_path_element,
      aux_sym_path_repeat1,
    STATE(272), 3,
      sym_filter,
      sym_graph_path,
      sym_subscript,
  [55339] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2147), 1,
      sym_keyword_dist,
    ACTIONS(2149), 1,
      sym_keyword_capacity,
    ACTIONS(2145), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55359] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2089), 1,
      sym_keyword_efc,
    ACTIONS(2091), 1,
      sym_keyword_m,
    ACTIONS(2085), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55379] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    STATE(1680), 1,
      sym_return_clause,
    STATE(1681), 1,
      sym_where_clause,
    STATE(1846), 1,
      sym_timeout_clause,
    STATE(2108), 1,
      sym_parallel_clause,
    ACTIONS(2101), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55411] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(383), 1,
      anon_sym_LBRACK,
    ACTIONS(421), 1,
      anon_sym_LT_DASH,
    ACTIONS(423), 1,
      anon_sym_DOT,
    ACTIONS(419), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(130), 2,
      sym_path_element,
      aux_sym_path_repeat1,
    STATE(68), 3,
      sym_filter,
      sym_graph_path,
      sym_subscript,
  [55437] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2151), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55457] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55485] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    STATE(1436), 1,
      sym_return_clause,
    STATE(1684), 1,
      sym_timeout_clause,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55517] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 1,
      anon_sym_LBRACK,
    ACTIONS(403), 1,
      anon_sym_LT_DASH,
    ACTIONS(405), 1,
      anon_sym_DOT,
    ACTIONS(399), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(122), 2,
      sym_path_element,
      aux_sym_path_repeat1,
    STATE(153), 3,
      sym_filter,
      sym_graph_path,
      sym_subscript,
  [55543] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1664), 1,
      sym_timeout_clause,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2153), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55587] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1630), 1,
      sym_table_view_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(1829), 1,
      sym_changefeed_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55619] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2157), 1,
      sym_keyword_permissions,
    ACTIONS(2103), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(2155), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1427), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [55643] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2113), 1,
      sym_keyword_comment,
    ACTIONS(2162), 1,
      sym_keyword_permissions,
    ACTIONS(2105), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(2159), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1427), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [55667] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2167), 1,
      anon_sym_COMMA,
    STATE(1428), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2165), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55687] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    STATE(1614), 1,
      sym_where_clause,
    STATE(1616), 1,
      sym_return_clause,
    STATE(1787), 1,
      sym_timeout_clause,
    STATE(2150), 1,
      sym_parallel_clause,
    ACTIONS(545), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55719] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    ACTIONS(607), 1,
      sym_keyword_where,
    STATE(1644), 1,
      sym_return_clause,
    STATE(1645), 1,
      sym_where_clause,
    STATE(1874), 1,
      sym_timeout_clause,
    STATE(1961), 1,
      sym_parallel_clause,
    ACTIONS(1570), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55751] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1688), 1,
      sym_timeout_clause,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55779] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1699), 1,
      sym_table_view_clause,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(1900), 1,
      sym_changefeed_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55811] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    STATE(1412), 1,
      sym_return_clause,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55843] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2170), 1,
      anon_sym_COMMA,
    STATE(1434), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 8,
      sym_semi_colon,
      sym_keyword_where,
      sym_keyword_group,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55863] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2024), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_DASH_GT,
      anon_sym_RBRACE,
  [55879] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1617), 1,
      sym_timeout_clause,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55907] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2173), 1,
      anon_sym_COMMA,
    STATE(1437), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 8,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55927] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    STATE(1443), 1,
      sym_return_clause,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [55959] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1419), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2176), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [55979] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    STATE(1420), 1,
      sym_return_clause,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [56011] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1625), 1,
      sym_timeout_clause,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56039] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    STATE(1447), 1,
      sym_return_clause,
    STATE(1654), 1,
      sym_timeout_clause,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [56071] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1647), 1,
      sym_timeout_clause,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56099] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1631), 1,
      sym_timeout_clause,
    STATE(1843), 1,
      sym_parallel_clause,
    STATE(2106), 1,
      sym_explain_clause,
    ACTIONS(1792), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56127] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    STATE(1484), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2178), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56147] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2182), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_GT,
  [56163] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1686), 1,
      sym_timeout_clause,
    STATE(1856), 1,
      sym_parallel_clause,
    STATE(2119), 1,
      sym_explain_clause,
    ACTIONS(2071), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56191] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2186), 1,
      sym_keyword_minkowski,
    STATE(1557), 1,
      sym_distance_values,
    ACTIONS(2184), 8,
      sym_keyword_chebyshev,
      sym_keyword_cosine,
      sym_keyword_euclidean,
      sym_keyword_hamming,
      sym_keyword_jaccard,
      sym_keyword_manhattan,
      sym_keyword_pearson,
      sym_int,
  [56211] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2157), 1,
      sym_keyword_permissions,
    ACTIONS(2093), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(2188), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1426), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [56235] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2157), 1,
      sym_keyword_permissions,
    ACTIONS(2093), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(2155), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1427), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [56259] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1622), 1,
      sym_timeout_clause,
    STATE(1895), 1,
      sym_parallel_clause,
    STATE(2192), 1,
      sym_explain_clause,
    ACTIONS(2190), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56287] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2026), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56303] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2194), 1,
      sym_keyword_with,
    ACTIONS(2196), 1,
      sym_keyword_signin,
    ACTIONS(2198), 1,
      sym_keyword_authenticate,
    STATE(1640), 1,
      sym_access_record_jwt_clause,
    STATE(2126), 1,
      sym_duration_clause,
    ACTIONS(2192), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56331] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1641), 1,
      sym_timeout_clause,
    STATE(1816), 1,
      sym_parallel_clause,
    STATE(1953), 1,
      sym_explain_clause,
    ACTIONS(2030), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56359] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1618), 1,
      sym_timeout_clause,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56387] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    STATE(1428), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2200), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56407] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1651), 1,
      sym_timeout_clause,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56435] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1469), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2202), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56455] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(2204), 1,
      sym_keyword_return,
    ACTIONS(2206), 1,
      sym_keyword_set,
    STATE(1785), 1,
      sym_return_clause,
    STATE(2174), 1,
      sym_timeout_clause,
    ACTIONS(2061), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1820), 2,
      sym_content_clause,
      sym_set_clause,
  [56485] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1667), 1,
      sym_table_view_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(1811), 1,
      sym_changefeed_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [56517] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(145), 1,
      anon_sym_LT_DASH,
    ACTIONS(200), 1,
      anon_sym_LBRACK,
    ACTIONS(202), 1,
      anon_sym_DOT,
    ACTIONS(133), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(24), 2,
      sym_path_element,
      aux_sym_path_repeat1,
    STATE(90), 3,
      sym_filter,
      sym_graph_path,
      sym_subscript,
  [56543] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2186), 1,
      sym_keyword_minkowski,
    STATE(2685), 1,
      sym_distance_values,
    ACTIONS(2184), 8,
      sym_keyword_chebyshev,
      sym_keyword_cosine,
      sym_keyword_euclidean,
      sym_keyword_hamming,
      sym_keyword_jaccard,
      sym_keyword_manhattan,
      sym_keyword_pearson,
      sym_int,
  [56563] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2208), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_capacity,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_PIPE_GT,
  [56579] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    STATE(1456), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2210), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56599] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(465), 1,
      sym_keyword_content,
    ACTIONS(2204), 1,
      sym_keyword_return,
    ACTIONS(2206), 1,
      sym_keyword_set,
    STATE(1782), 1,
      sym_return_clause,
    STATE(2090), 1,
      sym_timeout_clause,
    ACTIONS(2143), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1824), 2,
      sym_content_clause,
      sym_set_clause,
  [56629] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2157), 1,
      sym_keyword_permissions,
    ACTIONS(2121), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    ACTIONS(2212), 3,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
    STATE(1450), 3,
      sym_permissions_for_clause,
      sym_comment_clause,
      aux_sym_alter_statement_repeat1,
  [56653] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2216), 1,
      sym_keyword_efc,
    ACTIONS(2218), 1,
      sym_keyword_m,
    ACTIONS(2214), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56673] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1690), 1,
      sym_timeout_clause,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56701] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2220), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2165), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56737] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(521), 1,
      sym_keyword_return,
    STATE(1451), 1,
      sym_return_clause,
    STATE(1686), 1,
      sym_timeout_clause,
    STATE(1856), 1,
      sym_parallel_clause,
    STATE(2119), 1,
      sym_explain_clause,
    ACTIONS(2071), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [56769] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2224), 1,
      anon_sym_COMMA,
    STATE(1474), 1,
      aux_sym_tokenizers_clause_repeat1,
    ACTIONS(2222), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56789] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2228), 1,
      sym_keyword_with,
    ACTIONS(2230), 1,
      sym_keyword_signin,
    ACTIONS(2232), 1,
      sym_keyword_authenticate,
    STATE(1646), 1,
      sym_access_record_jwt_clause,
    STATE(1965), 1,
      sym_duration_clause,
    ACTIONS(2226), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56817] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2236), 1,
      anon_sym_COMMA,
    STATE(1474), 1,
      aux_sym_tokenizers_clause_repeat1,
    ACTIONS(2234), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56837] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2241), 1,
      sym_keyword_else,
    STATE(1475), 2,
      sym_else_if_clause,
      aux_sym_if_statement_repeat1,
    ACTIONS(2239), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56857] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2246), 1,
      anon_sym_COMMA,
    STATE(1478), 1,
      aux_sym_filters_clause_repeat1,
    ACTIONS(2244), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56877] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1648), 1,
      sym_timeout_clause,
    STATE(1793), 1,
      sym_parallel_clause,
    STATE(1975), 1,
      sym_explain_clause,
    ACTIONS(2248), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56905] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2252), 1,
      anon_sym_COMMA,
    STATE(1478), 1,
      aux_sym_filters_clause_repeat1,
    ACTIONS(2250), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56925] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2224), 1,
      anon_sym_COMMA,
    STATE(1472), 1,
      aux_sym_tokenizers_clause_repeat1,
    ACTIONS(2255), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56945] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2257), 1,
      sym_keyword_for,
    STATE(1481), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1738), 8,
      sym_semi_colon,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56965] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2259), 1,
      sym_keyword_for,
    STATE(1481), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1875), 8,
      sym_semi_colon,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [56985] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2246), 1,
      anon_sym_COMMA,
    STATE(1476), 1,
      aux_sym_filters_clause_repeat1,
    ACTIONS(2262), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57005] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2264), 10,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57021] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2180), 1,
      anon_sym_COMMA,
    STATE(1428), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2210), 8,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57041] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1718), 1,
      sym_keyword_as,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1694), 1,
      sym_table_view_clause,
    STATE(1872), 1,
      sym_permissions_for_clause,
    STATE(1879), 1,
      sym_changefeed_clause,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [57073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2186), 1,
      sym_keyword_minkowski,
    STATE(1550), 1,
      sym_distance_values,
    ACTIONS(2184), 8,
      sym_keyword_chebyshev,
      sym_keyword_cosine,
      sym_keyword_euclidean,
      sym_keyword_hamming,
      sym_keyword_jaccard,
      sym_keyword_manhattan,
      sym_keyword_pearson,
      sym_int,
  [57093] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(625), 1,
      anon_sym_LBRACK,
    ACTIONS(627), 1,
      anon_sym_LT_DASH,
    ACTIONS(629), 1,
      anon_sym_DOT,
    ACTIONS(623), 2,
      anon_sym_DASH_GT,
      anon_sym_LT_DASH_GT,
    STATE(220), 2,
      sym_path_element,
      aux_sym_path_repeat1,
    STATE(341), 3,
      sym_filter,
      sym_graph_path,
      sym_subscript,
  [57119] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1624), 1,
      sym_timeout_clause,
    STATE(1832), 1,
      sym_parallel_clause,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57147] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1642), 1,
      sym_return_clause,
    STATE(1860), 1,
      sym_timeout_clause,
    STATE(1960), 1,
      sym_parallel_clause,
    ACTIONS(1956), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57174] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(2266), 1,
      anon_sym_DOT_DOT,
    STATE(285), 1,
      sym_record_id_range,
    STATE(367), 1,
      sym_record_id_value,
    ACTIONS(579), 2,
      sym_int,
      sym_record_id_ident,
    STATE(243), 2,
      sym_array,
      sym_object,
  [57201] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(2268), 1,
      anon_sym_DOT_DOT,
    STATE(333), 1,
      sym_record_id_range,
    STATE(353), 1,
      sym_record_id_value,
    ACTIONS(619), 2,
      sym_int,
      sym_record_id_ident,
    STATE(284), 2,
      sym_array,
      sym_object,
  [57228] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2270), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(601), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57255] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2272), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(602), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57282] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(2274), 1,
      anon_sym_DOT_DOT,
    STATE(158), 1,
      sym_record_id_range,
    STATE(368), 1,
      sym_record_id_value,
    ACTIONS(569), 2,
      sym_int,
      sym_record_id_ident,
    STATE(138), 2,
      sym_array,
      sym_object,
  [57309] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2276), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(514), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57336] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2278), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(423), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57363] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(2280), 1,
      anon_sym_DOT_DOT,
    STATE(285), 1,
      sym_record_id_range,
    STATE(310), 1,
      sym_record_id_value,
    ACTIONS(579), 2,
      sym_int,
      sym_record_id_ident,
    STATE(243), 2,
      sym_array,
      sym_object,
  [57390] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2282), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(542), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57417] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2284), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(444), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57444] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2286), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(544), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57471] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 1,
      sym_keyword_group,
    STATE(1722), 1,
      sym_group_clause,
    ACTIONS(2004), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57490] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2288), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(445), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57517] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2290), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(543), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57544] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2292), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(545), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57571] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2294), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(377), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57598] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2296), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(529), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57625] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2298), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(424), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57652] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2300), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(530), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57679] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2302), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(425), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57706] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2304), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(500), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57733] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(2306), 1,
      anon_sym_DOT_DOT,
    STATE(158), 1,
      sym_record_id_range,
    STATE(354), 1,
      sym_record_id_value,
    ACTIONS(569), 2,
      sym_int,
      sym_record_id_ident,
    STATE(138), 2,
      sym_array,
      sym_object,
  [57760] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2308), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(476), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57787] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2310), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2312), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57817] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2314), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(588), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57844] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2316), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(452), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57871] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2318), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(437), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57898] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2320), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(585), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [57925] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2322), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(311), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [57952] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1678), 1,
      sym_return_clause,
    STATE(1840), 1,
      sym_timeout_clause,
    STATE(2105), 1,
      sym_parallel_clause,
    ACTIONS(2324), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [57979] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2326), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(239), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [58006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2091), 1,
      sym_keyword_m,
    ACTIONS(2085), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58023] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2328), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58038] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2330), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(561), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [58065] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2332), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58080] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(535), 1,
      anon_sym_DASH_GT,
    ACTIONS(1681), 1,
      anon_sym_EQ,
    STATE(46), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58107] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2334), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58126] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(314), 1,
      anon_sym_DASH_GT,
    ACTIONS(1679), 1,
      anon_sym_EQ,
    STATE(34), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58153] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2336), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(471), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58180] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 1,
      sym_keyword_group,
    STATE(1752), 1,
      sym_group_clause,
    ACTIONS(745), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58199] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2338), 1,
      anon_sym_COMMA,
    STATE(1564), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2210), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [58218] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(2340), 1,
      anon_sym_DOT_DOT,
    STATE(289), 1,
      sym_record_id_value,
    STATE(333), 1,
      sym_record_id_range,
    ACTIONS(619), 2,
      sym_int,
      sym_record_id_ident,
    STATE(284), 2,
      sym_array,
      sym_object,
  [58245] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(749), 1,
      sym_keyword_group,
    STATE(1757), 1,
      sym_group_clause,
    ACTIONS(2342), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58264] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2344), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(650), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [58291] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2338), 1,
      anon_sym_COMMA,
    STATE(1586), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2210), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [58310] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1615), 1,
      sym_return_clause,
    STATE(1891), 1,
      sym_timeout_clause,
    STATE(1995), 1,
      sym_parallel_clause,
    ACTIONS(2346), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58337] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2348), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(548), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58364] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1680), 1,
      sym_return_clause,
    STATE(1846), 1,
      sym_timeout_clause,
    STATE(2108), 1,
      sym_parallel_clause,
    ACTIONS(2101), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58391] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2194), 1,
      sym_keyword_with,
    ACTIONS(2198), 1,
      sym_keyword_authenticate,
    STATE(1640), 1,
      sym_access_record_jwt_clause,
    STATE(2126), 1,
      sym_duration_clause,
    ACTIONS(2192), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58416] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2350), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(525), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58443] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2354), 1,
      anon_sym_COMMA,
    STATE(1545), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2352), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58462] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2356), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(501), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58489] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1612), 1,
      sym_return_clause,
    STATE(1784), 1,
      sym_timeout_clause,
    STATE(2041), 1,
      sym_parallel_clause,
    ACTIONS(739), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58516] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2358), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(503), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58543] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2360), 1,
      anon_sym_COMMA,
    STATE(1545), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58562] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2363), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58577] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1601), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2022), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58596] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2365), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(504), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58623] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1616), 1,
      sym_return_clause,
    STATE(1787), 1,
      sym_timeout_clause,
    STATE(2150), 1,
      sym_parallel_clause,
    ACTIONS(545), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58650] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2149), 1,
      sym_keyword_capacity,
    ACTIONS(2145), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58667] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    ACTIONS(2367), 1,
      anon_sym_DOT_DOT,
    STATE(250), 1,
      sym_record_id_value,
    STATE(285), 1,
      sym_record_id_range,
    ACTIONS(579), 2,
      sym_int,
      sym_record_id_ident,
    STATE(243), 2,
      sym_array,
      sym_object,
  [58694] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2369), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(472), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [58721] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    ACTIONS(2371), 1,
      anon_sym_DOT_DOT,
    STATE(158), 1,
      sym_record_id_range,
    STATE(245), 1,
      sym_record_id_value,
    ACTIONS(569), 2,
      sym_int,
      sym_record_id_ident,
    STATE(138), 2,
      sym_array,
      sym_object,
  [58748] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2373), 1,
      anon_sym_COMMA,
    STATE(1554), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_where,
      sym_keyword_group,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
  [58767] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2020), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58786] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2376), 1,
      anon_sym_COMMA,
    STATE(1556), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58805] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2381), 1,
      sym_keyword_capacity,
    ACTIONS(2379), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58822] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2383), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(355), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58849] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1644), 1,
      sym_return_clause,
    STATE(1874), 1,
      sym_timeout_clause,
    STATE(1961), 1,
      sym_parallel_clause,
    ACTIONS(1570), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58876] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1729), 1,
      sym_changefeed_clause,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [58903] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2385), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(527), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58930] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2387), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(526), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [58957] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2389), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(261), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [58984] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2338), 1,
      anon_sym_COMMA,
    STATE(1586), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2200), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [59003] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2218), 1,
      sym_keyword_m,
    ACTIONS(2214), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59020] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1662), 1,
      sym_return_clause,
    STATE(1899), 1,
      sym_timeout_clause,
    STATE(2038), 1,
      sym_parallel_clause,
    ACTIONS(1804), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59047] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2354), 1,
      anon_sym_COMMA,
    STATE(1541), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2391), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59066] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1730), 1,
      sym_changefeed_clause,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59093] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2393), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(2229), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59120] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2395), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(505), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59147] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1731), 1,
      sym_changefeed_clause,
    STATE(1872), 1,
      sym_permissions_for_clause,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59174] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1732), 1,
      sym_changefeed_clause,
    STATE(1817), 1,
      sym_permissions_for_clause,
    STATE(2088), 1,
      sym_comment_clause,
    ACTIONS(2397), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59201] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1527), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2399), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59220] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2228), 1,
      sym_keyword_with,
    ACTIONS(2232), 1,
      sym_keyword_authenticate,
    STATE(1646), 1,
      sym_access_record_jwt_clause,
    STATE(1965), 1,
      sym_duration_clause,
    ACTIONS(2226), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59245] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2401), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(492), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2234), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59287] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2403), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(475), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59314] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(887), 1,
      sym_keyword_where,
    ACTIONS(889), 1,
      anon_sym_COMMA,
    STATE(1754), 1,
      aux_sym_update_statement_repeat1,
    STATE(1788), 1,
      sym_where_clause,
    STATE(2053), 1,
      sym_fetch_clause,
    ACTIONS(2405), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59341] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2407), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(493), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59368] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2338), 1,
      anon_sym_COMMA,
    STATE(1535), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2178), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [59387] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2409), 1,
      anon_sym_COMMA,
    STATE(1581), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59406] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2250), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59421] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(547), 1,
      sym_keyword_return,
    STATE(1687), 1,
      sym_return_clause,
    STATE(1858), 1,
      sym_timeout_clause,
    STATE(2124), 1,
      sym_parallel_clause,
    ACTIONS(2412), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2414), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59463] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(901), 1,
      anon_sym_COMMA,
    STATE(1581), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2416), 7,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59482] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2418), 1,
      anon_sym_COMMA,
    STATE(1586), 1,
      aux_sym_order_clause_repeat1,
    ACTIONS(2165), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      sym_keyword_limit,
  [59501] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2423), 1,
      sym_keyword_m,
    ACTIONS(2421), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59518] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2425), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(494), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59545] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2427), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59560] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2429), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(589), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2431), 9,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59602] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2433), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(287), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59629] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    ACTIONS(2435), 1,
      anon_sym_DOT_DOT,
    STATE(333), 1,
      sym_record_id_range,
    STATE(398), 1,
      sym_record_id_value,
    ACTIONS(619), 2,
      sym_int,
      sym_record_id_ident,
    STATE(284), 2,
      sym_array,
      sym_object,
  [59656] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2437), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(590), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59683] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2439), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(400), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59710] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2441), 1,
      anon_sym_COMMA,
    STATE(1596), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [59729] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2446), 1,
      sym_keyword_with,
    ACTIONS(2448), 1,
      sym_keyword_authenticate,
    STATE(1655), 1,
      sym_access_record_jwt_clause,
    STATE(1996), 1,
      sym_duration_clause,
    ACTIONS(2444), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59754] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2450), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(597), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59781] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2452), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(528), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59808] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1555), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2032), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59827] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
    ACTIONS(2032), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59846] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2456), 1,
      sym_keyword_with,
    ACTIONS(2458), 1,
      sym_keyword_authenticate,
    STATE(1656), 1,
      sym_access_record_jwt_clause,
    STATE(2001), 1,
      sym_duration_clause,
    ACTIONS(2454), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [59871] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2460), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(442), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59898] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2462), 1,
      anon_sym_DOT_DOT,
    STATE(40), 1,
      sym_record_id_range,
    STATE(1409), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [59925] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2464), 1,
      sym_keyword_for,
    STATE(1606), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1738), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_permissions,
      sym_keyword_comment,
  [59944] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2466), 1,
      sym_keyword_for,
    STATE(1606), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1875), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_drop,
      sym_keyword_schemafull,
      sym_keyword_schemaless,
      sym_keyword_permissions,
      sym_keyword_comment,
  [59963] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2469), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(512), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [59990] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(2471), 1,
      anon_sym_DOT_DOT,
    STATE(86), 1,
      sym_record_id_range,
    STATE(563), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [60017] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1728), 1,
      sym_changefeed_clause,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60044] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1662), 1,
      sym_return_clause,
    STATE(1899), 1,
      sym_timeout_clause,
    STATE(2038), 1,
      sym_parallel_clause,
    ACTIONS(1804), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [60070] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1642), 1,
      sym_return_clause,
    STATE(1860), 1,
      sym_timeout_clause,
    STATE(1960), 1,
      sym_parallel_clause,
    ACTIONS(1956), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [60096] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1860), 1,
      sym_timeout_clause,
    STATE(1960), 1,
      sym_parallel_clause,
    ACTIONS(1956), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2085), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60132] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1644), 1,
      sym_return_clause,
    STATE(1874), 1,
      sym_timeout_clause,
    STATE(1961), 1,
      sym_parallel_clause,
    ACTIONS(1570), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [60158] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1798), 1,
      sym_timeout_clause,
    STATE(1956), 1,
      sym_parallel_clause,
    ACTIONS(2473), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60180] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1874), 1,
      sym_timeout_clause,
    STATE(1961), 1,
      sym_parallel_clause,
    ACTIONS(1570), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60202] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1804), 1,
      sym_parallel_clause,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60224] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1790), 1,
      sym_parallel_clause,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60246] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2045), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60260] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1813), 1,
      sym_parallel_clause,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(899), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1833), 1,
      sym_parallel_clause,
    STATE(2089), 1,
      sym_explain_clause,
    ACTIONS(2475), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60318] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2477), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_tokenizers,
      sym_keyword_function,
      sym_keyword_filters,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60332] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1843), 1,
      sym_parallel_clause,
    STATE(2106), 1,
      sym_explain_clause,
    ACTIONS(1792), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60354] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1791), 1,
      sym_parallel_clause,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60376] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2067), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60390] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2479), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2481), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2483), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      sym_keyword_session,
      sym_keyword_signin,
      sym_keyword_signup,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60432] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(1811), 1,
      sym_changefeed_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [60458] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1816), 1,
      sym_parallel_clause,
    STATE(1953), 1,
      sym_explain_clause,
    ACTIONS(2030), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2379), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60494] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2083), 1,
      sym_keyword_authenticate,
    ACTIONS(2485), 1,
      sym_keyword_with,
    STATE(2107), 1,
      sym_duration_clause,
    ACTIONS(2073), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2214), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60530] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1818), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60544] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2489), 1,
      sym_keyword_permissions,
    ACTIONS(2487), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1639), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [60564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2491), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60578] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2489), 1,
      sym_keyword_permissions,
    ACTIONS(2493), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1639), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [60598] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2497), 1,
      sym_keyword_permissions,
    ACTIONS(2500), 1,
      sym_keyword_comment,
    ACTIONS(2495), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1639), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [60618] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2232), 1,
      sym_keyword_authenticate,
    ACTIONS(2503), 1,
      sym_keyword_with,
    STATE(1965), 1,
      sym_duration_clause,
    ACTIONS(2226), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60640] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1793), 1,
      sym_parallel_clause,
    STATE(1975), 1,
      sym_explain_clause,
    ACTIONS(2248), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60662] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1840), 1,
      sym_timeout_clause,
    STATE(2105), 1,
      sym_parallel_clause,
    ACTIONS(2324), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60684] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1678), 1,
      sym_return_clause,
    STATE(1840), 1,
      sym_timeout_clause,
    STATE(2105), 1,
      sym_parallel_clause,
    ACTIONS(2324), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [60710] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1846), 1,
      sym_timeout_clause,
    STATE(2108), 1,
      sym_parallel_clause,
    ACTIONS(2101), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60732] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1680), 1,
      sym_return_clause,
    STATE(1846), 1,
      sym_timeout_clause,
    STATE(2108), 1,
      sym_parallel_clause,
    ACTIONS(2101), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [60758] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2507), 1,
      sym_keyword_with,
    ACTIONS(2509), 1,
      sym_keyword_authenticate,
    STATE(1980), 1,
      sym_duration_clause,
    ACTIONS(2505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60780] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1853), 1,
      sym_parallel_clause,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60802] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1809), 1,
      sym_parallel_clause,
    STATE(1984), 1,
      sym_explain_clause,
    ACTIONS(2511), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60824] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2513), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60838] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2421), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60852] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1864), 1,
      sym_parallel_clause,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60874] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2515), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_fetch,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60888] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2517), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60902] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1856), 1,
      sym_parallel_clause,
    STATE(2119), 1,
      sym_explain_clause,
    ACTIONS(2071), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60924] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2458), 1,
      sym_keyword_authenticate,
    ACTIONS(2519), 1,
      sym_keyword_with,
    STATE(2001), 1,
      sym_duration_clause,
    ACTIONS(2454), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60946] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2523), 1,
      sym_keyword_with,
    ACTIONS(2525), 1,
      sym_keyword_authenticate,
    STATE(2004), 1,
      sym_duration_clause,
    ACTIONS(2521), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [60968] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2527), 1,
      anon_sym_COMMA,
    STATE(1657), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [60986] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2530), 1,
      anon_sym_COMMA,
    STATE(1692), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2391), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [61004] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2489), 1,
      sym_keyword_permissions,
    ACTIONS(2487), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1638), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [61024] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2145), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61038] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1687), 1,
      sym_return_clause,
    STATE(1858), 1,
      sym_timeout_clause,
    STATE(2124), 1,
      sym_parallel_clause,
    ACTIONS(2412), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61064] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1858), 1,
      sym_timeout_clause,
    STATE(2124), 1,
      sym_parallel_clause,
    ACTIONS(2412), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2532), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_unique,
      sym_keyword_search,
      sym_keyword_mtree,
      sym_keyword_hnsw,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61100] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1867), 1,
      sym_parallel_clause,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61122] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2534), 1,
      anon_sym_COMMA,
    STATE(1665), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [61140] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2537), 1,
      anon_sym_COMMA,
    STATE(1670), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2352), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61158] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(1900), 1,
      sym_changefeed_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2537), 1,
      anon_sym_COMMA,
    STATE(1666), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2391), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2539), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61216] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2541), 1,
      anon_sym_COMMA,
    STATE(1670), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 6,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61234] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2125), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61248] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    ACTIONS(913), 1,
      sym_keyword_where,
    ACTIONS(915), 1,
      anon_sym_COMMA,
    STATE(1788), 1,
      sym_where_clause,
    STATE(1845), 1,
      aux_sym_update_statement_repeat1,
    STATE(2053), 1,
      sym_fetch_clause,
    ACTIONS(2405), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61274] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(919), 1,
      anon_sym_COMMA,
    STATE(1657), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2416), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
  [61292] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1612), 1,
      sym_return_clause,
    STATE(1784), 1,
      sym_timeout_clause,
    STATE(2041), 1,
      sym_parallel_clause,
    ACTIONS(739), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61318] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2544), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      sym_keyword_content,
      sym_keyword_set,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61332] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2548), 1,
      sym_keyword_with,
    ACTIONS(2550), 1,
      sym_keyword_authenticate,
    STATE(2179), 1,
      sym_duration_clause,
    ACTIONS(2546), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61354] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2552), 1,
      anon_sym_COMMA,
    STATE(1677), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 6,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61372] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1888), 1,
      sym_timeout_clause,
    STATE(2093), 1,
      sym_parallel_clause,
    ACTIONS(2555), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61394] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1784), 1,
      sym_timeout_clause,
    STATE(2041), 1,
      sym_parallel_clause,
    ACTIONS(739), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61416] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1891), 1,
      sym_timeout_clause,
    STATE(1995), 1,
      sym_parallel_clause,
    ACTIONS(2346), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61438] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1615), 1,
      sym_return_clause,
    STATE(1891), 1,
      sym_timeout_clause,
    STATE(1995), 1,
      sym_parallel_clause,
    ACTIONS(2346), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61464] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(605), 1,
      sym_keyword_return,
    STATE(1616), 1,
      sym_return_clause,
    STATE(1787), 1,
      sym_timeout_clause,
    STATE(2150), 1,
      sym_parallel_clause,
    ACTIONS(545), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61490] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1787), 1,
      sym_timeout_clause,
    STATE(2150), 1,
      sym_parallel_clause,
    ACTIONS(545), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61512] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1880), 1,
      sym_parallel_clause,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61534] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1789), 1,
      sym_parallel_clause,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61556] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1895), 1,
      sym_parallel_clause,
    STATE(2192), 1,
      sym_explain_clause,
    ACTIONS(2190), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61578] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1805), 1,
      sym_timeout_clause,
    STATE(1978), 1,
      sym_parallel_clause,
    ACTIONS(2557), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61600] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1869), 1,
      sym_parallel_clause,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61622] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1899), 1,
      sym_timeout_clause,
    STATE(2038), 1,
      sym_parallel_clause,
    ACTIONS(1804), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61644] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1832), 1,
      sym_parallel_clause,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61666] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2559), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_else,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61680] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2530), 1,
      anon_sym_COMMA,
    STATE(1693), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2352), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [61698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2561), 1,
      anon_sym_COMMA,
    STATE(1693), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
      sym_keyword_where,
  [61716] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1817), 1,
      sym_permissions_for_clause,
    STATE(1818), 1,
      sym_changefeed_clause,
    STATE(2088), 1,
      sym_comment_clause,
    ACTIONS(2397), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61742] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    ACTIONS(1734), 1,
      sym_string,
    ACTIONS(1736), 1,
      sym_int,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1129), 1,
      sym_duration,
    STATE(1126), 2,
      sym_type_name,
      sym_literal_value,
  [61768] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1867), 8,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_as,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61782] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(925), 1,
      anon_sym_COMMA,
    STATE(1677), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 6,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61800] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(925), 1,
      anon_sym_COMMA,
    STATE(1677), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 6,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61818] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1872), 1,
      sym_permissions_for_clause,
    STATE(1879), 1,
      sym_changefeed_clause,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61844] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1700), 1,
      sym_keyword_changefeed,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(1829), 1,
      sym_changefeed_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [61870] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2489), 1,
      sym_keyword_permissions,
    ACTIONS(2566), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    STATE(1636), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [61890] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(36), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [61911] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    STATE(171), 1,
      sym_record_id_value,
    ACTIONS(569), 2,
      sym_int,
      sym_record_id_ident,
    STATE(138), 2,
      sym_array,
      sym_object,
  [61932] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(34), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [61953] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2568), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_with,
      sym_keyword_duration,
      sym_keyword_authenticate,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61966] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2509), 1,
      sym_keyword_authenticate,
    STATE(1980), 1,
      sym_duration_clause,
    ACTIONS(2505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2570), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [61998] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2572), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62011] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2576), 1,
      sym_keyword_authenticate,
    STATE(1986), 1,
      sym_duration_clause,
    ACTIONS(2574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62030] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2448), 1,
      sym_keyword_authenticate,
    STATE(1996), 1,
      sym_duration_clause,
    ACTIONS(2444), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2578), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_with,
      sym_keyword_duration,
      sym_keyword_authenticate,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62062] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    ACTIONS(2580), 1,
      sym_keyword_when,
    ACTIONS(2582), 1,
      sym_keyword_then,
    STATE(1797), 1,
      sym_when_then_clause,
    STATE(1719), 2,
      sym_block,
      sym_sub_query,
  [62085] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    STATE(174), 1,
      sym_record_id_value,
    ACTIONS(569), 2,
      sym_int,
      sym_record_id_ident,
    STATE(138), 2,
      sym_array,
      sym_object,
  [62106] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2584), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_with,
      sym_keyword_duration,
      sym_keyword_authenticate,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62119] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2525), 1,
      sym_keyword_authenticate,
    STATE(2004), 1,
      sym_duration_clause,
    ACTIONS(2521), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62138] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2588), 1,
      sym_keyword_authenticate,
    STATE(2005), 1,
      sym_duration_clause,
    ACTIONS(2586), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62157] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2592), 1,
      sym_keyword_authenticate,
    STATE(2008), 1,
      sym_duration_clause,
    ACTIONS(2590), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62176] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(306), 1,
      anon_sym_LT_DASH,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    STATE(1802), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(304), 4,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
  [62195] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1735), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2594), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2598), 1,
      anon_sym_COMMA,
    STATE(1751), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2391), 5,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62229] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2600), 1,
      sym_keyword_permissions,
    ACTIONS(2566), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1738), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [62248] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2342), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62261] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(306), 1,
      anon_sym_LT_DASH,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    STATE(1799), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(304), 4,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
  [62280] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(306), 1,
      anon_sym_LT_DASH,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    STATE(1857), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(304), 4,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
  [62299] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(306), 1,
      anon_sym_LT_DASH,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    STATE(1897), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(304), 4,
      anon_sym_DASH_GT,
      anon_sym_LBRACK,
      anon_sym_LT_DASH_GT,
      anon_sym_DOT,
  [62318] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(565), 1,
      anon_sym_LBRACK,
    ACTIONS(567), 1,
      anon_sym_LBRACE,
    STATE(175), 1,
      sym_record_id_value,
    ACTIONS(569), 2,
      sym_int,
      sym_record_id_ident,
    STATE(138), 2,
      sym_array,
      sym_object,
  [62339] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62360] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62381] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62402] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1872), 1,
      sym_permissions_for_clause,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62423] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1817), 1,
      sym_permissions_for_clause,
    STATE(2088), 1,
      sym_comment_clause,
    ACTIONS(2397), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62444] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1704), 1,
      sym_keyword_permissions,
    STATE(1827), 1,
      sym_permissions_for_clause,
    STATE(1988), 1,
      sym_comment_clause,
    ACTIONS(2602), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62465] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2608), 1,
      anon_sym_snowball,
    STATE(1582), 1,
      sym_analyzer_filters,
    ACTIONS(2606), 2,
      anon_sym_edgengram,
      anon_sym_ngram,
    ACTIONS(2604), 3,
      anon_sym_ascii,
      anon_sym_lowercase,
      anon_sym_uppercase,
  [62484] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1771), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2610), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62501] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1772), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2610), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62518] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1772), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2612), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62535] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2600), 1,
      sym_keyword_permissions,
    ACTIONS(2487), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1778), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [62554] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2600), 1,
      sym_keyword_permissions,
    ACTIONS(2487), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1779), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [62573] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    STATE(100), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [62594] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(2063), 1,
      sym_keyword_return,
    STATE(1785), 1,
      sym_return_clause,
    STATE(2174), 1,
      sym_timeout_clause,
    ACTIONS(2061), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62615] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2198), 1,
      sym_keyword_authenticate,
    STATE(2126), 1,
      sym_duration_clause,
    ACTIONS(2192), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62634] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2614), 1,
      anon_sym_COMMA,
    STATE(1775), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2391), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [62651] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    STATE(103), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [62672] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1736), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2616), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(745), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62702] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1772), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2616), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62719] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(135), 1,
      anon_sym_LBRACK,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    STATE(104), 1,
      sym_record_id_value,
    ACTIONS(541), 2,
      sym_int,
      sym_record_id_ident,
    STATE(70), 2,
      sym_array,
      sym_object,
  [62740] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(2063), 1,
      sym_keyword_return,
    STATE(1841), 1,
      sym_return_clause,
    STATE(1951), 1,
      sym_timeout_clause,
    ACTIONS(2618), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62761] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2620), 1,
      anon_sym_COMMA,
    STATE(1749), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 5,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62778] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2623), 1,
      anon_sym_COMMA,
    STATE(1750), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [62795] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2598), 1,
      anon_sym_COMMA,
    STATE(1756), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2352), 5,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2004), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62825] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2550), 1,
      sym_keyword_authenticate,
    STATE(2179), 1,
      sym_duration_clause,
    ACTIONS(2546), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62844] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2626), 1,
      anon_sym_COMMA,
    STATE(1754), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 5,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_where,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(927), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62874] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2629), 1,
      anon_sym_COMMA,
    STATE(1756), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 5,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62891] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2632), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_changefeed,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62904] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    STATE(321), 1,
      sym_record_id_value,
    ACTIONS(619), 2,
      sym_int,
      sym_record_id_ident,
    STATE(284), 2,
      sym_array,
      sym_object,
  [62925] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    STATE(315), 1,
      sym_record_id_value,
    ACTIONS(619), 2,
      sym_int,
      sym_record_id_ident,
    STATE(284), 2,
      sym_array,
      sym_object,
  [62946] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(615), 1,
      anon_sym_LBRACK,
    ACTIONS(617), 1,
      anon_sym_LBRACE,
    STATE(316), 1,
      sym_record_id_value,
    ACTIONS(619), 2,
      sym_int,
      sym_record_id_ident,
    STATE(284), 2,
      sym_array,
      sym_object,
  [62967] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2232), 1,
      sym_keyword_authenticate,
    STATE(1965), 1,
      sym_duration_clause,
    ACTIONS(2226), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62986] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2041), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [62999] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(37), 1,
      sym_record_id_value,
    ACTIONS(559), 2,
      sym_int,
      sym_record_id_ident,
    STATE(28), 2,
      sym_array,
      sym_object,
  [63020] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2608), 1,
      anon_sym_snowball,
    STATE(1482), 1,
      sym_analyzer_filters,
    ACTIONS(2606), 2,
      anon_sym_edgengram,
      anon_sym_ngram,
    ACTIONS(2604), 3,
      anon_sym_ascii,
      anon_sym_lowercase,
      anon_sym_uppercase,
  [63039] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    STATE(301), 1,
      sym_record_id_value,
    ACTIONS(579), 2,
      sym_int,
      sym_record_id_ident,
    STATE(243), 2,
      sym_array,
      sym_object,
  [63060] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    ACTIONS(2580), 1,
      sym_keyword_when,
    ACTIONS(2582), 1,
      sym_keyword_then,
    STATE(1844), 1,
      sym_when_then_clause,
    STATE(1719), 2,
      sym_block,
      sym_sub_query,
  [63083] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    STATE(304), 1,
      sym_record_id_value,
    ACTIONS(579), 2,
      sym_int,
      sym_record_id_ident,
    STATE(243), 2,
      sym_array,
      sym_object,
  [63104] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(575), 1,
      anon_sym_LBRACK,
    ACTIONS(577), 1,
      anon_sym_LBRACE,
    STATE(305), 1,
      sym_record_id_value,
    ACTIONS(579), 2,
      sym_int,
      sym_record_id_ident,
    STATE(243), 2,
      sym_array,
      sym_object,
  [63125] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    ACTIONS(2636), 1,
      sym_keyword_authenticate,
    STATE(2061), 1,
      sym_duration_clause,
    ACTIONS(2634), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63144] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1746), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2638), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63161] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2596), 1,
      anon_sym_COMMA,
    STATE(1772), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2638), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63178] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2642), 1,
      anon_sym_COMMA,
    STATE(1772), 1,
      aux_sym_when_then_clause_repeat1,
    ACTIONS(2640), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63195] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(937), 1,
      anon_sym_COMMA,
    STATE(1749), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 5,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63212] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(937), 1,
      anon_sym_COMMA,
    STATE(1749), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 5,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63229] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2614), 1,
      anon_sym_COMMA,
    STATE(1780), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2352), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [63246] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(941), 1,
      anon_sym_COMMA,
    STATE(1750), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [63263] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(941), 1,
      anon_sym_COMMA,
    STATE(1750), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [63280] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(2600), 1,
      sym_keyword_permissions,
    ACTIONS(2493), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1779), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [63299] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2500), 1,
      sym_keyword_comment,
    ACTIONS(2645), 1,
      sym_keyword_permissions,
    ACTIONS(2495), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
    STATE(1779), 3,
      sym_permissions_basic_clause,
      sym_comment_clause,
      aux_sym_define_function_statement_repeat1,
  [63318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2648), 1,
      anon_sym_COMMA,
    STATE(1780), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [63335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2651), 7,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_with,
      sym_keyword_duration,
      sym_keyword_authenticate,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63348] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(2174), 1,
      sym_timeout_clause,
    ACTIONS(2061), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63364] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(1980), 1,
      sym_duration_clause,
    ACTIONS(2505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63380] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1960), 1,
      sym_parallel_clause,
    ACTIONS(1956), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63396] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(1951), 1,
      sym_timeout_clause,
    ACTIONS(2618), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63412] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(39), 1,
      sym_argument_list,
    STATE(2141), 1,
      aux_sym_function_call_repeat1,
    STATE(2498), 1,
      sym_version,
  [63434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1961), 1,
      sym_parallel_clause,
    ACTIONS(1570), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63450] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(2120), 1,
      sym_fetch_clause,
    ACTIONS(2655), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63466] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1970), 1,
      sym_explain_clause,
    ACTIONS(1508), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63482] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2115), 1,
      sym_explain_clause,
    ACTIONS(1740), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63498] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2147), 1,
      sym_explain_clause,
    ACTIONS(1683), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63514] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2659), 1,
      anon_sym_COMMA,
    STATE(1792), 1,
      aux_sym_duration_clause_repeat1,
    ACTIONS(2657), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63530] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1984), 1,
      sym_explain_clause,
    ACTIONS(2511), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63546] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(947), 1,
      anon_sym_COMMA,
    STATE(1826), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 4,
      sym_semi_colon,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63562] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2662), 1,
      anon_sym_RBRACE,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    STATE(2328), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
    STATE(2810), 1,
      sym_object_content,
  [63584] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(947), 1,
      anon_sym_COMMA,
    STATE(1826), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 4,
      sym_semi_colon,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63600] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2169), 1,
      sym_comment_clause,
    ACTIONS(2668), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63616] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2114), 1,
      sym_parallel_clause,
    ACTIONS(2670), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63632] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    ACTIONS(669), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(332), 1,
      sym_argument_list,
    STATE(2141), 1,
      aux_sym_function_call_repeat1,
    STATE(2558), 1,
      sym_version,
  [63654] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2162), 1,
      sym_comment_clause,
    ACTIONS(2672), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63670] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2674), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 4,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [63686] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(79), 1,
      sym_argument_list,
    STATE(2141), 1,
      aux_sym_function_call_repeat1,
    STATE(2420), 1,
      sym_version,
  [63708] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(1969), 1,
      sym_comment_clause,
    ACTIONS(2677), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63724] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2119), 1,
      sym_explain_clause,
    ACTIONS(2071), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63740] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2101), 1,
      sym_parallel_clause,
    ACTIONS(2679), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63756] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(1986), 1,
      sym_duration_clause,
    ACTIONS(2574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2061), 1,
      sym_duration_clause,
    ACTIONS(2634), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63788] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63804] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1993), 1,
      sym_explain_clause,
    ACTIONS(2681), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63820] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2683), 1,
      anon_sym_COMMA,
    STATE(1849), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2391), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
  [63836] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1898), 1,
      sym_permissions_for_clause,
    STATE(2181), 1,
      sym_comment_clause,
    ACTIONS(1983), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [63856] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2126), 1,
      sym_duration_clause,
    ACTIONS(2192), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63872] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2135), 1,
      sym_explain_clause,
    ACTIONS(1492), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63888] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2687), 1,
      sym_keyword_where,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    STATE(1205), 1,
      sym_where_clause,
    STATE(1902), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2685), 2,
      sym_keyword_full,
      sym_keyword_none,
  [63908] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63924] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1975), 1,
      sym_explain_clause,
    ACTIONS(2248), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(1988), 1,
      sym_comment_clause,
    ACTIONS(2602), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63956] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1827), 1,
      sym_permissions_for_clause,
    STATE(1988), 1,
      sym_comment_clause,
    ACTIONS(2602), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [63976] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(1996), 1,
      sym_duration_clause,
    ACTIONS(2444), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [63992] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(2204), 1,
      sym_keyword_return,
    STATE(1841), 1,
      sym_return_clause,
    STATE(1951), 1,
      sym_timeout_clause,
    ACTIONS(2618), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [64012] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2691), 1,
      sym_keyword_where,
    STATE(1205), 1,
      sym_where_clause,
    STATE(1838), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2685), 2,
      sym_keyword_full,
      sym_keyword_none,
  [64032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      sym_keyword_fetch,
    STATE(2053), 1,
      sym_fetch_clause,
    ACTIONS(2405), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64048] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2695), 1,
      anon_sym_COMMA,
    STATE(1892), 1,
      aux_sym_duration_clause_repeat1,
    ACTIONS(2693), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64064] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    ACTIONS(2204), 1,
      sym_keyword_return,
    STATE(1785), 1,
      sym_return_clause,
    STATE(2174), 1,
      sym_timeout_clause,
    ACTIONS(2061), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [64084] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2177), 1,
      sym_comment_clause,
    ACTIONS(2697), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64100] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2699), 1,
      anon_sym_COMMA,
    STATE(1826), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 4,
      sym_semi_colon,
      sym_keyword_timeout,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64116] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2026), 1,
      sym_comment_clause,
    ACTIONS(2702), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64132] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2038), 1,
      sym_parallel_clause,
    ACTIONS(1804), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64148] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1808), 1,
      sym_permissions_for_clause,
    STATE(2081), 1,
      sym_comment_clause,
    ACTIONS(1756), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [64168] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2045), 1,
      sym_comment_clause,
    ACTIONS(2704), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2706), 1,
      anon_sym_COMMA,
    STATE(1831), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [64200] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2106), 1,
      sym_explain_clause,
    ACTIONS(1792), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64216] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2136), 1,
      sym_explain_clause,
    ACTIONS(2709), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64232] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2001), 1,
      sym_duration_clause,
    ACTIONS(2454), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64248] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2094), 1,
      sym_duration_clause,
    ACTIONS(2711), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64264] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2041), 1,
      sym_parallel_clause,
    ACTIONS(739), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64280] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2713), 1,
      anon_sym_COMMA,
    STATE(1837), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
  [64296] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2691), 1,
      sym_keyword_where,
    STATE(1203), 1,
      sym_where_clause,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2716), 2,
      sym_keyword_full,
      sym_keyword_none,
  [64316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2718), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64328] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2093), 1,
      sym_parallel_clause,
    ACTIONS(2555), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64344] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      sym_keyword_timeout,
    STATE(2099), 1,
      sym_timeout_clause,
    ACTIONS(2720), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64360] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2004), 1,
      sym_duration_clause,
    ACTIONS(2521), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64376] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1953), 1,
      sym_explain_clause,
    ACTIONS(2030), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64392] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2064), 1,
      sym_comment_clause,
    ACTIONS(2722), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64408] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2724), 1,
      anon_sym_COMMA,
    STATE(1845), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_fetch,
      sym_keyword_where,
  [64424] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1995), 1,
      sym_parallel_clause,
    ACTIONS(2346), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64440] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    ACTIONS(2727), 1,
      anon_sym_RBRACE,
    STATE(2328), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
    STATE(2768), 1,
      sym_object_content,
  [64462] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2729), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      sym_keyword_parallel,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64474] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2683), 1,
      anon_sym_COMMA,
    STATE(1837), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2352), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_return,
      sym_keyword_timeout,
  [64490] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2150), 1,
      sym_parallel_clause,
    ACTIONS(545), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64506] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2054), 1,
      sym_comment_clause,
    ACTIONS(2731), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2179), 1,
      sym_duration_clause,
    ACTIONS(2546), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64538] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2042), 1,
      sym_explain_clause,
    ACTIONS(1714), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64554] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2733), 1,
      sym_keyword_where,
    STATE(1205), 1,
      sym_where_clause,
    STATE(1876), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2685), 2,
      sym_keyword_full,
      sym_keyword_none,
  [64574] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1997), 1,
      sym_explain_clause,
    ACTIONS(507), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64590] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2192), 1,
      sym_explain_clause,
    ACTIONS(2190), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64606] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    ACTIONS(643), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(274), 1,
      sym_argument_list,
    STATE(2141), 1,
      aux_sym_function_call_repeat1,
    STATE(2439), 1,
      sym_version,
  [64628] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1978), 1,
      sym_parallel_clause,
    ACTIONS(2557), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64644] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2005), 1,
      sym_duration_clause,
    ACTIONS(2586), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64660] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2105), 1,
      sym_parallel_clause,
    ACTIONS(2324), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64676] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2008), 1,
      sym_duration_clause,
    ACTIONS(2590), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64692] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2057), 1,
      sym_duration_clause,
    ACTIONS(2735), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64708] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2011), 1,
      sym_duration_clause,
    ACTIONS(2737), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64724] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2019), 1,
      sym_explain_clause,
    ACTIONS(1574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64740] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(1965), 1,
      sym_duration_clause,
    ACTIONS(2226), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64756] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2741), 1,
      sym_keyword_on,
    STATE(1968), 1,
      sym_on_level_clause,
    ACTIONS(2739), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64772] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1994), 1,
      sym_explain_clause,
    ACTIONS(1754), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64788] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2081), 1,
      sym_keyword_duration,
    STATE(2014), 1,
      sym_duration_clause,
    ACTIONS(2743), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64804] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2058), 1,
      sym_explain_clause,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64820] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2747), 1,
      sym_keyword_db,
    STATE(2080), 1,
      sym_db_clause,
    ACTIONS(2745), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64836] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1987), 1,
      sym_explain_clause,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64852] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2088), 1,
      sym_comment_clause,
    ACTIONS(2397), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64868] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2024), 1,
      sym_comment_clause,
    ACTIONS(2749), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64884] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2108), 1,
      sym_parallel_clause,
    ACTIONS(2101), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64900] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2751), 1,
      sym_keyword_where,
    STATE(1205), 1,
      sym_where_clause,
    STATE(1878), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2685), 2,
      sym_keyword_full,
      sym_keyword_none,
  [64920] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2733), 1,
      sym_keyword_where,
    STATE(1203), 1,
      sym_where_clause,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2716), 2,
      sym_keyword_full,
      sym_keyword_none,
  [64940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      sym_keyword_for,
    STATE(1889), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1738), 4,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [64956] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2751), 1,
      sym_keyword_where,
    STATE(1203), 1,
      sym_where_clause,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2716), 2,
      sym_keyword_full,
      sym_keyword_none,
  [64976] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1817), 1,
      sym_permissions_for_clause,
    STATE(2088), 1,
      sym_comment_clause,
    ACTIONS(2397), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [64996] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(1989), 1,
      sym_explain_clause,
    ACTIONS(1726), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65012] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2755), 1,
      sym_keyword_where,
    STATE(1205), 1,
      sym_where_clause,
    STATE(1882), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2685), 2,
      sym_keyword_full,
      sym_keyword_none,
  [65032] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2755), 1,
      sym_keyword_where,
    STATE(1203), 1,
      sym_where_clause,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2716), 2,
      sym_keyword_full,
      sym_keyword_none,
  [65052] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    ACTIONS(2757), 1,
      anon_sym_RBRACE,
    STATE(2328), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
    STATE(2657), 1,
      sym_object_content,
  [65074] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(949), 1,
      anon_sym_COMMA,
    STATE(1831), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [65090] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(949), 1,
      anon_sym_COMMA,
    STATE(1831), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_parallel,
      sym_keyword_timeout,
  [65106] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2640), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65118] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2759), 1,
      sym_keyword_where,
    STATE(1205), 1,
      sym_where_clause,
    STATE(1890), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2685), 2,
      sym_keyword_full,
      sym_keyword_none,
  [65138] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2138), 1,
      sym_parallel_clause,
    ACTIONS(2761), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65154] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2763), 1,
      sym_keyword_for,
    STATE(1889), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1875), 4,
      sym_semi_colon,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65170] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    ACTIONS(2759), 1,
      sym_keyword_where,
    STATE(1203), 1,
      sym_where_clause,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2716), 2,
      sym_keyword_full,
      sym_keyword_none,
  [65190] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(1956), 1,
      sym_parallel_clause,
    ACTIONS(2473), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65206] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2695), 1,
      anon_sym_COMMA,
    STATE(1792), 1,
      aux_sym_duration_clause_repeat1,
    ACTIONS(2766), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65222] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    ACTIONS(2768), 1,
      anon_sym_RBRACE,
    STATE(2328), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
    STATE(2814), 1,
      sym_object_content,
  [65244] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    ACTIONS(2770), 1,
      anon_sym_RBRACE,
    STATE(2328), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
    STATE(2803), 1,
      sym_object_content,
  [65266] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      sym_keyword_explain,
    STATE(2089), 1,
      sym_explain_clause,
    ACTIONS(2475), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65282] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2772), 6,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_permissions,
      sym_keyword_comment,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65294] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(308), 1,
      anon_sym_COLON_COLON,
    ACTIONS(434), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(154), 1,
      sym_argument_list,
    STATE(2141), 1,
      aux_sym_function_call_repeat1,
    STATE(2445), 1,
      sym_version,
  [65316] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65332] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(451), 1,
      sym_keyword_parallel,
    STATE(2124), 1,
      sym_parallel_clause,
    ACTIONS(2412), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65348] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1872), 1,
      sym_permissions_for_clause,
    STATE(2157), 1,
      sym_comment_clause,
    ACTIONS(2119), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [65368] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65384] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2687), 1,
      sym_keyword_where,
    ACTIONS(2689), 1,
      anon_sym_COMMA,
    STATE(1203), 1,
      sym_where_clause,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2716), 2,
      sym_keyword_full,
      sym_keyword_none,
  [65404] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    ACTIONS(1724), 1,
      sym_keyword_permissions,
    STATE(1815), 1,
      sym_permissions_for_clause,
    STATE(2078), 1,
      sym_comment_clause,
    ACTIONS(1706), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [65424] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1594), 1,
      sym_keyword_comment,
    STATE(2100), 1,
      sym_comment_clause,
    ACTIONS(2774), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2778), 1,
      sym_keyword_transaction,
    ACTIONS(2776), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2780), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_db,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65464] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1916), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2782), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65479] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2788), 1,
      anon_sym_COMMA,
    STATE(1908), 1,
      aux_sym_permissions_for_clause_repeat1,
    ACTIONS(2786), 3,
      sym_keyword_full,
      sym_keyword_where,
      sym_keyword_none,
  [65494] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1907), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2791), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65509] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    ACTIONS(2793), 1,
      anon_sym_RBRACE,
    STATE(2470), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
  [65528] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2795), 1,
      sym_keyword_for,
    STATE(1915), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1738), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
  [65543] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(965), 1,
      sym_keyword_as,
    ACTIONS(967), 1,
      sym_keyword_where,
    STATE(2210), 1,
      sym_where_clause,
    ACTIONS(969), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [65560] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1481), 1,
      anon_sym_PIPE,
    ACTIONS(2797), 1,
      anon_sym_COMMA,
    ACTIONS(2799), 1,
      anon_sym_GT,
    STATE(1125), 1,
      aux_sym_union_type_repeat1,
    STATE(2302), 1,
      aux_sym_parameterized_type_repeat1,
  [65579] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    ACTIONS(2801), 1,
      anon_sym_RBRACE,
    STATE(2470), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
  [65598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2803), 1,
      sym_keyword_for,
    STATE(1915), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(1875), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_comment,
  [65613] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2806), 1,
      anon_sym_COMMA,
    STATE(1916), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65628] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1920), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2809), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2811), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65654] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2813), 1,
      anon_sym_COMMA,
    STATE(1919), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
  [65669] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1916), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2791), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65684] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2818), 1,
      sym_keyword_overwrite,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    STATE(2579), 1,
      sym_if_not_exists_clause,
    STATE(2581), 1,
      sym_identifier,
  [65703] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2822), 1,
      sym_keyword_overwrite,
    STATE(1318), 1,
      sym_identifier,
    STATE(2582), 1,
      sym_if_not_exists_clause,
  [65722] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2824), 1,
      sym_keyword_overwrite,
    STATE(2586), 1,
      sym_if_not_exists_clause,
    STATE(2587), 1,
      sym_identifier,
  [65741] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(953), 1,
      anon_sym_COMMA,
    STATE(1919), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
  [65756] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65771] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2826), 1,
      sym_keyword_overwrite,
    STATE(1307), 1,
      sym_identifier,
    STATE(2369), 1,
      sym_if_not_exists_clause,
  [65790] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2828), 1,
      sym_keyword_overwrite,
    STATE(1212), 1,
      sym_identifier,
    STATE(2377), 1,
      sym_if_not_exists_clause,
  [65809] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2832), 1,
      sym_keyword_transaction,
    ACTIONS(2830), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65822] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1934), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2834), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65837] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1576), 1,
      sym_analyzer_tokenizers,
    ACTIONS(2836), 4,
      anon_sym_blank,
      anon_sym_camel,
      anon_sym_class,
      anon_sym_punct,
  [65850] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 2,
      sym_keyword_on,
      aux_sym_type_name_token1,
    ACTIONS(93), 3,
      anon_sym_LPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LT,
  [65863] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2840), 1,
      sym_keyword_full,
    ACTIONS(2838), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65876] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2842), 1,
      sym_keyword_overwrite,
    STATE(2388), 1,
      sym_if_not_exists_clause,
    STATE(2615), 1,
      sym_identifier,
  [65895] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1916), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2844), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65910] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1939), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2844), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65925] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2846), 1,
      sym_keyword_overwrite,
    STATE(2380), 1,
      sym_if_not_exists_clause,
    STATE(2841), 1,
      sym_identifier,
  [65944] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2848), 1,
      sym_keyword_overwrite,
    STATE(2383), 1,
      sym_if_not_exists_clause,
    STATE(2865), 1,
      sym_identifier,
  [65963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2850), 5,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_explain,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65974] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1916), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2852), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [65989] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2854), 1,
      sym_keyword_overwrite,
    STATE(1803), 1,
      sym_identifier,
    STATE(2384), 1,
      sym_if_not_exists_clause,
  [66008] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66023] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1945), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2852), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66038] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1479), 1,
      sym_analyzer_tokenizers,
    ACTIONS(2836), 4,
      anon_sym_blank,
      anon_sym_camel,
      anon_sym_class,
      anon_sym_punct,
  [66051] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2856), 1,
      sym_keyword_overwrite,
    STATE(1206), 1,
      sym_identifier,
    STATE(2577), 1,
      sym_if_not_exists_clause,
  [66070] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2784), 1,
      anon_sym_COMMA,
    STATE(1916), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2809), 3,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66085] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(953), 1,
      anon_sym_COMMA,
    STATE(1919), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      sym_keyword_timeout,
  [66100] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2860), 1,
      sym_keyword_transaction,
    ACTIONS(2858), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66113] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2816), 1,
      sym_keyword_if,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2862), 1,
      sym_keyword_overwrite,
    STATE(1800), 1,
      sym_identifier,
    STATE(2366), 1,
      sym_if_not_exists_clause,
  [66132] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1177), 1,
      sym_on_table_clause,
    STATE(2321), 1,
      aux_sym_define_field_statement_repeat1,
  [66148] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_LPAREN,
    ACTIONS(2870), 1,
      anon_sym_LBRACK,
    STATE(1976), 1,
      sym_object,
  [66164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2720), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66174] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(269), 1,
      sym_argument_list,
    STATE(2541), 1,
      sym_version,
  [66190] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2248), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66200] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2872), 1,
      anon_sym_LPAREN,
    ACTIONS(2874), 1,
      anon_sym_QMARK,
    ACTIONS(2876), 1,
      aux_sym_type_name_token1,
    STATE(270), 1,
      sym_identifier,
  [66216] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2878), 1,
      sym_keyword_if,
    STATE(2415), 1,
      sym_if_exists_clause,
    STATE(2633), 1,
      sym_identifier,
  [66232] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2670), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66242] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1649), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66256] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1587), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66270] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1650), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66284] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2324), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66294] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2101), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66304] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(434), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(150), 1,
      sym_argument_list,
    STATE(2371), 1,
      sym_version,
  [66320] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2880), 1,
      anon_sym_LPAREN,
    ACTIONS(2882), 1,
      anon_sym_QMARK,
    ACTIONS(2884), 1,
      aux_sym_type_name_token1,
    STATE(60), 1,
      sym_identifier,
  [66336] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2886), 1,
      anon_sym_STAR,
    ACTIONS(2888), 1,
      aux_sym_type_name_token1,
    ACTIONS(2890), 1,
      sym_function_name,
    STATE(131), 1,
      sym_identifier,
  [66352] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2786), 4,
      sym_keyword_full,
      sym_keyword_where,
      sym_keyword_none,
      anon_sym_COMMA,
  [66372] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(2035), 1,
      sym_level_clause,
    ACTIONS(2892), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [66384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2894), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66394] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2697), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1740), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66414] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2896), 1,
      anon_sym_LPAREN,
    ACTIONS(2898), 1,
      anon_sym_QMARK,
    ACTIONS(2900), 1,
      aux_sym_type_name_token1,
    STATE(151), 1,
      sym_identifier,
  [66430] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(2056), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2844), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66444] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2904), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66454] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(1982), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2844), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2511), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66478] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2906), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2908), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66498] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2679), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66508] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2910), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66518] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66528] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    ACTIONS(2666), 1,
      sym_string,
    STATE(2470), 1,
      sym_object_property,
    STATE(2610), 1,
      sym_object_key,
  [66544] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(2056), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2852), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66558] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(1991), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2852), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66572] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2681), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66582] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1653), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66596] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2444), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66606] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1492), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2702), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2071), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66636] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2912), 4,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
      sym_keyword_database,
  [66646] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(2056), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2809), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66660] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(1999), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2809), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66674] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2914), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1792), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66694] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2473), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66704] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2454), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1508), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66724] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1734), 2,
      sym_block,
      sym_sub_query,
  [66738] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(2056), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2791), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66752] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(2003), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2791), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66766] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2521), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(884), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [66788] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(2056), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2782), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [66802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2586), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2590), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66822] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1632), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66836] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1467), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66850] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2737), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66860] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2918), 1,
      sym_keyword_select,
    STATE(2037), 1,
      sym_select_clause,
    STATE(2110), 2,
      sym_select_statement,
      sym_live_select_diff_statement,
  [66874] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(45), 1,
      sym_argument_list,
    STATE(2488), 1,
      sym_version,
  [66890] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2743), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66900] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1565), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66914] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2920), 1,
      sym_keyword_if,
    ACTIONS(2922), 1,
      sym_keyword_overwrite,
    ACTIONS(2924), 1,
      sym_variable_name,
    STATE(2790), 1,
      sym_if_not_exists_clause,
  [66930] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2926), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66940] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1634), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [66954] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2928), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [66964] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1161), 1,
      sym_on_table_clause,
    STATE(2021), 1,
      aux_sym_define_field_statement_repeat1,
  [66980] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2930), 1,
      sym_keyword_from,
    ACTIONS(2932), 1,
      sym_keyword_omit,
    STATE(2027), 1,
      sym_from_clause,
    STATE(2433), 1,
      sym_omit_clause,
  [66996] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1628), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67006] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1163), 1,
      sym_on_table_clause,
    STATE(2102), 1,
      aux_sym_define_field_statement_repeat1,
  [67022] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1163), 1,
      sym_on_table_clause,
    STATE(2321), 1,
      aux_sym_define_field_statement_repeat1,
  [67038] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1463), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [67052] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2934), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2936), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2938), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [67082] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2940), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67092] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2942), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67102] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(82), 1,
      sym_argument_list,
    STATE(2504), 1,
      sym_version,
  [67118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2944), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67128] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2946), 1,
      anon_sym_LPAREN,
    ACTIONS(2948), 1,
      anon_sym_QMARK,
    ACTIONS(2950), 1,
      aux_sym_type_name_token1,
    STATE(84), 1,
      sym_identifier,
  [67144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(583), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67154] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2952), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [67164] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2954), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2956), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67184] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2958), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67194] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2878), 1,
      sym_keyword_if,
    STATE(1466), 1,
      sym_identifier,
    STATE(2482), 1,
      sym_if_exists_clause,
  [67210] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2932), 1,
      sym_keyword_omit,
    ACTIONS(2960), 1,
      sym_keyword_from,
    STATE(2027), 1,
      sym_from_clause,
    STATE(2536), 1,
      sym_omit_clause,
  [67226] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2412), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67236] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2962), 1,
      anon_sym_STAR,
    ACTIONS(2964), 1,
      sym_function_name,
    STATE(38), 1,
      sym_identifier,
  [67252] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2966), 1,
      sym_keyword_select,
    STATE(2018), 1,
      sym_select_clause,
    STATE(2110), 2,
      sym_select_statement,
      sym_live_select_diff_statement,
  [67266] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1956), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1726), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67286] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2753), 1,
      sym_keyword_for,
    STATE(1877), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(2968), 2,
      sym_keyword_full,
      sym_keyword_none,
  [67300] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2747), 1,
      sym_keyword_db,
    ACTIONS(2970), 1,
      sym_keyword_ns,
    STATE(1870), 1,
      sym_ns_clause,
    STATE(2113), 1,
      sym_db_clause,
  [67316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2731), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67326] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(894), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [67338] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2972), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67348] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2974), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67358] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2976), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2978), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67378] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2980), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [67388] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2982), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2655), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67408] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2984), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67418] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2986), 1,
      anon_sym_STAR,
    ACTIONS(2988), 1,
      aux_sym_type_name_token1,
    ACTIONS(2990), 1,
      sym_function_name,
    STATE(69), 1,
      sym_identifier,
  [67434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2992), 1,
      anon_sym_COMMA,
    STATE(2056), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2153), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [67448] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2995), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67458] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1683), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67468] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(985), 1,
      anon_sym_COMMA,
    STATE(2151), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(923), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [67482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2997), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2192), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67502] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3001), 1,
      anon_sym_COMMA,
    STATE(2154), 1,
      aux_sym_define_field_statement_repeat1,
    ACTIONS(2999), 2,
      sym_keyword_from,
      sym_keyword_omit,
  [67516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3003), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67526] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2668), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67536] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1886), 2,
      sym_block,
      sym_sub_query,
  [67550] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1184), 1,
      sym_on_table_clause,
    STATE(2161), 1,
      aux_sym_define_field_statement_repeat1,
  [67566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(905), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [67578] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3005), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67588] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(2870), 1,
      anon_sym_LBRACK,
    ACTIONS(3007), 1,
      anon_sym_LPAREN,
    STATE(1976), 1,
      sym_object,
  [67604] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3009), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67614] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1660), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [67628] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2878), 1,
      sym_keyword_if,
    STATE(2483), 1,
      sym_if_exists_clause,
    STATE(2484), 1,
      sym_identifier,
  [67644] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1830), 1,
      sym_keyword_for,
    STATE(1295), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(2968), 2,
      sym_keyword_full,
      sym_keyword_none,
  [67658] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1416), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [67672] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1522), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [67686] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1613), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [67700] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3013), 1,
      sym_keyword_where,
    STATE(1896), 1,
      sym_where_clause,
    ACTIONS(3011), 2,
      sym_keyword_full,
      sym_keyword_none,
  [67714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1756), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3015), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67734] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3017), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67744] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1983), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67754] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(928), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [67766] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3019), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67776] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3021), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67786] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3023), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67796] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3025), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(948), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [67818] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2602), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67828] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2709), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67838] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2061), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67848] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(957), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [67860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(849), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [67872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2761), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2735), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2405), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67902] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1035), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67912] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3027), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67922] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2880), 1,
      anon_sym_LPAREN,
    ACTIONS(2882), 1,
      anon_sym_QMARK,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(60), 1,
      sym_identifier,
  [67938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3031), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2704), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67958] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3033), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67968] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1166), 1,
      sym_on_table_clause,
    STATE(2321), 1,
      aux_sym_define_field_statement_repeat1,
  [67984] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3035), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [67994] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(739), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68004] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2555), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68014] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2030), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68024] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2546), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2346), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68044] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(545), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68054] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3037), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68064] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2073), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68074] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3039), 1,
      sym_keyword_where,
    STATE(1896), 1,
      sym_where_clause,
    ACTIONS(3011), 2,
      sym_keyword_full,
      sym_keyword_none,
  [68088] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2745), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68098] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3041), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68108] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1714), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68118] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3043), 1,
      anon_sym_STAR,
    ACTIONS(3045), 1,
      aux_sym_type_name_token1,
    ACTIONS(3047), 1,
      sym_function_name,
    STATE(260), 1,
      sym_identifier,
  [68134] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2878), 1,
      sym_keyword_if,
    ACTIONS(3049), 1,
      aux_sym_type_name_token1,
    STATE(2282), 1,
      sym_identifier,
    STATE(2397), 1,
      sym_if_exists_clause,
  [68150] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(507), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2190), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68170] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3051), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68180] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(3053), 1,
      anon_sym_LPAREN,
    ACTIONS(3055), 1,
      anon_sym_LBRACK,
    STATE(2068), 1,
      sym_object,
  [68196] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1804), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68206] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3057), 4,
      sym_keyword_on,
      sym_keyword_from,
      sym_keyword_omit,
      anon_sym_COMMA,
  [68216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2557), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68226] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3059), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68236] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2226), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2878), 1,
      sym_keyword_if,
    STATE(2084), 1,
      sym_identifier,
    STATE(2400), 1,
      sym_if_exists_clause,
  [68262] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3001), 1,
      anon_sym_COMMA,
    STATE(2062), 1,
      aux_sym_define_field_statement_repeat1,
    ACTIONS(3061), 2,
      sym_keyword_from,
      sym_keyword_omit,
  [68276] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3063), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68296] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(487), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68306] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3065), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68316] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3067), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3069), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68336] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1574), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68346] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3071), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68356] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2902), 1,
      anon_sym_COMMA,
    STATE(1972), 1,
      aux_sym_upsert_statement_repeat1,
    ACTIONS(2834), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [68370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3073), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68380] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3075), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68390] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3077), 1,
      sym_keyword_if,
    ACTIONS(3079), 1,
      sym_keyword_overwrite,
    ACTIONS(3081), 1,
      sym_custom_function_name,
    STATE(2880), 1,
      sym_if_not_exists_clause,
  [68406] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3085), 1,
      anon_sym_COLON_COLON,
    STATE(2141), 1,
      aux_sym_function_call_repeat1,
    ACTIONS(3083), 2,
      anon_sym_LPAREN,
      anon_sym_LT,
  [68420] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1652), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [68434] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2920), 1,
      sym_keyword_if,
    ACTIONS(3088), 1,
      sym_keyword_overwrite,
    ACTIONS(3090), 1,
      sym_variable_name,
    STATE(2636), 1,
      sym_if_not_exists_clause,
  [68450] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2878), 1,
      sym_keyword_if,
    STATE(2410), 1,
      sym_if_exists_clause,
    STATE(2597), 1,
      sym_identifier,
  [68466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3092), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68476] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2962), 1,
      anon_sym_STAR,
    ACTIONS(2964), 1,
      sym_function_name,
    ACTIONS(3094), 1,
      aux_sym_type_name_token1,
    STATE(38), 1,
      sym_identifier,
  [68492] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1754), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1023), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68512] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(985), 1,
      anon_sym_COMMA,
    STATE(2151), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(2564), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [68526] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1570), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68536] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3096), 1,
      anon_sym_COMMA,
    STATE(2151), 1,
      aux_sym_update_statement_repeat1,
    ACTIONS(697), 2,
      ts_builtin_sym_end,
      sym_semi_colon,
  [68550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3099), 4,
      sym_keyword_on,
      sym_keyword_from,
      sym_keyword_omit,
      anon_sym_COMMA,
  [68560] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3101), 4,
      sym_keyword_on,
      sym_keyword_from,
      sym_keyword_omit,
      anon_sym_COMMA,
  [68570] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3103), 1,
      anon_sym_COMMA,
    STATE(2154), 1,
      aux_sym_define_field_statement_repeat1,
    ACTIONS(3101), 2,
      sym_keyword_from,
      sym_keyword_omit,
  [68584] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1379), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [68598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(89), 1,
      sym_decimal,
    STATE(1344), 1,
      sym_number,
    ACTIONS(87), 2,
      sym_int,
      sym_float,
  [68612] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2397), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68622] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3106), 1,
      anon_sym_STAR,
    ACTIONS(3108), 1,
      aux_sym_type_name_token1,
    ACTIONS(3110), 1,
      sym_function_name,
    STATE(230), 1,
      sym_identifier,
  [68638] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1191), 1,
      sym_on_table_clause,
    STATE(1949), 1,
      aux_sym_define_field_statement_repeat1,
  [68654] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3112), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [68664] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2864), 1,
      sym_keyword_on,
    ACTIONS(2866), 1,
      anon_sym_COMMA,
    STATE(1191), 1,
      sym_on_table_clause,
    STATE(2321), 1,
      aux_sym_define_field_statement_repeat1,
  [68680] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2749), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68690] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(669), 1,
      anon_sym_LPAREN,
    ACTIONS(2653), 1,
      anon_sym_LT,
    STATE(327), 1,
      sym_argument_list,
    STATE(2538), 1,
      sym_version,
  [68706] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2034), 1,
      sym_keyword_for,
    STATE(1372), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(2968), 2,
      sym_keyword_full,
      sym_keyword_none,
  [68720] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(900), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [68732] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3114), 1,
      anon_sym_LPAREN,
    ACTIONS(3116), 1,
      anon_sym_QMARK,
    ACTIONS(3118), 1,
      aux_sym_type_name_token1,
    STATE(328), 1,
      sym_identifier,
  [68748] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3122), 1,
      sym_keyword_scope,
    ACTIONS(3120), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [68760] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1628), 2,
      sym_block,
      sym_sub_query,
  [68774] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3124), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68784] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1744), 2,
      sym_block,
      sym_sub_query,
  [68798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3126), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [68808] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(977), 1,
      anon_sym_LPAREN,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1629), 2,
      sym_block,
      sym_sub_query,
  [68822] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2257), 1,
      sym_keyword_for,
    STATE(1480), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(2968), 2,
      sym_keyword_full,
      sym_keyword_none,
  [68836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2618), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68846] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1481), 1,
      anon_sym_PIPE,
    STATE(1125), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(3128), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [68860] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(923), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [68872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3130), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3132), 4,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
      sym_keyword_database,
  [68892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2634), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68902] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(943), 1,
      sym_assignment_operator,
    ACTIONS(2916), 3,
      anon_sym_EQ,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
  [68914] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2119), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68924] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2795), 1,
      sym_keyword_for,
    STATE(1911), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(2968), 2,
      sym_keyword_full,
      sym_keyword_none,
  [68938] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1706), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [68948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3134), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [68958] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3077), 1,
      sym_keyword_if,
    ACTIONS(3136), 1,
      sym_keyword_overwrite,
    ACTIONS(3138), 1,
      sym_custom_function_name,
    STATE(2887), 1,
      sym_if_not_exists_clause,
  [68974] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(2878), 1,
      sym_keyword_if,
    STATE(1405), 1,
      sym_identifier,
    STATE(2529), 1,
      sym_if_exists_clause,
  [68990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3140), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [69000] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3142), 4,
      sym_keyword_select,
      sym_keyword_create,
      sym_keyword_delete,
      sym_keyword_update,
  [69010] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3146), 1,
      sym_keyword_scope,
    ACTIONS(3144), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [69022] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2464), 1,
      sym_keyword_for,
    STATE(1605), 1,
      aux_sym_permissions_for_clause_repeat2,
    ACTIONS(2968), 2,
      sym_keyword_full,
      sym_keyword_none,
  [69036] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(3055), 1,
      anon_sym_LBRACK,
    ACTIONS(3148), 1,
      anon_sym_LPAREN,
    STATE(2068), 1,
      sym_object,
  [69052] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2475), 4,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [69062] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1668), 1,
      sym_field_assignment,
    STATE(2087), 1,
      sym_identifier,
  [69075] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1823), 1,
      sym_duration,
  [69088] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3150), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69101] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3152), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69114] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3154), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69127] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3156), 3,
      sym_keyword_owner,
      sym_keyword_editor,
      sym_keyword_viewer,
  [69136] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1992), 1,
      sym_field_assignment,
    STATE(2046), 1,
      sym_identifier,
  [69149] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3158), 1,
      sym_keyword_on_duplicate_key_update,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [69162] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2092), 1,
      sym_identifier,
  [69175] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2046), 1,
      sym_identifier,
  [69188] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3164), 1,
      anon_sym_RPAREN,
    STATE(2351), 1,
      aux_sym_graph_path_repeat1,
  [69201] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1720), 1,
      sym_field_assignment,
    STATE(2092), 1,
      sym_identifier,
  [69214] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1339), 1,
      sym_record_or_separated,
    STATE(1355), 1,
      sym_identifier,
  [69227] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1240), 1,
      sym_field_assignment,
    STATE(2082), 1,
      sym_identifier,
  [69240] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1271), 1,
      sym_field_assignment,
    STATE(2176), 1,
      sym_identifier,
  [69253] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1211), 1,
      sym_field_assignment,
    STATE(2082), 1,
      sym_identifier,
  [69266] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(159), 1,
      ts_builtin_sym_end,
    ACTIONS(3166), 1,
      sym_semi_colon,
    STATE(2251), 1,
      aux_sym_expressions_repeat1,
  [69279] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3168), 1,
      sym_keyword_as,
    ACTIONS(3170), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [69290] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3172), 1,
      sym_keyword_select,
    STATE(2037), 1,
      sym_select_clause,
    STATE(2853), 1,
      sym_select_statement,
  [69303] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2002), 1,
      sym_identifier,
  [69316] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(2063), 1,
      sym_duration,
  [69329] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(159), 1,
      anon_sym_RBRACE,
    ACTIONS(3174), 1,
      sym_semi_colon,
    STATE(2293), 1,
      aux_sym_expressions_repeat1,
  [69342] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3176), 1,
      anon_sym_RPAREN,
    STATE(2351), 1,
      aux_sym_graph_path_repeat1,
  [69355] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1031), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3178), 3,
      sym_keyword_token,
      sym_keyword_session,
      sym_keyword_grant,
  [69377] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3180), 1,
      sym_keyword_from,
    ACTIONS(3182), 1,
      anon_sym_COMMA,
    STATE(2246), 1,
      aux_sym_define_field_statement_repeat1,
  [69390] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3184), 3,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
  [69399] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1037), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69412] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1251), 1,
      sym_field_assignment,
    STATE(2176), 1,
      sym_identifier,
  [69425] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3186), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69438] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3188), 1,
      anon_sym_COMMA,
    ACTIONS(3191), 1,
      anon_sym_RBRACE,
    STATE(2223), 1,
      aux_sym_object_content_repeat1,
  [69451] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3193), 3,
      sym_keyword_owner,
      sym_keyword_editor,
      sym_keyword_viewer,
  [69460] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(3195), 1,
      sym_keyword_on,
    STATE(2187), 1,
      sym_identifier,
  [69473] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3172), 1,
      sym_keyword_select,
    STATE(2037), 1,
      sym_select_clause,
    STATE(2750), 1,
      sym_select_statement,
  [69486] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3197), 3,
      sym_keyword_token,
      sym_keyword_session,
      sym_keyword_grant,
  [69495] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3199), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2349), 1,
      aux_sym_insert_statement_repeat2,
  [69508] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(288), 1,
      anon_sym_DASH_GT,
    ACTIONS(2129), 1,
      anon_sym_GT,
    ACTIONS(3201), 1,
      anon_sym_DOT_DOT,
  [69521] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3203), 1,
      anon_sym_COMMA,
    ACTIONS(3205), 1,
      anon_sym_RBRACE,
    STATE(2283), 1,
      aux_sym_type_object_repeat1,
  [69534] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3207), 1,
      anon_sym_RPAREN,
    STATE(2314), 1,
      aux_sym_graph_path_repeat1,
  [69547] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    STATE(2324), 1,
      sym_type_object_property,
    STATE(2829), 1,
      sym_object_key,
  [69560] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1280), 1,
      sym_field_assignment,
    STATE(2176), 1,
      sym_identifier,
  [69573] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3209), 1,
      anon_sym_RPAREN,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
  [69586] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2067), 1,
      sym_identifier,
  [69599] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2000), 1,
      sym_field_assignment,
    STATE(2046), 1,
      sym_identifier,
  [69612] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_COMMA,
    ACTIONS(3213), 1,
      anon_sym_RBRACK,
    STATE(2281), 1,
      aux_sym_insert_statement_repeat1,
  [69625] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1249), 1,
      anon_sym_RBRACK,
    ACTIONS(3215), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69638] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3209), 1,
      anon_sym_RPAREN,
    STATE(2301), 1,
      aux_sym_upsert_statement_repeat2,
  [69651] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_COMMA,
    ACTIONS(3213), 1,
      anon_sym_RBRACK,
    STATE(2331), 1,
      aux_sym_insert_statement_repeat1,
  [69664] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3045), 1,
      aux_sym_type_name_token1,
    ACTIONS(3217), 1,
      sym_keyword_table,
    STATE(1182), 1,
      sym_identifier,
  [69677] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3219), 1,
      sym_keyword_if,
    ACTIONS(3221), 1,
      sym_custom_function_name,
    STATE(2840), 1,
      sym_if_exists_clause,
  [69690] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1567), 1,
      sym_field_assignment,
    STATE(2067), 1,
      sym_identifier,
  [69703] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3223), 1,
      anon_sym_RPAREN,
    STATE(2215), 1,
      aux_sym_graph_path_repeat1,
  [69716] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1275), 1,
      anon_sym_RBRACK,
    ACTIONS(3225), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [69729] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3182), 1,
      anon_sym_COMMA,
    ACTIONS(3227), 1,
      sym_keyword_from,
    STATE(2254), 1,
      aux_sym_define_field_statement_repeat1,
  [69742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3229), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [69751] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2801), 1,
      anon_sym_RBRACE,
    ACTIONS(3231), 1,
      anon_sym_COMMA,
    STATE(2223), 1,
      aux_sym_object_content_repeat1,
  [69764] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2797), 1,
      anon_sym_COMMA,
    ACTIONS(2799), 1,
      anon_sym_GT,
    STATE(2302), 1,
      aux_sym_parameterized_type_repeat1,
  [69777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3233), 3,
      ts_builtin_sym_end,
      sym_semi_colon,
      anon_sym_RBRACE,
  [69786] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3233), 1,
      ts_builtin_sym_end,
    ACTIONS(3235), 1,
      sym_semi_colon,
    STATE(2251), 1,
      aux_sym_expressions_repeat1,
  [69799] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3238), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2253), 1,
      aux_sym_insert_statement_repeat2,
  [69812] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3240), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [69825] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3101), 1,
      sym_keyword_from,
    ACTIONS(3242), 1,
      anon_sym_COMMA,
    STATE(2254), 1,
      aux_sym_define_field_statement_repeat1,
  [69838] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3221), 1,
      sym_variable_name,
    ACTIONS(3245), 1,
      sym_keyword_if,
    STATE(2878), 1,
      sym_if_exists_clause,
  [69851] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3240), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2258), 1,
      aux_sym_insert_statement_repeat2,
  [69864] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(3247), 1,
      sym_keyword_by,
    STATE(1547), 1,
      sym_identifier,
  [69877] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3249), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [69890] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3249), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2260), 1,
      aux_sym_insert_statement_repeat2,
  [69903] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3251), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [69916] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3251), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2264), 1,
      aux_sym_insert_statement_repeat2,
  [69929] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3253), 1,
      anon_sym_RPAREN,
    STATE(2285), 1,
      aux_sym_graph_path_repeat1,
  [69942] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1929), 1,
      sym_field_assignment,
    STATE(2091), 1,
      sym_identifier,
  [69955] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3255), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [69968] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3083), 3,
      anon_sym_LPAREN,
      anon_sym_COLON_COLON,
      anon_sym_LT,
  [69977] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1983), 1,
      sym_field_assignment,
    STATE(2046), 1,
      sym_identifier,
  [69990] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1209), 1,
      anon_sym_RBRACK,
    ACTIONS(3257), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70003] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3259), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [70016] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1935), 1,
      sym_field_assignment,
    STATE(2091), 1,
      sym_identifier,
  [70029] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3259), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2200), 1,
      aux_sym_insert_statement_repeat2,
  [70042] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3261), 1,
      anon_sym_RPAREN,
    STATE(2234), 1,
      aux_sym_upsert_statement_repeat2,
  [70055] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1942), 1,
      sym_field_assignment,
    STATE(2091), 1,
      sym_identifier,
  [70068] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3263), 1,
      sym_semi_colon,
    ACTIONS(3265), 1,
      anon_sym_RBRACE,
    STATE(2214), 1,
      aux_sym_expressions_repeat1,
  [70081] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3045), 1,
      aux_sym_type_name_token1,
    ACTIONS(3267), 1,
      sym_keyword_at,
    STATE(1285), 1,
      sym_identifier,
  [70094] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3045), 1,
      aux_sym_type_name_token1,
    ACTIONS(3269), 1,
      sym_keyword_by,
    STATE(1365), 1,
      sym_identifier,
  [70107] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2082), 1,
      sym_identifier,
  [70120] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    ACTIONS(3271), 1,
      sym_keyword_if,
    STATE(1707), 1,
      sym_block,
  [70133] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1917), 1,
      sym_field_assignment,
    STATE(2091), 1,
      sym_identifier,
  [70146] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3273), 1,
      anon_sym_COMMA,
    ACTIONS(3276), 1,
      anon_sym_RBRACK,
    STATE(2279), 1,
      aux_sym_composite_type_repeat1,
  [70159] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3278), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [70168] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3280), 1,
      anon_sym_COMMA,
    ACTIONS(3283), 1,
      anon_sym_RBRACK,
    STATE(2281), 1,
      aux_sym_insert_statement_repeat1,
  [70181] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(3285), 1,
      sym_keyword_on,
    STATE(2085), 1,
      sym_identifier,
  [70194] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3287), 1,
      anon_sym_COMMA,
    ACTIONS(3290), 1,
      anon_sym_RBRACE,
    STATE(2283), 1,
      aux_sym_type_object_repeat1,
  [70207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3229), 3,
      sym_keyword_namespace,
      sym_keyword_scope,
      sym_keyword_root,
  [70216] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3292), 1,
      anon_sym_RPAREN,
    STATE(2351), 1,
      aux_sym_graph_path_repeat1,
  [70229] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_COMMA,
    ACTIONS(3294), 1,
      anon_sym_RBRACK,
    STATE(2237), 1,
      aux_sym_insert_statement_repeat1,
  [70242] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3172), 1,
      sym_keyword_select,
    STATE(2037), 1,
      sym_select_clause,
    STATE(2845), 1,
      sym_select_statement,
  [70255] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3296), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70268] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3265), 1,
      ts_builtin_sym_end,
    ACTIONS(3298), 1,
      sym_semi_colon,
    STATE(2209), 1,
      aux_sym_expressions_repeat1,
  [70281] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2820), 1,
      aux_sym_type_name_token1,
    ACTIONS(3300), 1,
      sym_keyword_table,
    STATE(1182), 1,
      sym_identifier,
  [70294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1294), 1,
      sym_fields_columns_clause,
    ACTIONS(3302), 2,
      sym_keyword_fields,
      sym_keyword_columns,
  [70305] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3304), 1,
      anon_sym_COMMA,
    ACTIONS(3306), 1,
      anon_sym_RPAREN,
    STATE(2306), 1,
      aux_sym_param_list_repeat1,
  [70318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3233), 1,
      anon_sym_RBRACE,
    ACTIONS(3308), 1,
      sym_semi_colon,
    STATE(2293), 1,
      aux_sym_expressions_repeat1,
  [70331] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3184), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [70340] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1974), 1,
      sym_field_assignment,
    STATE(2046), 1,
      sym_identifier,
  [70353] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1005), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70366] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3182), 1,
      anon_sym_COMMA,
    ACTIONS(3311), 1,
      sym_keyword_from,
    STATE(2342), 1,
      aux_sym_define_field_statement_repeat1,
  [70379] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3313), 1,
      aux_sym_type_name_token1,
    STATE(1281), 1,
      sym_identifier,
    STATE(1334), 1,
      sym_record_or_separated,
  [70392] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3315), 1,
      sym_keyword_on_duplicate_key_update,
    ACTIONS(3317), 1,
      anon_sym_COMMA,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [70405] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1355), 1,
      sym_identifier,
    STATE(1408), 1,
      sym_record_or_separated,
  [70418] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3320), 1,
      anon_sym_RPAREN,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
  [70431] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2797), 1,
      anon_sym_COMMA,
    ACTIONS(3322), 1,
      anon_sym_GT,
    STATE(2320), 1,
      aux_sym_parameterized_type_repeat1,
  [70444] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3324), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70457] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3326), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70470] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2087), 1,
      sym_identifier,
  [70483] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3328), 1,
      anon_sym_COMMA,
    ACTIONS(3331), 1,
      anon_sym_RPAREN,
    STATE(2306), 1,
      aux_sym_param_list_repeat1,
  [70496] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3333), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [70509] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2165), 1,
      sym_identifier,
  [70522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3335), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70535] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(1289), 1,
      sym_fields_columns_clause,
    ACTIONS(3302), 2,
      sym_keyword_fields,
      sym_keyword_columns,
  [70546] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3333), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2268), 1,
      aux_sym_insert_statement_repeat2,
  [70559] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1627), 1,
      sym_duration,
  [70572] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3337), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70585] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3339), 1,
      anon_sym_RPAREN,
    STATE(2351), 1,
      aux_sym_graph_path_repeat1,
  [70598] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1848), 1,
      sym_duration,
  [70611] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3341), 3,
      sym_keyword_namespace,
      sym_keyword_root,
      sym_keyword_database,
  [70620] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    ACTIONS(3343), 1,
      sym_variable_name,
    STATE(1546), 1,
      sym_object,
  [70633] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1810), 1,
      sym_field_assignment,
    STATE(2002), 1,
      sym_identifier,
  [70646] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3345), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70659] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3128), 1,
      anon_sym_GT,
    ACTIONS(3347), 1,
      anon_sym_COMMA,
    STATE(2320), 1,
      aux_sym_parameterized_type_repeat1,
  [70672] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3101), 1,
      sym_keyword_on,
    ACTIONS(3350), 1,
      anon_sym_COMMA,
    STATE(2321), 1,
      aux_sym_define_field_statement_repeat1,
  [70685] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2091), 1,
      sym_identifier,
  [70698] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3353), 1,
      anon_sym_COMMA,
    ACTIONS(3355), 1,
      anon_sym_RBRACK,
    STATE(2348), 1,
      aux_sym_composite_type_repeat1,
  [70711] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3203), 1,
      anon_sym_COMMA,
    ACTIONS(3357), 1,
      anon_sym_RBRACE,
    STATE(2230), 1,
      aux_sym_type_object_repeat1,
  [70724] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3359), 1,
      anon_sym_RPAREN,
    STATE(2203), 1,
      aux_sym_graph_path_repeat1,
  [70737] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2176), 1,
      sym_identifier,
  [70750] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1355), 1,
      sym_identifier,
    STATE(1406), 1,
      sym_record_or_separated,
  [70763] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3361), 1,
      anon_sym_COMMA,
    ACTIONS(3363), 1,
      anon_sym_RBRACE,
    STATE(2248), 1,
      aux_sym_object_content_repeat1,
  [70776] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3365), 1,
      anon_sym_RPAREN,
    STATE(2345), 1,
      aux_sym_graph_path_repeat1,
  [70789] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1839), 1,
      sym_duration,
  [70802] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3211), 1,
      anon_sym_COMMA,
    ACTIONS(3367), 1,
      anon_sym_RBRACK,
    STATE(2281), 1,
      aux_sym_insert_statement_repeat1,
  [70815] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1235), 1,
      anon_sym_RBRACK,
    ACTIONS(3369), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70828] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3304), 1,
      anon_sym_COMMA,
    ACTIONS(3371), 1,
      anon_sym_RPAREN,
    STATE(2292), 1,
      aux_sym_param_list_repeat1,
  [70841] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1237), 1,
      anon_sym_RBRACK,
    ACTIONS(3373), 1,
      anon_sym_COMMA,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70854] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3375), 1,
      sym_keyword_jwt,
    ACTIONS(3377), 1,
      sym_keyword_record,
    ACTIONS(3379), 1,
      sym_keyword_bearer,
  [70867] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1424), 1,
      sym_field_assignment,
    STATE(2180), 1,
      sym_identifier,
  [70880] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3381), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70893] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3172), 1,
      sym_keyword_select,
    STATE(2037), 1,
      sym_select_clause,
    STATE(2721), 1,
      sym_select_statement,
  [70906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3385), 1,
      sym_keyword_relation,
    ACTIONS(3383), 2,
      sym_keyword_any,
      sym_keyword_normal,
  [70917] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3387), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [70930] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2046), 1,
      sym_identifier,
    STATE(2137), 1,
      sym_field_assignment,
  [70943] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3182), 1,
      anon_sym_COMMA,
    ACTIONS(3389), 1,
      sym_keyword_from,
    STATE(2254), 1,
      aux_sym_define_field_statement_repeat1,
  [70956] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1355), 1,
      sym_identifier,
    STATE(1378), 1,
      sym_record_or_separated,
  [70969] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3313), 1,
      aux_sym_type_name_token1,
    STATE(1281), 1,
      sym_identifier,
    STATE(1339), 1,
      sym_record_or_separated,
  [70982] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3162), 1,
      anon_sym_COMMA,
    ACTIONS(3391), 1,
      anon_sym_RPAREN,
    STATE(2351), 1,
      aux_sym_graph_path_repeat1,
  [70995] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1225), 1,
      sym_field_assignment,
    STATE(2082), 1,
      sym_identifier,
  [71008] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3393), 1,
      sym_keyword_jwt,
    ACTIONS(3395), 1,
      sym_keyword_record,
    ACTIONS(3397), 1,
      sym_keyword_bearer,
  [71021] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3353), 1,
      anon_sym_COMMA,
    ACTIONS(3399), 1,
      anon_sym_RBRACK,
    STATE(2279), 1,
      aux_sym_composite_type_repeat1,
  [71034] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3401), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2299), 1,
      aux_sym_insert_statement_repeat2,
  [71047] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1658), 1,
      sym_field_assignment,
    STATE(2165), 1,
      sym_identifier,
  [71060] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3403), 1,
      anon_sym_COMMA,
    ACTIONS(3406), 1,
      anon_sym_RPAREN,
    STATE(2351), 1,
      aux_sym_graph_path_repeat1,
  [71073] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3160), 1,
      anon_sym_COMMA,
    ACTIONS(3401), 1,
      sym_keyword_on_duplicate_key_update,
    STATE(2307), 1,
      aux_sym_insert_statement_repeat2,
  [71086] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1742), 1,
      sym_field_assignment,
    STATE(2180), 1,
      sym_identifier,
  [71099] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(1007), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [71112] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2664), 1,
      aux_sym_type_name_token1,
    STATE(2363), 1,
      sym_type_object_property,
    STATE(2829), 1,
      sym_object_key,
  [71125] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3408), 1,
      anon_sym_RPAREN,
    STATE(2357), 1,
      aux_sym_upsert_statement_repeat2,
  [71138] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3410), 1,
      anon_sym_RPAREN,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
  [71151] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3410), 1,
      anon_sym_RPAREN,
    STATE(2359), 1,
      aux_sym_upsert_statement_repeat2,
  [71164] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1712), 1,
      anon_sym_COMMA,
    ACTIONS(3412), 1,
      anon_sym_RPAREN,
    STATE(1188), 1,
      aux_sym_upsert_statement_repeat2,
  [71177] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 1,
      sym_duration_part,
    STATE(16), 1,
      aux_sym_duration_repeat1,
    STATE(1918), 1,
      sym_duration,
  [71190] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(963), 1,
      anon_sym_COMMA,
    ACTIONS(3414), 1,
      anon_sym_RPAREN,
    STATE(1801), 1,
      aux_sym_update_statement_repeat1,
  [71203] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1909), 1,
      sym_field_assignment,
    STATE(2091), 1,
      sym_identifier,
  [71216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3290), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [71224] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3416), 1,
      anon_sym_LPAREN,
    STATE(2527), 1,
      sym_param_list,
  [71234] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1861), 1,
      sym_block,
  [71244] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1873), 1,
      sym_identifier,
  [71254] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1863), 1,
      sym_block,
  [71264] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(2286), 1,
      sym_object,
  [71274] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1330), 1,
      sym_identifier,
  [71284] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2756), 1,
      sym_type_name,
  [71294] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(434), 1,
      anon_sym_LPAREN,
    STATE(154), 1,
      sym_argument_list,
  [71304] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1868), 1,
      sym_block,
  [71314] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1481), 1,
      anon_sym_PIPE,
    STATE(1125), 1,
      aux_sym_union_type_repeat1,
  [71324] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2693), 1,
      sym_type_name,
  [71334] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2739), 1,
      sym_type_name,
  [71344] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2770), 1,
      sym_type_name,
  [71354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1231), 1,
      sym_identifier,
  [71364] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2823), 1,
      sym_type_name,
  [71374] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3283), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [71382] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2894), 1,
      sym_identifier,
  [71392] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3418), 1,
      sym_keyword_jwt,
    ACTIONS(3420), 1,
      sym_keyword_refresh,
  [71402] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2239), 1,
      sym_identifier,
  [71412] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2886), 1,
      sym_identifier,
  [71422] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1825), 1,
      sym_identifier,
  [71432] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2805), 1,
      sym_type_name,
  [71442] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(2240), 1,
      sym_object,
  [71452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3418), 1,
      sym_keyword_jwt,
    ACTIONS(3422), 1,
      sym_keyword_refresh,
  [71462] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2765), 1,
      sym_identifier,
  [71472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1151), 1,
      sym_identifier,
  [71482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1496), 2,
      aux_sym_type_name_token1,
      sym_variable_name,
  [71490] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3118), 1,
      aux_sym_type_name_token1,
    STATE(1291), 1,
      sym_identifier,
  [71500] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3276), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [71508] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3118), 1,
      aux_sym_type_name_token1,
    STATE(1176), 1,
      sym_identifier,
  [71518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3118), 1,
      aux_sym_type_name_token1,
    STATE(1370), 1,
      sym_identifier,
  [71528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3424), 1,
      anon_sym_EQ,
    ACTIONS(3426), 1,
      sym_int,
  [71538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1737), 1,
      sym_block,
  [71548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3428), 1,
      aux_sym_type_name_token1,
    STATE(2225), 1,
      sym_identifier,
  [71558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1176), 1,
      sym_identifier,
  [71568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2690), 1,
      sym_type_name,
  [71578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2085), 1,
      sym_identifier,
  [71588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1209), 1,
      sym_identifier,
  [71598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3118), 1,
      aux_sym_type_name_token1,
    STATE(1151), 1,
      sym_identifier,
  [71608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1458), 1,
      sym_identifier,
  [71618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3430), 1,
      anon_sym_LPAREN,
    STATE(269), 1,
      sym_argument_list_count,
  [71628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2812), 1,
      sym_identifier,
  [71638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2776), 1,
      sym_type_name,
  [71648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2782), 1,
      sym_type_name,
  [71658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2793), 1,
      sym_type_name,
  [71668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2816), 1,
      sym_type_name,
  [71678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2710), 1,
      sym_identifier,
  [71688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3432), 1,
      anon_sym_EQ,
    ACTIONS(3434), 1,
      sym_int,
  [71698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3436), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [71706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      anon_sym_RBRACK,
    ACTIONS(3438), 1,
      anon_sym_QMARK,
  [71716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2121), 1,
      sym_identifier,
  [71726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2599), 1,
      sym_identifier,
  [71736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    STATE(91), 1,
      sym_argument_list,
  [71746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1600), 1,
      sym_identifier,
  [71756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3440), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [71764] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1234), 1,
      sym_identifier,
  [71774] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    STATE(93), 1,
      sym_argument_list,
  [71784] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2619), 1,
      sym_type_name,
  [71794] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1819), 1,
      sym_block,
  [71804] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3442), 1,
      sym_keyword_index,
    ACTIONS(3444), 1,
      sym_keyword_no_index,
  [71814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3446), 1,
      sym_keyword_type,
    STATE(2862), 1,
      sym_token_type_clause,
  [71824] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2563), 1,
      sym_identifier,
  [71834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2590), 1,
      sym_identifier,
  [71844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3406), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [71852] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3448), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [71860] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3450), 2,
      sym_keyword_password,
      sym_keyword_password_hash,
  [71868] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1210), 1,
      sym_identifier,
  [71878] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2717), 1,
      sym_type_name,
  [71888] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3452), 1,
      anon_sym_LPAREN,
    STATE(82), 1,
      sym_argument_list_count,
  [71898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2930), 1,
      sym_keyword_from,
    STATE(2134), 1,
      sym_from_clause,
  [71908] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1057), 1,
      anon_sym_RBRACK,
    ACTIONS(3454), 1,
      anon_sym_QMARK,
  [71918] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3456), 2,
      sym_keyword_on_duplicate_key_update,
      anon_sym_COMMA,
  [71926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 1,
      anon_sym_LPAREN,
    STATE(291), 1,
      sym_argument_list,
  [71936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1071), 1,
      anon_sym_RBRACK,
    ACTIONS(3458), 1,
      anon_sym_QMARK,
  [71946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2811), 1,
      sym_type_name,
  [71956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 1,
      anon_sym_LPAREN,
    STATE(293), 1,
      sym_argument_list,
  [71966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2781), 1,
      sym_type_name,
  [71976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2060), 1,
      sym_identifier,
  [71986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2873), 1,
      sym_identifier,
  [71996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3460), 1,
      sym_keyword_on,
    STATE(1979), 1,
      sym_on_table_clause,
  [72006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(434), 1,
      anon_sym_LPAREN,
    STATE(163), 1,
      sym_argument_list,
  [72016] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(434), 1,
      anon_sym_LPAREN,
    STATE(165), 1,
      sym_argument_list,
  [72026] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2726), 1,
      sym_identifier,
  [72036] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2819), 1,
      sym_type_name,
  [72046] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3418), 1,
      sym_keyword_jwt,
    ACTIONS(3462), 1,
      sym_keyword_refresh,
  [72056] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1269), 1,
      sym_identifier,
  [72066] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2914), 1,
      sym_type_name,
  [72076] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1834), 1,
      sym_block,
  [72086] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3128), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [72094] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1286), 1,
      sym_identifier,
  [72104] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1807), 1,
      sym_block,
  [72114] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2418), 1,
      sym_identifier,
  [72124] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3462), 2,
      sym_keyword_user,
      sym_keyword_record,
  [72132] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2868), 1,
      sym_type_name,
  [72142] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1852), 1,
      sym_block,
  [72152] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2736), 1,
      sym_type_name,
  [72162] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3464), 1,
      sym_keyword_algorithm,
    ACTIONS(3466), 1,
      sym_keyword_url,
  [72172] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3468), 1,
      sym_keyword_algorithm,
    ACTIONS(3470), 1,
      sym_keyword_url,
  [72182] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3472), 1,
      sym_keyword_create,
    STATE(2787), 1,
      sym_create_statement,
  [72192] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3313), 1,
      aux_sym_type_name_token1,
    STATE(1286), 1,
      sym_identifier,
  [72202] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1906), 1,
      sym_identifier,
  [72212] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(1513), 1,
      sym_object,
  [72222] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2910), 1,
      sym_type_name,
  [72232] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 1,
      anon_sym_LBRACK,
    STATE(1514), 1,
      sym_array,
  [72242] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1439), 1,
      sym_identifier,
  [72252] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2079), 1,
      sym_identifier,
  [72262] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3191), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [72270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(1525), 1,
      sym_object,
  [72280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1250), 1,
      sym_identifier,
  [72290] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2601), 1,
      sym_type_name,
  [72300] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3422), 2,
      sym_keyword_user,
      sym_keyword_record,
  [72308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2614), 1,
      sym_type_name,
  [72318] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1783), 1,
      sym_block,
  [72328] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2069), 1,
      sym_identifier,
  [72338] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3474), 1,
      sym_keyword_algorithm,
    ACTIONS(3476), 1,
      sym_keyword_url,
  [72348] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3478), 1,
      sym_keyword_into,
    ACTIONS(3480), 1,
      sym_keyword_ignore,
  [72358] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2627), 1,
      sym_type_name,
  [72368] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(73), 1,
      anon_sym_LBRACE,
    STATE(2379), 1,
      sym_object,
  [72378] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1449), 1,
      sym_identifier,
  [72388] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2443), 1,
      sym_identifier,
  [72398] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3460), 1,
      sym_keyword_on,
    STATE(2103), 1,
      sym_on_table_clause,
  [72408] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2640), 1,
      sym_type_name,
  [72418] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2653), 1,
      sym_type_name,
  [72428] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3482), 1,
      sym_keyword_into,
    ACTIONS(3484), 1,
      sym_keyword_ignore,
  [72438] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(39), 1,
      sym_argument_list,
  [72448] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2666), 1,
      sym_type_name,
  [72458] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3486), 1,
      anon_sym_LPAREN,
    STATE(45), 1,
      sym_argument_list_count,
  [72468] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3418), 1,
      sym_keyword_jwt,
    ACTIONS(3488), 1,
      sym_keyword_refresh,
  [72478] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2679), 1,
      sym_type_name,
  [72488] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1573), 1,
      sym_identifier,
  [72498] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3490), 1,
      anon_sym_COMMA,
    ACTIONS(3492), 1,
      anon_sym_PIPE_GT,
  [72508] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1069), 1,
      anon_sym_RBRACK,
    ACTIONS(3494), 1,
      anon_sym_QMARK,
  [72518] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2692), 1,
      sym_type_name,
  [72528] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(64), 1,
      sym_argument_list,
  [72538] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(43), 1,
      sym_argument_list,
  [72548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2705), 1,
      sym_type_name,
  [72558] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3444), 1,
      sym_keyword_no_index,
    ACTIONS(3496), 1,
      sym_keyword_index,
  [72568] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2732), 1,
      sym_identifier,
  [72578] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2654), 1,
      sym_type_name,
  [72588] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2718), 1,
      sym_type_name,
  [72598] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(363), 1,
      anon_sym_LPAREN,
    STATE(79), 1,
      sym_argument_list,
  [72608] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2731), 1,
      sym_type_name,
  [72618] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3428), 1,
      aux_sym_type_name_token1,
    STATE(2265), 1,
      sym_identifier,
  [72628] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2738), 1,
      sym_type_name,
  [72638] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1701), 1,
      sym_block,
  [72648] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2745), 1,
      sym_type_name,
  [72658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3472), 1,
      sym_keyword_create,
    STATE(2898), 1,
      sym_create_statement,
  [72668] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3460), 1,
      sym_keyword_on,
    STATE(2310), 1,
      sym_on_table_clause,
  [72678] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2752), 1,
      sym_type_name,
  [72688] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1114), 1,
      sym_identifier,
  [72698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3498), 2,
      sym_keyword_on_duplicate_key_update,
      anon_sym_COMMA,
  [72706] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2759), 1,
      sym_type_name,
  [72716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2766), 1,
      sym_type_name,
  [72726] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3460), 1,
      sym_keyword_on,
    STATE(1712), 1,
      sym_on_table_clause,
  [72736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2145), 1,
      sym_identifier,
  [72746] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1659), 1,
      sym_block,
  [72756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3500), 1,
      anon_sym_EQ,
    ACTIONS(3502), 1,
      sym_int,
  [72766] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2773), 1,
      sym_type_name,
  [72776] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1866), 1,
      sym_identifier,
  [72786] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3416), 1,
      anon_sym_LPAREN,
    STATE(2396), 1,
      sym_param_list,
  [72796] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3504), 1,
      anon_sym_RPAREN,
    ACTIONS(3506), 1,
      sym_variable_name,
  [72806] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2780), 1,
      sym_type_name,
  [72816] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2730), 1,
      sym_type_name,
  [72826] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1721), 1,
      sym_block,
  [72836] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3416), 1,
      anon_sym_LPAREN,
    STATE(2508), 1,
      sym_param_list,
  [72846] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1395), 1,
      sym_identifier,
  [72856] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3416), 1,
      anon_sym_LPAREN,
    STATE(2519), 1,
      sym_param_list,
  [72866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1842), 1,
      sym_block,
  [72876] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2668), 1,
      sym_identifier,
  [72886] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3508), 1,
      anon_sym_LPAREN,
    STATE(327), 1,
      sym_argument_list_count,
  [72896] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1812), 1,
      sym_block,
  [72906] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3446), 1,
      sym_keyword_type,
    STATE(2675), 1,
      sym_token_type_clause,
  [72916] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2960), 1,
      sym_keyword_from,
    STATE(2134), 1,
      sym_from_clause,
  [72926] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3418), 1,
      sym_keyword_jwt,
    ACTIONS(3510), 1,
      sym_keyword_refresh,
  [72936] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(669), 1,
      anon_sym_LPAREN,
    STATE(332), 1,
      sym_argument_list,
  [72946] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2424), 1,
      sym_identifier,
  [72956] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1276), 1,
      sym_identifier,
  [72966] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(643), 1,
      anon_sym_LPAREN,
    STATE(274), 1,
      sym_argument_list,
  [72976] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1806), 1,
      sym_block,
  [72986] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3512), 1,
      anon_sym_EQ,
    ACTIONS(3514), 1,
      sym_int,
  [72996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3516), 1,
      anon_sym_LPAREN,
    STATE(150), 1,
      sym_argument_list_count,
  [73006] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3518), 1,
      anon_sym_EQ,
    ACTIONS(3520), 1,
      sym_int,
  [73016] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3522), 2,
      sym_keyword_password,
      sym_keyword_password_hash,
  [73024] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2815), 1,
      sym_type_name,
  [73034] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1865), 1,
      sym_block,
  [73044] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3418), 1,
      sym_keyword_jwt,
    ACTIONS(3524), 1,
      sym_keyword_refresh,
  [73054] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(2999), 2,
      sym_keyword_from,
      sym_keyword_omit,
  [73062] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(979), 1,
      anon_sym_LBRACE,
    STATE(1859), 1,
      sym_block,
  [73072] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3526), 2,
      aux_sym_type_name_token1,
      sym_variable_name,
  [73080] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2271), 1,
      sym_identifier,
  [73090] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2778), 1,
      sym_identifier,
  [73100] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2152), 1,
      sym_identifier,
  [73110] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1063), 1,
      anon_sym_RBRACK,
    ACTIONS(3528), 1,
      anon_sym_QMARK,
  [73120] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(669), 1,
      anon_sym_LPAREN,
    STATE(344), 1,
      sym_argument_list,
  [73130] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(669), 1,
      anon_sym_LPAREN,
    STATE(346), 1,
      sym_argument_list,
  [73140] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2902), 1,
      sym_type_name,
  [73150] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2680), 1,
      sym_type_name,
  [73160] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2767), 1,
      sym_type_name,
  [73170] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2802), 1,
      sym_type_name,
  [73180] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3446), 1,
      sym_keyword_type,
    STATE(2713), 1,
      sym_token_type_clause,
  [73190] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2838), 1,
      sym_type_name,
  [73200] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2879), 1,
      sym_type_name,
  [73210] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2593), 1,
      sym_type_name,
  [73220] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2608), 1,
      sym_type_name,
  [73230] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2621), 1,
      sym_type_name,
  [73240] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2634), 1,
      sym_type_name,
  [73250] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2647), 1,
      sym_type_name,
  [73260] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2660), 1,
      sym_type_name,
  [73270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2673), 1,
      sym_type_name,
  [73280] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2686), 1,
      sym_type_name,
  [73290] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2699), 1,
      sym_type_name,
  [73300] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2712), 1,
      sym_type_name,
  [73310] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2725), 1,
      sym_type_name,
  [73320] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1207), 1,
      sym_identifier,
  [73330] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2626), 1,
      sym_identifier,
  [73340] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2511), 1,
      sym_identifier,
  [73350] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2097), 1,
      sym_identifier,
  [73360] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3460), 1,
      sym_keyword_on,
    STATE(2291), 1,
      sym_on_table_clause,
  [73370] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1310), 1,
      sym_identifier,
  [73380] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1732), 1,
      aux_sym_type_name_token1,
    STATE(2799), 1,
      sym_type_name,
  [73390] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2356), 1,
      sym_identifier,
  [73400] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2358), 1,
      sym_identifier,
  [73410] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2517), 1,
      sym_identifier,
  [73420] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3460), 1,
      sym_keyword_on,
    STATE(1766), 1,
      sym_on_table_clause,
  [73430] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(2191), 1,
      sym_identifier,
  [73440] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3029), 1,
      aux_sym_type_name_token1,
    STATE(1950), 1,
      sym_identifier,
  [73450] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3530), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [73458] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3532), 1,
      anon_sym_DASH_GT,
  [73465] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3534), 1,
      anon_sym_COLON,
  [73472] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3536), 1,
      anon_sym_GT,
  [73479] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3538), 1,
      sym_keyword_changes,
  [73486] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3540), 1,
      anon_sym_COLON,
  [73493] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3542), 1,
      anon_sym_RPAREN,
  [73500] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3544), 1,
      sym_keyword_on,
  [73507] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3526), 1,
      sym_custom_function_name,
  [73514] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3546), 1,
      sym_keyword_on,
  [73521] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3548), 1,
      anon_sym_COLON,
  [73528] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3550), 1,
      anon_sym_GT,
  [73535] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1029), 1,
      anon_sym_RPAREN,
  [73542] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3462), 1,
      sym_keyword_refresh,
  [73549] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3552), 1,
      anon_sym_COLON,
  [73556] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3554), 1,
      anon_sym_COLON,
  [73563] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3556), 1,
      anon_sym_COLON,
  [73570] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3558), 1,
      anon_sym_COLON,
  [73577] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3560), 1,
      anon_sym_GT,
  [73584] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3562), 1,
      anon_sym_COLON,
  [73591] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3564), 1,
      anon_sym_COLON,
  [73598] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3566), 1,
      anon_sym_COLON,
  [73605] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3568), 1,
      anon_sym_COLON,
  [73612] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3570), 1,
      anon_sym_COLON,
  [73619] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3572), 1,
      anon_sym_GT,
  [73626] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3574), 1,
      sym_keyword_on,
  [73633] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3576), 1,
      anon_sym_LBRACE,
  [73640] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3578), 1,
      anon_sym_COLON,
  [73647] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3580), 1,
      anon_sym_COLON,
  [73654] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3582), 1,
      anon_sym_GT,
  [73661] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3584), 1,
      anon_sym_DASH_GT,
  [73668] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3586), 1,
      anon_sym_GT,
  [73675] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3588), 1,
      anon_sym_COLON,
  [73682] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3590), 1,
      sym_keyword_from,
  [73689] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3592), 1,
      anon_sym_LPAREN,
  [73696] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3594), 1,
      sym_keyword_values,
  [73703] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3596), 1,
      sym_keyword_key,
  [73710] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3598), 1,
      anon_sym_GT,
  [73717] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3600), 1,
      anon_sym_DASH_GT,
  [73724] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1043), 1,
      anon_sym_RPAREN,
  [73731] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3602), 1,
      anon_sym_COLON,
  [73738] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3604), 1,
      anon_sym_COLON,
  [73745] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3606), 1,
      anon_sym_DASH_GT,
  [73752] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3608), 1,
      sym_keyword_on,
  [73759] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3610), 1,
      anon_sym_GT,
  [73766] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3612), 1,
      anon_sym_COLON,
  [73773] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3614), 1,
      sym_variable_name,
  [73780] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3616), 1,
      anon_sym_COLON,
  [73787] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3618), 1,
      anon_sym_COLON,
  [73794] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3620), 1,
      anon_sym_RPAREN,
  [73801] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3622), 1,
      anon_sym_GT,
  [73808] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3624), 1,
      sym_keyword_value,
  [73815] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3626), 1,
      sym_decimal,
  [73822] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3628), 1,
      anon_sym_COLON,
  [73829] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3630), 1,
      anon_sym_COLON,
  [73836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3632), 1,
      anon_sym_COLON,
  [73843] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3634), 1,
      anon_sym_COLON,
  [73850] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3636), 1,
      anon_sym_GT,
  [73857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3638), 1,
      anon_sym_COLON,
  [73864] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3640), 1,
      anon_sym_COLON,
  [73871] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3642), 1,
      anon_sym_COLON,
  [73878] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3644), 1,
      sym_variable_name,
  [73885] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3646), 1,
      sym_version_number,
  [73892] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3648), 1,
      anon_sym_GT,
  [73899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3650), 1,
      anon_sym_GT,
  [73906] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3652), 1,
      anon_sym_COLON,
  [73913] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3654), 1,
      anon_sym_COLON,
  [73920] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3656), 1,
      anon_sym_RBRACE,
  [73927] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3658), 1,
      sym_keyword_exists,
  [73934] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3660), 1,
      sym_string,
  [73941] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3662), 1,
      anon_sym_GT,
  [73948] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3664), 1,
      anon_sym_COLON,
  [73955] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3666), 1,
      anon_sym_COLON,
  [73962] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3668), 1,
      anon_sym_COLON,
  [73969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3670), 1,
      sym_int,
  [73976] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1496), 1,
      sym_custom_function_name,
  [73983] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3672), 1,
      anon_sym_GT,
  [73990] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3674), 1,
      sym_keyword_exists,
  [73997] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3676), 1,
      anon_sym_COLON,
  [74004] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3678), 1,
      anon_sym_COLON,
  [74011] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3680), 1,
      sym_keyword_table,
  [74018] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3682), 1,
      anon_sym_COLON,
  [74025] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3684), 1,
      anon_sym_COLON,
  [74032] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3686), 1,
      anon_sym_GT,
  [74039] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3688), 1,
      anon_sym_COLON,
  [74046] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3690), 1,
      sym_keyword_value,
  [74053] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3692), 1,
      anon_sym_COLON,
  [74060] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3694), 1,
      anon_sym_COLON,
  [74067] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3696), 1,
      anon_sym_LPAREN,
  [74074] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3698), 1,
      anon_sym_GT,
  [74081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3700), 1,
      anon_sym_GT,
  [74088] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3702), 1,
      anon_sym_COLON,
  [74095] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3704), 1,
      anon_sym_COLON,
  [74102] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3706), 1,
      sym_keyword_for,
  [74109] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3708), 1,
      anon_sym_COLON,
  [74116] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3710), 1,
      anon_sym_PIPE_GT,
  [74123] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3712), 1,
      anon_sym_GT,
  [74130] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3492), 1,
      anon_sym_AT,
  [74137] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3714), 1,
      sym_int,
  [74144] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3716), 1,
      anon_sym_COLON,
  [74151] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3718), 1,
      anon_sym_GT,
  [74158] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3720), 1,
      anon_sym_COLON,
  [74165] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3722), 1,
      anon_sym_GT,
  [74172] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3724), 1,
      anon_sym_GT,
  [74179] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3726), 1,
      anon_sym_COLON,
  [74186] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3728), 1,
      sym_keyword_value,
  [74193] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3730), 1,
      anon_sym_COLON,
  [74200] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3732), 1,
      anon_sym_COLON,
  [74207] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3734), 1,
      anon_sym_COLON,
  [74214] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3736), 1,
      anon_sym_GT,
  [74221] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3738), 1,
      anon_sym_COLON,
  [74228] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3740), 1,
      sym_string,
  [74235] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3742), 1,
      anon_sym_COLON,
  [74242] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3744), 1,
      anon_sym_COLON,
  [74249] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3746), 1,
      anon_sym_COLON,
  [74256] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3748), 1,
      anon_sym_GT,
  [74263] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3750), 1,
      anon_sym_LPAREN,
  [74270] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3752), 1,
      anon_sym_COLON,
  [74277] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3754), 1,
      anon_sym_COLON,
  [74284] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3756), 1,
      anon_sym_COLON,
  [74291] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3758), 1,
      sym_keyword_on,
  [74298] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3760), 1,
      anon_sym_COLON,
  [74305] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3762), 1,
      anon_sym_GT,
  [74312] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3764), 1,
      sym_keyword_value,
  [74319] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3766), 1,
      anon_sym_LPAREN,
  [74326] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3768), 1,
      anon_sym_RPAREN,
  [74333] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3770), 1,
      anon_sym_EQ,
  [74340] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3772), 1,
      anon_sym_GT,
  [74347] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3774), 1,
      anon_sym_GT,
  [74354] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3776), 1,
      sym_keyword_into,
  [74361] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3778), 1,
      anon_sym_RBRACE,
  [74368] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3780), 1,
      anon_sym_RPAREN,
  [74375] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3782), 1,
      sym_keyword_key,
  [74382] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3784), 1,
      sym_variable_name,
  [74389] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3786), 1,
      sym_string,
  [74396] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3788), 1,
      anon_sym_GT,
  [74403] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3790), 1,
      sym_keyword_key,
  [74410] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3792), 1,
      sym_float,
  [74417] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3794), 1,
      sym_keyword_analyzer,
  [74424] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3796), 1,
      sym_keyword_dimension,
  [74431] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3798), 1,
      anon_sym_GT,
  [74438] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3800), 1,
      anon_sym_GT,
  [74445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3802), 1,
      sym_keyword_since,
  [74452] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3804), 1,
      sym_keyword_table,
  [74459] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3806), 1,
      sym_keyword_dimension,
  [74466] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3808), 1,
      ts_builtin_sym_end,
  [74473] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3810), 1,
      anon_sym_GT,
  [74480] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3812), 1,
      anon_sym_LPAREN,
  [74487] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3814), 1,
      anon_sym_GT,
  [74494] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3816), 1,
      anon_sym_GT,
  [74501] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3818), 1,
      sym_variable_name,
  [74508] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3820), 1,
      sym_keyword_select,
  [74515] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3822), 1,
      ts_builtin_sym_end,
  [74522] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3422), 1,
      sym_string,
  [74529] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3824), 1,
      anon_sym_LPAREN,
  [74536] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3826), 1,
      anon_sym_GT,
  [74543] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3828), 1,
      anon_sym_LPAREN,
  [74550] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3830), 1,
      sym_keyword_exists,
  [74557] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3832), 1,
      anon_sym_LBRACE,
  [74564] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3834), 1,
      sym_keyword_type,
  [74571] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3836), 1,
      anon_sym_RPAREN,
  [74578] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3838), 1,
      anon_sym_RPAREN,
  [74585] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3840), 1,
      anon_sym_GT,
  [74592] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1009), 1,
      anon_sym_RPAREN,
  [74599] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3842), 1,
      anon_sym_RPAREN,
  [74606] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3844), 1,
      sym_keyword_for,
  [74613] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3846), 1,
      anon_sym_GT,
  [74620] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3848), 1,
      anon_sym_RPAREN,
  [74627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3850), 1,
      anon_sym_LPAREN,
  [74634] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3852), 1,
      anon_sym_GT,
  [74641] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3854), 1,
      anon_sym_LPAREN,
  [74648] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3856), 1,
      sym_custom_function_name,
  [74655] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3858), 1,
      anon_sym_DOT_DOT,
  [74662] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3860), 1,
      anon_sym_DASH_GT,
  [74669] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3862), 1,
      sym_string,
  [74676] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3864), 1,
      sym_keyword_on,
  [74683] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3866), 1,
      anon_sym_GT,
  [74690] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3868), 1,
      anon_sym_GT,
  [74697] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3870), 1,
      anon_sym_RBRACE,
  [74704] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3872), 1,
      sym_keyword_key,
  [74711] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3874), 1,
      anon_sym_GT,
  [74718] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3420), 1,
      sym_keyword_refresh,
  [74725] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3876), 1,
      sym_int,
  [74732] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3878), 1,
      anon_sym_GT,
  [74739] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3880), 1,
      sym_keyword_not,
  [74746] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3882), 1,
      sym_keyword_for,
  [74753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3884), 1,
      anon_sym_GT,
  [74760] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3886), 1,
      anon_sym_COMMA,
  [74767] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3888), 1,
      anon_sym_RPAREN,
  [74774] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3890), 1,
      sym_keyword_type,
  [74781] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3892), 1,
      anon_sym_GT,
  [74788] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3894), 1,
      anon_sym_GT,
  [74795] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3896), 1,
      anon_sym_GT,
  [74802] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3898), 1,
      sym_keyword_for,
  [74809] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3900), 1,
      anon_sym_COLON,
  [74816] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3902), 1,
      anon_sym_RPAREN,
  [74823] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      sym_keyword_refresh,
  [74830] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3906), 1,
      anon_sym_RPAREN,
  [74837] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3908), 1,
      sym_string,
  [74844] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3910), 1,
      anon_sym_RPAREN,
  [74851] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3912), 1,
      sym_variable_name,
  [74858] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3914), 1,
      sym_keyword_value,
  [74865] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3916), 1,
      anon_sym_DOT_DOT,
  [74872] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3918), 1,
      anon_sym_GT,
  [74879] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3920), 1,
      sym_keyword_not,
  [74886] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3922), 1,
      sym_keyword_table,
  [74893] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3924), 1,
      sym_decimal,
  [74900] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3926), 1,
      anon_sym_DASH_GT,
  [74907] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3928), 1,
      anon_sym_PIPE,
  [74914] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3930), 1,
      anon_sym_GT,
  [74921] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3932), 1,
      sym_string,
  [74928] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3934), 1,
      sym_string,
  [74935] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3936), 1,
      anon_sym_GT,
  [74942] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3938), 1,
      anon_sym_RBRACE,
  [74949] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3940), 1,
      anon_sym_DOT_DOT,
  [74956] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3942), 1,
      anon_sym_GT,
  [74963] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3944), 1,
      sym_keyword_values,
  [74970] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3946), 1,
      sym_keyword_refresh,
  [74977] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3948), 1,
      anon_sym_RPAREN,
  [74984] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3950), 1,
      anon_sym_COLON,
  [74991] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3952), 1,
      anon_sym_RBRACE,
  [74998] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3954), 1,
      anon_sym_GT,
  [75005] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3956), 1,
      sym_keyword_since,
  [75012] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3958), 1,
      sym_keyword_in,
  [75019] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3960), 1,
      anon_sym_RBRACE,
  [75026] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3962), 1,
      anon_sym_GT,
  [75033] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3964), 1,
      anon_sym_GT,
  [75040] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3966), 1,
      sym_string,
  [75047] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3462), 1,
      sym_string,
  [75054] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3968), 1,
      anon_sym_GT,
  [75061] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3970), 1,
      sym_int,
  [75068] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3972), 1,
      sym_keyword_select,
  [75075] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3974), 1,
      sym_keyword_index,
  [75082] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3976), 1,
      anon_sym_GT,
  [75089] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3978), 1,
      anon_sym_LPAREN,
  [75096] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3980), 1,
      anon_sym_DASH_GT,
  [75103] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3982), 1,
      sym_decimal,
  [75110] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1003), 1,
      anon_sym_RPAREN,
  [75117] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3984), 1,
      sym_int,
  [75124] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3986), 1,
      anon_sym_COLON,
  [75131] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3988), 1,
      sym_int,
  [75138] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3990), 1,
      anon_sym_LPAREN,
  [75145] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      anon_sym_RPAREN,
  [75152] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3992), 1,
      anon_sym_COLON,
  [75159] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3994), 1,
      anon_sym_COLON,
  [75166] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3996), 1,
      anon_sym_LPAREN,
  [75173] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3998), 1,
      sym_int,
  [75180] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4000), 1,
      sym_keyword_roles,
  [75187] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4002), 1,
      anon_sym_GT,
  [75194] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4004), 1,
      sym_keyword_type,
  [75201] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4006), 1,
      sym_custom_function_name,
  [75208] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4008), 1,
      sym_keyword_on,
  [75215] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4010), 1,
      anon_sym_COMMA,
  [75222] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4012), 1,
      anon_sym_RPAREN,
  [75229] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4014), 1,
      anon_sym_LPAREN,
  [75236] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4016), 1,
      anon_sym_RPAREN,
  [75243] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4018), 1,
      sym_keyword_value,
  [75250] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4020), 1,
      sym_int,
  [75257] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3524), 1,
      sym_keyword_refresh,
  [75264] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4022), 1,
      sym_keyword_exists,
  [75271] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4024), 1,
      sym_keyword_from,
  [75278] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4026), 1,
      sym_int,
  [75285] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4028), 1,
      sym_string,
  [75292] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4030), 1,
      anon_sym_RPAREN,
  [75299] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4032), 1,
      anon_sym_RPAREN,
  [75306] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4034), 1,
      sym_keyword_for,
  [75313] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4036), 1,
      sym_int,
  [75320] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4038), 1,
      sym_int,
  [75327] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4040), 1,
      sym_variable_name,
  [75334] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4042), 1,
      sym_keyword_exists,
  [75341] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4044), 1,
      sym_keyword_table,
  [75348] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4046), 1,
      sym_keyword_for,
  [75355] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4048), 1,
      sym_keyword_value,
  [75362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4050), 1,
      sym_decimal,
  [75369] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4052), 1,
      sym_keyword_value,
  [75376] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4054), 1,
      sym_keyword_on,
  [75383] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4056), 1,
      sym_string,
  [75390] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4058), 1,
      sym_string,
  [75397] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4060), 1,
      anon_sym_GT,
  [75404] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4062), 1,
      sym_keyword_roles,
  [75411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4064), 1,
      anon_sym_DOT_DOT,
  [75418] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4066), 1,
      sym_int,
  [75425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4068), 1,
      sym_float,
  [75432] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4070), 1,
      sym_keyword_key,
  [75439] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4072), 1,
      sym_int,
  [75446] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4074), 1,
      sym_int,
  [75453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4076), 1,
      sym_keyword_table,
  [75460] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4078), 1,
      anon_sym_LBRACE,
  [75467] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4006), 1,
      sym_variable_name,
  [75474] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4080), 1,
      anon_sym_GT,
  [75481] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4082), 1,
      sym_custom_function_name,
  [75488] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4084), 1,
      sym_keyword_values,
  [75495] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4086), 1,
      sym_keyword_changes,
  [75502] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4088), 1,
      sym_int,
  [75509] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4090), 1,
      anon_sym_DOT_DOT,
  [75516] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4092), 1,
      anon_sym_EQ,
  [75523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4094), 1,
      sym_keyword_on,
  [75530] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4096), 1,
      sym_custom_function_name,
  [75537] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4098), 1,
      anon_sym_COLON,
  [75544] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4100), 1,
      anon_sym_GT,
  [75551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4102), 1,
      anon_sym_DASH_GT,
  [75558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4104), 1,
      sym_keyword_for,
  [75565] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4106), 1,
      sym_keyword_not,
  [75572] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3904), 1,
      sym_string,
  [75579] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4108), 1,
      sym_keyword_on,
  [75586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4110), 1,
      anon_sym_LPAREN,
  [75593] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4112), 1,
      anon_sym_LPAREN,
  [75600] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4114), 1,
      anon_sym_LPAREN,
  [75607] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4116), 1,
      anon_sym_RPAREN,
  [75614] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(3271), 1,
      sym_keyword_if,
  [75621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4118), 1,
      anon_sym_COLON,
  [75628] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4120), 1,
      sym_keyword_table,
  [75635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4122), 1,
      anon_sym_GT,
  [75642] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4124), 1,
      sym_int,
  [75649] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4126), 1,
      sym_keyword_values,
  [75656] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4128), 1,
      sym_keyword_values,
  [75663] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4130), 1,
      sym_keyword_values,
  [75670] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4132), 1,
      sym_decimal,
  [75677] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4134), 1,
      anon_sym_RPAREN,
  [75684] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4136), 1,
      sym_int,
  [75691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4138), 1,
      anon_sym_GT,
  [75698] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4140), 1,
      sym_int,
  [75705] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4142), 1,
      anon_sym_COLON,
  [75712] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4144), 1,
      sym_keyword_refresh,
  [75719] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4146), 1,
      anon_sym_GT,
  [75726] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4148), 1,
      anon_sym_COLON,
  [75733] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4150), 1,
      anon_sym_COLON,
  [75740] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4152), 1,
      anon_sym_COLON,
  [75747] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4154), 1,
      sym_keyword_into,
  [75754] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(4156), 1,
      sym_keyword_in,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(630)] = 0,
  [SMALL_STATE(631)] = 93,
  [SMALL_STATE(632)] = 186,
  [SMALL_STATE(633)] = 275,
  [SMALL_STATE(634)] = 348,
  [SMALL_STATE(635)] = 421,
  [SMALL_STATE(636)] = 494,
  [SMALL_STATE(637)] = 567,
  [SMALL_STATE(638)] = 642,
  [SMALL_STATE(639)] = 731,
  [SMALL_STATE(640)] = 806,
  [SMALL_STATE(641)] = 899,
  [SMALL_STATE(642)] = 974,
  [SMALL_STATE(643)] = 1049,
  [SMALL_STATE(644)] = 1124,
  [SMALL_STATE(645)] = 1217,
  [SMALL_STATE(646)] = 1292,
  [SMALL_STATE(647)] = 1367,
  [SMALL_STATE(648)] = 1462,
  [SMALL_STATE(649)] = 1537,
  [SMALL_STATE(650)] = 1612,
  [SMALL_STATE(651)] = 1687,
  [SMALL_STATE(652)] = 1762,
  [SMALL_STATE(653)] = 1837,
  [SMALL_STATE(654)] = 1910,
  [SMALL_STATE(655)] = 2005,
  [SMALL_STATE(656)] = 2094,
  [SMALL_STATE(657)] = 2183,
  [SMALL_STATE(658)] = 2276,
  [SMALL_STATE(659)] = 2365,
  [SMALL_STATE(660)] = 2454,
  [SMALL_STATE(661)] = 2543,
  [SMALL_STATE(662)] = 2632,
  [SMALL_STATE(663)] = 2707,
  [SMALL_STATE(664)] = 2797,
  [SMALL_STATE(665)] = 2871,
  [SMALL_STATE(666)] = 2945,
  [SMALL_STATE(667)] = 3019,
  [SMALL_STATE(668)] = 3093,
  [SMALL_STATE(669)] = 3167,
  [SMALL_STATE(670)] = 3241,
  [SMALL_STATE(671)] = 3315,
  [SMALL_STATE(672)] = 3403,
  [SMALL_STATE(673)] = 3477,
  [SMALL_STATE(674)] = 3565,
  [SMALL_STATE(675)] = 3639,
  [SMALL_STATE(676)] = 3731,
  [SMALL_STATE(677)] = 3805,
  [SMALL_STATE(678)] = 3897,
  [SMALL_STATE(679)] = 3971,
  [SMALL_STATE(680)] = 4059,
  [SMALL_STATE(681)] = 4147,
  [SMALL_STATE(682)] = 4235,
  [SMALL_STATE(683)] = 4309,
  [SMALL_STATE(684)] = 4383,
  [SMALL_STATE(685)] = 4457,
  [SMALL_STATE(686)] = 4549,
  [SMALL_STATE(687)] = 4640,
  [SMALL_STATE(688)] = 4713,
  [SMALL_STATE(689)] = 4786,
  [SMALL_STATE(690)] = 4859,
  [SMALL_STATE(691)] = 4932,
  [SMALL_STATE(692)] = 5019,
  [SMALL_STATE(693)] = 5106,
  [SMALL_STATE(694)] = 5179,
  [SMALL_STATE(695)] = 5252,
  [SMALL_STATE(696)] = 5325,
  [SMALL_STATE(697)] = 5398,
  [SMALL_STATE(698)] = 5489,
  [SMALL_STATE(699)] = 5580,
  [SMALL_STATE(700)] = 5667,
  [SMALL_STATE(701)] = 5758,
  [SMALL_STATE(702)] = 5845,
  [SMALL_STATE(703)] = 5932,
  [SMALL_STATE(704)] = 6023,
  [SMALL_STATE(705)] = 6114,
  [SMALL_STATE(706)] = 6205,
  [SMALL_STATE(707)] = 6296,
  [SMALL_STATE(708)] = 6387,
  [SMALL_STATE(709)] = 6478,
  [SMALL_STATE(710)] = 6569,
  [SMALL_STATE(711)] = 6660,
  [SMALL_STATE(712)] = 6751,
  [SMALL_STATE(713)] = 6840,
  [SMALL_STATE(714)] = 6913,
  [SMALL_STATE(715)] = 7000,
  [SMALL_STATE(716)] = 7073,
  [SMALL_STATE(717)] = 7164,
  [SMALL_STATE(718)] = 7255,
  [SMALL_STATE(719)] = 7346,
  [SMALL_STATE(720)] = 7437,
  [SMALL_STATE(721)] = 7526,
  [SMALL_STATE(722)] = 7613,
  [SMALL_STATE(723)] = 7700,
  [SMALL_STATE(724)] = 7787,
  [SMALL_STATE(725)] = 7874,
  [SMALL_STATE(726)] = 7965,
  [SMALL_STATE(727)] = 8056,
  [SMALL_STATE(728)] = 8147,
  [SMALL_STATE(729)] = 8238,
  [SMALL_STATE(730)] = 8311,
  [SMALL_STATE(731)] = 8384,
  [SMALL_STATE(732)] = 8457,
  [SMALL_STATE(733)] = 8530,
  [SMALL_STATE(734)] = 8621,
  [SMALL_STATE(735)] = 8707,
  [SMALL_STATE(736)] = 8795,
  [SMALL_STATE(737)] = 8883,
  [SMALL_STATE(738)] = 8969,
  [SMALL_STATE(739)] = 9055,
  [SMALL_STATE(740)] = 9141,
  [SMALL_STATE(741)] = 9229,
  [SMALL_STATE(742)] = 9315,
  [SMALL_STATE(743)] = 9403,
  [SMALL_STATE(744)] = 9489,
  [SMALL_STATE(745)] = 9575,
  [SMALL_STATE(746)] = 9660,
  [SMALL_STATE(747)] = 9731,
  [SMALL_STATE(748)] = 9816,
  [SMALL_STATE(749)] = 9901,
  [SMALL_STATE(750)] = 9986,
  [SMALL_STATE(751)] = 10071,
  [SMALL_STATE(752)] = 10156,
  [SMALL_STATE(753)] = 10241,
  [SMALL_STATE(754)] = 10326,
  [SMALL_STATE(755)] = 10411,
  [SMALL_STATE(756)] = 10496,
  [SMALL_STATE(757)] = 10567,
  [SMALL_STATE(758)] = 10652,
  [SMALL_STATE(759)] = 10737,
  [SMALL_STATE(760)] = 10846,
  [SMALL_STATE(761)] = 10955,
  [SMALL_STATE(762)] = 11064,
  [SMALL_STATE(763)] = 11173,
  [SMALL_STATE(764)] = 11282,
  [SMALL_STATE(765)] = 11395,
  [SMALL_STATE(766)] = 11504,
  [SMALL_STATE(767)] = 11613,
  [SMALL_STATE(768)] = 11726,
  [SMALL_STATE(769)] = 11835,
  [SMALL_STATE(770)] = 11945,
  [SMALL_STATE(771)] = 12055,
  [SMALL_STATE(772)] = 12162,
  [SMALL_STATE(773)] = 12269,
  [SMALL_STATE(774)] = 12376,
  [SMALL_STATE(775)] = 12480,
  [SMALL_STATE(776)] = 12584,
  [SMALL_STATE(777)] = 12688,
  [SMALL_STATE(778)] = 12792,
  [SMALL_STATE(779)] = 12896,
  [SMALL_STATE(780)] = 13000,
  [SMALL_STATE(781)] = 13104,
  [SMALL_STATE(782)] = 13208,
  [SMALL_STATE(783)] = 13312,
  [SMALL_STATE(784)] = 13413,
  [SMALL_STATE(785)] = 13514,
  [SMALL_STATE(786)] = 13615,
  [SMALL_STATE(787)] = 13716,
  [SMALL_STATE(788)] = 13817,
  [SMALL_STATE(789)] = 13918,
  [SMALL_STATE(790)] = 14019,
  [SMALL_STATE(791)] = 14120,
  [SMALL_STATE(792)] = 14221,
  [SMALL_STATE(793)] = 14322,
  [SMALL_STATE(794)] = 14423,
  [SMALL_STATE(795)] = 14524,
  [SMALL_STATE(796)] = 14625,
  [SMALL_STATE(797)] = 14723,
  [SMALL_STATE(798)] = 14821,
  [SMALL_STATE(799)] = 14919,
  [SMALL_STATE(800)] = 15017,
  [SMALL_STATE(801)] = 15115,
  [SMALL_STATE(802)] = 15213,
  [SMALL_STATE(803)] = 15311,
  [SMALL_STATE(804)] = 15409,
  [SMALL_STATE(805)] = 15507,
  [SMALL_STATE(806)] = 15605,
  [SMALL_STATE(807)] = 15703,
  [SMALL_STATE(808)] = 15801,
  [SMALL_STATE(809)] = 15899,
  [SMALL_STATE(810)] = 15997,
  [SMALL_STATE(811)] = 16095,
  [SMALL_STATE(812)] = 16193,
  [SMALL_STATE(813)] = 16291,
  [SMALL_STATE(814)] = 16389,
  [SMALL_STATE(815)] = 16487,
  [SMALL_STATE(816)] = 16585,
  [SMALL_STATE(817)] = 16683,
  [SMALL_STATE(818)] = 16781,
  [SMALL_STATE(819)] = 16879,
  [SMALL_STATE(820)] = 16977,
  [SMALL_STATE(821)] = 17075,
  [SMALL_STATE(822)] = 17173,
  [SMALL_STATE(823)] = 17271,
  [SMALL_STATE(824)] = 17369,
  [SMALL_STATE(825)] = 17467,
  [SMALL_STATE(826)] = 17565,
  [SMALL_STATE(827)] = 17663,
  [SMALL_STATE(828)] = 17758,
  [SMALL_STATE(829)] = 17853,
  [SMALL_STATE(830)] = 17948,
  [SMALL_STATE(831)] = 18043,
  [SMALL_STATE(832)] = 18138,
  [SMALL_STATE(833)] = 18233,
  [SMALL_STATE(834)] = 18328,
  [SMALL_STATE(835)] = 18423,
  [SMALL_STATE(836)] = 18518,
  [SMALL_STATE(837)] = 18613,
  [SMALL_STATE(838)] = 18708,
  [SMALL_STATE(839)] = 18803,
  [SMALL_STATE(840)] = 18898,
  [SMALL_STATE(841)] = 18993,
  [SMALL_STATE(842)] = 19088,
  [SMALL_STATE(843)] = 19183,
  [SMALL_STATE(844)] = 19278,
  [SMALL_STATE(845)] = 19373,
  [SMALL_STATE(846)] = 19468,
  [SMALL_STATE(847)] = 19563,
  [SMALL_STATE(848)] = 19658,
  [SMALL_STATE(849)] = 19753,
  [SMALL_STATE(850)] = 19848,
  [SMALL_STATE(851)] = 19943,
  [SMALL_STATE(852)] = 20038,
  [SMALL_STATE(853)] = 20133,
  [SMALL_STATE(854)] = 20228,
  [SMALL_STATE(855)] = 20323,
  [SMALL_STATE(856)] = 20418,
  [SMALL_STATE(857)] = 20513,
  [SMALL_STATE(858)] = 20608,
  [SMALL_STATE(859)] = 20703,
  [SMALL_STATE(860)] = 20798,
  [SMALL_STATE(861)] = 20893,
  [SMALL_STATE(862)] = 20988,
  [SMALL_STATE(863)] = 21083,
  [SMALL_STATE(864)] = 21178,
  [SMALL_STATE(865)] = 21273,
  [SMALL_STATE(866)] = 21368,
  [SMALL_STATE(867)] = 21463,
  [SMALL_STATE(868)] = 21558,
  [SMALL_STATE(869)] = 21653,
  [SMALL_STATE(870)] = 21748,
  [SMALL_STATE(871)] = 21843,
  [SMALL_STATE(872)] = 21938,
  [SMALL_STATE(873)] = 22033,
  [SMALL_STATE(874)] = 22128,
  [SMALL_STATE(875)] = 22223,
  [SMALL_STATE(876)] = 22318,
  [SMALL_STATE(877)] = 22413,
  [SMALL_STATE(878)] = 22508,
  [SMALL_STATE(879)] = 22603,
  [SMALL_STATE(880)] = 22698,
  [SMALL_STATE(881)] = 22793,
  [SMALL_STATE(882)] = 22888,
  [SMALL_STATE(883)] = 22983,
  [SMALL_STATE(884)] = 23078,
  [SMALL_STATE(885)] = 23173,
  [SMALL_STATE(886)] = 23268,
  [SMALL_STATE(887)] = 23363,
  [SMALL_STATE(888)] = 23458,
  [SMALL_STATE(889)] = 23553,
  [SMALL_STATE(890)] = 23648,
  [SMALL_STATE(891)] = 23743,
  [SMALL_STATE(892)] = 23838,
  [SMALL_STATE(893)] = 23933,
  [SMALL_STATE(894)] = 24028,
  [SMALL_STATE(895)] = 24123,
  [SMALL_STATE(896)] = 24218,
  [SMALL_STATE(897)] = 24313,
  [SMALL_STATE(898)] = 24408,
  [SMALL_STATE(899)] = 24503,
  [SMALL_STATE(900)] = 24598,
  [SMALL_STATE(901)] = 24693,
  [SMALL_STATE(902)] = 24788,
  [SMALL_STATE(903)] = 24883,
  [SMALL_STATE(904)] = 24978,
  [SMALL_STATE(905)] = 25073,
  [SMALL_STATE(906)] = 25168,
  [SMALL_STATE(907)] = 25263,
  [SMALL_STATE(908)] = 25358,
  [SMALL_STATE(909)] = 25453,
  [SMALL_STATE(910)] = 25548,
  [SMALL_STATE(911)] = 25643,
  [SMALL_STATE(912)] = 25738,
  [SMALL_STATE(913)] = 25833,
  [SMALL_STATE(914)] = 25928,
  [SMALL_STATE(915)] = 26023,
  [SMALL_STATE(916)] = 26118,
  [SMALL_STATE(917)] = 26213,
  [SMALL_STATE(918)] = 26308,
  [SMALL_STATE(919)] = 26403,
  [SMALL_STATE(920)] = 26498,
  [SMALL_STATE(921)] = 26593,
  [SMALL_STATE(922)] = 26688,
  [SMALL_STATE(923)] = 26783,
  [SMALL_STATE(924)] = 26878,
  [SMALL_STATE(925)] = 26973,
  [SMALL_STATE(926)] = 27068,
  [SMALL_STATE(927)] = 27163,
  [SMALL_STATE(928)] = 27258,
  [SMALL_STATE(929)] = 27353,
  [SMALL_STATE(930)] = 27448,
  [SMALL_STATE(931)] = 27543,
  [SMALL_STATE(932)] = 27638,
  [SMALL_STATE(933)] = 27733,
  [SMALL_STATE(934)] = 27828,
  [SMALL_STATE(935)] = 27923,
  [SMALL_STATE(936)] = 28018,
  [SMALL_STATE(937)] = 28113,
  [SMALL_STATE(938)] = 28208,
  [SMALL_STATE(939)] = 28303,
  [SMALL_STATE(940)] = 28398,
  [SMALL_STATE(941)] = 28493,
  [SMALL_STATE(942)] = 28588,
  [SMALL_STATE(943)] = 28683,
  [SMALL_STATE(944)] = 28778,
  [SMALL_STATE(945)] = 28873,
  [SMALL_STATE(946)] = 28968,
  [SMALL_STATE(947)] = 29063,
  [SMALL_STATE(948)] = 29158,
  [SMALL_STATE(949)] = 29253,
  [SMALL_STATE(950)] = 29348,
  [SMALL_STATE(951)] = 29443,
  [SMALL_STATE(952)] = 29538,
  [SMALL_STATE(953)] = 29633,
  [SMALL_STATE(954)] = 29728,
  [SMALL_STATE(955)] = 29823,
  [SMALL_STATE(956)] = 29918,
  [SMALL_STATE(957)] = 30013,
  [SMALL_STATE(958)] = 30108,
  [SMALL_STATE(959)] = 30203,
  [SMALL_STATE(960)] = 30298,
  [SMALL_STATE(961)] = 30393,
  [SMALL_STATE(962)] = 30488,
  [SMALL_STATE(963)] = 30583,
  [SMALL_STATE(964)] = 30678,
  [SMALL_STATE(965)] = 30773,
  [SMALL_STATE(966)] = 30868,
  [SMALL_STATE(967)] = 30963,
  [SMALL_STATE(968)] = 31058,
  [SMALL_STATE(969)] = 31153,
  [SMALL_STATE(970)] = 31248,
  [SMALL_STATE(971)] = 31343,
  [SMALL_STATE(972)] = 31438,
  [SMALL_STATE(973)] = 31533,
  [SMALL_STATE(974)] = 31628,
  [SMALL_STATE(975)] = 31723,
  [SMALL_STATE(976)] = 31818,
  [SMALL_STATE(977)] = 31913,
  [SMALL_STATE(978)] = 32008,
  [SMALL_STATE(979)] = 32103,
  [SMALL_STATE(980)] = 32198,
  [SMALL_STATE(981)] = 32293,
  [SMALL_STATE(982)] = 32388,
  [SMALL_STATE(983)] = 32483,
  [SMALL_STATE(984)] = 32578,
  [SMALL_STATE(985)] = 32673,
  [SMALL_STATE(986)] = 32768,
  [SMALL_STATE(987)] = 32863,
  [SMALL_STATE(988)] = 32958,
  [SMALL_STATE(989)] = 33053,
  [SMALL_STATE(990)] = 33148,
  [SMALL_STATE(991)] = 33243,
  [SMALL_STATE(992)] = 33338,
  [SMALL_STATE(993)] = 33433,
  [SMALL_STATE(994)] = 33528,
  [SMALL_STATE(995)] = 33623,
  [SMALL_STATE(996)] = 33718,
  [SMALL_STATE(997)] = 33813,
  [SMALL_STATE(998)] = 33908,
  [SMALL_STATE(999)] = 34003,
  [SMALL_STATE(1000)] = 34098,
  [SMALL_STATE(1001)] = 34193,
  [SMALL_STATE(1002)] = 34288,
  [SMALL_STATE(1003)] = 34383,
  [SMALL_STATE(1004)] = 34478,
  [SMALL_STATE(1005)] = 34573,
  [SMALL_STATE(1006)] = 34668,
  [SMALL_STATE(1007)] = 34763,
  [SMALL_STATE(1008)] = 34858,
  [SMALL_STATE(1009)] = 34953,
  [SMALL_STATE(1010)] = 35048,
  [SMALL_STATE(1011)] = 35143,
  [SMALL_STATE(1012)] = 35238,
  [SMALL_STATE(1013)] = 35333,
  [SMALL_STATE(1014)] = 35428,
  [SMALL_STATE(1015)] = 35523,
  [SMALL_STATE(1016)] = 35618,
  [SMALL_STATE(1017)] = 35713,
  [SMALL_STATE(1018)] = 35808,
  [SMALL_STATE(1019)] = 35903,
  [SMALL_STATE(1020)] = 35998,
  [SMALL_STATE(1021)] = 36093,
  [SMALL_STATE(1022)] = 36188,
  [SMALL_STATE(1023)] = 36283,
  [SMALL_STATE(1024)] = 36378,
  [SMALL_STATE(1025)] = 36473,
  [SMALL_STATE(1026)] = 36568,
  [SMALL_STATE(1027)] = 36663,
  [SMALL_STATE(1028)] = 36758,
  [SMALL_STATE(1029)] = 36853,
  [SMALL_STATE(1030)] = 36948,
  [SMALL_STATE(1031)] = 37043,
  [SMALL_STATE(1032)] = 37138,
  [SMALL_STATE(1033)] = 37233,
  [SMALL_STATE(1034)] = 37328,
  [SMALL_STATE(1035)] = 37423,
  [SMALL_STATE(1036)] = 37518,
  [SMALL_STATE(1037)] = 37613,
  [SMALL_STATE(1038)] = 37708,
  [SMALL_STATE(1039)] = 37803,
  [SMALL_STATE(1040)] = 37898,
  [SMALL_STATE(1041)] = 37993,
  [SMALL_STATE(1042)] = 38088,
  [SMALL_STATE(1043)] = 38183,
  [SMALL_STATE(1044)] = 38278,
  [SMALL_STATE(1045)] = 38373,
  [SMALL_STATE(1046)] = 38468,
  [SMALL_STATE(1047)] = 38563,
  [SMALL_STATE(1048)] = 38658,
  [SMALL_STATE(1049)] = 38753,
  [SMALL_STATE(1050)] = 38848,
  [SMALL_STATE(1051)] = 38943,
  [SMALL_STATE(1052)] = 39038,
  [SMALL_STATE(1053)] = 39133,
  [SMALL_STATE(1054)] = 39228,
  [SMALL_STATE(1055)] = 39314,
  [SMALL_STATE(1056)] = 39400,
  [SMALL_STATE(1057)] = 39486,
  [SMALL_STATE(1058)] = 39572,
  [SMALL_STATE(1059)] = 39658,
  [SMALL_STATE(1060)] = 39744,
  [SMALL_STATE(1061)] = 39830,
  [SMALL_STATE(1062)] = 39916,
  [SMALL_STATE(1063)] = 40002,
  [SMALL_STATE(1064)] = 40088,
  [SMALL_STATE(1065)] = 40174,
  [SMALL_STATE(1066)] = 40260,
  [SMALL_STATE(1067)] = 40346,
  [SMALL_STATE(1068)] = 40432,
  [SMALL_STATE(1069)] = 40518,
  [SMALL_STATE(1070)] = 40604,
  [SMALL_STATE(1071)] = 40690,
  [SMALL_STATE(1072)] = 40776,
  [SMALL_STATE(1073)] = 40862,
  [SMALL_STATE(1074)] = 40948,
  [SMALL_STATE(1075)] = 41034,
  [SMALL_STATE(1076)] = 41120,
  [SMALL_STATE(1077)] = 41206,
  [SMALL_STATE(1078)] = 41292,
  [SMALL_STATE(1079)] = 41378,
  [SMALL_STATE(1080)] = 41464,
  [SMALL_STATE(1081)] = 41550,
  [SMALL_STATE(1082)] = 41636,
  [SMALL_STATE(1083)] = 41722,
  [SMALL_STATE(1084)] = 41808,
  [SMALL_STATE(1085)] = 41894,
  [SMALL_STATE(1086)] = 41980,
  [SMALL_STATE(1087)] = 42066,
  [SMALL_STATE(1088)] = 42152,
  [SMALL_STATE(1089)] = 42238,
  [SMALL_STATE(1090)] = 42324,
  [SMALL_STATE(1091)] = 42410,
  [SMALL_STATE(1092)] = 42496,
  [SMALL_STATE(1093)] = 42582,
  [SMALL_STATE(1094)] = 42668,
  [SMALL_STATE(1095)] = 42754,
  [SMALL_STATE(1096)] = 42840,
  [SMALL_STATE(1097)] = 42926,
  [SMALL_STATE(1098)] = 43012,
  [SMALL_STATE(1099)] = 43098,
  [SMALL_STATE(1100)] = 43184,
  [SMALL_STATE(1101)] = 43270,
  [SMALL_STATE(1102)] = 43356,
  [SMALL_STATE(1103)] = 43442,
  [SMALL_STATE(1104)] = 43528,
  [SMALL_STATE(1105)] = 43614,
  [SMALL_STATE(1106)] = 43700,
  [SMALL_STATE(1107)] = 43786,
  [SMALL_STATE(1108)] = 43872,
  [SMALL_STATE(1109)] = 43958,
  [SMALL_STATE(1110)] = 44044,
  [SMALL_STATE(1111)] = 44130,
  [SMALL_STATE(1112)] = 44216,
  [SMALL_STATE(1113)] = 44302,
  [SMALL_STATE(1114)] = 44358,
  [SMALL_STATE(1115)] = 44414,
  [SMALL_STATE(1116)] = 44470,
  [SMALL_STATE(1117)] = 44510,
  [SMALL_STATE(1118)] = 44547,
  [SMALL_STATE(1119)] = 44616,
  [SMALL_STATE(1120)] = 44691,
  [SMALL_STATE(1121)] = 44766,
  [SMALL_STATE(1122)] = 44799,
  [SMALL_STATE(1123)] = 44834,
  [SMALL_STATE(1124)] = 44867,
  [SMALL_STATE(1125)] = 44936,
  [SMALL_STATE(1126)] = 44973,
  [SMALL_STATE(1127)] = 45005,
  [SMALL_STATE(1128)] = 45073,
  [SMALL_STATE(1129)] = 45105,
  [SMALL_STATE(1130)] = 45137,
  [SMALL_STATE(1131)] = 45211,
  [SMALL_STATE(1132)] = 45285,
  [SMALL_STATE(1133)] = 45317,
  [SMALL_STATE(1134)] = 45349,
  [SMALL_STATE(1135)] = 45381,
  [SMALL_STATE(1136)] = 45413,
  [SMALL_STATE(1137)] = 45481,
  [SMALL_STATE(1138)] = 45513,
  [SMALL_STATE(1139)] = 45574,
  [SMALL_STATE(1140)] = 45605,
  [SMALL_STATE(1141)] = 45636,
  [SMALL_STATE(1142)] = 45667,
  [SMALL_STATE(1143)] = 45698,
  [SMALL_STATE(1144)] = 45729,
  [SMALL_STATE(1145)] = 45760,
  [SMALL_STATE(1146)] = 45791,
  [SMALL_STATE(1147)] = 45852,
  [SMALL_STATE(1148)] = 45912,
  [SMALL_STATE(1149)] = 45972,
  [SMALL_STATE(1150)] = 45999,
  [SMALL_STATE(1151)] = 46062,
  [SMALL_STATE(1152)] = 46089,
  [SMALL_STATE(1153)] = 46152,
  [SMALL_STATE(1154)] = 46215,
  [SMALL_STATE(1155)] = 46277,
  [SMALL_STATE(1156)] = 46339,
  [SMALL_STATE(1157)] = 46401,
  [SMALL_STATE(1158)] = 46458,
  [SMALL_STATE(1159)] = 46501,
  [SMALL_STATE(1160)] = 46544,
  [SMALL_STATE(1161)] = 46587,
  [SMALL_STATE(1162)] = 46630,
  [SMALL_STATE(1163)] = 46673,
  [SMALL_STATE(1164)] = 46716,
  [SMALL_STATE(1165)] = 46773,
  [SMALL_STATE(1166)] = 46830,
  [SMALL_STATE(1167)] = 46873,
  [SMALL_STATE(1168)] = 46930,
  [SMALL_STATE(1169)] = 46957,
  [SMALL_STATE(1170)] = 46981,
  [SMALL_STATE(1171)] = 47023,
  [SMALL_STATE(1172)] = 47047,
  [SMALL_STATE(1173)] = 47089,
  [SMALL_STATE(1174)] = 47145,
  [SMALL_STATE(1175)] = 47201,
  [SMALL_STATE(1176)] = 47225,
  [SMALL_STATE(1177)] = 47249,
  [SMALL_STATE(1178)] = 47291,
  [SMALL_STATE(1179)] = 47315,
  [SMALL_STATE(1180)] = 47339,
  [SMALL_STATE(1181)] = 47363,
  [SMALL_STATE(1182)] = 47405,
  [SMALL_STATE(1183)] = 47429,
  [SMALL_STATE(1184)] = 47485,
  [SMALL_STATE(1185)] = 47527,
  [SMALL_STATE(1186)] = 47551,
  [SMALL_STATE(1187)] = 47607,
  [SMALL_STATE(1188)] = 47631,
  [SMALL_STATE(1189)] = 47659,
  [SMALL_STATE(1190)] = 47683,
  [SMALL_STATE(1191)] = 47725,
  [SMALL_STATE(1192)] = 47767,
  [SMALL_STATE(1193)] = 47804,
  [SMALL_STATE(1194)] = 47841,
  [SMALL_STATE(1195)] = 47892,
  [SMALL_STATE(1196)] = 47943,
  [SMALL_STATE(1197)] = 47994,
  [SMALL_STATE(1198)] = 48045,
  [SMALL_STATE(1199)] = 48096,
  [SMALL_STATE(1200)] = 48146,
  [SMALL_STATE(1201)] = 48196,
  [SMALL_STATE(1202)] = 48246,
  [SMALL_STATE(1203)] = 48296,
  [SMALL_STATE(1204)] = 48318,
  [SMALL_STATE(1205)] = 48344,
  [SMALL_STATE(1206)] = 48366,
  [SMALL_STATE(1207)] = 48412,
  [SMALL_STATE(1208)] = 48458,
  [SMALL_STATE(1209)] = 48508,
  [SMALL_STATE(1210)] = 48553,
  [SMALL_STATE(1211)] = 48598,
  [SMALL_STATE(1212)] = 48643,
  [SMALL_STATE(1213)] = 48688,
  [SMALL_STATE(1214)] = 48733,
  [SMALL_STATE(1215)] = 48778,
  [SMALL_STATE(1216)] = 48823,
  [SMALL_STATE(1217)] = 48866,
  [SMALL_STATE(1218)] = 48909,
  [SMALL_STATE(1219)] = 48930,
  [SMALL_STATE(1220)] = 48975,
  [SMALL_STATE(1221)] = 49018,
  [SMALL_STATE(1222)] = 49043,
  [SMALL_STATE(1223)] = 49064,
  [SMALL_STATE(1224)] = 49109,
  [SMALL_STATE(1225)] = 49152,
  [SMALL_STATE(1226)] = 49197,
  [SMALL_STATE(1227)] = 49242,
  [SMALL_STATE(1228)] = 49287,
  [SMALL_STATE(1229)] = 49312,
  [SMALL_STATE(1230)] = 49355,
  [SMALL_STATE(1231)] = 49400,
  [SMALL_STATE(1232)] = 49445,
  [SMALL_STATE(1233)] = 49488,
  [SMALL_STATE(1234)] = 49531,
  [SMALL_STATE(1235)] = 49576,
  [SMALL_STATE(1236)] = 49621,
  [SMALL_STATE(1237)] = 49664,
  [SMALL_STATE(1238)] = 49707,
  [SMALL_STATE(1239)] = 49752,
  [SMALL_STATE(1240)] = 49797,
  [SMALL_STATE(1241)] = 49842,
  [SMALL_STATE(1242)] = 49885,
  [SMALL_STATE(1243)] = 49930,
  [SMALL_STATE(1244)] = 49973,
  [SMALL_STATE(1245)] = 50016,
  [SMALL_STATE(1246)] = 50059,
  [SMALL_STATE(1247)] = 50080,
  [SMALL_STATE(1248)] = 50124,
  [SMALL_STATE(1249)] = 50166,
  [SMALL_STATE(1250)] = 50206,
  [SMALL_STATE(1251)] = 50250,
  [SMALL_STATE(1252)] = 50294,
  [SMALL_STATE(1253)] = 50338,
  [SMALL_STATE(1254)] = 50378,
  [SMALL_STATE(1255)] = 50402,
  [SMALL_STATE(1256)] = 50446,
  [SMALL_STATE(1257)] = 50486,
  [SMALL_STATE(1258)] = 50510,
  [SMALL_STATE(1259)] = 50534,
  [SMALL_STATE(1260)] = 50572,
  [SMALL_STATE(1261)] = 50616,
  [SMALL_STATE(1262)] = 50640,
  [SMALL_STATE(1263)] = 50660,
  [SMALL_STATE(1264)] = 50702,
  [SMALL_STATE(1265)] = 50726,
  [SMALL_STATE(1266)] = 50770,
  [SMALL_STATE(1267)] = 50810,
  [SMALL_STATE(1268)] = 50854,
  [SMALL_STATE(1269)] = 50894,
  [SMALL_STATE(1270)] = 50938,
  [SMALL_STATE(1271)] = 50982,
  [SMALL_STATE(1272)] = 51026,
  [SMALL_STATE(1273)] = 51050,
  [SMALL_STATE(1274)] = 51094,
  [SMALL_STATE(1275)] = 51138,
  [SMALL_STATE(1276)] = 51182,
  [SMALL_STATE(1277)] = 51226,
  [SMALL_STATE(1278)] = 51270,
  [SMALL_STATE(1279)] = 51310,
  [SMALL_STATE(1280)] = 51350,
  [SMALL_STATE(1281)] = 51394,
  [SMALL_STATE(1282)] = 51418,
  [SMALL_STATE(1283)] = 51456,
  [SMALL_STATE(1284)] = 51500,
  [SMALL_STATE(1285)] = 51523,
  [SMALL_STATE(1286)] = 51546,
  [SMALL_STATE(1287)] = 51565,
  [SMALL_STATE(1288)] = 51602,
  [SMALL_STATE(1289)] = 51641,
  [SMALL_STATE(1290)] = 51670,
  [SMALL_STATE(1291)] = 51695,
  [SMALL_STATE(1292)] = 51718,
  [SMALL_STATE(1293)] = 51741,
  [SMALL_STATE(1294)] = 51780,
  [SMALL_STATE(1295)] = 51809,
  [SMALL_STATE(1296)] = 51832,
  [SMALL_STATE(1297)] = 51867,
  [SMALL_STATE(1298)] = 51896,
  [SMALL_STATE(1299)] = 51931,
  [SMALL_STATE(1300)] = 51954,
  [SMALL_STATE(1301)] = 51993,
  [SMALL_STATE(1302)] = 52024,
  [SMALL_STATE(1303)] = 52053,
  [SMALL_STATE(1304)] = 52080,
  [SMALL_STATE(1305)] = 52119,
  [SMALL_STATE(1306)] = 52142,
  [SMALL_STATE(1307)] = 52185,
  [SMALL_STATE(1308)] = 52214,
  [SMALL_STATE(1309)] = 52233,
  [SMALL_STATE(1310)] = 52262,
  [SMALL_STATE(1311)] = 52291,
  [SMALL_STATE(1312)] = 52330,
  [SMALL_STATE(1313)] = 52365,
  [SMALL_STATE(1314)] = 52400,
  [SMALL_STATE(1315)] = 52429,
  [SMALL_STATE(1316)] = 52458,
  [SMALL_STATE(1317)] = 52497,
  [SMALL_STATE(1318)] = 52520,
  [SMALL_STATE(1319)] = 52549,
  [SMALL_STATE(1320)] = 52584,
  [SMALL_STATE(1321)] = 52619,
  [SMALL_STATE(1322)] = 52662,
  [SMALL_STATE(1323)] = 52681,
  [SMALL_STATE(1324)] = 52710,
  [SMALL_STATE(1325)] = 52745,
  [SMALL_STATE(1326)] = 52768,
  [SMALL_STATE(1327)] = 52803,
  [SMALL_STATE(1328)] = 52838,
  [SMALL_STATE(1329)] = 52873,
  [SMALL_STATE(1330)] = 52896,
  [SMALL_STATE(1331)] = 52925,
  [SMALL_STATE(1332)] = 52954,
  [SMALL_STATE(1333)] = 52983,
  [SMALL_STATE(1334)] = 53022,
  [SMALL_STATE(1335)] = 53049,
  [SMALL_STATE(1336)] = 53072,
  [SMALL_STATE(1337)] = 53101,
  [SMALL_STATE(1338)] = 53138,
  [SMALL_STATE(1339)] = 53177,
  [SMALL_STATE(1340)] = 53195,
  [SMALL_STATE(1341)] = 53213,
  [SMALL_STATE(1342)] = 53235,
  [SMALL_STATE(1343)] = 53273,
  [SMALL_STATE(1344)] = 53291,
  [SMALL_STATE(1345)] = 53317,
  [SMALL_STATE(1346)] = 53347,
  [SMALL_STATE(1347)] = 53369,
  [SMALL_STATE(1348)] = 53399,
  [SMALL_STATE(1349)] = 53437,
  [SMALL_STATE(1350)] = 53475,
  [SMALL_STATE(1351)] = 53509,
  [SMALL_STATE(1352)] = 53547,
  [SMALL_STATE(1353)] = 53575,
  [SMALL_STATE(1354)] = 53611,
  [SMALL_STATE(1355)] = 53645,
  [SMALL_STATE(1356)] = 53667,
  [SMALL_STATE(1357)] = 53701,
  [SMALL_STATE(1358)] = 53723,
  [SMALL_STATE(1359)] = 53761,
  [SMALL_STATE(1360)] = 53799,
  [SMALL_STATE(1361)] = 53833,
  [SMALL_STATE(1362)] = 53869,
  [SMALL_STATE(1363)] = 53903,
  [SMALL_STATE(1364)] = 53937,
  [SMALL_STATE(1365)] = 53975,
  [SMALL_STATE(1366)] = 53997,
  [SMALL_STATE(1367)] = 54019,
  [SMALL_STATE(1368)] = 54039,
  [SMALL_STATE(1369)] = 54073,
  [SMALL_STATE(1370)] = 54107,
  [SMALL_STATE(1371)] = 54129,
  [SMALL_STATE(1372)] = 54151,
  [SMALL_STATE(1373)] = 54173,
  [SMALL_STATE(1374)] = 54195,
  [SMALL_STATE(1375)] = 54213,
  [SMALL_STATE(1376)] = 54251,
  [SMALL_STATE(1377)] = 54274,
  [SMALL_STATE(1378)] = 54297,
  [SMALL_STATE(1379)] = 54320,
  [SMALL_STATE(1380)] = 54343,
  [SMALL_STATE(1381)] = 54376,
  [SMALL_STATE(1382)] = 54399,
  [SMALL_STATE(1383)] = 54432,
  [SMALL_STATE(1384)] = 54465,
  [SMALL_STATE(1385)] = 54488,
  [SMALL_STATE(1386)] = 54521,
  [SMALL_STATE(1387)] = 54554,
  [SMALL_STATE(1388)] = 54585,
  [SMALL_STATE(1389)] = 54618,
  [SMALL_STATE(1390)] = 54641,
  [SMALL_STATE(1391)] = 54674,
  [SMALL_STATE(1392)] = 54705,
  [SMALL_STATE(1393)] = 54734,
  [SMALL_STATE(1394)] = 54757,
  [SMALL_STATE(1395)] = 54790,
  [SMALL_STATE(1396)] = 54815,
  [SMALL_STATE(1397)] = 54840,
  [SMALL_STATE(1398)] = 54873,
  [SMALL_STATE(1399)] = 54906,
  [SMALL_STATE(1400)] = 54931,
  [SMALL_STATE(1401)] = 54956,
  [SMALL_STATE(1402)] = 54989,
  [SMALL_STATE(1403)] = 55010,
  [SMALL_STATE(1404)] = 55043,
  [SMALL_STATE(1405)] = 55072,
  [SMALL_STATE(1406)] = 55097,
  [SMALL_STATE(1407)] = 55120,
  [SMALL_STATE(1408)] = 55153,
  [SMALL_STATE(1409)] = 55176,
  [SMALL_STATE(1410)] = 55197,
  [SMALL_STATE(1411)] = 55228,
  [SMALL_STATE(1412)] = 55259,
  [SMALL_STATE(1413)] = 55287,
  [SMALL_STATE(1414)] = 55313,
  [SMALL_STATE(1415)] = 55339,
  [SMALL_STATE(1416)] = 55359,
  [SMALL_STATE(1417)] = 55379,
  [SMALL_STATE(1418)] = 55411,
  [SMALL_STATE(1419)] = 55437,
  [SMALL_STATE(1420)] = 55457,
  [SMALL_STATE(1421)] = 55485,
  [SMALL_STATE(1422)] = 55517,
  [SMALL_STATE(1423)] = 55543,
  [SMALL_STATE(1424)] = 55571,
  [SMALL_STATE(1425)] = 55587,
  [SMALL_STATE(1426)] = 55619,
  [SMALL_STATE(1427)] = 55643,
  [SMALL_STATE(1428)] = 55667,
  [SMALL_STATE(1429)] = 55687,
  [SMALL_STATE(1430)] = 55719,
  [SMALL_STATE(1431)] = 55751,
  [SMALL_STATE(1432)] = 55779,
  [SMALL_STATE(1433)] = 55811,
  [SMALL_STATE(1434)] = 55843,
  [SMALL_STATE(1435)] = 55863,
  [SMALL_STATE(1436)] = 55879,
  [SMALL_STATE(1437)] = 55907,
  [SMALL_STATE(1438)] = 55927,
  [SMALL_STATE(1439)] = 55959,
  [SMALL_STATE(1440)] = 55979,
  [SMALL_STATE(1441)] = 56011,
  [SMALL_STATE(1442)] = 56039,
  [SMALL_STATE(1443)] = 56071,
  [SMALL_STATE(1444)] = 56099,
  [SMALL_STATE(1445)] = 56127,
  [SMALL_STATE(1446)] = 56147,
  [SMALL_STATE(1447)] = 56163,
  [SMALL_STATE(1448)] = 56191,
  [SMALL_STATE(1449)] = 56211,
  [SMALL_STATE(1450)] = 56235,
  [SMALL_STATE(1451)] = 56259,
  [SMALL_STATE(1452)] = 56287,
  [SMALL_STATE(1453)] = 56303,
  [SMALL_STATE(1454)] = 56331,
  [SMALL_STATE(1455)] = 56359,
  [SMALL_STATE(1456)] = 56387,
  [SMALL_STATE(1457)] = 56407,
  [SMALL_STATE(1458)] = 56435,
  [SMALL_STATE(1459)] = 56455,
  [SMALL_STATE(1460)] = 56485,
  [SMALL_STATE(1461)] = 56517,
  [SMALL_STATE(1462)] = 56543,
  [SMALL_STATE(1463)] = 56563,
  [SMALL_STATE(1464)] = 56579,
  [SMALL_STATE(1465)] = 56599,
  [SMALL_STATE(1466)] = 56629,
  [SMALL_STATE(1467)] = 56653,
  [SMALL_STATE(1468)] = 56673,
  [SMALL_STATE(1469)] = 56701,
  [SMALL_STATE(1470)] = 56721,
  [SMALL_STATE(1471)] = 56737,
  [SMALL_STATE(1472)] = 56769,
  [SMALL_STATE(1473)] = 56789,
  [SMALL_STATE(1474)] = 56817,
  [SMALL_STATE(1475)] = 56837,
  [SMALL_STATE(1476)] = 56857,
  [SMALL_STATE(1477)] = 56877,
  [SMALL_STATE(1478)] = 56905,
  [SMALL_STATE(1479)] = 56925,
  [SMALL_STATE(1480)] = 56945,
  [SMALL_STATE(1481)] = 56965,
  [SMALL_STATE(1482)] = 56985,
  [SMALL_STATE(1483)] = 57005,
  [SMALL_STATE(1484)] = 57021,
  [SMALL_STATE(1485)] = 57041,
  [SMALL_STATE(1486)] = 57073,
  [SMALL_STATE(1487)] = 57093,
  [SMALL_STATE(1488)] = 57119,
  [SMALL_STATE(1489)] = 57147,
  [SMALL_STATE(1490)] = 57174,
  [SMALL_STATE(1491)] = 57201,
  [SMALL_STATE(1492)] = 57228,
  [SMALL_STATE(1493)] = 57255,
  [SMALL_STATE(1494)] = 57282,
  [SMALL_STATE(1495)] = 57309,
  [SMALL_STATE(1496)] = 57336,
  [SMALL_STATE(1497)] = 57363,
  [SMALL_STATE(1498)] = 57390,
  [SMALL_STATE(1499)] = 57417,
  [SMALL_STATE(1500)] = 57444,
  [SMALL_STATE(1501)] = 57471,
  [SMALL_STATE(1502)] = 57490,
  [SMALL_STATE(1503)] = 57517,
  [SMALL_STATE(1504)] = 57544,
  [SMALL_STATE(1505)] = 57571,
  [SMALL_STATE(1506)] = 57598,
  [SMALL_STATE(1507)] = 57625,
  [SMALL_STATE(1508)] = 57652,
  [SMALL_STATE(1509)] = 57679,
  [SMALL_STATE(1510)] = 57706,
  [SMALL_STATE(1511)] = 57733,
  [SMALL_STATE(1512)] = 57760,
  [SMALL_STATE(1513)] = 57787,
  [SMALL_STATE(1514)] = 57802,
  [SMALL_STATE(1515)] = 57817,
  [SMALL_STATE(1516)] = 57844,
  [SMALL_STATE(1517)] = 57871,
  [SMALL_STATE(1518)] = 57898,
  [SMALL_STATE(1519)] = 57925,
  [SMALL_STATE(1520)] = 57952,
  [SMALL_STATE(1521)] = 57979,
  [SMALL_STATE(1522)] = 58006,
  [SMALL_STATE(1523)] = 58023,
  [SMALL_STATE(1524)] = 58038,
  [SMALL_STATE(1525)] = 58065,
  [SMALL_STATE(1526)] = 58080,
  [SMALL_STATE(1527)] = 58107,
  [SMALL_STATE(1528)] = 58126,
  [SMALL_STATE(1529)] = 58153,
  [SMALL_STATE(1530)] = 58180,
  [SMALL_STATE(1531)] = 58199,
  [SMALL_STATE(1532)] = 58218,
  [SMALL_STATE(1533)] = 58245,
  [SMALL_STATE(1534)] = 58264,
  [SMALL_STATE(1535)] = 58291,
  [SMALL_STATE(1536)] = 58310,
  [SMALL_STATE(1537)] = 58337,
  [SMALL_STATE(1538)] = 58364,
  [SMALL_STATE(1539)] = 58391,
  [SMALL_STATE(1540)] = 58416,
  [SMALL_STATE(1541)] = 58443,
  [SMALL_STATE(1542)] = 58462,
  [SMALL_STATE(1543)] = 58489,
  [SMALL_STATE(1544)] = 58516,
  [SMALL_STATE(1545)] = 58543,
  [SMALL_STATE(1546)] = 58562,
  [SMALL_STATE(1547)] = 58577,
  [SMALL_STATE(1548)] = 58596,
  [SMALL_STATE(1549)] = 58623,
  [SMALL_STATE(1550)] = 58650,
  [SMALL_STATE(1551)] = 58667,
  [SMALL_STATE(1552)] = 58694,
  [SMALL_STATE(1553)] = 58721,
  [SMALL_STATE(1554)] = 58748,
  [SMALL_STATE(1555)] = 58767,
  [SMALL_STATE(1556)] = 58786,
  [SMALL_STATE(1557)] = 58805,
  [SMALL_STATE(1558)] = 58822,
  [SMALL_STATE(1559)] = 58849,
  [SMALL_STATE(1560)] = 58876,
  [SMALL_STATE(1561)] = 58903,
  [SMALL_STATE(1562)] = 58930,
  [SMALL_STATE(1563)] = 58957,
  [SMALL_STATE(1564)] = 58984,
  [SMALL_STATE(1565)] = 59003,
  [SMALL_STATE(1566)] = 59020,
  [SMALL_STATE(1567)] = 59047,
  [SMALL_STATE(1568)] = 59066,
  [SMALL_STATE(1569)] = 59093,
  [SMALL_STATE(1570)] = 59120,
  [SMALL_STATE(1571)] = 59147,
  [SMALL_STATE(1572)] = 59174,
  [SMALL_STATE(1573)] = 59201,
  [SMALL_STATE(1574)] = 59220,
  [SMALL_STATE(1575)] = 59245,
  [SMALL_STATE(1576)] = 59272,
  [SMALL_STATE(1577)] = 59287,
  [SMALL_STATE(1578)] = 59314,
  [SMALL_STATE(1579)] = 59341,
  [SMALL_STATE(1580)] = 59368,
  [SMALL_STATE(1581)] = 59387,
  [SMALL_STATE(1582)] = 59406,
  [SMALL_STATE(1583)] = 59421,
  [SMALL_STATE(1584)] = 59448,
  [SMALL_STATE(1585)] = 59463,
  [SMALL_STATE(1586)] = 59482,
  [SMALL_STATE(1587)] = 59501,
  [SMALL_STATE(1588)] = 59518,
  [SMALL_STATE(1589)] = 59545,
  [SMALL_STATE(1590)] = 59560,
  [SMALL_STATE(1591)] = 59587,
  [SMALL_STATE(1592)] = 59602,
  [SMALL_STATE(1593)] = 59629,
  [SMALL_STATE(1594)] = 59656,
  [SMALL_STATE(1595)] = 59683,
  [SMALL_STATE(1596)] = 59710,
  [SMALL_STATE(1597)] = 59729,
  [SMALL_STATE(1598)] = 59754,
  [SMALL_STATE(1599)] = 59781,
  [SMALL_STATE(1600)] = 59808,
  [SMALL_STATE(1601)] = 59827,
  [SMALL_STATE(1602)] = 59846,
  [SMALL_STATE(1603)] = 59871,
  [SMALL_STATE(1604)] = 59898,
  [SMALL_STATE(1605)] = 59925,
  [SMALL_STATE(1606)] = 59944,
  [SMALL_STATE(1607)] = 59963,
  [SMALL_STATE(1608)] = 59990,
  [SMALL_STATE(1609)] = 60017,
  [SMALL_STATE(1610)] = 60044,
  [SMALL_STATE(1611)] = 60070,
  [SMALL_STATE(1612)] = 60096,
  [SMALL_STATE(1613)] = 60118,
  [SMALL_STATE(1614)] = 60132,
  [SMALL_STATE(1615)] = 60158,
  [SMALL_STATE(1616)] = 60180,
  [SMALL_STATE(1617)] = 60202,
  [SMALL_STATE(1618)] = 60224,
  [SMALL_STATE(1619)] = 60246,
  [SMALL_STATE(1620)] = 60260,
  [SMALL_STATE(1621)] = 60282,
  [SMALL_STATE(1622)] = 60296,
  [SMALL_STATE(1623)] = 60318,
  [SMALL_STATE(1624)] = 60332,
  [SMALL_STATE(1625)] = 60354,
  [SMALL_STATE(1626)] = 60376,
  [SMALL_STATE(1627)] = 60390,
  [SMALL_STATE(1628)] = 60404,
  [SMALL_STATE(1629)] = 60418,
  [SMALL_STATE(1630)] = 60432,
  [SMALL_STATE(1631)] = 60458,
  [SMALL_STATE(1632)] = 60480,
  [SMALL_STATE(1633)] = 60494,
  [SMALL_STATE(1634)] = 60516,
  [SMALL_STATE(1635)] = 60530,
  [SMALL_STATE(1636)] = 60544,
  [SMALL_STATE(1637)] = 60564,
  [SMALL_STATE(1638)] = 60578,
  [SMALL_STATE(1639)] = 60598,
  [SMALL_STATE(1640)] = 60618,
  [SMALL_STATE(1641)] = 60640,
  [SMALL_STATE(1642)] = 60662,
  [SMALL_STATE(1643)] = 60684,
  [SMALL_STATE(1644)] = 60710,
  [SMALL_STATE(1645)] = 60732,
  [SMALL_STATE(1646)] = 60758,
  [SMALL_STATE(1647)] = 60780,
  [SMALL_STATE(1648)] = 60802,
  [SMALL_STATE(1649)] = 60824,
  [SMALL_STATE(1650)] = 60838,
  [SMALL_STATE(1651)] = 60852,
  [SMALL_STATE(1652)] = 60874,
  [SMALL_STATE(1653)] = 60888,
  [SMALL_STATE(1654)] = 60902,
  [SMALL_STATE(1655)] = 60924,
  [SMALL_STATE(1656)] = 60946,
  [SMALL_STATE(1657)] = 60968,
  [SMALL_STATE(1658)] = 60986,
  [SMALL_STATE(1659)] = 61004,
  [SMALL_STATE(1660)] = 61024,
  [SMALL_STATE(1661)] = 61038,
  [SMALL_STATE(1662)] = 61064,
  [SMALL_STATE(1663)] = 61086,
  [SMALL_STATE(1664)] = 61100,
  [SMALL_STATE(1665)] = 61122,
  [SMALL_STATE(1666)] = 61140,
  [SMALL_STATE(1667)] = 61158,
  [SMALL_STATE(1668)] = 61184,
  [SMALL_STATE(1669)] = 61202,
  [SMALL_STATE(1670)] = 61216,
  [SMALL_STATE(1671)] = 61234,
  [SMALL_STATE(1672)] = 61248,
  [SMALL_STATE(1673)] = 61274,
  [SMALL_STATE(1674)] = 61292,
  [SMALL_STATE(1675)] = 61318,
  [SMALL_STATE(1676)] = 61332,
  [SMALL_STATE(1677)] = 61354,
  [SMALL_STATE(1678)] = 61372,
  [SMALL_STATE(1679)] = 61394,
  [SMALL_STATE(1680)] = 61416,
  [SMALL_STATE(1681)] = 61438,
  [SMALL_STATE(1682)] = 61464,
  [SMALL_STATE(1683)] = 61490,
  [SMALL_STATE(1684)] = 61512,
  [SMALL_STATE(1685)] = 61534,
  [SMALL_STATE(1686)] = 61556,
  [SMALL_STATE(1687)] = 61578,
  [SMALL_STATE(1688)] = 61600,
  [SMALL_STATE(1689)] = 61622,
  [SMALL_STATE(1690)] = 61644,
  [SMALL_STATE(1691)] = 61666,
  [SMALL_STATE(1692)] = 61680,
  [SMALL_STATE(1693)] = 61698,
  [SMALL_STATE(1694)] = 61716,
  [SMALL_STATE(1695)] = 61742,
  [SMALL_STATE(1696)] = 61768,
  [SMALL_STATE(1697)] = 61782,
  [SMALL_STATE(1698)] = 61800,
  [SMALL_STATE(1699)] = 61818,
  [SMALL_STATE(1700)] = 61844,
  [SMALL_STATE(1701)] = 61870,
  [SMALL_STATE(1702)] = 61890,
  [SMALL_STATE(1703)] = 61911,
  [SMALL_STATE(1704)] = 61932,
  [SMALL_STATE(1705)] = 61953,
  [SMALL_STATE(1706)] = 61966,
  [SMALL_STATE(1707)] = 61985,
  [SMALL_STATE(1708)] = 61998,
  [SMALL_STATE(1709)] = 62011,
  [SMALL_STATE(1710)] = 62030,
  [SMALL_STATE(1711)] = 62049,
  [SMALL_STATE(1712)] = 62062,
  [SMALL_STATE(1713)] = 62085,
  [SMALL_STATE(1714)] = 62106,
  [SMALL_STATE(1715)] = 62119,
  [SMALL_STATE(1716)] = 62138,
  [SMALL_STATE(1717)] = 62157,
  [SMALL_STATE(1718)] = 62176,
  [SMALL_STATE(1719)] = 62195,
  [SMALL_STATE(1720)] = 62212,
  [SMALL_STATE(1721)] = 62229,
  [SMALL_STATE(1722)] = 62248,
  [SMALL_STATE(1723)] = 62261,
  [SMALL_STATE(1724)] = 62280,
  [SMALL_STATE(1725)] = 62299,
  [SMALL_STATE(1726)] = 62318,
  [SMALL_STATE(1727)] = 62339,
  [SMALL_STATE(1728)] = 62360,
  [SMALL_STATE(1729)] = 62381,
  [SMALL_STATE(1730)] = 62402,
  [SMALL_STATE(1731)] = 62423,
  [SMALL_STATE(1732)] = 62444,
  [SMALL_STATE(1733)] = 62465,
  [SMALL_STATE(1734)] = 62484,
  [SMALL_STATE(1735)] = 62501,
  [SMALL_STATE(1736)] = 62518,
  [SMALL_STATE(1737)] = 62535,
  [SMALL_STATE(1738)] = 62554,
  [SMALL_STATE(1739)] = 62573,
  [SMALL_STATE(1740)] = 62594,
  [SMALL_STATE(1741)] = 62615,
  [SMALL_STATE(1742)] = 62634,
  [SMALL_STATE(1743)] = 62651,
  [SMALL_STATE(1744)] = 62672,
  [SMALL_STATE(1745)] = 62689,
  [SMALL_STATE(1746)] = 62702,
  [SMALL_STATE(1747)] = 62719,
  [SMALL_STATE(1748)] = 62740,
  [SMALL_STATE(1749)] = 62761,
  [SMALL_STATE(1750)] = 62778,
  [SMALL_STATE(1751)] = 62795,
  [SMALL_STATE(1752)] = 62812,
  [SMALL_STATE(1753)] = 62825,
  [SMALL_STATE(1754)] = 62844,
  [SMALL_STATE(1755)] = 62861,
  [SMALL_STATE(1756)] = 62874,
  [SMALL_STATE(1757)] = 62891,
  [SMALL_STATE(1758)] = 62904,
  [SMALL_STATE(1759)] = 62925,
  [SMALL_STATE(1760)] = 62946,
  [SMALL_STATE(1761)] = 62967,
  [SMALL_STATE(1762)] = 62986,
  [SMALL_STATE(1763)] = 62999,
  [SMALL_STATE(1764)] = 63020,
  [SMALL_STATE(1765)] = 63039,
  [SMALL_STATE(1766)] = 63060,
  [SMALL_STATE(1767)] = 63083,
  [SMALL_STATE(1768)] = 63104,
  [SMALL_STATE(1769)] = 63125,
  [SMALL_STATE(1770)] = 63144,
  [SMALL_STATE(1771)] = 63161,
  [SMALL_STATE(1772)] = 63178,
  [SMALL_STATE(1773)] = 63195,
  [SMALL_STATE(1774)] = 63212,
  [SMALL_STATE(1775)] = 63229,
  [SMALL_STATE(1776)] = 63246,
  [SMALL_STATE(1777)] = 63263,
  [SMALL_STATE(1778)] = 63280,
  [SMALL_STATE(1779)] = 63299,
  [SMALL_STATE(1780)] = 63318,
  [SMALL_STATE(1781)] = 63335,
  [SMALL_STATE(1782)] = 63348,
  [SMALL_STATE(1783)] = 63364,
  [SMALL_STATE(1784)] = 63380,
  [SMALL_STATE(1785)] = 63396,
  [SMALL_STATE(1786)] = 63412,
  [SMALL_STATE(1787)] = 63434,
  [SMALL_STATE(1788)] = 63450,
  [SMALL_STATE(1789)] = 63466,
  [SMALL_STATE(1790)] = 63482,
  [SMALL_STATE(1791)] = 63498,
  [SMALL_STATE(1792)] = 63514,
  [SMALL_STATE(1793)] = 63530,
  [SMALL_STATE(1794)] = 63546,
  [SMALL_STATE(1795)] = 63562,
  [SMALL_STATE(1796)] = 63584,
  [SMALL_STATE(1797)] = 63600,
  [SMALL_STATE(1798)] = 63616,
  [SMALL_STATE(1799)] = 63632,
  [SMALL_STATE(1800)] = 63654,
  [SMALL_STATE(1801)] = 63670,
  [SMALL_STATE(1802)] = 63686,
  [SMALL_STATE(1803)] = 63708,
  [SMALL_STATE(1804)] = 63724,
  [SMALL_STATE(1805)] = 63740,
  [SMALL_STATE(1806)] = 63756,
  [SMALL_STATE(1807)] = 63772,
  [SMALL_STATE(1808)] = 63788,
  [SMALL_STATE(1809)] = 63804,
  [SMALL_STATE(1810)] = 63820,
  [SMALL_STATE(1811)] = 63836,
  [SMALL_STATE(1812)] = 63856,
  [SMALL_STATE(1813)] = 63872,
  [SMALL_STATE(1814)] = 63888,
  [SMALL_STATE(1815)] = 63908,
  [SMALL_STATE(1816)] = 63924,
  [SMALL_STATE(1817)] = 63940,
  [SMALL_STATE(1818)] = 63956,
  [SMALL_STATE(1819)] = 63976,
  [SMALL_STATE(1820)] = 63992,
  [SMALL_STATE(1821)] = 64012,
  [SMALL_STATE(1822)] = 64032,
  [SMALL_STATE(1823)] = 64048,
  [SMALL_STATE(1824)] = 64064,
  [SMALL_STATE(1825)] = 64084,
  [SMALL_STATE(1826)] = 64100,
  [SMALL_STATE(1827)] = 64116,
  [SMALL_STATE(1828)] = 64132,
  [SMALL_STATE(1829)] = 64148,
  [SMALL_STATE(1830)] = 64168,
  [SMALL_STATE(1831)] = 64184,
  [SMALL_STATE(1832)] = 64200,
  [SMALL_STATE(1833)] = 64216,
  [SMALL_STATE(1834)] = 64232,
  [SMALL_STATE(1835)] = 64248,
  [SMALL_STATE(1836)] = 64264,
  [SMALL_STATE(1837)] = 64280,
  [SMALL_STATE(1838)] = 64296,
  [SMALL_STATE(1839)] = 64316,
  [SMALL_STATE(1840)] = 64328,
  [SMALL_STATE(1841)] = 64344,
  [SMALL_STATE(1842)] = 64360,
  [SMALL_STATE(1843)] = 64376,
  [SMALL_STATE(1844)] = 64392,
  [SMALL_STATE(1845)] = 64408,
  [SMALL_STATE(1846)] = 64424,
  [SMALL_STATE(1847)] = 64440,
  [SMALL_STATE(1848)] = 64462,
  [SMALL_STATE(1849)] = 64474,
  [SMALL_STATE(1850)] = 64490,
  [SMALL_STATE(1851)] = 64506,
  [SMALL_STATE(1852)] = 64522,
  [SMALL_STATE(1853)] = 64538,
  [SMALL_STATE(1854)] = 64554,
  [SMALL_STATE(1855)] = 64574,
  [SMALL_STATE(1856)] = 64590,
  [SMALL_STATE(1857)] = 64606,
  [SMALL_STATE(1858)] = 64628,
  [SMALL_STATE(1859)] = 64644,
  [SMALL_STATE(1860)] = 64660,
  [SMALL_STATE(1861)] = 64676,
  [SMALL_STATE(1862)] = 64692,
  [SMALL_STATE(1863)] = 64708,
  [SMALL_STATE(1864)] = 64724,
  [SMALL_STATE(1865)] = 64740,
  [SMALL_STATE(1866)] = 64756,
  [SMALL_STATE(1867)] = 64772,
  [SMALL_STATE(1868)] = 64788,
  [SMALL_STATE(1869)] = 64804,
  [SMALL_STATE(1870)] = 64820,
  [SMALL_STATE(1871)] = 64836,
  [SMALL_STATE(1872)] = 64852,
  [SMALL_STATE(1873)] = 64868,
  [SMALL_STATE(1874)] = 64884,
  [SMALL_STATE(1875)] = 64900,
  [SMALL_STATE(1876)] = 64920,
  [SMALL_STATE(1877)] = 64940,
  [SMALL_STATE(1878)] = 64956,
  [SMALL_STATE(1879)] = 64976,
  [SMALL_STATE(1880)] = 64996,
  [SMALL_STATE(1881)] = 65012,
  [SMALL_STATE(1882)] = 65032,
  [SMALL_STATE(1883)] = 65052,
  [SMALL_STATE(1884)] = 65074,
  [SMALL_STATE(1885)] = 65090,
  [SMALL_STATE(1886)] = 65106,
  [SMALL_STATE(1887)] = 65118,
  [SMALL_STATE(1888)] = 65138,
  [SMALL_STATE(1889)] = 65154,
  [SMALL_STATE(1890)] = 65170,
  [SMALL_STATE(1891)] = 65190,
  [SMALL_STATE(1892)] = 65206,
  [SMALL_STATE(1893)] = 65222,
  [SMALL_STATE(1894)] = 65244,
  [SMALL_STATE(1895)] = 65266,
  [SMALL_STATE(1896)] = 65282,
  [SMALL_STATE(1897)] = 65294,
  [SMALL_STATE(1898)] = 65316,
  [SMALL_STATE(1899)] = 65332,
  [SMALL_STATE(1900)] = 65348,
  [SMALL_STATE(1901)] = 65368,
  [SMALL_STATE(1902)] = 65384,
  [SMALL_STATE(1903)] = 65404,
  [SMALL_STATE(1904)] = 65424,
  [SMALL_STATE(1905)] = 65440,
  [SMALL_STATE(1906)] = 65453,
  [SMALL_STATE(1907)] = 65464,
  [SMALL_STATE(1908)] = 65479,
  [SMALL_STATE(1909)] = 65494,
  [SMALL_STATE(1910)] = 65509,
  [SMALL_STATE(1911)] = 65528,
  [SMALL_STATE(1912)] = 65543,
  [SMALL_STATE(1913)] = 65560,
  [SMALL_STATE(1914)] = 65579,
  [SMALL_STATE(1915)] = 65598,
  [SMALL_STATE(1916)] = 65613,
  [SMALL_STATE(1917)] = 65628,
  [SMALL_STATE(1918)] = 65643,
  [SMALL_STATE(1919)] = 65654,
  [SMALL_STATE(1920)] = 65669,
  [SMALL_STATE(1921)] = 65684,
  [SMALL_STATE(1922)] = 65703,
  [SMALL_STATE(1923)] = 65722,
  [SMALL_STATE(1924)] = 65741,
  [SMALL_STATE(1925)] = 65756,
  [SMALL_STATE(1926)] = 65771,
  [SMALL_STATE(1927)] = 65790,
  [SMALL_STATE(1928)] = 65809,
  [SMALL_STATE(1929)] = 65822,
  [SMALL_STATE(1930)] = 65837,
  [SMALL_STATE(1931)] = 65850,
  [SMALL_STATE(1932)] = 65863,
  [SMALL_STATE(1933)] = 65876,
  [SMALL_STATE(1934)] = 65895,
  [SMALL_STATE(1935)] = 65910,
  [SMALL_STATE(1936)] = 65925,
  [SMALL_STATE(1937)] = 65944,
  [SMALL_STATE(1938)] = 65963,
  [SMALL_STATE(1939)] = 65974,
  [SMALL_STATE(1940)] = 65989,
  [SMALL_STATE(1941)] = 66008,
  [SMALL_STATE(1942)] = 66023,
  [SMALL_STATE(1943)] = 66038,
  [SMALL_STATE(1944)] = 66051,
  [SMALL_STATE(1945)] = 66070,
  [SMALL_STATE(1946)] = 66085,
  [SMALL_STATE(1947)] = 66100,
  [SMALL_STATE(1948)] = 66113,
  [SMALL_STATE(1949)] = 66132,
  [SMALL_STATE(1950)] = 66148,
  [SMALL_STATE(1951)] = 66164,
  [SMALL_STATE(1952)] = 66174,
  [SMALL_STATE(1953)] = 66190,
  [SMALL_STATE(1954)] = 66200,
  [SMALL_STATE(1955)] = 66216,
  [SMALL_STATE(1956)] = 66232,
  [SMALL_STATE(1957)] = 66242,
  [SMALL_STATE(1958)] = 66256,
  [SMALL_STATE(1959)] = 66270,
  [SMALL_STATE(1960)] = 66284,
  [SMALL_STATE(1961)] = 66294,
  [SMALL_STATE(1962)] = 66304,
  [SMALL_STATE(1963)] = 66320,
  [SMALL_STATE(1964)] = 66336,
  [SMALL_STATE(1965)] = 66352,
  [SMALL_STATE(1966)] = 66362,
  [SMALL_STATE(1967)] = 66372,
  [SMALL_STATE(1968)] = 66384,
  [SMALL_STATE(1969)] = 66394,
  [SMALL_STATE(1970)] = 66404,
  [SMALL_STATE(1971)] = 66414,
  [SMALL_STATE(1972)] = 66430,
  [SMALL_STATE(1973)] = 66444,
  [SMALL_STATE(1974)] = 66454,
  [SMALL_STATE(1975)] = 66468,
  [SMALL_STATE(1976)] = 66478,
  [SMALL_STATE(1977)] = 66488,
  [SMALL_STATE(1978)] = 66498,
  [SMALL_STATE(1979)] = 66508,
  [SMALL_STATE(1980)] = 66518,
  [SMALL_STATE(1981)] = 66528,
  [SMALL_STATE(1982)] = 66544,
  [SMALL_STATE(1983)] = 66558,
  [SMALL_STATE(1984)] = 66572,
  [SMALL_STATE(1985)] = 66582,
  [SMALL_STATE(1986)] = 66596,
  [SMALL_STATE(1987)] = 66606,
  [SMALL_STATE(1988)] = 66616,
  [SMALL_STATE(1989)] = 66626,
  [SMALL_STATE(1990)] = 66636,
  [SMALL_STATE(1991)] = 66646,
  [SMALL_STATE(1992)] = 66660,
  [SMALL_STATE(1993)] = 66674,
  [SMALL_STATE(1994)] = 66684,
  [SMALL_STATE(1995)] = 66694,
  [SMALL_STATE(1996)] = 66704,
  [SMALL_STATE(1997)] = 66714,
  [SMALL_STATE(1998)] = 66724,
  [SMALL_STATE(1999)] = 66738,
  [SMALL_STATE(2000)] = 66752,
  [SMALL_STATE(2001)] = 66766,
  [SMALL_STATE(2002)] = 66776,
  [SMALL_STATE(2003)] = 66788,
  [SMALL_STATE(2004)] = 66802,
  [SMALL_STATE(2005)] = 66812,
  [SMALL_STATE(2006)] = 66822,
  [SMALL_STATE(2007)] = 66836,
  [SMALL_STATE(2008)] = 66850,
  [SMALL_STATE(2009)] = 66860,
  [SMALL_STATE(2010)] = 66874,
  [SMALL_STATE(2011)] = 66890,
  [SMALL_STATE(2012)] = 66900,
  [SMALL_STATE(2013)] = 66914,
  [SMALL_STATE(2014)] = 66930,
  [SMALL_STATE(2015)] = 66940,
  [SMALL_STATE(2016)] = 66954,
  [SMALL_STATE(2017)] = 66964,
  [SMALL_STATE(2018)] = 66980,
  [SMALL_STATE(2019)] = 66996,
  [SMALL_STATE(2020)] = 67006,
  [SMALL_STATE(2021)] = 67022,
  [SMALL_STATE(2022)] = 67038,
  [SMALL_STATE(2023)] = 67052,
  [SMALL_STATE(2024)] = 67062,
  [SMALL_STATE(2025)] = 67072,
  [SMALL_STATE(2026)] = 67082,
  [SMALL_STATE(2027)] = 67092,
  [SMALL_STATE(2028)] = 67102,
  [SMALL_STATE(2029)] = 67118,
  [SMALL_STATE(2030)] = 67128,
  [SMALL_STATE(2031)] = 67144,
  [SMALL_STATE(2032)] = 67154,
  [SMALL_STATE(2033)] = 67164,
  [SMALL_STATE(2034)] = 67174,
  [SMALL_STATE(2035)] = 67184,
  [SMALL_STATE(2036)] = 67194,
  [SMALL_STATE(2037)] = 67210,
  [SMALL_STATE(2038)] = 67226,
  [SMALL_STATE(2039)] = 67236,
  [SMALL_STATE(2040)] = 67252,
  [SMALL_STATE(2041)] = 67266,
  [SMALL_STATE(2042)] = 67276,
  [SMALL_STATE(2043)] = 67286,
  [SMALL_STATE(2044)] = 67300,
  [SMALL_STATE(2045)] = 67316,
  [SMALL_STATE(2046)] = 67326,
  [SMALL_STATE(2047)] = 67338,
  [SMALL_STATE(2048)] = 67348,
  [SMALL_STATE(2049)] = 67358,
  [SMALL_STATE(2050)] = 67368,
  [SMALL_STATE(2051)] = 67378,
  [SMALL_STATE(2052)] = 67388,
  [SMALL_STATE(2053)] = 67398,
  [SMALL_STATE(2054)] = 67408,
  [SMALL_STATE(2055)] = 67418,
  [SMALL_STATE(2056)] = 67434,
  [SMALL_STATE(2057)] = 67448,
  [SMALL_STATE(2058)] = 67458,
  [SMALL_STATE(2059)] = 67468,
  [SMALL_STATE(2060)] = 67482,
  [SMALL_STATE(2061)] = 67492,
  [SMALL_STATE(2062)] = 67502,
  [SMALL_STATE(2063)] = 67516,
  [SMALL_STATE(2064)] = 67526,
  [SMALL_STATE(2065)] = 67536,
  [SMALL_STATE(2066)] = 67550,
  [SMALL_STATE(2067)] = 67566,
  [SMALL_STATE(2068)] = 67578,
  [SMALL_STATE(2069)] = 67588,
  [SMALL_STATE(2070)] = 67604,
  [SMALL_STATE(2071)] = 67614,
  [SMALL_STATE(2072)] = 67628,
  [SMALL_STATE(2073)] = 67644,
  [SMALL_STATE(2074)] = 67658,
  [SMALL_STATE(2075)] = 67672,
  [SMALL_STATE(2076)] = 67686,
  [SMALL_STATE(2077)] = 67700,
  [SMALL_STATE(2078)] = 67714,
  [SMALL_STATE(2079)] = 67724,
  [SMALL_STATE(2080)] = 67734,
  [SMALL_STATE(2081)] = 67744,
  [SMALL_STATE(2082)] = 67754,
  [SMALL_STATE(2083)] = 67766,
  [SMALL_STATE(2084)] = 67776,
  [SMALL_STATE(2085)] = 67786,
  [SMALL_STATE(2086)] = 67796,
  [SMALL_STATE(2087)] = 67806,
  [SMALL_STATE(2088)] = 67818,
  [SMALL_STATE(2089)] = 67828,
  [SMALL_STATE(2090)] = 67838,
  [SMALL_STATE(2091)] = 67848,
  [SMALL_STATE(2092)] = 67860,
  [SMALL_STATE(2093)] = 67872,
  [SMALL_STATE(2094)] = 67882,
  [SMALL_STATE(2095)] = 67892,
  [SMALL_STATE(2096)] = 67902,
  [SMALL_STATE(2097)] = 67912,
  [SMALL_STATE(2098)] = 67922,
  [SMALL_STATE(2099)] = 67938,
  [SMALL_STATE(2100)] = 67948,
  [SMALL_STATE(2101)] = 67958,
  [SMALL_STATE(2102)] = 67968,
  [SMALL_STATE(2103)] = 67984,
  [SMALL_STATE(2104)] = 67994,
  [SMALL_STATE(2105)] = 68004,
  [SMALL_STATE(2106)] = 68014,
  [SMALL_STATE(2107)] = 68024,
  [SMALL_STATE(2108)] = 68034,
  [SMALL_STATE(2109)] = 68044,
  [SMALL_STATE(2110)] = 68054,
  [SMALL_STATE(2111)] = 68064,
  [SMALL_STATE(2112)] = 68074,
  [SMALL_STATE(2113)] = 68088,
  [SMALL_STATE(2114)] = 68098,
  [SMALL_STATE(2115)] = 68108,
  [SMALL_STATE(2116)] = 68118,
  [SMALL_STATE(2117)] = 68134,
  [SMALL_STATE(2118)] = 68150,
  [SMALL_STATE(2119)] = 68160,
  [SMALL_STATE(2120)] = 68170,
  [SMALL_STATE(2121)] = 68180,
  [SMALL_STATE(2122)] = 68196,
  [SMALL_STATE(2123)] = 68206,
  [SMALL_STATE(2124)] = 68216,
  [SMALL_STATE(2125)] = 68226,
  [SMALL_STATE(2126)] = 68236,
  [SMALL_STATE(2127)] = 68246,
  [SMALL_STATE(2128)] = 68262,
  [SMALL_STATE(2129)] = 68276,
  [SMALL_STATE(2130)] = 68286,
  [SMALL_STATE(2131)] = 68296,
  [SMALL_STATE(2132)] = 68306,
  [SMALL_STATE(2133)] = 68316,
  [SMALL_STATE(2134)] = 68326,
  [SMALL_STATE(2135)] = 68336,
  [SMALL_STATE(2136)] = 68346,
  [SMALL_STATE(2137)] = 68356,
  [SMALL_STATE(2138)] = 68370,
  [SMALL_STATE(2139)] = 68380,
  [SMALL_STATE(2140)] = 68390,
  [SMALL_STATE(2141)] = 68406,
  [SMALL_STATE(2142)] = 68420,
  [SMALL_STATE(2143)] = 68434,
  [SMALL_STATE(2144)] = 68450,
  [SMALL_STATE(2145)] = 68466,
  [SMALL_STATE(2146)] = 68476,
  [SMALL_STATE(2147)] = 68492,
  [SMALL_STATE(2148)] = 68502,
  [SMALL_STATE(2149)] = 68512,
  [SMALL_STATE(2150)] = 68526,
  [SMALL_STATE(2151)] = 68536,
  [SMALL_STATE(2152)] = 68550,
  [SMALL_STATE(2153)] = 68560,
  [SMALL_STATE(2154)] = 68570,
  [SMALL_STATE(2155)] = 68584,
  [SMALL_STATE(2156)] = 68598,
  [SMALL_STATE(2157)] = 68612,
  [SMALL_STATE(2158)] = 68622,
  [SMALL_STATE(2159)] = 68638,
  [SMALL_STATE(2160)] = 68654,
  [SMALL_STATE(2161)] = 68664,
  [SMALL_STATE(2162)] = 68680,
  [SMALL_STATE(2163)] = 68690,
  [SMALL_STATE(2164)] = 68706,
  [SMALL_STATE(2165)] = 68720,
  [SMALL_STATE(2166)] = 68732,
  [SMALL_STATE(2167)] = 68748,
  [SMALL_STATE(2168)] = 68760,
  [SMALL_STATE(2169)] = 68774,
  [SMALL_STATE(2170)] = 68784,
  [SMALL_STATE(2171)] = 68798,
  [SMALL_STATE(2172)] = 68808,
  [SMALL_STATE(2173)] = 68822,
  [SMALL_STATE(2174)] = 68836,
  [SMALL_STATE(2175)] = 68846,
  [SMALL_STATE(2176)] = 68860,
  [SMALL_STATE(2177)] = 68872,
  [SMALL_STATE(2178)] = 68882,
  [SMALL_STATE(2179)] = 68892,
  [SMALL_STATE(2180)] = 68902,
  [SMALL_STATE(2181)] = 68914,
  [SMALL_STATE(2182)] = 68924,
  [SMALL_STATE(2183)] = 68938,
  [SMALL_STATE(2184)] = 68948,
  [SMALL_STATE(2185)] = 68958,
  [SMALL_STATE(2186)] = 68974,
  [SMALL_STATE(2187)] = 68990,
  [SMALL_STATE(2188)] = 69000,
  [SMALL_STATE(2189)] = 69010,
  [SMALL_STATE(2190)] = 69022,
  [SMALL_STATE(2191)] = 69036,
  [SMALL_STATE(2192)] = 69052,
  [SMALL_STATE(2193)] = 69062,
  [SMALL_STATE(2194)] = 69075,
  [SMALL_STATE(2195)] = 69088,
  [SMALL_STATE(2196)] = 69101,
  [SMALL_STATE(2197)] = 69114,
  [SMALL_STATE(2198)] = 69127,
  [SMALL_STATE(2199)] = 69136,
  [SMALL_STATE(2200)] = 69149,
  [SMALL_STATE(2201)] = 69162,
  [SMALL_STATE(2202)] = 69175,
  [SMALL_STATE(2203)] = 69188,
  [SMALL_STATE(2204)] = 69201,
  [SMALL_STATE(2205)] = 69214,
  [SMALL_STATE(2206)] = 69227,
  [SMALL_STATE(2207)] = 69240,
  [SMALL_STATE(2208)] = 69253,
  [SMALL_STATE(2209)] = 69266,
  [SMALL_STATE(2210)] = 69279,
  [SMALL_STATE(2211)] = 69290,
  [SMALL_STATE(2212)] = 69303,
  [SMALL_STATE(2213)] = 69316,
  [SMALL_STATE(2214)] = 69329,
  [SMALL_STATE(2215)] = 69342,
  [SMALL_STATE(2216)] = 69355,
  [SMALL_STATE(2217)] = 69368,
  [SMALL_STATE(2218)] = 69377,
  [SMALL_STATE(2219)] = 69390,
  [SMALL_STATE(2220)] = 69399,
  [SMALL_STATE(2221)] = 69412,
  [SMALL_STATE(2222)] = 69425,
  [SMALL_STATE(2223)] = 69438,
  [SMALL_STATE(2224)] = 69451,
  [SMALL_STATE(2225)] = 69460,
  [SMALL_STATE(2226)] = 69473,
  [SMALL_STATE(2227)] = 69486,
  [SMALL_STATE(2228)] = 69495,
  [SMALL_STATE(2229)] = 69508,
  [SMALL_STATE(2230)] = 69521,
  [SMALL_STATE(2231)] = 69534,
  [SMALL_STATE(2232)] = 69547,
  [SMALL_STATE(2233)] = 69560,
  [SMALL_STATE(2234)] = 69573,
  [SMALL_STATE(2235)] = 69586,
  [SMALL_STATE(2236)] = 69599,
  [SMALL_STATE(2237)] = 69612,
  [SMALL_STATE(2238)] = 69625,
  [SMALL_STATE(2239)] = 69638,
  [SMALL_STATE(2240)] = 69651,
  [SMALL_STATE(2241)] = 69664,
  [SMALL_STATE(2242)] = 69677,
  [SMALL_STATE(2243)] = 69690,
  [SMALL_STATE(2244)] = 69703,
  [SMALL_STATE(2245)] = 69716,
  [SMALL_STATE(2246)] = 69729,
  [SMALL_STATE(2247)] = 69742,
  [SMALL_STATE(2248)] = 69751,
  [SMALL_STATE(2249)] = 69764,
  [SMALL_STATE(2250)] = 69777,
  [SMALL_STATE(2251)] = 69786,
  [SMALL_STATE(2252)] = 69799,
  [SMALL_STATE(2253)] = 69812,
  [SMALL_STATE(2254)] = 69825,
  [SMALL_STATE(2255)] = 69838,
  [SMALL_STATE(2256)] = 69851,
  [SMALL_STATE(2257)] = 69864,
  [SMALL_STATE(2258)] = 69877,
  [SMALL_STATE(2259)] = 69890,
  [SMALL_STATE(2260)] = 69903,
  [SMALL_STATE(2261)] = 69916,
  [SMALL_STATE(2262)] = 69929,
  [SMALL_STATE(2263)] = 69942,
  [SMALL_STATE(2264)] = 69955,
  [SMALL_STATE(2265)] = 69968,
  [SMALL_STATE(2266)] = 69977,
  [SMALL_STATE(2267)] = 69990,
  [SMALL_STATE(2268)] = 70003,
  [SMALL_STATE(2269)] = 70016,
  [SMALL_STATE(2270)] = 70029,
  [SMALL_STATE(2271)] = 70042,
  [SMALL_STATE(2272)] = 70055,
  [SMALL_STATE(2273)] = 70068,
  [SMALL_STATE(2274)] = 70081,
  [SMALL_STATE(2275)] = 70094,
  [SMALL_STATE(2276)] = 70107,
  [SMALL_STATE(2277)] = 70120,
  [SMALL_STATE(2278)] = 70133,
  [SMALL_STATE(2279)] = 70146,
  [SMALL_STATE(2280)] = 70159,
  [SMALL_STATE(2281)] = 70168,
  [SMALL_STATE(2282)] = 70181,
  [SMALL_STATE(2283)] = 70194,
  [SMALL_STATE(2284)] = 70207,
  [SMALL_STATE(2285)] = 70216,
  [SMALL_STATE(2286)] = 70229,
  [SMALL_STATE(2287)] = 70242,
  [SMALL_STATE(2288)] = 70255,
  [SMALL_STATE(2289)] = 70268,
  [SMALL_STATE(2290)] = 70281,
  [SMALL_STATE(2291)] = 70294,
  [SMALL_STATE(2292)] = 70305,
  [SMALL_STATE(2293)] = 70318,
  [SMALL_STATE(2294)] = 70331,
  [SMALL_STATE(2295)] = 70340,
  [SMALL_STATE(2296)] = 70353,
  [SMALL_STATE(2297)] = 70366,
  [SMALL_STATE(2298)] = 70379,
  [SMALL_STATE(2299)] = 70392,
  [SMALL_STATE(2300)] = 70405,
  [SMALL_STATE(2301)] = 70418,
  [SMALL_STATE(2302)] = 70431,
  [SMALL_STATE(2303)] = 70444,
  [SMALL_STATE(2304)] = 70457,
  [SMALL_STATE(2305)] = 70470,
  [SMALL_STATE(2306)] = 70483,
  [SMALL_STATE(2307)] = 70496,
  [SMALL_STATE(2308)] = 70509,
  [SMALL_STATE(2309)] = 70522,
  [SMALL_STATE(2310)] = 70535,
  [SMALL_STATE(2311)] = 70546,
  [SMALL_STATE(2312)] = 70559,
  [SMALL_STATE(2313)] = 70572,
  [SMALL_STATE(2314)] = 70585,
  [SMALL_STATE(2315)] = 70598,
  [SMALL_STATE(2316)] = 70611,
  [SMALL_STATE(2317)] = 70620,
  [SMALL_STATE(2318)] = 70633,
  [SMALL_STATE(2319)] = 70646,
  [SMALL_STATE(2320)] = 70659,
  [SMALL_STATE(2321)] = 70672,
  [SMALL_STATE(2322)] = 70685,
  [SMALL_STATE(2323)] = 70698,
  [SMALL_STATE(2324)] = 70711,
  [SMALL_STATE(2325)] = 70724,
  [SMALL_STATE(2326)] = 70737,
  [SMALL_STATE(2327)] = 70750,
  [SMALL_STATE(2328)] = 70763,
  [SMALL_STATE(2329)] = 70776,
  [SMALL_STATE(2330)] = 70789,
  [SMALL_STATE(2331)] = 70802,
  [SMALL_STATE(2332)] = 70815,
  [SMALL_STATE(2333)] = 70828,
  [SMALL_STATE(2334)] = 70841,
  [SMALL_STATE(2335)] = 70854,
  [SMALL_STATE(2336)] = 70867,
  [SMALL_STATE(2337)] = 70880,
  [SMALL_STATE(2338)] = 70893,
  [SMALL_STATE(2339)] = 70906,
  [SMALL_STATE(2340)] = 70917,
  [SMALL_STATE(2341)] = 70930,
  [SMALL_STATE(2342)] = 70943,
  [SMALL_STATE(2343)] = 70956,
  [SMALL_STATE(2344)] = 70969,
  [SMALL_STATE(2345)] = 70982,
  [SMALL_STATE(2346)] = 70995,
  [SMALL_STATE(2347)] = 71008,
  [SMALL_STATE(2348)] = 71021,
  [SMALL_STATE(2349)] = 71034,
  [SMALL_STATE(2350)] = 71047,
  [SMALL_STATE(2351)] = 71060,
  [SMALL_STATE(2352)] = 71073,
  [SMALL_STATE(2353)] = 71086,
  [SMALL_STATE(2354)] = 71099,
  [SMALL_STATE(2355)] = 71112,
  [SMALL_STATE(2356)] = 71125,
  [SMALL_STATE(2357)] = 71138,
  [SMALL_STATE(2358)] = 71151,
  [SMALL_STATE(2359)] = 71164,
  [SMALL_STATE(2360)] = 71177,
  [SMALL_STATE(2361)] = 71190,
  [SMALL_STATE(2362)] = 71203,
  [SMALL_STATE(2363)] = 71216,
  [SMALL_STATE(2364)] = 71224,
  [SMALL_STATE(2365)] = 71234,
  [SMALL_STATE(2366)] = 71244,
  [SMALL_STATE(2367)] = 71254,
  [SMALL_STATE(2368)] = 71264,
  [SMALL_STATE(2369)] = 71274,
  [SMALL_STATE(2370)] = 71284,
  [SMALL_STATE(2371)] = 71294,
  [SMALL_STATE(2372)] = 71304,
  [SMALL_STATE(2373)] = 71314,
  [SMALL_STATE(2374)] = 71324,
  [SMALL_STATE(2375)] = 71334,
  [SMALL_STATE(2376)] = 71344,
  [SMALL_STATE(2377)] = 71354,
  [SMALL_STATE(2378)] = 71364,
  [SMALL_STATE(2379)] = 71374,
  [SMALL_STATE(2380)] = 71382,
  [SMALL_STATE(2381)] = 71392,
  [SMALL_STATE(2382)] = 71402,
  [SMALL_STATE(2383)] = 71412,
  [SMALL_STATE(2384)] = 71422,
  [SMALL_STATE(2385)] = 71432,
  [SMALL_STATE(2386)] = 71442,
  [SMALL_STATE(2387)] = 71452,
  [SMALL_STATE(2388)] = 71462,
  [SMALL_STATE(2389)] = 71472,
  [SMALL_STATE(2390)] = 71482,
  [SMALL_STATE(2391)] = 71490,
  [SMALL_STATE(2392)] = 71500,
  [SMALL_STATE(2393)] = 71508,
  [SMALL_STATE(2394)] = 71518,
  [SMALL_STATE(2395)] = 71528,
  [SMALL_STATE(2396)] = 71538,
  [SMALL_STATE(2397)] = 71548,
  [SMALL_STATE(2398)] = 71558,
  [SMALL_STATE(2399)] = 71568,
  [SMALL_STATE(2400)] = 71578,
  [SMALL_STATE(2401)] = 71588,
  [SMALL_STATE(2402)] = 71598,
  [SMALL_STATE(2403)] = 71608,
  [SMALL_STATE(2404)] = 71618,
  [SMALL_STATE(2405)] = 71628,
  [SMALL_STATE(2406)] = 71638,
  [SMALL_STATE(2407)] = 71648,
  [SMALL_STATE(2408)] = 71658,
  [SMALL_STATE(2409)] = 71668,
  [SMALL_STATE(2410)] = 71678,
  [SMALL_STATE(2411)] = 71688,
  [SMALL_STATE(2412)] = 71698,
  [SMALL_STATE(2413)] = 71706,
  [SMALL_STATE(2414)] = 71716,
  [SMALL_STATE(2415)] = 71726,
  [SMALL_STATE(2416)] = 71736,
  [SMALL_STATE(2417)] = 71746,
  [SMALL_STATE(2418)] = 71756,
  [SMALL_STATE(2419)] = 71764,
  [SMALL_STATE(2420)] = 71774,
  [SMALL_STATE(2421)] = 71784,
  [SMALL_STATE(2422)] = 71794,
  [SMALL_STATE(2423)] = 71804,
  [SMALL_STATE(2424)] = 71814,
  [SMALL_STATE(2425)] = 71824,
  [SMALL_STATE(2426)] = 71834,
  [SMALL_STATE(2427)] = 71844,
  [SMALL_STATE(2428)] = 71852,
  [SMALL_STATE(2429)] = 71860,
  [SMALL_STATE(2430)] = 71868,
  [SMALL_STATE(2431)] = 71878,
  [SMALL_STATE(2432)] = 71888,
  [SMALL_STATE(2433)] = 71898,
  [SMALL_STATE(2434)] = 71908,
  [SMALL_STATE(2435)] = 71918,
  [SMALL_STATE(2436)] = 71926,
  [SMALL_STATE(2437)] = 71936,
  [SMALL_STATE(2438)] = 71946,
  [SMALL_STATE(2439)] = 71956,
  [SMALL_STATE(2440)] = 71966,
  [SMALL_STATE(2441)] = 71976,
  [SMALL_STATE(2442)] = 71986,
  [SMALL_STATE(2443)] = 71996,
  [SMALL_STATE(2444)] = 72006,
  [SMALL_STATE(2445)] = 72016,
  [SMALL_STATE(2446)] = 72026,
  [SMALL_STATE(2447)] = 72036,
  [SMALL_STATE(2448)] = 72046,
  [SMALL_STATE(2449)] = 72056,
  [SMALL_STATE(2450)] = 72066,
  [SMALL_STATE(2451)] = 72076,
  [SMALL_STATE(2452)] = 72086,
  [SMALL_STATE(2453)] = 72094,
  [SMALL_STATE(2454)] = 72104,
  [SMALL_STATE(2455)] = 72114,
  [SMALL_STATE(2456)] = 72124,
  [SMALL_STATE(2457)] = 72132,
  [SMALL_STATE(2458)] = 72142,
  [SMALL_STATE(2459)] = 72152,
  [SMALL_STATE(2460)] = 72162,
  [SMALL_STATE(2461)] = 72172,
  [SMALL_STATE(2462)] = 72182,
  [SMALL_STATE(2463)] = 72192,
  [SMALL_STATE(2464)] = 72202,
  [SMALL_STATE(2465)] = 72212,
  [SMALL_STATE(2466)] = 72222,
  [SMALL_STATE(2467)] = 72232,
  [SMALL_STATE(2468)] = 72242,
  [SMALL_STATE(2469)] = 72252,
  [SMALL_STATE(2470)] = 72262,
  [SMALL_STATE(2471)] = 72270,
  [SMALL_STATE(2472)] = 72280,
  [SMALL_STATE(2473)] = 72290,
  [SMALL_STATE(2474)] = 72300,
  [SMALL_STATE(2475)] = 72308,
  [SMALL_STATE(2476)] = 72318,
  [SMALL_STATE(2477)] = 72328,
  [SMALL_STATE(2478)] = 72338,
  [SMALL_STATE(2479)] = 72348,
  [SMALL_STATE(2480)] = 72358,
  [SMALL_STATE(2481)] = 72368,
  [SMALL_STATE(2482)] = 72378,
  [SMALL_STATE(2483)] = 72388,
  [SMALL_STATE(2484)] = 72398,
  [SMALL_STATE(2485)] = 72408,
  [SMALL_STATE(2486)] = 72418,
  [SMALL_STATE(2487)] = 72428,
  [SMALL_STATE(2488)] = 72438,
  [SMALL_STATE(2489)] = 72448,
  [SMALL_STATE(2490)] = 72458,
  [SMALL_STATE(2491)] = 72468,
  [SMALL_STATE(2492)] = 72478,
  [SMALL_STATE(2493)] = 72488,
  [SMALL_STATE(2494)] = 72498,
  [SMALL_STATE(2495)] = 72508,
  [SMALL_STATE(2496)] = 72518,
  [SMALL_STATE(2497)] = 72528,
  [SMALL_STATE(2498)] = 72538,
  [SMALL_STATE(2499)] = 72548,
  [SMALL_STATE(2500)] = 72558,
  [SMALL_STATE(2501)] = 72568,
  [SMALL_STATE(2502)] = 72578,
  [SMALL_STATE(2503)] = 72588,
  [SMALL_STATE(2504)] = 72598,
  [SMALL_STATE(2505)] = 72608,
  [SMALL_STATE(2506)] = 72618,
  [SMALL_STATE(2507)] = 72628,
  [SMALL_STATE(2508)] = 72638,
  [SMALL_STATE(2509)] = 72648,
  [SMALL_STATE(2510)] = 72658,
  [SMALL_STATE(2511)] = 72668,
  [SMALL_STATE(2512)] = 72678,
  [SMALL_STATE(2513)] = 72688,
  [SMALL_STATE(2514)] = 72698,
  [SMALL_STATE(2515)] = 72706,
  [SMALL_STATE(2516)] = 72716,
  [SMALL_STATE(2517)] = 72726,
  [SMALL_STATE(2518)] = 72736,
  [SMALL_STATE(2519)] = 72746,
  [SMALL_STATE(2520)] = 72756,
  [SMALL_STATE(2521)] = 72766,
  [SMALL_STATE(2522)] = 72776,
  [SMALL_STATE(2523)] = 72786,
  [SMALL_STATE(2524)] = 72796,
  [SMALL_STATE(2525)] = 72806,
  [SMALL_STATE(2526)] = 72816,
  [SMALL_STATE(2527)] = 72826,
  [SMALL_STATE(2528)] = 72836,
  [SMALL_STATE(2529)] = 72846,
  [SMALL_STATE(2530)] = 72856,
  [SMALL_STATE(2531)] = 72866,
  [SMALL_STATE(2532)] = 72876,
  [SMALL_STATE(2533)] = 72886,
  [SMALL_STATE(2534)] = 72896,
  [SMALL_STATE(2535)] = 72906,
  [SMALL_STATE(2536)] = 72916,
  [SMALL_STATE(2537)] = 72926,
  [SMALL_STATE(2538)] = 72936,
  [SMALL_STATE(2539)] = 72946,
  [SMALL_STATE(2540)] = 72956,
  [SMALL_STATE(2541)] = 72966,
  [SMALL_STATE(2542)] = 72976,
  [SMALL_STATE(2543)] = 72986,
  [SMALL_STATE(2544)] = 72996,
  [SMALL_STATE(2545)] = 73006,
  [SMALL_STATE(2546)] = 73016,
  [SMALL_STATE(2547)] = 73024,
  [SMALL_STATE(2548)] = 73034,
  [SMALL_STATE(2549)] = 73044,
  [SMALL_STATE(2550)] = 73054,
  [SMALL_STATE(2551)] = 73062,
  [SMALL_STATE(2552)] = 73072,
  [SMALL_STATE(2553)] = 73080,
  [SMALL_STATE(2554)] = 73090,
  [SMALL_STATE(2555)] = 73100,
  [SMALL_STATE(2556)] = 73110,
  [SMALL_STATE(2557)] = 73120,
  [SMALL_STATE(2558)] = 73130,
  [SMALL_STATE(2559)] = 73140,
  [SMALL_STATE(2560)] = 73150,
  [SMALL_STATE(2561)] = 73160,
  [SMALL_STATE(2562)] = 73170,
  [SMALL_STATE(2563)] = 73180,
  [SMALL_STATE(2564)] = 73190,
  [SMALL_STATE(2565)] = 73200,
  [SMALL_STATE(2566)] = 73210,
  [SMALL_STATE(2567)] = 73220,
  [SMALL_STATE(2568)] = 73230,
  [SMALL_STATE(2569)] = 73240,
  [SMALL_STATE(2570)] = 73250,
  [SMALL_STATE(2571)] = 73260,
  [SMALL_STATE(2572)] = 73270,
  [SMALL_STATE(2573)] = 73280,
  [SMALL_STATE(2574)] = 73290,
  [SMALL_STATE(2575)] = 73300,
  [SMALL_STATE(2576)] = 73310,
  [SMALL_STATE(2577)] = 73320,
  [SMALL_STATE(2578)] = 73330,
  [SMALL_STATE(2579)] = 73340,
  [SMALL_STATE(2580)] = 73350,
  [SMALL_STATE(2581)] = 73360,
  [SMALL_STATE(2582)] = 73370,
  [SMALL_STATE(2583)] = 73380,
  [SMALL_STATE(2584)] = 73390,
  [SMALL_STATE(2585)] = 73400,
  [SMALL_STATE(2586)] = 73410,
  [SMALL_STATE(2587)] = 73420,
  [SMALL_STATE(2588)] = 73430,
  [SMALL_STATE(2589)] = 73440,
  [SMALL_STATE(2590)] = 73450,
  [SMALL_STATE(2591)] = 73458,
  [SMALL_STATE(2592)] = 73465,
  [SMALL_STATE(2593)] = 73472,
  [SMALL_STATE(2594)] = 73479,
  [SMALL_STATE(2595)] = 73486,
  [SMALL_STATE(2596)] = 73493,
  [SMALL_STATE(2597)] = 73500,
  [SMALL_STATE(2598)] = 73507,
  [SMALL_STATE(2599)] = 73514,
  [SMALL_STATE(2600)] = 73521,
  [SMALL_STATE(2601)] = 73528,
  [SMALL_STATE(2602)] = 73535,
  [SMALL_STATE(2603)] = 73542,
  [SMALL_STATE(2604)] = 73549,
  [SMALL_STATE(2605)] = 73556,
  [SMALL_STATE(2606)] = 73563,
  [SMALL_STATE(2607)] = 73570,
  [SMALL_STATE(2608)] = 73577,
  [SMALL_STATE(2609)] = 73584,
  [SMALL_STATE(2610)] = 73591,
  [SMALL_STATE(2611)] = 73598,
  [SMALL_STATE(2612)] = 73605,
  [SMALL_STATE(2613)] = 73612,
  [SMALL_STATE(2614)] = 73619,
  [SMALL_STATE(2615)] = 73626,
  [SMALL_STATE(2616)] = 73633,
  [SMALL_STATE(2617)] = 73640,
  [SMALL_STATE(2618)] = 73647,
  [SMALL_STATE(2619)] = 73654,
  [SMALL_STATE(2620)] = 73661,
  [SMALL_STATE(2621)] = 73668,
  [SMALL_STATE(2622)] = 73675,
  [SMALL_STATE(2623)] = 73682,
  [SMALL_STATE(2624)] = 73689,
  [SMALL_STATE(2625)] = 73696,
  [SMALL_STATE(2626)] = 73703,
  [SMALL_STATE(2627)] = 73710,
  [SMALL_STATE(2628)] = 73717,
  [SMALL_STATE(2629)] = 73724,
  [SMALL_STATE(2630)] = 73731,
  [SMALL_STATE(2631)] = 73738,
  [SMALL_STATE(2632)] = 73745,
  [SMALL_STATE(2633)] = 73752,
  [SMALL_STATE(2634)] = 73759,
  [SMALL_STATE(2635)] = 73766,
  [SMALL_STATE(2636)] = 73773,
  [SMALL_STATE(2637)] = 73780,
  [SMALL_STATE(2638)] = 73787,
  [SMALL_STATE(2639)] = 73794,
  [SMALL_STATE(2640)] = 73801,
  [SMALL_STATE(2641)] = 73808,
  [SMALL_STATE(2642)] = 73815,
  [SMALL_STATE(2643)] = 73822,
  [SMALL_STATE(2644)] = 73829,
  [SMALL_STATE(2645)] = 73836,
  [SMALL_STATE(2646)] = 73843,
  [SMALL_STATE(2647)] = 73850,
  [SMALL_STATE(2648)] = 73857,
  [SMALL_STATE(2649)] = 73864,
  [SMALL_STATE(2650)] = 73871,
  [SMALL_STATE(2651)] = 73878,
  [SMALL_STATE(2652)] = 73885,
  [SMALL_STATE(2653)] = 73892,
  [SMALL_STATE(2654)] = 73899,
  [SMALL_STATE(2655)] = 73906,
  [SMALL_STATE(2656)] = 73913,
  [SMALL_STATE(2657)] = 73920,
  [SMALL_STATE(2658)] = 73927,
  [SMALL_STATE(2659)] = 73934,
  [SMALL_STATE(2660)] = 73941,
  [SMALL_STATE(2661)] = 73948,
  [SMALL_STATE(2662)] = 73955,
  [SMALL_STATE(2663)] = 73962,
  [SMALL_STATE(2664)] = 73969,
  [SMALL_STATE(2665)] = 73976,
  [SMALL_STATE(2666)] = 73983,
  [SMALL_STATE(2667)] = 73990,
  [SMALL_STATE(2668)] = 73997,
  [SMALL_STATE(2669)] = 74004,
  [SMALL_STATE(2670)] = 74011,
  [SMALL_STATE(2671)] = 74018,
  [SMALL_STATE(2672)] = 74025,
  [SMALL_STATE(2673)] = 74032,
  [SMALL_STATE(2674)] = 74039,
  [SMALL_STATE(2675)] = 74046,
  [SMALL_STATE(2676)] = 74053,
  [SMALL_STATE(2677)] = 74060,
  [SMALL_STATE(2678)] = 74067,
  [SMALL_STATE(2679)] = 74074,
  [SMALL_STATE(2680)] = 74081,
  [SMALL_STATE(2681)] = 74088,
  [SMALL_STATE(2682)] = 74095,
  [SMALL_STATE(2683)] = 74102,
  [SMALL_STATE(2684)] = 74109,
  [SMALL_STATE(2685)] = 74116,
  [SMALL_STATE(2686)] = 74123,
  [SMALL_STATE(2687)] = 74130,
  [SMALL_STATE(2688)] = 74137,
  [SMALL_STATE(2689)] = 74144,
  [SMALL_STATE(2690)] = 74151,
  [SMALL_STATE(2691)] = 74158,
  [SMALL_STATE(2692)] = 74165,
  [SMALL_STATE(2693)] = 74172,
  [SMALL_STATE(2694)] = 74179,
  [SMALL_STATE(2695)] = 74186,
  [SMALL_STATE(2696)] = 74193,
  [SMALL_STATE(2697)] = 74200,
  [SMALL_STATE(2698)] = 74207,
  [SMALL_STATE(2699)] = 74214,
  [SMALL_STATE(2700)] = 74221,
  [SMALL_STATE(2701)] = 74228,
  [SMALL_STATE(2702)] = 74235,
  [SMALL_STATE(2703)] = 74242,
  [SMALL_STATE(2704)] = 74249,
  [SMALL_STATE(2705)] = 74256,
  [SMALL_STATE(2706)] = 74263,
  [SMALL_STATE(2707)] = 74270,
  [SMALL_STATE(2708)] = 74277,
  [SMALL_STATE(2709)] = 74284,
  [SMALL_STATE(2710)] = 74291,
  [SMALL_STATE(2711)] = 74298,
  [SMALL_STATE(2712)] = 74305,
  [SMALL_STATE(2713)] = 74312,
  [SMALL_STATE(2714)] = 74319,
  [SMALL_STATE(2715)] = 74326,
  [SMALL_STATE(2716)] = 74333,
  [SMALL_STATE(2717)] = 74340,
  [SMALL_STATE(2718)] = 74347,
  [SMALL_STATE(2719)] = 74354,
  [SMALL_STATE(2720)] = 74361,
  [SMALL_STATE(2721)] = 74368,
  [SMALL_STATE(2722)] = 74375,
  [SMALL_STATE(2723)] = 74382,
  [SMALL_STATE(2724)] = 74389,
  [SMALL_STATE(2725)] = 74396,
  [SMALL_STATE(2726)] = 74403,
  [SMALL_STATE(2727)] = 74410,
  [SMALL_STATE(2728)] = 74417,
  [SMALL_STATE(2729)] = 74424,
  [SMALL_STATE(2730)] = 74431,
  [SMALL_STATE(2731)] = 74438,
  [SMALL_STATE(2732)] = 74445,
  [SMALL_STATE(2733)] = 74452,
  [SMALL_STATE(2734)] = 74459,
  [SMALL_STATE(2735)] = 74466,
  [SMALL_STATE(2736)] = 74473,
  [SMALL_STATE(2737)] = 74480,
  [SMALL_STATE(2738)] = 74487,
  [SMALL_STATE(2739)] = 74494,
  [SMALL_STATE(2740)] = 74501,
  [SMALL_STATE(2741)] = 74508,
  [SMALL_STATE(2742)] = 74515,
  [SMALL_STATE(2743)] = 74522,
  [SMALL_STATE(2744)] = 74529,
  [SMALL_STATE(2745)] = 74536,
  [SMALL_STATE(2746)] = 74543,
  [SMALL_STATE(2747)] = 74550,
  [SMALL_STATE(2748)] = 74557,
  [SMALL_STATE(2749)] = 74564,
  [SMALL_STATE(2750)] = 74571,
  [SMALL_STATE(2751)] = 74578,
  [SMALL_STATE(2752)] = 74585,
  [SMALL_STATE(2753)] = 74592,
  [SMALL_STATE(2754)] = 74599,
  [SMALL_STATE(2755)] = 74606,
  [SMALL_STATE(2756)] = 74613,
  [SMALL_STATE(2757)] = 74620,
  [SMALL_STATE(2758)] = 74627,
  [SMALL_STATE(2759)] = 74634,
  [SMALL_STATE(2760)] = 74641,
  [SMALL_STATE(2761)] = 74648,
  [SMALL_STATE(2762)] = 74655,
  [SMALL_STATE(2763)] = 74662,
  [SMALL_STATE(2764)] = 74669,
  [SMALL_STATE(2765)] = 74676,
  [SMALL_STATE(2766)] = 74683,
  [SMALL_STATE(2767)] = 74690,
  [SMALL_STATE(2768)] = 74697,
  [SMALL_STATE(2769)] = 74704,
  [SMALL_STATE(2770)] = 74711,
  [SMALL_STATE(2771)] = 74718,
  [SMALL_STATE(2772)] = 74725,
  [SMALL_STATE(2773)] = 74732,
  [SMALL_STATE(2774)] = 74739,
  [SMALL_STATE(2775)] = 74746,
  [SMALL_STATE(2776)] = 74753,
  [SMALL_STATE(2777)] = 74760,
  [SMALL_STATE(2778)] = 74767,
  [SMALL_STATE(2779)] = 74774,
  [SMALL_STATE(2780)] = 74781,
  [SMALL_STATE(2781)] = 74788,
  [SMALL_STATE(2782)] = 74795,
  [SMALL_STATE(2783)] = 74802,
  [SMALL_STATE(2784)] = 74809,
  [SMALL_STATE(2785)] = 74816,
  [SMALL_STATE(2786)] = 74823,
  [SMALL_STATE(2787)] = 74830,
  [SMALL_STATE(2788)] = 74837,
  [SMALL_STATE(2789)] = 74844,
  [SMALL_STATE(2790)] = 74851,
  [SMALL_STATE(2791)] = 74858,
  [SMALL_STATE(2792)] = 74865,
  [SMALL_STATE(2793)] = 74872,
  [SMALL_STATE(2794)] = 74879,
  [SMALL_STATE(2795)] = 74886,
  [SMALL_STATE(2796)] = 74893,
  [SMALL_STATE(2797)] = 74900,
  [SMALL_STATE(2798)] = 74907,
  [SMALL_STATE(2799)] = 74914,
  [SMALL_STATE(2800)] = 74921,
  [SMALL_STATE(2801)] = 74928,
  [SMALL_STATE(2802)] = 74935,
  [SMALL_STATE(2803)] = 74942,
  [SMALL_STATE(2804)] = 74949,
  [SMALL_STATE(2805)] = 74956,
  [SMALL_STATE(2806)] = 74963,
  [SMALL_STATE(2807)] = 74970,
  [SMALL_STATE(2808)] = 74977,
  [SMALL_STATE(2809)] = 74984,
  [SMALL_STATE(2810)] = 74991,
  [SMALL_STATE(2811)] = 74998,
  [SMALL_STATE(2812)] = 75005,
  [SMALL_STATE(2813)] = 75012,
  [SMALL_STATE(2814)] = 75019,
  [SMALL_STATE(2815)] = 75026,
  [SMALL_STATE(2816)] = 75033,
  [SMALL_STATE(2817)] = 75040,
  [SMALL_STATE(2818)] = 75047,
  [SMALL_STATE(2819)] = 75054,
  [SMALL_STATE(2820)] = 75061,
  [SMALL_STATE(2821)] = 75068,
  [SMALL_STATE(2822)] = 75075,
  [SMALL_STATE(2823)] = 75082,
  [SMALL_STATE(2824)] = 75089,
  [SMALL_STATE(2825)] = 75096,
  [SMALL_STATE(2826)] = 75103,
  [SMALL_STATE(2827)] = 75110,
  [SMALL_STATE(2828)] = 75117,
  [SMALL_STATE(2829)] = 75124,
  [SMALL_STATE(2830)] = 75131,
  [SMALL_STATE(2831)] = 75138,
  [SMALL_STATE(2832)] = 75145,
  [SMALL_STATE(2833)] = 75152,
  [SMALL_STATE(2834)] = 75159,
  [SMALL_STATE(2835)] = 75166,
  [SMALL_STATE(2836)] = 75173,
  [SMALL_STATE(2837)] = 75180,
  [SMALL_STATE(2838)] = 75187,
  [SMALL_STATE(2839)] = 75194,
  [SMALL_STATE(2840)] = 75201,
  [SMALL_STATE(2841)] = 75208,
  [SMALL_STATE(2842)] = 75215,
  [SMALL_STATE(2843)] = 75222,
  [SMALL_STATE(2844)] = 75229,
  [SMALL_STATE(2845)] = 75236,
  [SMALL_STATE(2846)] = 75243,
  [SMALL_STATE(2847)] = 75250,
  [SMALL_STATE(2848)] = 75257,
  [SMALL_STATE(2849)] = 75264,
  [SMALL_STATE(2850)] = 75271,
  [SMALL_STATE(2851)] = 75278,
  [SMALL_STATE(2852)] = 75285,
  [SMALL_STATE(2853)] = 75292,
  [SMALL_STATE(2854)] = 75299,
  [SMALL_STATE(2855)] = 75306,
  [SMALL_STATE(2856)] = 75313,
  [SMALL_STATE(2857)] = 75320,
  [SMALL_STATE(2858)] = 75327,
  [SMALL_STATE(2859)] = 75334,
  [SMALL_STATE(2860)] = 75341,
  [SMALL_STATE(2861)] = 75348,
  [SMALL_STATE(2862)] = 75355,
  [SMALL_STATE(2863)] = 75362,
  [SMALL_STATE(2864)] = 75369,
  [SMALL_STATE(2865)] = 75376,
  [SMALL_STATE(2866)] = 75383,
  [SMALL_STATE(2867)] = 75390,
  [SMALL_STATE(2868)] = 75397,
  [SMALL_STATE(2869)] = 75404,
  [SMALL_STATE(2870)] = 75411,
  [SMALL_STATE(2871)] = 75418,
  [SMALL_STATE(2872)] = 75425,
  [SMALL_STATE(2873)] = 75432,
  [SMALL_STATE(2874)] = 75439,
  [SMALL_STATE(2875)] = 75446,
  [SMALL_STATE(2876)] = 75453,
  [SMALL_STATE(2877)] = 75460,
  [SMALL_STATE(2878)] = 75467,
  [SMALL_STATE(2879)] = 75474,
  [SMALL_STATE(2880)] = 75481,
  [SMALL_STATE(2881)] = 75488,
  [SMALL_STATE(2882)] = 75495,
  [SMALL_STATE(2883)] = 75502,
  [SMALL_STATE(2884)] = 75509,
  [SMALL_STATE(2885)] = 75516,
  [SMALL_STATE(2886)] = 75523,
  [SMALL_STATE(2887)] = 75530,
  [SMALL_STATE(2888)] = 75537,
  [SMALL_STATE(2889)] = 75544,
  [SMALL_STATE(2890)] = 75551,
  [SMALL_STATE(2891)] = 75558,
  [SMALL_STATE(2892)] = 75565,
  [SMALL_STATE(2893)] = 75572,
  [SMALL_STATE(2894)] = 75579,
  [SMALL_STATE(2895)] = 75586,
  [SMALL_STATE(2896)] = 75593,
  [SMALL_STATE(2897)] = 75600,
  [SMALL_STATE(2898)] = 75607,
  [SMALL_STATE(2899)] = 75614,
  [SMALL_STATE(2900)] = 75621,
  [SMALL_STATE(2901)] = 75628,
  [SMALL_STATE(2902)] = 75635,
  [SMALL_STATE(2903)] = 75642,
  [SMALL_STATE(2904)] = 75649,
  [SMALL_STATE(2905)] = 75656,
  [SMALL_STATE(2906)] = 75663,
  [SMALL_STATE(2907)] = 75670,
  [SMALL_STATE(2908)] = 75677,
  [SMALL_STATE(2909)] = 75684,
  [SMALL_STATE(2910)] = 75691,
  [SMALL_STATE(2911)] = 75698,
  [SMALL_STATE(2912)] = 75705,
  [SMALL_STATE(2913)] = 75712,
  [SMALL_STATE(2914)] = 75719,
  [SMALL_STATE(2915)] = 75726,
  [SMALL_STATE(2916)] = 75733,
  [SMALL_STATE(2917)] = 75740,
  [SMALL_STATE(2918)] = 75747,
  [SMALL_STATE(2919)] = 75754,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2891),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2594),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(978),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(840),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2858),
  [15] = {.entry = {.count = 1, .reusable = false}}, SHIFT(761),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2010),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(886),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1905),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1928),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1306),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2040),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2044),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1352),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(771),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(517),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(796),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2479),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1259),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2651),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2490),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2670),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2139),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2086),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2213),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2822),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2583),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2098),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(54),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [93] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_identifier, 1, 0, 0),
  [95] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_identifier, 1, 0, 0),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2882),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2740),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(768),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2028),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1321),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2009),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(773),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(532),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2487),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2432),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2901),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2385),
  [143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1086),
  [145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(50),
  [149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(58),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(99),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [159] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expressions, 2, 0, 0),
  [161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expressions, 3, 0, 0),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(653),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [173] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_duration, 1, 0, 0),
  [175] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_duration, 1, 0, 0),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0),
  [181] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0),
  [183] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(17),
  [186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_number, 1, 0, 0),
  [188] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_number, 1, 0, 0),
  [190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sub_query, 3, 0, 0),
  [192] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_sub_query, 3, 0, 0),
  [194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_key, 1, 0, 0),
  [196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path, 1, 0, 0),
  [198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path, 1, 0, 0),
  [200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2055),
  [204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_negated_expression, 2, 0, 0),
  [206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_negated_expression, 2, 0, 0),
  [208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 2, 0, 0),
  [210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 2, 0, 0),
  [212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path, 2, 0, 0),
  [214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path, 2, 0, 0),
  [216] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0),
  [218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0),
  [220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2030),
  [223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(792),
  [226] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2030),
  [229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2055),
  [232] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object, 3, 0, 0),
  [234] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object, 3, 0, 0),
  [236] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value, 1, 0, 0),
  [238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_value, 1, 0, 0),
  [240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_value, 1, 0, 0),
  [242] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_value, 1, 0, 0),
  [244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 2, 0, 0),
  [246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 2, 0, 0),
  [248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 4, 0, 0),
  [250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 4, 0, 0),
  [252] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 3, 0, 0),
  [254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 3, 0, 0),
  [256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array, 5, 0, 0),
  [258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array, 5, 0, 0),
  [260] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [262] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 3, 0, 0),
  [266] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 3, 0, 0),
  [268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1763),
  [270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 4, 0, 0),
  [272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 4, 0, 0),
  [274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 5, 0, 0),
  [276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 5, 0, 0),
  [278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 2, 0, 0),
  [280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 2, 0, 0),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [284] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 3, 0, 0),
  [286] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 3, 0, 0),
  [288] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id, 3, 0, 0),
  [290] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id, 3, 0, 0),
  [292] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list_count, 2, 0, 0),
  [294] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list_count, 2, 0, 0),
  [296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list_count, 3, 0, 0),
  [298] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list_count, 3, 0, 0),
  [300] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 0),
  [302] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 0),
  [304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_value, 1, 0, 0),
  [306] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_base_value, 1, 0, 0),
  [308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 0),
  [312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 0),
  [314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 2, 0, 0),
  [316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 2, 0, 0),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list_count, 4, 0, 0),
  [324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list_count, 4, 0, 0),
  [326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(53),
  [335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filter, 5, 0, 0),
  [339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filter, 5, 0, 0),
  [341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [343] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_path, 4, 0, 0),
  [345] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_path, 4, 0, 0),
  [347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_path, 2, 0, 0),
  [349] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_path, 2, 0, 0),
  [351] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filter, 3, 0, 0),
  [353] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_filter, 3, 0, 0),
  [355] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript, 3, 0, 0),
  [357] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript, 3, 0, 0),
  [359] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_path_element, 1, 0, 0),
  [361] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_path_element, 1, 0, 0),
  [363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [365] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_point, 5, 0, 0),
  [367] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_point, 5, 0, 0),
  [369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_path, 5, 0, 0),
  [371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_graph_path, 5, 0, 0),
  [373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1747),
  [375] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 4, 0, 0),
  [381] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 4, 0, 0),
  [383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [387] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2098),
  [390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(790),
  [393] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2098),
  [396] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2039),
  [399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1971),
  [401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1971),
  [405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [407] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1971),
  [410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(787),
  [413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1971),
  [416] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1964),
  [419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1963),
  [423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2146),
  [425] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1963),
  [428] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1963),
  [431] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2146),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(132),
  [439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2411),
  [443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1726),
  [445] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 2, 0, 0),
  [447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(762),
  [449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2315),
  [455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(935),
  [457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1122),
  [461] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2813),
  [463] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1132),
  [465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2465),
  [469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2467),
  [471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2401),
  [475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2206),
  [477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [479] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2857),
  [483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2874),
  [485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1135),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 2, 0, 0),
  [489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2493),
  [491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2274),
  [501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2275),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 3, 0, 0),
  [507] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 3, 0, 0),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2346),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2500),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2472),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2221),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2449),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2207),
  [535] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_id_range, 1, 0, 0),
  [537] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_record_id_range, 1, 0, 0),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1739),
  [541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(70),
  [543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1743),
  [545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 3, 0, 0),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2468),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [557] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1704),
  [559] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [561] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1702),
  [563] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1713),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1765),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1847),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1767),
  [583] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 2, 0, 0),
  [585] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1954),
  [588] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(793),
  [591] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(1954),
  [594] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2158),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1954),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(765),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(899),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2350),
  [611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1758),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(797),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1795),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1759),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [627] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2166),
  [629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2116),
  [631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2166),
  [634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(789),
  [637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2166),
  [640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_path_repeat1, 2, 0, 0), SHIFT_REPEAT(2116),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(236),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [650] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2804),
  [652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2520),
  [656] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2762),
  [658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [662] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2792),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [666] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_repeat1, 2, 0, 0), SHIFT_REPEAT(251),
  [669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [671] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2870),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2543),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2884),
  [681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1768),
  [685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [695] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1760),
  [697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0),
  [699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cast_expression, 4, 0, 0),
  [711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cast_expression, 4, 0, 0),
  [713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 3, 0, 0),
  [715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_criteria, 1, 0, 0),
  [719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1452),
  [723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 2, 0, 0),
  [737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 3, 0, 0),
  [741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 6, 0, 0),
  [747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2257),
  [751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_where_clause, 2, 0, 0),
  [761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [763] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 5, 0, 0),
  [765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_clause, 3, 0, 0),
  [771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_value_clause, 2, 0, 0),
  [777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_default_clause, 2, 0, 0),
  [779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_clause, 2, 0, 0),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(547),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2163),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(323),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2533),
  [813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2438),
  [817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(541),
  [833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2559),
  [835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(546),
  [839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1952),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [843] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2404),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [847] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2450),
  [849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(237),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(399),
  [877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(380),
  [879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_live_select_diff_statement, 4, 0, 0),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [891] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2440),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_assignment, 3, 0, 0),
  [899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_target, 1, 0, 0),
  [901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(406),
  [905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_clause, 3, 0, 0),
  [925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_clause, 2, 0, 0),
  [929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(454),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(968),
  [951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_statement, 7, 0, 0),
  [953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2826),
  [957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2796),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2863),
  [961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2907),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2455),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [969] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 1, 0, 0),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predicate, 1, 0, 0),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2555),
  [985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_kill_statement, 2, 0, 0),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2228),
  [999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 2, 0, 0),
  [1001] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_param_statement, 5, 0, 0),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2352),
  [1007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2311),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2435),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2252),
  [1015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [1023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_let_statement, 4, 0, 0),
  [1025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [1031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2256),
  [1033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_param_statement, 6, 0, 0),
  [1035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1053] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_property, 3, 0, 0),
  [1055] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_where_clause, 2, 0, 0),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [1067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [1069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [1071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [1075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_omit_clause, 2, 0, 0),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [1081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1755),
  [1083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2475),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(938),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2565),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(852),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(944),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2485),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [1101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(888),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2561),
  [1105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [1107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [1109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2399),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [1115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [1117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(917),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2562),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(901),
  [1125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2473),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [1129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [1131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [1133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(824),
  [1135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2850),
  [1137] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2370),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2623),
  [1143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2532),
  [1147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2526),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [1151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [1153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2421),
  [1155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1069),
  [1157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2496),
  [1159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1096),
  [1161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2457),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(802),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2502),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [1177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(148),
  [1181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2544),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2459),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(133),
  [1191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [1197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(882),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2560),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [1207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [1217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1229] = {.entry = {.count = 1, .reusable = false}}, SHIFT(837),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2431),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1071),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2447),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [1249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [1251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2376),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [1259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [1261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2547),
  [1263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [1265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(922),
  [1269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2378),
  [1271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [1275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [1277] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2515),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [1281] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2573),
  [1283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [1285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2466),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [1289] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2499),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2503),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2507),
  [1299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2567),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2492),
  [1307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2407),
  [1311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [1315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2375),
  [1319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2568),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2408),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [1329] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2409),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2570),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2564),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [1345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2480),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [1349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2566),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1112),
  [1353] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2569),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1087),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2505),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2486),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2571),
  [1367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2489),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1092),
  [1373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2572),
  [1375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1093),
  [1377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2509),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2574),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2512),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1107),
  [1389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2575),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [1393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2516),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2576),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2521),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2525),
  [1407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [1409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [1411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [1413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [1417] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [1419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0),
  [1421] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1168),
  [1424] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2847),
  [1427] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2851),
  [1430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2856),
  [1433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2883),
  [1436] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2903),
  [1439] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2909),
  [1442] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2820),
  [1445] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2871),
  [1448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_search_analyzer_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1113),
  [1451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_search_analyzer_clause, 3, 0, 0),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2883),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2903),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2909),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2820),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2871),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [1473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_search_analyzer_clause, 4, 0, 0),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1113),
  [1477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [1479] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1695),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [1485] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0),
  [1487] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0),
  [1489] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1695),
  [1492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 4, 0, 0),
  [1494] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_not_exists_clause, 3, 0, 0),
  [1496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_not_exists_clause, 3, 0, 0),
  [1498] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 1, 0, 0),
  [1500] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [1502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 1, 0, 0),
  [1504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_name, 1, 0, 0),
  [1506] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_name, 1, 0, 0),
  [1508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 4, 0, 0),
  [1510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2430),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2208),
  [1514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 2, 0, 0),
  [1516] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 2, 0, 0),
  [1518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2540),
  [1520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2233),
  [1522] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 3, 0, 0),
  [1524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 3, 0, 0),
  [1526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_value, 1, 0, 0),
  [1528] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_value, 1, 0, 0),
  [1530] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 5, 0, 0),
  [1532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 5, 0, 0),
  [1534] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_operator, 2, 0, 0),
  [1536] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_operator, 2, 0, 0),
  [1538] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 1, 0, 0),
  [1540] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 1, 0, 0),
  [1542] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_operator, 1, 0, 0),
  [1544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_operator, 1, 0, 0),
  [1546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_composite_type, 3, 0, 0),
  [1548] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_composite_type, 3, 0, 0),
  [1550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_object, 3, 0, 0),
  [1552] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_object, 3, 0, 0),
  [1554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameterized_type, 5, 0, 0),
  [1556] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameterized_type, 5, 0, 0),
  [1558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameterized_type, 4, 0, 0),
  [1560] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parameterized_type, 4, 0, 0),
  [1562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_object, 4, 0, 0),
  [1564] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_object, 4, 0, 0),
  [1566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_composite_type, 4, 0, 0),
  [1568] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_composite_type, 4, 0, 0),
  [1570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 4, 0, 0),
  [1572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment_clause, 2, 0, 0),
  [1574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 5, 0, 0),
  [1576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat2, 2, 0, 0),
  [1578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 6, 0, 0),
  [1580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [1582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2779),
  [1584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1340),
  [1586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1233),
  [1588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(820),
  [1590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [1594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [1596] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0),
  [1598] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(846),
  [1601] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2779),
  [1604] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1340),
  [1607] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(1233),
  [1610] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(820),
  [1613] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(847),
  [1616] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2073),
  [1619] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2764),
  [1622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 7, 0, 0),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 4, 0, 0),
  [1626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_field_statement, 5, 0, 0),
  [1628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 6, 0, 0),
  [1630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bm25_clause, 1, 0, 0),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2727),
  [1634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_ids_order_clause, 2, 0, 0),
  [1636] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(873),
  [1639] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(823),
  [1642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(874),
  [1645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2164),
  [1648] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_lengths_order_clause, 2, 0, 0),
  [1650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2164),
  [1658] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_bm25_clause, 6, 0, 0),
  [1660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_on_table_clause, 3, 0, 0),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postings_cache_clause, 2, 0, 0),
  [1664] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postings_order_clause, 2, 0, 0),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_terms_cache_clause, 2, 0, 0),
  [1668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_on_table_clause, 2, 0, 0),
  [1670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_terms_order_clause, 2, 0, 0),
  [1672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_ids_cache_clause, 2, 0, 0),
  [1674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2389),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_lengths_cache_clause, 2, 0, 0),
  [1679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1704),
  [1683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 7, 0, 0),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 4, 0, 0),
  [1687] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(955),
  [1690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 3, 0, 0),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 3, 0, 0),
  [1694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [1696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [1698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [1700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2330),
  [1702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2339),
  [1704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [1706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 4, 0, 0),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [1710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [1712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [1714] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 6, 0, 0),
  [1716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2276),
  [1718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1359),
  [1724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2182),
  [1726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 7, 0, 0),
  [1728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [1730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2232),
  [1732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [1734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [1738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissions_for_clause, 2, 0, 0),
  [1740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 5, 0, 0),
  [1742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1053),
  [1745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 3, 0, 0),
  [1747] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(862),
  [1750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [1752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [1754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 8, 0, 0),
  [1756] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 5, 0, 0),
  [1758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1338),
  [1760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 2, 0, 0),
  [1762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [1764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(910),
  [1767] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(946),
  [1770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(856),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1327),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [1777] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 4, 0, 0),
  [1779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2864),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [1783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_record_or_separated_repeat1, 2, 0, 0),
  [1785] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_or_separated_repeat1, 2, 0, 0), SHIFT_REPEAT(2463),
  [1788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_or_separated, 2, 0, 0),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 9, 0, 0),
  [1794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_record_or_separated, 1, 0, 0),
  [1796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1296),
  [1798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_split_clause, 4, 0, 0),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [1802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_split_clause, 2, 0, 0),
  [1804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 7, 0, 0),
  [1806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [1808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_index_statement, 6, 0, 0),
  [1810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [1812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2728),
  [1814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2729),
  [1816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2734),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 2, 0, 0),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [1822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2300),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_split_clause, 3, 0, 0),
  [1828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_index_statement, 5, 0, 0),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [1832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_analyzer_statement, 5, 0, 0),
  [1834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1764),
  [1840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(940),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [1845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2518),
  [1847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [1849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [1851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2522),
  [1853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0),
  [1855] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1943),
  [1858] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2761),
  [1861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1764),
  [1864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_analyzer_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [1867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 5, 0, 0),
  [1869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2343),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1671),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [1875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0),
  [1877] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(2032),
  [1880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [1882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1922),
  [1884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1923),
  [1886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(764),
  [1888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [1892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [1894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [1896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1927),
  [1898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1936),
  [1900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1937),
  [1902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [1904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1933),
  [1906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_scope_statement, 3, 0, 0),
  [1908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2312),
  [1910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [1914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_index_statement, 7, 0, 0),
  [1916] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_analyzer_statement, 4, 0, 0),
  [1918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0),
  [1920] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1663),
  [1923] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2728),
  [1926] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2729),
  [1929] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_index_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2734),
  [1932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_analyzer_statement, 3, 0, 0),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(767),
  [1936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2185),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1944),
  [1942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_with_clause, 2, 0, 0),
  [1944] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(907),
  [1947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_table_type_clause_repeat1, 2, 0, 0),
  [1949] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_table_type_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2344),
  [1952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_scope_statement, 4, 0, 0),
  [1954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_scope_statement, 5, 0, 0),
  [1956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 4, 0, 0),
  [1958] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 4, 0, 0),
  [1960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2327),
  [1962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [1964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2402),
  [1967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0),
  [1969] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [1972] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2312),
  [1975] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2168),
  [1978] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_scope_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2172),
  [1981] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 6, 0, 0),
  [1983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 6, 0, 0),
  [1985] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_readonly_clause, 1, 0, 0),
  [1987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2453),
  [1989] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_clause, 2, 0, 0),
  [1991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hnsw_dimension_clause, 3, 0, 0),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [1999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2076),
  [2001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_record_or_separated_repeat1, 2, 0, 0), SHIFT_REPEAT(2453),
  [2004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 7, 0, 0),
  [2006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [2008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2127),
  [2010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [2012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2255),
  [2014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [2016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1955),
  [2018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [2020] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 4, 0, 0),
  [2022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 2, 0, 0),
  [2024] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_subject, 1, 0, 0),
  [2026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_criteria, 2, 0, 0),
  [2028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1483),
  [2030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 10, 0, 0),
  [2032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_group_clause, 3, 0, 0),
  [2034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [2036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(2051),
  [2039] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_clause, 3, 0, 0),
  [2041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 4, 0, 0),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2277),
  [2045] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 7, 0, 0),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2205),
  [2051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mtree_dimension_clause, 3, 0, 0),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2071),
  [2059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 3, 0, 0),
  [2061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 3, 0, 0),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2204),
  [2067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 8, 0, 0),
  [2069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1637),
  [2071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 8, 0, 0),
  [2073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 8, 0, 0),
  [2075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2448),
  [2077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [2079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2835),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [2083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2454),
  [2085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hnsw_dimension_clause, 5, 0, 0),
  [2087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [2089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2015),
  [2093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alter_statement, 4, 0, 0),
  [2095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [2101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 5, 0, 0),
  [2103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alter_statement, 5, 0, 0),
  [2105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_alter_statement_repeat1, 2, 0, 0),
  [2107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_alter_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1400),
  [2110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_alter_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2173),
  [2113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_alter_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [2116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_table_type_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2205),
  [2119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 7, 0, 0),
  [2121] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_alter_statement, 3, 0, 0),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [2125] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 6, 0, 0),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [2129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2870),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [2133] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 7, 0, 0),
  [2135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2387),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2758),
  [2139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [2143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 2, 0, 0),
  [2145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mtree_dimension_clause, 5, 0, 0),
  [2147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [2151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unset_clause, 3, 0, 0),
  [2153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0),
  [2155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2190),
  [2159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_alter_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1427),
  [2162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_alter_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2190),
  [2165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0),
  [2167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(805),
  [2170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(995),
  [2173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2276),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unset_clause, 2, 0, 0),
  [2178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 2, 0, 0),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_distance_values, 1, 0, 0),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [2190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 9, 0, 0),
  [2192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 11, 0, 0),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [2196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2678),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2476),
  [2200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 4, 0, 0),
  [2202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_columns_clause, 2, 0, 0),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2318),
  [2208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_distance_values, 2, 0, 0),
  [2210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_clause, 3, 0, 0),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [2214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hnsw_dimension_clause, 7, 0, 0),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1958),
  [2218] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1959),
  [2220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fields_columns_clause, 3, 0, 0),
  [2222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tokenizers_clause, 3, 0, 0),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1930),
  [2226] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 12, 0, 0),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2381),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2706),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2542),
  [2234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_tokenizers_clause_repeat1, 2, 0, 0),
  [2236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_tokenizers_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1930),
  [2239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [2241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2899),
  [2244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filters_clause, 3, 0, 0),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1733),
  [2248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 11, 0, 0),
  [2250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_filters_clause_repeat1, 2, 0, 0),
  [2252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_filters_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1733),
  [2255] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tokenizers_clause, 2, 0, 0),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [2259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(2171),
  [2262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_filters_clause, 2, 0, 0),
  [2264] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_order_criteria, 3, 0, 0),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [2286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [2288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [2300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [2310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_merge_clause, 2, 0, 0),
  [2312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_patch_clause, 2, 0, 0),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 5, 0, 0),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_filters, 6, 0, 0),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [2332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_replace_clause, 2, 0, 0),
  [2334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fetch_clause, 3, 0, 0),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [2342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 8, 0, 0),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [2346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 6, 0, 0),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [2352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_clause, 3, 0, 0),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [2360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2235),
  [2363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_content_clause, 2, 0, 0),
  [2365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [2367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [2369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [2371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2373] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(992),
  [2376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(926),
  [2379] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mtree_dimension_clause, 7, 0, 0),
  [2381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [2383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [2387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [2389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2391] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_clause, 2, 0, 0),
  [2393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [2395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [2397] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 8, 0, 0),
  [2399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fetch_clause, 2, 0, 0),
  [2401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [2403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [2405] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_live_select_diff_statement, 5, 0, 0),
  [2407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [2409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(903),
  [2412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 8, 0, 0),
  [2414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_filters, 4, 0, 0),
  [2416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_target, 2, 0, 0),
  [2418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_order_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(813),
  [2421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hnsw_dimension_clause, 9, 0, 0),
  [2423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1985),
  [2425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [2427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_tokenizers, 1, 0, 0),
  [2429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [2431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_analyzer_filters, 1, 0, 0),
  [2433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [2437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [2439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [2441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2326),
  [2444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 15, 0, 0),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2537),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [2454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 16, 0, 0),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2188),
  [2466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(2188),
  [2469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [2471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [2473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 7, 0, 0),
  [2475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 10, 0, 0),
  [2477] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_clause, 2, 0, 0),
  [2479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_session_clause, 2, 0, 0),
  [2481] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signin_clause, 2, 0, 0),
  [2483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signup_clause, 2, 0, 0),
  [2485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2603),
  [2487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function_statement, 6, 0, 0),
  [2489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [2491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 9, 0, 0),
  [2493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function_statement, 7, 0, 0),
  [2495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0),
  [2497] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2112),
  [2500] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2764),
  [2503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [2505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 13, 0, 0),
  [2507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2913),
  [2509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2422),
  [2511] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 12, 0, 0),
  [2513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_mtree_dimension_clause, 9, 0, 0),
  [2515] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_limit_clause, 2, 0, 0),
  [2517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hnsw_dimension_clause, 11, 0, 0),
  [2519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2848),
  [2521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 17, 0, 0),
  [2523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2807),
  [2525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [2527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(891),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2308),
  [2532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unique_clause, 1, 0, 0),
  [2534] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(919),
  [2537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2305),
  [2539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_type_clause, 3, 0, 0),
  [2541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2305),
  [2544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multi_record, 5, 0, 0),
  [2546] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 9, 0, 0),
  [2548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2786),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [2552] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [2555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 6, 0, 0),
  [2557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 9, 0, 0),
  [2559] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_if_clause, 4, 0, 0),
  [2561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2308),
  [2564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_clause, 4, 0, 0),
  [2566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_function_statement, 5, 0, 0),
  [2568] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_record_jwt_clause, 6, 0, 0),
  [2570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2572] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 0),
  [2574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 14, 0, 0),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2451),
  [2578] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_record_jwt_clause, 8, 0, 0),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1998),
  [2584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_record_jwt_clause, 10, 0, 0),
  [2586] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 18, 0, 0),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2367),
  [2590] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 19, 0, 0),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [2594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 1, 0, 0),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2065),
  [2598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2077),
  [2602] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 9, 0, 0),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1591),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [2608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [2610] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 2, 0, 0),
  [2612] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 5, 0, 0),
  [2614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2336),
  [2616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 4, 0, 0),
  [2618] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 4, 0, 0),
  [2620] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(972),
  [2623] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(976),
  [2626] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(988),
  [2629] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2201),
  [2632] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_view_clause, 9, 0, 0),
  [2634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 10, 0, 0),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2548),
  [2638] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_when_then_clause, 3, 0, 0),
  [2640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_when_then_clause_repeat1, 2, 0, 0),
  [2642] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_when_then_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2065),
  [2645] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_function_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2077),
  [2648] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2336),
  [2651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_access_record_jwt_clause, 4, 0, 0),
  [2653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2652),
  [2655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_live_select_diff_statement, 6, 0, 0),
  [2657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_duration_clause_repeat1, 2, 0, 0),
  [2659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_duration_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2683),
  [2662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [2668] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_event_statement, 6, 0, 0),
  [2670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 8, 0, 0),
  [2672] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_namespace_statement, 3, 0, 0),
  [2674] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(842),
  [2677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_database_statement, 3, 0, 0),
  [2679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 10, 0, 0),
  [2681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 13, 0, 0),
  [2683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2212),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [2689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2184),
  [2691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_duration_clause, 4, 0, 0),
  [2695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [2697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_database_statement, 4, 0, 0),
  [2699] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(964),
  [2702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 10, 0, 0),
  [2704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_token_statement, 9, 0, 0),
  [2706] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(968),
  [2709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 11, 0, 0),
  [2711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_user_statement, 9, 0, 0),
  [2713] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2212),
  [2716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [2718] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_changefeed_clause, 2, 0, 0),
  [2720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 5, 0, 0),
  [2722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_event_statement, 5, 0, 0),
  [2724] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(985),
  [2727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2729] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_timeout_clause, 2, 0, 0),
  [2731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_token_statement, 10, 0, 0),
  [2733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_user_statement, 10, 0, 0),
  [2737] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 20, 0, 0),
  [2739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_info, 2, 0, 0),
  [2741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1967),
  [2743] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 21, 0, 0),
  [2745] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_statement, 2, 0, 0),
  [2747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2469),
  [2749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_namespace_statement, 4, 0, 0),
  [2751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [2755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [2757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [2761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 7, 0, 0),
  [2763] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(2025),
  [2766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_duration_clause, 5, 0, 0),
  [2768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [2770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [2772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_permissions_basic_clause, 2, 0, 0),
  [2774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_token_statement, 8, 0, 0),
  [2776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_begin_statement, 1, 0, 0),
  [2778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [2780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ns_clause, 2, 0, 0),
  [2782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 17, 0, 0),
  [2784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2322),
  [2786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat1, 2, 0, 0),
  [2788] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(2184),
  [2791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 16, 0, 0),
  [2793] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_content, 3, 0, 0),
  [2795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [2797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [2799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_content, 2, 0, 0),
  [2803] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_permissions_for_clause_repeat2, 2, 0, 0), SHIFT_REPEAT(2160),
  [2806] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2322),
  [2809] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 15, 0, 0),
  [2811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_duration_clause_repeat1, 4, 0, 0),
  [2813] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(960),
  [2816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2892),
  [2818] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2579),
  [2820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [2822] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2582),
  [2824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2586),
  [2826] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2369),
  [2828] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2377),
  [2830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cancel_statement, 1, 0, 0),
  [2832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2132),
  [2834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 12, 0, 0),
  [2836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [2838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explain_clause, 1, 0, 0),
  [2840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [2842] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2388),
  [2844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 13, 0, 0),
  [2846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2380),
  [2848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2383),
  [2850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parallel_clause, 1, 0, 0),
  [2852] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 14, 0, 0),
  [2854] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2384),
  [2856] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2577),
  [2858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_commit_statement, 1, 0, 0),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [2862] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2366),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2241),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(777),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2585),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [2872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [2878] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2658),
  [2880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [2884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [2886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2888] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [2890] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2444),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2034),
  [2894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_user_info, 3, 0, 0),
  [2896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [2898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2202),
  [2904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_statement, 1, 0, 0),
  [2906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 5, 0, 0),
  [2908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 5, 0, 0),
  [2910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rebuild_index_statement, 5, 0, 0),
  [2912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [2914] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_from_clause, 14, 0, 0),
  [2916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2790),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [2926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_access_statement, 22, 0, 0),
  [2928] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subquery_statement, 1, 0, 0),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [2934] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 1, 0, 0),
  [2936] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_namespace_statement, 5, 0, 0),
  [2938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [2940] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_table_statement, 11, 0, 0),
  [2942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 2, 0, 0),
  [2944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_explain_clause, 2, 0, 0),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [2948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [2950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [2952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [2954] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 8, 0, 0),
  [2956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_level_clause, 1, 0, 0),
  [2958] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_on_level_clause, 2, 0, 0),
  [2960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [2964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2497),
  [2966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [2968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [2970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [2972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_info, 1, 0, 0),
  [2974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_root_info, 1, 0, 0),
  [2976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_database_info, 1, 0, 0),
  [2978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_info_statement, 3, 0, 0),
  [2980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [2982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_info_target, 1, 0, 0),
  [2984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_token_statement, 11, 0, 0),
  [2986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [2988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(85),
  [2990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2416),
  [2992] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_upsert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2202),
  [2995] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_user_statement, 11, 0, 0),
  [2997] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 7, 0, 0),
  [2999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 3, 0, 0),
  [3001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [3003] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_sleep_statement, 2, 0, 0),
  [3005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 4, 0, 0),
  [3007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2382),
  [3009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_statement, 8, 0, 0),
  [3011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [3013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [3015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_db_clause, 2, 0, 0),
  [3017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_use_statement, 3, 0, 0),
  [3019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 7, 0, 0),
  [3021] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 3, 0, 0),
  [3023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 4, 0, 0),
  [3025] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 1, 0, 0),
  [3027] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 6, 0, 0),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [3031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_create_statement, 6, 0, 0),
  [3033] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_relate_statement, 11, 0, 0),
  [3035] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rebuild_index_statement, 4, 0, 0),
  [3037] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_live_select_statement, 2, 0, 0),
  [3039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [3041] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_statement, 9, 0, 0),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(141),
  [3047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2557),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [3051] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_live_select_diff_statement, 7, 0, 0),
  [3053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2553),
  [3055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2368),
  [3057] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inclusive_predicate, 1, 0, 0),
  [3059] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert_statement, 6, 0, 0),
  [3061] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_clause, 2, 0, 0),
  [3063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_begin_statement, 2, 0, 0),
  [3065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cancel_statement, 2, 0, 0),
  [3067] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_commit_statement, 2, 0, 0),
  [3069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_select_statement, 3, 0, 0),
  [3071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upsert_statement, 12, 0, 0),
  [3073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_delete_statement, 8, 0, 0),
  [3075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 1, 0, 0),
  [3077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [3079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2880),
  [3081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2364),
  [3083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_call_repeat1, 2, 0, 0),
  [3085] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_function_call_repeat1, 2, 0, 0), SHIFT_REPEAT(2506),
  [3088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2636),
  [3090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [3092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_table_info, 2, 0, 0),
  [3094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(147),
  [3096] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_update_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(841),
  [3099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_predicate, 3, 0, 0),
  [3101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0),
  [3103] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(782),
  [3106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [3108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [3110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2436),
  [3112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [3114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [3116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [3118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [3120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2424),
  [3122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [3124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_event_statement, 7, 0, 0),
  [3126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [3128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameterized_type_repeat1, 2, 0, 0),
  [3130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_define_database_statement, 5, 0, 0),
  [3132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [3134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1966),
  [3136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2887),
  [3138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [3140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_remove_statement, 5, 0, 0),
  [3142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [3144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2535),
  [3146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2539),
  [3148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2584),
  [3150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [3152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [3154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [3156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [3158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [3160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2760),
  [3162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(788),
  [3164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [3166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [3168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [3170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 2, 0, 0),
  [3172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(772),
  [3174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [3176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [3178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2194),
  [3180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [3182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [3184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [3186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2261),
  [3188] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_content_repeat1, 2, 0, 0), SHIFT_REPEAT(1981),
  [3191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_content_repeat1, 2, 0, 0),
  [3193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [3195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2860),
  [3197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2360),
  [3199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2341),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1528),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2355),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2881),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [3213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2083),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [3217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2393),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2859),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [3229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [3233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expressions_repeat1, 2, 0, 0),
  [3235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expressions_repeat1, 2, 0, 0), SHIFT_REPEAT(10),
  [3238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2263),
  [3240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2269),
  [3242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(776),
  [3245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2658),
  [3247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2417),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2272),
  [3251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2278),
  [3253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [3255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2362),
  [3257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [3259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [3261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2625),
  [3263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [3265] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expressions, 1, 0, 0),
  [3267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2391),
  [3269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2394),
  [3271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [3273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_composite_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1236),
  [3276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_composite_type_repeat1, 2, 0, 0),
  [3278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [3280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2481),
  [3283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat1, 2, 0, 0),
  [3285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2876),
  [3287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_object_repeat1, 2, 0, 0), SHIFT_REPEAT(2355),
  [3290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_object_repeat1, 2, 0, 0),
  [3292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [3294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2125),
  [3296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [3300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2398),
  [3302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [3304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2616),
  [3308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expressions_repeat1, 2, 0, 0), SHIFT_REPEAT(11),
  [3311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [3313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1308),
  [3315] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 2, 0, 0),
  [3317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 2, 0, 0), SHIFT_REPEAT(2760),
  [3320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [3322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [3326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [3328] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2723),
  [3331] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 2, 0, 0),
  [3333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2266),
  [3335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [3337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [3339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [3341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2429),
  [3343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [3345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2270),
  [3347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameterized_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1216),
  [3350] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_define_field_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(777),
  [3353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1236),
  [3355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [3357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1140),
  [3359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [3361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [3363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_content, 1, 0, 0),
  [3365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2033),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2748),
  [3373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [3375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [3379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2755),
  [3381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [3389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1391),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2775),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1145),
  [3401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [3403] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_graph_path_repeat1, 2, 0, 0), SHIFT_REPEAT(788),
  [3406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_graph_path_repeat1, 2, 0, 0),
  [3408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2904),
  [3410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2905),
  [3412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2906),
  [3414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2524),
  [3418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2460),
  [3420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [3422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1753),
  [3424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2664),
  [3426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [3428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [3430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [3432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [3434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [3436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_object_property, 3, 0, 0),
  [3438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [3440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 3, 0, 0),
  [3442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [3444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1322),
  [3446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [3448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_param_list_repeat1, 4, 0, 0),
  [3450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [3452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [3454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [3456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 4, 0, 0),
  [3458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [3460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2290),
  [3462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1769),
  [3464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2578),
  [3466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2852),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2446),
  [3470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2818),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [3474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2442),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [3478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2414),
  [3480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2719),
  [3482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [3484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2918),
  [3486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [3488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [3490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [3492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [3494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [3496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [3498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_insert_statement_repeat2, 5, 0, 0),
  [3500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2688),
  [3502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [3504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2877),
  [3506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2912),
  [3508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [3510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [3512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2836),
  [3514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [3516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [3518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [3520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [3522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [3524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [3526] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_exists_clause, 2, 0, 0),
  [3528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [3530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_graph_predicate, 4, 0, 0),
  [3532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [3534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1569),
  [3536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [3538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [3540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1515),
  [3542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [3544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2219),
  [3546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2247),
  [3548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1516),
  [3550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [3552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [3554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1519),
  [3556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1521),
  [3558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [3560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [3562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1532),
  [3564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(859),
  [3566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [3568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1537),
  [3570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [3572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [3574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [3576] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 6, 0, 0),
  [3578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [3580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [3582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [3584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [3586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [3588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1548),
  [3590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [3592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [3594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [3596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [3598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [3600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [3602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1551),
  [3604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [3606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1312),
  [3608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2294),
  [3610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [3612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1562),
  [3614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2791),
  [3616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1570),
  [3618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1575),
  [3620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [3622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [3624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [3626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2843),
  [3628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [3630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [3632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [3634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1592),
  [3636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [3638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [3640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1594),
  [3642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1595),
  [3644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2919),
  [3646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2889),
  [3648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [3650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [3652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1598),
  [3654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1599),
  [3656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [3658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2552),
  [3660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [3662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [3664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [3666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [3668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1607),
  [3670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [3672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [3674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [3676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2875),
  [3678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1553),
  [3680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [3682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1490),
  [3684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [3686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [3688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [3690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2866),
  [3692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1493),
  [3694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [3696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2226),
  [3698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [3700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [3702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1495),
  [3704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [3706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2227),
  [3708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1497),
  [3710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [3712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [3714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [3716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1498),
  [3718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [3720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1499),
  [3722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [3724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [3726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1500),
  [3728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [3730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [3732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [3734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1504),
  [3736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [3738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [3740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2869),
  [3742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1506),
  [3744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1507),
  [3746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [3748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [3750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2338),
  [3752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [3754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1510),
  [3756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1511),
  [3758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2284),
  [3760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1512),
  [3762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1030),
  [3764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2801),
  [3766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [3768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [3770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [3772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [3774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [3776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2477),
  [3778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [3780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1602),
  [3782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2800),
  [3784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2915),
  [3786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [3788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [3790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [3792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [3794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2513),
  [3796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [3798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [3800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [3802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [3804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2405),
  [3806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2156),
  [3808] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [3812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2554),
  [3814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [3816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [3818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2716),
  [3820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [3822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [3824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_version, 3, 0, 0),
  [3826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [3828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [3830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [3832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 5, 0, 0),
  [3834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2347),
  [3836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1597),
  [3838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [3840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1042),
  [3842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [3844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2474),
  [3846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [3848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [3850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [3852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [3854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [3856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [3858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [3860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [3862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [3864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2178),
  [3866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [3868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [3870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [3872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [3874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [3876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [3878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [3880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2667),
  [3882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2456),
  [3884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [3886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2911),
  [3888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1584),
  [3890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [3892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [3894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [3896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [3898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2733),
  [3900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [3902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [3904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1741),
  [3906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [3908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [3910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [3912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [3914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [3916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [3918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [3920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2849),
  [3922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [3930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1714),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1851),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(969),
  [3938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [3940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [3942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [3944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2624),
  [3946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1717),
  [3948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [3950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [3952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [3954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(857),
  [3956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [3958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1134),
  [3960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [3962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [3964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [3966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [3968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [3970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [3972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(779),
  [3974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [3976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [3978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [3980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1328),
  [3982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2785),
  [3984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [3986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [3988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2777),
  [3990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2462),
  [3992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_key, 1, 0, 0),
  [3994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1529),
  [3996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2510),
  [3998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [4000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2198),
  [4002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [4004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [4006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [4008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [4010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2872),
  [4012] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [4014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [4016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [4018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [4020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [4022] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [4024] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [4026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [4028] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1781),
  [4030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [4032] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [4034] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [4036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [4038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2687),
  [4040] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [4042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [4044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2441),
  [4046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [4048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [4050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2757),
  [4052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_token_type_clause, 2, 0, 0),
  [4054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2280),
  [4056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [4058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2837),
  [4060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [4062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2224),
  [4064] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [4066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [4068] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [4070] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [4072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2494),
  [4074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2798),
  [4076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [4078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_param_list, 2, 0, 0),
  [4080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [4082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2523),
  [4084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2746),
  [4086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [4088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [4090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [4092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [4094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2316),
  [4096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2530),
  [4098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1577),
  [4100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2744),
  [4102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1326),
  [4104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [4106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [4108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [4110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [4112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1051),
  [4114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1052),
  [4116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1473),
  [4118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1552),
  [4120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2186),
  [4122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [4124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [4126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2895),
  [4128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2896),
  [4130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2897),
  [4132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2751),
  [4134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [4136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1179),
  [4138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [4140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2596),
  [4142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [4144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1710),
  [4146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [4148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [4150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1558),
  [4152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [4154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2589),
  [4156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_surrealql(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "surrealql",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 2,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
